@@ -19,7 +19,7 @@
 
 
 #include <extended/AccessibleBrowseBoxTableCell.hxx>
-#include <svtools/accessibletableprovider.hxx>
+#include <vcl/accessibletableprovider.hxx>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 
 namespace accessibility
@@ -50,13 +50,11 @@ namespace accessibility
     // implementation of a table cell
     OUString AccessibleBrowseBoxTableCell::implGetText()
     {
-        ensureIsAlive();
         return mpBrowseBox->GetAccessibleCellText( getRowPos(), static_cast< sal_uInt16 >( getColumnPos() ) );
     }
 
     css::lang::Locale AccessibleBrowseBoxTableCell::implGetLocale()
     {
-        ensureIsAlive();
         return mpBrowseBox->GetAccessible()->getAccessibleContext()->getLocale();
     }
 
@@ -67,17 +65,17 @@ namespace accessibility
     }
 
     AccessibleBrowseBoxTableCell::AccessibleBrowseBoxTableCell(const Reference<XAccessible >& _rxParent,
-                                IAccessibleTableProvider& _rBrowseBox,
+                                vcl::IAccessibleTableProvider& _rBrowseBox,
                                 const css::uno::Reference< css::awt::XWindow >& _xFocusWindow,
                                 sal_Int32 _nRowPos,
                                 sal_uInt16 _nColPos,
                                 sal_Int32 _nOffset )
         :AccessibleBrowseBoxCell( _rxParent, _rBrowseBox, _xFocusWindow, _nRowPos, _nColPos )
     {
-        m_nOffset = ( _nOffset == OFFSET_DEFAULT ) ? sal_Int32(BBINDEX_FIRSTCONTROL) : _nOffset;
+        m_nOffset = ( _nOffset == OFFSET_DEFAULT ) ? sal_Int32(vcl::BBINDEX_FIRSTCONTROL) : _nOffset;
         sal_Int32 nIndex = getIndex_Impl( _nRowPos, _nColPos, _rBrowseBox.GetColumnCount() );
-       setAccessibleName( _rBrowseBox.GetAccessibleObjectName( BBTYPE_TABLECELL, nIndex ) );
-       setAccessibleDescription( _rBrowseBox.GetAccessibleObjectDescription( BBTYPE_TABLECELL, nIndex ) );
+       setAccessibleName( _rBrowseBox.GetAccessibleObjectName( vcl::BBTYPE_TABLECELL, nIndex ) );
+       setAccessibleDescription( _rBrowseBox.GetAccessibleObjectDescription( vcl::BBTYPE_TABLECELL, nIndex ) );
         // Need to register as event listener
         Reference< XComponent > xComponent(_rxParent, UNO_QUERY);
         if( xComponent.is() )
@@ -208,7 +206,7 @@ namespace accessibility
         SolarMethodGuard aGuard(getMutex());
         ensureIsAlive();
 
-        return /*BBINDEX_FIRSTCONTROL*/ m_nOffset + ( getRowPos() * mpBrowseBox->GetColumnCount() ) + getColumnPos();
+        return /*vcl::BBINDEX_FIRSTCONTROL*/ m_nOffset + ( getRowPos() * mpBrowseBox->GetColumnCount() ) + getColumnPos();
     }
 
     sal_Int32 SAL_CALL AccessibleBrowseBoxTableCell::getCaretPosition(  )
@@ -219,6 +217,7 @@ namespace accessibility
     sal_Bool SAL_CALL AccessibleBrowseBoxTableCell::setCaretPosition ( sal_Int32 nIndex )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         if ( !implIsValidRange( nIndex, nIndex, implGetText().getLength() ) )
             throw IndexOutOfBoundsException();
@@ -228,12 +227,14 @@ namespace accessibility
     sal_Unicode SAL_CALL AccessibleBrowseBoxTableCell::getCharacter( sal_Int32 nIndex )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::implGetCharacter( implGetText(), nIndex );
     }
     css::uno::Sequence< css::beans::PropertyValue > SAL_CALL AccessibleBrowseBoxTableCell::getCharacterAttributes( sal_Int32 nIndex, const css::uno::Sequence< OUString >& )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         OUString sText( implGetText() );
 
@@ -245,6 +246,7 @@ namespace accessibility
     sal_Int32 SAL_CALL AccessibleBrowseBoxTableCell::getCharacterCount(  )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return implGetText().getLength();
     }
@@ -252,24 +254,28 @@ namespace accessibility
     OUString SAL_CALL AccessibleBrowseBoxTableCell::getSelectedText(  )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::getSelectedText(  );
     }
     sal_Int32 SAL_CALL AccessibleBrowseBoxTableCell::getSelectionStart(  )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::getSelectionStart(  );
     }
     sal_Int32 SAL_CALL AccessibleBrowseBoxTableCell::getSelectionEnd(  )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::getSelectionEnd(  );
     }
     sal_Bool SAL_CALL AccessibleBrowseBoxTableCell::setSelection( sal_Int32 nStartIndex, sal_Int32 nEndIndex )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         if ( !implIsValidRange( nStartIndex, nEndIndex, implGetText().getLength() ) )
             throw IndexOutOfBoundsException();
@@ -279,36 +285,42 @@ namespace accessibility
     OUString SAL_CALL AccessibleBrowseBoxTableCell::getText(  )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return implGetText(  );
     }
     OUString SAL_CALL AccessibleBrowseBoxTableCell::getTextRange( sal_Int32 nStartIndex, sal_Int32 nEndIndex )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::implGetTextRange( implGetText(), nStartIndex, nEndIndex );
     }
     css::accessibility::TextSegment SAL_CALL AccessibleBrowseBoxTableCell::getTextAtIndex( sal_Int32 nIndex, sal_Int16 aTextType )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::getTextAtIndex( nIndex ,aTextType);
     }
     css::accessibility::TextSegment SAL_CALL AccessibleBrowseBoxTableCell::getTextBeforeIndex( sal_Int32 nIndex, sal_Int16 aTextType )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::getTextBeforeIndex( nIndex ,aTextType);
     }
     css::accessibility::TextSegment SAL_CALL AccessibleBrowseBoxTableCell::getTextBehindIndex( sal_Int32 nIndex, sal_Int16 aTextType )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         return OCommonAccessibleText::getTextBehindIndex( nIndex ,aTextType);
     }
     sal_Bool SAL_CALL AccessibleBrowseBoxTableCell::copyText( sal_Int32 nStartIndex, sal_Int32 nEndIndex )
     {
         SolarMethodGuard aGuard(getMutex());
+        ensureIsAlive();
 
         OUString sText = implGetText();
         checkIndex_Impl( nStartIndex, sText );
