@@ -18,7 +18,7 @@
  */
 
 #include <sal/types.h>
-#include <svtools/accessibletableprovider.hxx>
+#include <vcl/accessibletableprovider.hxx>
 #include <extended/accessiblebrowseboxcell.hxx>
 
 namespace accessibility
@@ -30,9 +30,9 @@ namespace accessibility
 
     // AccessibleBrowseBoxCell
     AccessibleBrowseBoxCell::AccessibleBrowseBoxCell(
-            const css::uno::Reference< css::accessibility::XAccessible >& _rxParent, ::svt::IAccessibleTableProvider& _rBrowseBox,
+            const css::uno::Reference< css::accessibility::XAccessible >& _rxParent, ::vcl::IAccessibleTableProvider& _rBrowseBox,
             const css::uno::Reference< css::awt::XWindow >& _xFocusWindow,
-            sal_Int32 _nRowPos, sal_uInt16 _nColPos, ::svt::AccessibleBrowseBoxObjType _eType )
+            sal_Int32 _nRowPos, sal_uInt16 _nColPos, ::vcl::AccessibleBrowseBoxObjType _eType )
         :AccessibleBrowseBoxBase( _rxParent, _rBrowseBox, _xFocusWindow, _eType )
         ,m_nRowPos( _nRowPos )
         ,m_nColPos( _nColPos )
@@ -40,7 +40,7 @@ namespace accessibility
         // set accessible name here, because for that we need the position of the cell
         // and so the base class isn't capable of doing this
         sal_Int32 nPos = _nRowPos * _rBrowseBox.GetColumnCount() + _nColPos;
-        OUString aAccName = _rBrowseBox.GetAccessibleObjectName( BBTYPE_TABLECELL, nPos );
+        OUString aAccName = _rBrowseBox.GetAccessibleObjectName( vcl::BBTYPE_TABLECELL, nPos );
         implSetName( aAccName );
     }
 
