@@ -50,7 +50,6 @@ namespace accessibility
         ,m_nPageId( nPageId )
         ,m_xParent( rxParent )
     {
-        m_bEnabled  = IsEnabled();
         m_bShowing  = IsShowing();
         m_bSelected = IsSelected();
 
@@ -59,11 +58,6 @@ namespace accessibility
     }
 
 
-    AccessibleTabBarPage::~AccessibleTabBarPage()
-    {
-    }
-
-
     bool AccessibleTabBarPage::IsEnabled()
     {
         OExternalLockGuard aGuard( this );
@@ -130,7 +124,7 @@ namespace accessibility
 
     void AccessibleTabBarPage::SetPageText( const OUString& sPageText )
     {
-        if ( !m_sPageText.equals( sPageText ) )
+        if ( m_sPageText != sPageText )
         {
             Any aOldValue, aNewValue;
             aOldValue <<= m_sPageText;
@@ -255,14 +249,11 @@ namespace accessibility
     }
 
 
-    Reference< XAccessible > AccessibleTabBarPage::getAccessibleChild( sal_Int32 i )
+    Reference< XAccessible > AccessibleTabBarPage::getAccessibleChild( sal_Int32 )
     {
         OExternalLockGuard aGuard( this );
 
-        if ( i < 0 || i >= getAccessibleChildCount() )
-            throw IndexOutOfBoundsException();
-
-        return Reference< XAccessible >();
+        throw IndexOutOfBoundsException();
     }
 
 
