@@ -21,7 +21,7 @@
 
 #include <toolkit/awt/vclxwindows.hxx>
 #include <toolkit/helper/accessiblefactory.hxx>
-#include <svtools/accessiblefactory.hxx>
+#include <vcl/accessiblefactory.hxx>
 #include <standard/vclxaccessiblebutton.hxx>
 #include <standard/vclxaccessiblecheckbox.hxx>
 #include <standard/vclxaccessibledropdowncombobox.hxx>
@@ -30,6 +30,7 @@
 #include <standard/vclxaccessibleedit.hxx>
 #include <standard/vclxaccessiblefixedhyperlink.hxx>
 #include <standard/vclxaccessiblefixedtext.hxx>
+#include <standard/vclxaccessibleheaderbar.hxx>
 #include <standard/vclxaccessiblelistbox.hxx>
 #include <standard/vclxaccessiblemenu.hxx>
 #include <standard/vclxaccessibleradiobutton.hxx>
@@ -56,7 +57,7 @@
 #include <vcl/lstbox.hxx>
 #include <vcl/combobox.hxx>
 #include <extended/AccessibleGridControl.hxx>
-#include <svtools/accessibletable.hxx>
+#include <vcl/accessibletable.hxx>
 #include <vcl/popupmenuwindow.hxx>
 
 #include <floatingwindowaccessible.hxx>
@@ -65,12 +66,12 @@ using namespace ::accessibility;
 using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star::awt;
 using namespace ::com::sun::star::accessibility;
-using namespace ::svt;
-using namespace ::svt::table;
+using namespace ::vcl;
+using namespace ::vcl::table;
 
 namespace {
 
-inline bool hasFloatingChild(vcl::Window *pWindow)
+bool hasFloatingChild(vcl::Window *pWindow)
 {
     vcl::Window * pChild = pWindow->GetAccessibleChildWindow(0);
     return pChild && pChild->GetType() == WindowType::FLOATINGWINDOW;
@@ -78,7 +79,7 @@ inline bool hasFloatingChild(vcl::Window *pWindow)
 
 // IAccessibleFactory
 class AccessibleFactory :public ::toolkit::IAccessibleFactory
-                        ,public ::svt::IAccessibleFactory
+                        ,public ::vcl::IAccessibleFactory
 {
 public:
     AccessibleFactory();
@@ -104,22 +105,24 @@ public:
         createAccessibleContext( VCLXComboBox* _pXWindow ) override;
     virtual css::uno::Reference< css::accessibility::XAccessibleContext >
         createAccessibleContext( VCLXToolBox* _pXWindow ) override;
+    virtual css::uno::Reference< css::accessibility::XAccessibleContext >
+        createAccessibleContext( VCLXHeaderBar* _pXWindow ) override;
     virtual css::uno::Reference< css::accessibility::XAccessibleContext >
         createAccessibleContext( VCLXWindow* _pXWindow ) override;
     virtual css::uno::Reference< css::accessibility::XAccessible >
         createAccessible( Menu* _pMenu, bool _bIsMenuBar ) override;
 
-    // ::svt::IAccessibleFactory
-    virtual IAccessibleTabListBox*
+    // ::vcl::IAccessibleFactory
+    virtual vcl::IAccessibleTabListBox*
         createAccessibleTabListBox(
             const css::uno::Reference< css::accessibility::XAccessible >& rxParent,
             SvHeaderTabListBox& rBox
         ) const override;
 
-    virtual IAccessibleBrowseBox*
+    virtual vcl::IAccessibleBrowseBox*
         createAccessibleBrowseBox(
             const css::uno::Reference< css::accessibility::XAccessible >& _rxParent,
-            IAccessibleTableProvider& _rBrowseBox
+            vcl::IAccessibleTableProvider& _rBrowseBox
         ) const override;
 
     virtual IAccessibleTableControl*
@@ -153,14 +156,14 @@ public:
     virtual css::uno::Reference< css::accessibility::XAccessible >
         createAccessibleBrowseBoxHeaderBar(
             const css::uno::Reference< css::accessibility::XAccessible >& rxParent,
-            IAccessibleTableProvider& _rOwningTable,
-            AccessibleBrowseBoxObjType _eObjType
+            vcl::IAccessibleTableProvider& _rOwningTable,
+            vcl::AccessibleBrowseBoxObjType _eObjType
         ) const override;
 
     virtual css::uno::Reference< css::accessibility::XAccessible >
         createAccessibleBrowseBoxTableCell(
             const css::uno::Reference< css::accessibility::XAccessible >& _rxParent,
-            IAccessibleTableProvider& _rBrowseBox,
+            vcl::IAccessibleTableProvider& _rBrowseBox,
             const css::uno::Reference< css::awt::XWindow >& _xFocusWindow,
             sal_Int32 _nRowId,
             sal_uInt16 _nColId,
@@ -171,15 +174,15 @@ public:
         createAccessibleBrowseBoxHeaderCell(
             sal_Int32 _nColumnRowId,
             const css::uno::Reference< css::accessibility::XAccessible >& rxParent,
-            IAccessibleTableProvider& _rBrowseBox,
+            vcl::IAccessibleTableProvider& _rBrowseBox,
             const css::uno::Reference< css::awt::XWindow >& _xFocusWindow,
-            AccessibleBrowseBoxObjType  _eObjType
+            vcl::AccessibleBrowseBoxObjType  _eObjType
         ) const override;
 
     virtual css::uno::Reference< css::accessibility::XAccessible >
         createAccessibleCheckBoxCell(
             const css::uno::Reference< css::accessibility::XAccessible >& _rxParent,
-            IAccessibleTableProvider& _rBrowseBox,
+            vcl::IAccessibleTableProvider& _rBrowseBox,
             const css::uno::Reference< css::awt::XWindow >& _xFocusWindow,
             sal_Int32 _nRowPos,
             sal_uInt16 _nColPos,
@@ -192,7 +195,7 @@ public:
             const css::uno::Reference< css::accessibility::XAccessible >& _rxParent,
             const css::uno::Reference< css::accessibility::XAccessible >& _rxControlAccessible,
             const css::uno::Reference< css::awt::XWindow >& _rxFocusWindow,
-            IAccessibleTableProvider& _rBrowseBox,
+            vcl::IAccessibleTableProvider& _rBrowseBox,
             sal_Int32 _nRowPos,
             sal_uInt16 _nColPos
         ) const override;
@@ -358,14 +361,19 @@ Reference< XAccessibleContext > AccessibleFactory::createAccessibleContext( VCLX
     return new VCLXAccessibleToolBox( _pXWindow );
 }
 
-IAccessibleTabListBox* AccessibleFactory::createAccessibleTabListBox(
+Reference< XAccessibleContext > AccessibleFactory::createAccessibleContext( VCLXHeaderBar* _pXWindow )
+{
+    return new VCLXAccessibleHeaderBar(_pXWindow);
+}
+
+vcl::IAccessibleTabListBox* AccessibleFactory::createAccessibleTabListBox(
     const Reference< XAccessible >& rxParent, SvHeaderTabListBox& rBox ) const
 {
     return new AccessibleTabListBox( rxParent, rBox );
 }
 
-IAccessibleBrowseBox* AccessibleFactory::createAccessibleBrowseBox(
-    const Reference< XAccessible >& _rxParent, IAccessibleTableProvider& _rBrowseBox ) const
+vcl::IAccessibleBrowseBox* AccessibleFactory::createAccessibleBrowseBox(
+    const Reference< XAccessible >& _rxParent, vcl::IAccessibleTableProvider& _rBrowseBox ) const
 {
     return new AccessibleBrowseBoxAccess( _rxParent, _rBrowseBox );
 }
@@ -400,14 +408,14 @@ Reference< XAccessible > AccessibleFactory::createAccessibleTreeListBox(
 }
 
 Reference< XAccessible > AccessibleFactory::createAccessibleBrowseBoxHeaderBar(
-    const Reference< XAccessible >& rxParent, IAccessibleTableProvider& _rOwningTable,
-    AccessibleBrowseBoxObjType _eObjType ) const
+    const Reference< XAccessible >& rxParent, vcl::IAccessibleTableProvider& _rOwningTable,
+    vcl::AccessibleBrowseBoxObjType _eObjType ) const
 {
     return new AccessibleBrowseBoxHeaderBar( rxParent, _rOwningTable, _eObjType );
 }
 
 Reference< XAccessible > AccessibleFactory::createAccessibleBrowseBoxTableCell(
-    const Reference< XAccessible >& _rxParent, IAccessibleTableProvider& _rBrowseBox,
+    const Reference< XAccessible >& _rxParent, vcl::IAccessibleTableProvider& _rBrowseBox,
     const Reference< XWindow >& _xFocusWindow, sal_Int32 _nRowId, sal_uInt16 _nColId, sal_Int32 _nOffset ) const
 {
     return new AccessibleBrowseBoxTableCell( _rxParent, _rBrowseBox, _xFocusWindow,
@@ -415,15 +423,15 @@ Reference< XAccessible > AccessibleFactory::createAccessibleBrowseBoxTableCell(
 }
 
 Reference< XAccessible > AccessibleFactory::createAccessibleBrowseBoxHeaderCell(
-    sal_Int32 _nColumnRowId, const Reference< XAccessible >& rxParent, IAccessibleTableProvider& _rBrowseBox,
-    const Reference< XWindow >& _xFocusWindow, AccessibleBrowseBoxObjType  _eObjType ) const
+    sal_Int32 _nColumnRowId, const Reference< XAccessible >& rxParent, vcl::IAccessibleTableProvider& _rBrowseBox,
+    const Reference< XWindow >& _xFocusWindow, vcl::AccessibleBrowseBoxObjType  _eObjType ) const
 {
     return new AccessibleBrowseBoxHeaderCell( _nColumnRowId, rxParent, _rBrowseBox,
         _xFocusWindow, _eObjType );
 }
 
 Reference< XAccessible > AccessibleFactory::createAccessibleCheckBoxCell(
-    const Reference< XAccessible >& _rxParent, IAccessibleTableProvider& _rBrowseBox,
+    const Reference< XAccessible >& _rxParent, vcl::IAccessibleTableProvider& _rBrowseBox,
     const Reference< XWindow >& _xFocusWindow, sal_Int32 _nRowPos, sal_uInt16 _nColPos,
     const TriState& _eState, bool _bIsTriState ) const
 {
@@ -433,7 +441,7 @@ Reference< XAccessible > AccessibleFactory::createAccessibleCheckBoxCell(
 
 Reference< XAccessible > AccessibleFactory::createEditBrowseBoxTableCellAccess(
     const Reference< XAccessible >& _rxParent, const Reference< XAccessible >& _rxControlAccessible,
-    const Reference< XWindow >& _rxFocusWindow, IAccessibleTableProvider& _rBrowseBox,
+    const Reference< XWindow >& _rxFocusWindow, vcl::IAccessibleTableProvider& _rBrowseBox,
     sal_Int32 _nRowPos, sal_uInt16 _nColPos ) const
 {
     return new EditBrowseBoxTableCellAccess( _rxParent, _rxControlAccessible,
@@ -469,7 +477,7 @@ extern "C"
 {
     SAL_DLLPUBLIC_EXPORT void* getSvtAccessibilityComponentFactory()
     {
-        ::svt::IAccessibleFactory* pFactory = new AccessibleFactory;
+        ::vcl::IAccessibleFactory* pFactory = new AccessibleFactory;
         pFactory->acquire();
         return pFactory;
     }
