@@ -25,6 +25,7 @@
 #include "sbxconv.hxx"
 
 #include <unotools/syslocale.hxx>
+#include <unotools/charclass.hxx>
 
 #include <stdlib.h>
 
@@ -46,6 +47,7 @@
 
 #include <rtl/strbuf.hxx>
 #include <rtl/character.hxx>
+#include <sal/log.hxx>
 #include <svl/zforlist.hxx>
 
 #include <o3tl/make_unique.hxx>
@@ -65,7 +67,7 @@ void ImpGetIntntlSep( sal_Unicode& rcDecimalSep, sal_Unicode& rcThousandSep, sal
     terminating NULL character to be part of the string and returns bool
     instead of pointer, if character is 0 returns false.
  */
-bool ImpStrChr( const sal_Unicode* p, sal_Unicode c )
+static bool ImpStrChr( const sal_Unicode* p, sal_Unicode c )
 {
     if (!c)
         return false;
@@ -406,7 +408,13 @@ static void myftoa( double nNum, char * pBuf, short nPrec, short nExpWidth,
         if( nExpWidth < 3 ) nExpWidth = 3;
         nExpWidth -= 2;
         *pBuf++ = 'E';
-        *pBuf++ =( nExp < 0 ) ?( (nExp = -nExp ), '-' ) : '+';
+        if ( nExp < 0 )
+        {
+            nExp = -nExp;
+            *pBuf++ = '-';
+        }
+        else
+            *pBuf++ = '+';
         while( nExpWidth > 3 )
         {
             *pBuf++ = '0';
@@ -614,6 +622,7 @@ struct VbaFormatInfo
     const char* mpOOoFormat;     // if meType = VbaFormatType::UserDefined
 };
 
+#if HAVE_FEATURE_SCRIPTING
 const VbaFormatInfo pFormatInfoTable[] =
 {
     { VbaFormatType::Offset,      OUStringLiteral("Long Date"),   NF_DATE_SYSTEM_LONG,    nullptr },
@@ -629,7 +638,6 @@ const VbaFormatInfo pFormatInfoTable[] =
     { VbaFormatType::Null,        OUStringLiteral(""),            NF_INDEX_TABLE_ENTRIES, nullptr }
 };
 
-#if HAVE_FEATURE_SCRIPTING
 const VbaFormatInfo* getFormatInfo( const OUString& rFmt )
 {
     const VbaFormatInfo* pInfo = pFormatInfoTable;
