@@ -17,26 +17,26 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "sal/config.h"
+#include <sal/config.h>
 
 #include <algorithm>
 #include <cassert>
 #include <exception>
 
-#include "com/sun/star/bridge/BridgeExistsException.hpp"
-#include "com/sun/star/connection/XConnection.hpp"
-#include "com/sun/star/lang/IllegalArgumentException.hpp"
-#include "com/sun/star/uno/Exception.hpp"
-#include "com/sun/star/uno/Reference.hxx"
-#include "com/sun/star/uno/RuntimeException.hpp"
-#include "com/sun/star/uno/XComponentContext.hpp"
-#include "com/sun/star/uno/XInterface.hpp"
-#include "cppuhelper/factory.hxx"
-#include "cppuhelper/implementationentry.hxx"
+#include <com/sun/star/bridge/BridgeExistsException.hpp>
+#include <com/sun/star/connection/XConnection.hpp>
+#include <com/sun/star/lang/IllegalArgumentException.hpp>
+#include <com/sun/star/uno/Exception.hpp>
+#include <com/sun/star/uno/Reference.hxx>
+#include <com/sun/star/uno/RuntimeException.hpp>
+#include <com/sun/star/uno/XComponentContext.hpp>
+#include <com/sun/star/uno/XInterface.hpp>
+#include <cppuhelper/factory.hxx>
+#include <cppuhelper/implementationentry.hxx>
 #include <cppuhelper/supportsservice.hxx>
-#include "rtl/ref.hxx"
-#include "sal/log.hxx"
-#include "sal/types.h"
+#include <rtl/ref.hxx>
+#include <sal/log.hxx>
+#include <sal/types.h>
 
 #include "bridge.hxx"
 #include "bridgefactory.hxx"
@@ -64,17 +64,15 @@ void BridgeFactory::removeBridge(
     assert(bridge.is());
     OUString n(bridge->getName());
     osl::MutexGuard g(m_aMutex);
-    if (n.isEmpty()) {
-        BridgeList::iterator i(
-            std::find(unnamed_.begin(), unnamed_.end(), bridge));
-        if (i != unnamed_.end()) {
-            unnamed_.erase(i);
-        }
-    } else {
+    if (n.isEmpty())
+    {
+        unnamed_.erase(std::remove(unnamed_.begin(), unnamed_.end(), bridge), unnamed_.end());
+    }
+    else
+    {
         BridgeMap::iterator i(named_.find(n));
-        if (i != named_.end() && i->second == bridge) {
+        if (i != named_.end() && i->second == bridge)
             named_.erase(i);
-        }
     }
 }
 
@@ -126,8 +124,7 @@ css::uno::Reference< css::bridge::XBridge > BridgeFactory::createBridge(
         }
         b.set(new Bridge(this, sName, aConnection, anInstanceProvider));
         if (sName.isEmpty()) {
-            unnamed_.push_back(
-                css::uno::Reference< css::bridge::XBridge >(b.get()));
+            unnamed_.emplace_back(b.get());
         } else {
             named_[sName] = b.get();
         }
@@ -162,37 +159,39 @@ BridgeFactory::getExistingBridges() {
     n = static_cast< sal_Int32 >(n + named_.size());
     css::uno::Sequence< css::uno::Reference< css::bridge::XBridge > > s(n);
     sal_Int32 i = 0;
-    for (BridgeList::iterator j(unnamed_.begin()); j != unnamed_.end(); ++j) {
-        s[i++] = *j;
-    }
-    for (BridgeMap::iterator j(named_.begin()); j != named_.end(); ++j) {
-        s[i++] = j->second;
-    }
+    for (auto const& item : unnamed_)
+        s[i++] = item;
+
+    for (auto const& item : named_)
+        s[i++] = item.second;
+
     return s;
 }
 
 void BridgeFactory::disposing() {
-    BridgeList l1;
+    BridgeVector l1;
     BridgeMap l2;
     {
         osl::MutexGuard g(m_aMutex);
         l1.swap(unnamed_);
         l2.swap(named_);
     }
-    for (BridgeList::iterator i(l1.begin()); i != l1.end(); ++i) {
+    for (auto const& item : l1)
+    {
         try {
             css::uno::Reference<css::lang::XComponent>(
-                *i, css::uno::UNO_QUERY_THROW)->dispose();
+                item, css::uno::UNO_QUERY_THROW)->dispose();
         } catch (css::uno::Exception & e) {
-            SAL_WARN("binaryurp", "ignoring Exception " << e.Message);
+            SAL_WARN("binaryurp", "ignoring " << e);
         }
     }
-    for (BridgeMap::iterator i(l2.begin()); i != l2.end(); ++i) {
+    for (auto const& item : l2)
+    {
         try {
             css::uno::Reference<css::lang::XComponent>(
-                i->second, css::uno::UNO_QUERY_THROW)->dispose();
+                item.second, css::uno::UNO_QUERY_THROW)->dispose();
         } catch (css::uno::Exception & e) {
-            SAL_WARN("binaryurp", "ignoring Exception " << e.Message);
+            SAL_WARN("binaryurp", "ignoring " << e);
         }
     }
 }
@@ -211,7 +210,7 @@ static cppu::ImplementationEntry const services[] = {
 
 }
 
-extern "C" SAL_DLLPUBLIC_EXPORT void * SAL_CALL binaryurp_component_getFactory(
+extern "C" SAL_DLLPUBLIC_EXPORT void * binaryurp_component_getFactory(
     char const * pImplName, void * pServiceManager, void * pRegistryKey)
 {
     return cppu::component_getFactoryHelper(
