@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <sal/config.h>
 
 #include <canvas/propertysethelper.hxx>
 
@@ -75,7 +76,7 @@ namespace canvas
 
     void PropertySetHelper::addProperties( const InputMap& rMap )
     {
-        InputMap aMerged( getPropertyMap() );
+        InputMap aMerged( maMapEntries );
         aMerged.insert( aMerged.end(),
                         rMap.begin(),
                         rMap.end() );
@@ -85,7 +86,7 @@ namespace canvas
 
     bool PropertySetHelper::isPropertyName( const OUString& aPropertyName ) const
     {
-        if( !mpMap.get() )
+        if (!mpMap)
             return false;
 
         Callbacks aDummy;
@@ -103,14 +104,12 @@ namespace canvas
                                               const uno::Any&        aValue )
     {
         Callbacks aCallbacks;
-        if( !mpMap.get() ||
-            !mpMap->lookup( aPropertyName,
-                            aCallbacks ) )
+        if (!mpMap || !mpMap->lookup(aPropertyName, aCallbacks))
         {
             throwUnknown( aPropertyName );
         }
 
-        if( aCallbacks.setter.empty() )
+        if (!aCallbacks.setter)
             throwVeto( aPropertyName );
 
         aCallbacks.setter(aValue);
@@ -119,14 +118,12 @@ namespace canvas
     uno::Any PropertySetHelper::getPropertyValue( const OUString& aPropertyName ) const
     {
         Callbacks aCallbacks;
-        if( !mpMap.get() ||
-            !mpMap->lookup( aPropertyName,
-                            aCallbacks ) )
+        if (!mpMap || !mpMap->lookup(aPropertyName, aCallbacks))
         {
             throwUnknown( aPropertyName );
         }
 
-        if( !aCallbacks.getter.empty() )
+        if (aCallbacks.getter)
             return aCallbacks.getter();
 
         // TODO(Q1): subtlety, empty getter method silently returns
