@@ -18,12 +18,15 @@
  */
 
 #include "TitleWrapper.hxx"
+#include "Chart2ModelContact.hxx"
 #include <ControllerLockGuard.hxx>
 
 #include <comphelper/sequence.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 #include <com/sun/star/chart2/RelativePosition.hpp>
+#include <com/sun/star/chart2/XTitle.hpp>
+#include <com/sun/star/frame/XModel.hpp>
 
 #include <CharacterProperties.hxx>
 #include <LinePropertiesHelper.hxx>
@@ -36,6 +39,7 @@
 
 #include <algorithm>
 #include <rtl/ustrbuf.hxx>
+#include <cppuhelper/propshlp.hxx>
 
 using namespace ::com::sun::star;
 using ::com::sun::star::beans::Property;
@@ -462,13 +466,13 @@ const Sequence< beans::Property >& TitleWrapper::getPropertySequence()
     return *StaticTitleWrapperPropertyArray::get();
 }
 
-const std::vector< WrappedProperty* > TitleWrapper::createWrappedProperties()
+std::vector< std::unique_ptr<WrappedProperty> > TitleWrapper::createWrappedProperties()
 {
-    std::vector< ::chart::WrappedProperty* > aWrappedProperties;
+    std::vector< std::unique_ptr<WrappedProperty> > aWrappedProperties;
 
-    aWrappedProperties.push_back( new WrappedTitleStringProperty( m_spChart2ModelContact->m_xContext ) );
-    aWrappedProperties.push_back( new WrappedTextRotationProperty( true ) );
-    aWrappedProperties.push_back( new WrappedStackedTextProperty() );
+    aWrappedProperties.emplace_back( new WrappedTitleStringProperty( m_spChart2ModelContact->m_xContext ) );
+    aWrappedProperties.emplace_back( new WrappedTextRotationProperty( true ) );
+    aWrappedProperties.emplace_back( new WrappedStackedTextProperty() );
     WrappedCharacterHeightProperty::addWrappedProperties( aWrappedProperties, this );
     WrappedAutomaticPositionProperties::addWrappedProperties( aWrappedProperties );
     WrappedScaleTextProperties::addWrappedProperties( aWrappedProperties, m_spChart2ModelContact );
