@@ -18,9 +18,8 @@
  */
 
 #include "DragMethod_Base.hxx"
+#include <DrawViewWrapper.hxx>
 
-#include <strings.hrc>
-#include <ResId.hxx>
 #include <ObjectNameProvider.hxx>
 #include <ObjectIdentifier.hxx>
 
