@@ -18,9 +18,9 @@
  */
 
 #include "UndoActions.hxx"
-#include "DisposeHelper.hxx"
-#include "CommonFunctors.hxx"
-#include "PropertyHelper.hxx"
+#include <DisposeHelper.hxx>
+#include <CommonFunctors.hxx>
+#include <PropertyHelper.hxx>
 #include "ChartModelClone.hxx"
 
 #include <com/sun/star/lang/DisposedException.hpp>
@@ -57,7 +57,7 @@ UndoElement::~UndoElement()
 
 void SAL_CALL UndoElement::disposing()
 {
-    if ( !!m_pModelClone )
+    if ( m_pModelClone )
         m_pModelClone->dispose();
     m_pModelClone.reset();
     m_xDocumentModel.clear();
@@ -90,10 +90,10 @@ void SAL_CALL UndoElement::redo(  )
 
 // = ShapeUndoElement
 
-ShapeUndoElement::ShapeUndoElement( SdrUndoAction& i_sdrUndoAction )
+ShapeUndoElement::ShapeUndoElement( std::unique_ptr<SdrUndoAction> xSdrUndoAction )
     :ShapeUndoElement_MBase()
     ,ShapeUndoElement_TBase( m_aMutex )
-    ,m_pAction( &i_sdrUndoAction )
+    ,m_xAction( std::move(xSdrUndoAction) )
 {
 }
 
@@ -103,23 +103,23 @@ ShapeUndoElement::~ShapeUndoElement()
 
 OUString SAL_CALL ShapeUndoElement::getTitle()
 {
-    if ( !m_pAction )
+    if ( !m_xAction )
         throw DisposedException( OUString(), *this );
-    return m_pAction->GetComment();
+    return m_xAction->GetComment();
 }
 
 void SAL_CALL ShapeUndoElement::undo(  )
 {
-    if ( !m_pAction )
+    if ( !m_xAction )
         throw DisposedException( OUString(), *this );
-    m_pAction->Undo();
+    m_xAction->Undo();
 }
 
 void SAL_CALL ShapeUndoElement::redo(  )
 {
-    if ( !m_pAction )
+    if ( !m_xAction )
         throw DisposedException( OUString(), *this );
-    m_pAction->Redo();
+    m_xAction->Redo();
 }
 
 void SAL_CALL ShapeUndoElement::disposing()
