@@ -18,28 +18,26 @@
  */
 
 #include "ChartTypeTemplate.hxx"
-#include <PropertyHelper.hxx>
-#include <DataSeriesHelper.hxx>
 #include "DataInterpreter.hxx"
 #include <CommonConverters.hxx>
 #include <ChartTypeHelper.hxx>
 
-#include <CartesianCoordinateSystem.hxx>
 #include <AxisHelper.hxx>
-#include <LegendHelper.hxx>
 #include <DiagramHelper.hxx>
 #include <AxisIndexDefines.hxx>
 #include <unonames.hxx>
 
-#include <cppuhelper/component_context.hxx>
-#include <com/sun/star/chart/ChartSolidType.hpp>
+#include <com/sun/star/uno/XComponentContext.hpp>
 #include <com/sun/star/chart2/AxisType.hpp>
+#include <com/sun/star/chart2/StackingDirection.hpp>
 #include <com/sun/star/chart2/XDataSeriesContainer.hpp>
 #include <com/sun/star/chart2/XChartTypeContainer.hpp>
+#include <com/sun/star/chart2/XCoordinateSystemContainer.hpp>
 #include <tools/diagnose_ex.h>
+#include <comphelper/property.hxx>
+#include <comphelper/sequence.hxx>
 
 #include <algorithm>
-#include <iterator>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::chart2;
