@@ -19,33 +19,33 @@
 
 #include <rtl/math.hxx>
 
-#include <valarray>
+#include <iterator>
 
 #include <InternalDataProvider.hxx>
 #include <LabeledDataSequence.hxx>
 #include <DataSource.hxx>
-#include <PropertyHelper.hxx>
 #include <XMLRangeHelper.hxx>
 #include <ContainerHelper.hxx>
-#include <CommonConverters.hxx>
 #include <CommonFunctors.hxx>
 #include <UncachedDataSequence.hxx>
 #include <DataSourceHelper.hxx>
+#include <ChartModel.hxx>
 #include <ChartModelHelper.hxx>
 #include <DiagramHelper.hxx>
 #include <ExplicitCategoriesProvider.hxx>
 
-#include <com/sun/star/chart2/XChartDocument.hpp>
 #include <com/sun/star/chart2/data/XDataSequence.hpp>
 #include <com/sun/star/chart/ChartDataRowSource.hpp>
-#include <rtl/ustrbuf.hxx>
-#include <unotools/charclass.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <comphelper/sequenceashashmap.hxx>
+#include <comphelper/property.hxx>
+#include <tools/diagnose_ex.h>
 
 #include <vector>
 #include <algorithm>
 
+namespace com { namespace sun { namespace star { namespace chart2 { class XChartDocument; } } } }
+
 using namespace ::com::sun::star;
 using namespace ::std;
 
@@ -393,15 +393,15 @@ InternalDataProvider::InternalDataProvider(
                 ftor( rxScreen );
         }
     }
-    catch( const uno::Exception & ex )
+    catch( const uno::Exception & )
     {
-        SAL_WARN("chart2", "Exception caught. " << ex );
+        DBG_UNHANDLED_EXCEPTION("chart2");
     }
 }
 
 // copy-CTOR
 InternalDataProvider::InternalDataProvider( const InternalDataProvider & rOther ) :
-        impl::InternalDataProvider_Base(),
+        impl::InternalDataProvider_Base(rOther),
         m_aSequenceMap( rOther.m_aSequenceMap ),
         m_aInternalData( rOther.m_aInternalData ),
         m_bDataInColumns( rOther.m_bDataInColumns )
@@ -661,12 +661,9 @@ namespace
 sal_Int32 lcl_getInnerLevelCount( const vector< vector< uno::Any > >& rLabels )
 {
     sal_Int32 nCount = 1;//minimum is 1!
-    vector< vector< uno::Any > >::const_iterator aLevelIt( rLabels.begin() );
-    vector< vector< uno::Any > >::const_iterator aLevelEnd( rLabels.end() );
-    for( ;aLevelIt!=aLevelEnd; ++aLevelIt )
+    for (auto const& elemLabel : rLabels)
     {
-        const vector< uno::Any >& rCurrentLevelLabels = *aLevelIt;
-        nCount = std::max<sal_Int32>( rCurrentLevelLabels.size(), nCount );
+        nCount = std::max<sal_Int32>( elemLabel.size(), nCount );
     }
     return nCount;
 }
@@ -722,7 +719,8 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
     // data with labels
     std::vector< Reference< chart2::data::XLabeledDataSequence > > aDataVec;
     const sal_Int32 nCount = (bUseColumns ? m_aInternalData.getColumnCount() : m_aInternalData.getRowCount());
-    for( sal_Int32 nIdx=0; nIdx<nCount; ++nIdx )
+    aDataVec.reserve(nCount);
+    for (sal_Int32 nIdx = 0; nIdx < nCount; ++nIdx)
     {
         aDataVec.push_back(
             new LabeledDataSequence(
@@ -751,12 +749,10 @@ Reference< chart2::data::XDataSource > SAL_CALL InternalDataProvider::createData
     }
 
     //add left over data sequences to result
-    std::vector< Reference< chart2::data::XLabeledDataSequence > >::iterator aIt(aDataVec.begin());
-    const std::vector< Reference< chart2::data::XLabeledDataSequence > >::const_iterator aEndIt(aDataVec.end());
-    for( ;aIt!=aEndIt; ++aIt)
+    for (auto const& elem : aDataVec)
     {
-        if( aIt->is() )
-            aResultLSeqVec.push_back( *aIt );
+        if( elem.is() )
+            aResultLSeqVec.push_back(elem);
     }
 
     return new DataSource( comphelper::containerToSequence(aResultLSeqVec) );
@@ -867,7 +863,7 @@ Sequence< uno::Any > SAL_CALL InternalDataProvider::getDataByRangeRepresentation
 
     if( aRange.match( lcl_aLabelRangePrefix ) )
     {
-        sal_Int32 nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toInt32();
+        auto nIndex = aRange.copy( strlen(lcl_aLabelRangePrefix)).toUInt32();
         vector< uno::Any > aComplexLabel = m_bDataInColumns
             ? m_aInternalData.getComplexColumnLabel( nIndex )
             : m_aInternalData.getComplexRowLabel( nIndex );
@@ -876,7 +872,7 @@ Sequence< uno::Any > SAL_CALL InternalDataProvider::getDataByRangeRepresentation
     }
     else if( aRange.match( lcl_aCategoriesPointRangeNamePrefix ) )
     {
-        sal_Int32 nPointIndex = aRange.copy( strlen(lcl_aCategoriesPointRangeNamePrefix) ).toInt32();
+        auto nPointIndex = aRange.copy( strlen(lcl_aCategoriesPointRangeNamePrefix) ).toUInt32();
         vector< uno::Any > aComplexCategory = m_bDataInColumns
             ? m_aInternalData.getComplexRowLabel( nPointIndex )
             : m_aInternalData.getComplexColumnLabel( nPointIndex );
@@ -1309,7 +1305,8 @@ vector< vector< uno::Any > > lcl_convertComplexStringSequenceToAnyVector( const
 {
     vector< vector< uno::Any > > aRet;
     sal_Int32 nOuterCount = rIn.getLength();
-    for( sal_Int32 nN=0; nN<nOuterCount; nN++)
+    aRet.reserve(nOuterCount);
+    for (sal_Int32 nN = 0; nN < nOuterCount; nN++)
         aRet.push_back( lcl_StringToAnyVector( rIn[nN] ) );
     return aRet;
 }
@@ -1355,13 +1352,12 @@ Sequence< double > SAL_CALL InternalDataProvider::getDateCategories()
     vector< vector< uno::Any > > aCategories( m_bDataInColumns ? m_aInternalData.getComplexRowLabels() : m_aInternalData.getComplexColumnLabels());
     sal_Int32 nCount = aCategories.size();
     Sequence< double > aDoubles( nCount );
-    vector< vector< uno::Any > >::iterator aIt( aCategories.begin() );
-    vector< vector< uno::Any > >::const_iterator aEnd( aCategories.end() );
-    for(sal_Int32 nN=0; nN<nCount && aIt!=aEnd; ++nN, ++aIt )
+    sal_Int32 nN=0;
+    for (auto const& category : aCategories)
     {
-        if( !( !aIt->empty() && ((*aIt)[0]>>=fValue) ) )
+        if( !( !category.empty() && (category[0]>>=fValue) ) )
             fValue = fNan;
-        aDoubles[nN]=fValue;
+        aDoubles[nN++]=fValue;
     }
     return aDoubles;
 }
@@ -1517,7 +1513,7 @@ css::uno::Sequence< OUString > SAL_CALL InternalDataProvider::getSupportedServic
 
 } //  namespace chart
 
-extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface *
 com_sun_star_comp_chart_InternalDataProvider_get_implementation(css::uno::XComponentContext *,
         css::uno::Sequence<css::uno::Any> const &)
 {
