@@ -23,11 +23,15 @@
 #include <AxisHelper.hxx>
 #include <DiagramHelper.hxx>
 #include <ChartModelHelper.hxx>
+#include <ExplicitCategoriesProvider.hxx>
 
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/chart/ChartAxisArrangeOrderType.hpp>
 #include <com/sun/star/drawing/LineStyle.hpp>
 #include <com/sun/star/text/WritingMode2.hpp>
+#include <com/sun/star/chart2/AxisType.hpp>
+
+#include <sal/log.hxx>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::chart2;
@@ -39,7 +43,7 @@ AxisLabelAlignment::AxisLabelAlignment() :
     mfInnerTickDirection(1.0),
     meAlignment(LABEL_ALIGN_RIGHT_TOP) {}
 
-sal_Int32 lcl_calcTickLengthForDepth(sal_Int32 nDepth,sal_Int32 nTickmarkStyle)
+static sal_Int32 lcl_calcTickLengthForDepth(sal_Int32 nDepth,sal_Int32 nTickmarkStyle)
 {
     sal_Int32 const nWidth = AXIS2D_TICKLENGTH; //@maybefuturetodo this length could be offered by the model
     double fPercent = 1.0;
@@ -63,7 +67,7 @@ sal_Int32 lcl_calcTickLengthForDepth(sal_Int32 nDepth,sal_Int32 nTickmarkStyle)
     return static_cast<sal_Int32>(nWidth*fPercent);
 }
 
-double lcl_getTickOffset(sal_Int32 nLength,sal_Int32 nTickmarkStyle)
+static double lcl_getTickOffset(sal_Int32 nLength,sal_Int32 nTickmarkStyle)
 {
     double fPercent = 0.0; //0<=fPercent<=1
     //0.0: completely inner
@@ -172,12 +176,11 @@ AxisProperties::AxisProperties( const uno::Reference< XAxis >& xAxisModel
     , m_nAxisType(AxisType::REALNUMBER)
     , m_bComplexCategories(false)
     , m_pExplicitCategoriesProvider(pExplicitCategoriesProvider)
-    , m_xAxisTextProvider(nullptr)
     , m_bLimitSpaceForLabels(false)
 {
 }
 
-LabelAlignment lcl_getLabelAlignmentForZAxis( const AxisProperties& rAxisProperties )
+static LabelAlignment lcl_getLabelAlignmentForZAxis( const AxisProperties& rAxisProperties )
 {
     LabelAlignment aRet( LABEL_ALIGN_RIGHT );
     if (rAxisProperties.maLabelAlignment.mfLabelDirection < 0)
@@ -185,7 +188,7 @@ LabelAlignment lcl_getLabelAlignmentForZAxis( const AxisProperties& rAxisPropert
     return aRet;
 }
 
-LabelAlignment lcl_getLabelAlignmentForYAxis( const AxisProperties& rAxisProperties )
+static LabelAlignment lcl_getLabelAlignmentForYAxis( const AxisProperties& rAxisProperties )
 {
     LabelAlignment aRet( LABEL_ALIGN_RIGHT );
     if (rAxisProperties.maLabelAlignment.mfLabelDirection < 0)
@@ -193,7 +196,7 @@ LabelAlignment lcl_getLabelAlignmentForYAxis( const AxisProperties& rAxisPropert
     return aRet;
 }
 
-LabelAlignment lcl_getLabelAlignmentForXAxis( const AxisProperties& rAxisProperties )
+static LabelAlignment lcl_getLabelAlignmentForXAxis( const AxisProperties& rAxisProperties )
 {
     LabelAlignment aRet( LABEL_ALIGN_BOTTOM );
     if (rAxisProperties.maLabelAlignment.mfLabelDirection < 0)
