@@ -64,7 +64,7 @@ OUString GraphicMimeTypeHelper::GetMimeTypeForExtension(const OString& rExt)
     return aMimeType;
 }
 
-OUString GraphicMimeTypeHelper::GetMimeTypeForXGraphic(Reference<XGraphic> xGraphic)
+OUString GraphicMimeTypeHelper::GetMimeTypeForXGraphic(const Reference<XGraphic>& xGraphic)
 {
     OUString aSourceMimeType;
     Reference<XPropertySet> const xGraphicPropertySet(xGraphic, UNO_QUERY);
@@ -76,7 +76,8 @@ OUString GraphicMimeTypeHelper::GetMimeTypeForXGraphic(Reference<XGraphic> xGrap
     return OUString("");
 }
 
-OUString GraphicMimeTypeHelper::GetMimeTypeForImageStream(Reference<XInputStream> xInputStream)
+OUString
+GraphicMimeTypeHelper::GetMimeTypeForImageStream(const Reference<XInputStream>& xInputStream)
 {
     // Create the graphic to retrieve the mimetype from it
     Reference<XGraphicProvider> xProvider
