@@ -22,6 +22,7 @@
 #include <com/sun/star/beans/NamedValue.hpp>
 #include <com/sun/star/lang/IllegalArgumentException.hpp>
 #include <com/sun/star/beans/PropertyState.hpp>
+#include <com/sun/star/beans/PropertyValue.hpp>
 
 #include <rtl/ustrbuf.hxx>
 #include <rtl/instance.hxx>
@@ -126,13 +127,10 @@ namespace comphelper
 
     NamedValueCollection& NamedValueCollection::merge( const NamedValueCollection& _rAdditionalValues, bool _bOverwriteExisting )
     {
-        for (   NamedValueRepository::const_iterator namedValue = _rAdditionalValues.m_pImpl->aValues.begin();
-                namedValue != _rAdditionalValues.m_pImpl->aValues.end();
-                ++namedValue
-            )
+        for (auto const& value : _rAdditionalValues.m_pImpl->aValues)
         {
-            if ( _bOverwriteExisting || !impl_has( namedValue->first ) )
-                impl_put( namedValue->first, namedValue->second );
+            if ( _bOverwriteExisting || !impl_has( value.first ) )
+                impl_put( value.first, value.second );
         }
 
         return *this;
@@ -154,9 +152,9 @@ namespace comphelper
     std::vector< OUString > NamedValueCollection::getNames() const
     {
         std::vector< OUString > aNames;
-        for ( NamedValueRepository::const_iterator it = m_pImpl->aValues.begin(), end = m_pImpl->aValues.end(); it != end; ++it )
+        for (auto const& value : m_pImpl->aValues)
         {
-            aNames.push_back( it->first );
+            aNames.push_back( value.first );
         }
         return aNames;
     }
@@ -302,31 +300,12 @@ namespace comphelper
     }
 
 
-    namespace
-    {
-        struct Value2PropertyValue
-        {
-            PropertyValue operator()( const NamedValueRepository::value_type& _rValue )
-            {
-                return PropertyValue(
-                    _rValue.first, 0, _rValue.second, PropertyState_DIRECT_VALUE );
-            }
-        };
-
-        struct Value2NamedValue
-        {
-            NamedValue operator()( const NamedValueRepository::value_type& _rValue )
-            {
-                return NamedValue( _rValue.first, _rValue.second );
-            }
-        };
-    }
-
-
     sal_Int32 NamedValueCollection::operator >>= ( Sequence< PropertyValue >& _out_rValues ) const
     {
         _out_rValues.realloc( m_pImpl->aValues.size() );
-        std::transform( m_pImpl->aValues.begin(), m_pImpl->aValues.end(), _out_rValues.getArray(), Value2PropertyValue() );
+        std::transform( m_pImpl->aValues.begin(), m_pImpl->aValues.end(), _out_rValues.getArray(),
+                [](const NamedValueRepository::value_type& _rValue)
+                    { return PropertyValue( _rValue.first, 0, _rValue.second, PropertyState_DIRECT_VALUE ); } );
         return _out_rValues.getLength();
     }
 
@@ -334,7 +313,9 @@ namespace comphelper
     sal_Int32 NamedValueCollection::operator >>= ( Sequence< NamedValue >& _out_rValues ) const
     {
         _out_rValues.realloc( m_pImpl->aValues.size() );
-        std::transform( m_pImpl->aValues.begin(), m_pImpl->aValues.end(), _out_rValues.getArray(), Value2NamedValue() );
+        std::transform( m_pImpl->aValues.begin(), m_pImpl->aValues.end(), _out_rValues.getArray(),
+                [](const NamedValueRepository::value_type& _rValue)
+                    { return NamedValue( _rValue.first, _rValue.second ); } );
         return _out_rValues.getLength();
     }
 
