@@ -61,7 +61,6 @@ void MasterPropertySetInfo::add( PropertyInfoHash &rHash, sal_uInt8 nMapId )
 }
 
 Sequence< ::Property > SAL_CALL MasterPropertySetInfo::getProperties()
-    throw(css::uno::RuntimeException, std::exception)
 {
     sal_Int32 nSize = maMap.size();
     if( maProperties.getLength() != nSize )
@@ -69,21 +68,21 @@ Sequence< ::Property > SAL_CALL MasterPropertySetInfo::getProperties()
         maProperties.realloc ( nSize );
         Property* pProperties = maProperties.getArray();
 
-        for (PropertyDataHash::const_iterator aIter(maMap.begin()), aEnd(maMap.end()) ; aIter != aEnd; ++aIter, ++pProperties)
+        for (auto const& elem : maMap)
         {
-            PropertyInfo const * pInfo = (*aIter).second->mpInfo;
+            PropertyInfo const * pInfo = elem.second->mpInfo;
 
             pProperties->Name = pInfo->maName;
             pProperties->Handle = pInfo->mnHandle;
             pProperties->Type = pInfo->maType;
             pProperties->Attributes = pInfo->mnAttributes;
+            ++pProperties;
         }
     }
     return maProperties;
 }
 
 Property SAL_CALL MasterPropertySetInfo::getPropertyByName( const OUString& rName )
-    throw(::UnknownPropertyException, css::uno::RuntimeException, std::exception)
 {
     PropertyDataHash::iterator aIter = maMap.find( rName );
 
@@ -101,7 +100,6 @@ Property SAL_CALL MasterPropertySetInfo::getPropertyByName( const OUString& rNam
 }
 
 sal_Bool SAL_CALL MasterPropertySetInfo::hasPropertyByName( const OUString& rName )
-    throw(css::uno::RuntimeException, std::exception)
 {
     return maMap.find ( rName ) != maMap.end();
 }
