@@ -9,8 +9,9 @@
 
 #include <cassert>
 
+#include <clang/AST/DeclCXX.h>
+
 #include "check.hxx"
-#include "compat.hxx"
 
 namespace loplugin {
 
@@ -88,7 +89,7 @@ TerminalCheck TypeCheck::AnyBoolean() const {
         n == "sal_Bool" || n == "BOOL" || n == "Boolean" || n == "FT_Bool"
         || n == "FcBool" || n == "GLboolean" || n == "NPBool" || n == "TW_BOOL"
         || n == "UBool" || n == "boolean" || n == "dbus_bool_t"
-        || n == "gboolean" || n == "hb_bool_t" || n == "jboolean");
+        || n == "gboolean" || n == "hb_bool_t" || n == "jboolean" || n == "my_bool");
 }
 
 TypeCheck TypeCheck::LvalueReference() const {
@@ -153,14 +154,14 @@ ContextCheck DeclCheck::MemberFunction() const {
 TerminalCheck ContextCheck::GlobalNamespace() const {
     return TerminalCheck(
         context_ != nullptr
-        && ((compat::isLookupContext(*context_)
+        && ((context_->isLookupContext()
              ? context_ : context_->getLookupParent())
             ->isTranslationUnit()));
 }
 
 TerminalCheck ContextCheck::StdNamespace() const {
     return TerminalCheck(
-        context_ != nullptr && compat::isStdNamespace(*context_));
+        context_ != nullptr && context_->isStdNamespace());
 }
 
 ContextCheck ContextCheck::AnonymousNamespace() const {
@@ -171,13 +172,7 @@ ContextCheck ContextCheck::AnonymousNamespace() const {
 
 namespace {
 
-bool BaseCheckNotSomethingInterestingSubclass(
-    const clang::CXXRecordDecl *BaseDefinition
-#if CLANG_VERSION < 30800
-    , void *
-#endif
-    )
-{
+bool BaseCheckNotSomethingInterestingSubclass(const clang::CXXRecordDecl *BaseDefinition) {
     if (BaseDefinition) {
         auto tc = TypeCheck(BaseDefinition);
         if (tc.Class("Dialog").GlobalNamespace() || tc.Class("SfxPoolItem").GlobalNamespace()) {
@@ -201,7 +196,7 @@ bool isDerivedFromSomethingInteresting(const clang::CXXRecordDecl *decl) {
     if (// not sure what hasAnyDependentBases() does,
         // but it avoids classes we don't want, e.g. WeakAggComponentImplHelper1
         !decl->hasAnyDependentBases() &&
-        !compat::forallBases(*decl, BaseCheckNotSomethingInterestingSubclass, nullptr, true)) {
+        !decl->forallBases(BaseCheckNotSomethingInterestingSubclass, true)) {
         return true;
     }
     return false;
@@ -233,6 +228,58 @@ bool isExtraWarnUnusedType(clang::QualType type) {
     return isDerivedFromSomethingInteresting(rec);
 }
 
+namespace {
+
+bool isArithmeticOp(clang::Expr const * expr) {
+    expr = expr->IgnoreParenImpCasts();
+    if (auto const e = llvm::dyn_cast<clang::BinaryOperator>(expr)) {
+        switch (e->getOpcode()) {
+        case clang::BO_Mul:
+        case clang::BO_Div:
+        case clang::BO_Rem:
+        case clang::BO_Add:
+        case clang::BO_Sub:
+        case clang::BO_Shl:
+        case clang::BO_Shr:
+        case clang::BO_And:
+        case clang::BO_Xor:
+        case clang::BO_Or:
+            return true;
+        case clang::BO_Comma:
+            return isArithmeticOp(e->getRHS());
+        default:
+            return false;
+        }
+    }
+    return llvm::isa<clang::UnaryOperator>(expr)
+        || llvm::isa<clang::AbstractConditionalOperator>(expr);
+}
+
+}
+
+bool isOkToRemoveArithmeticCast(
+    clang::ASTContext & context, clang::QualType t1, clang::QualType t2, const clang::Expr* subExpr)
+{
+    // Don't warn if the types are arithmetic (in the C++ meaning), and: either
+    // at least one is a typedef or decltype (and if both are, they're different),
+    // or the sub-expression involves some operation that is likely to change
+    // types through promotion, or the sub-expression is an integer literal (so
+    // its type generally depends on its value and suffix if any---even with a
+    // suffix like L it could still be either long or long long):
+    if ((t1->isIntegralType(context)
+         || t1->isRealFloatingType())
+        && ((t1.getLocalUnqualifiedType() != t2.getLocalUnqualifiedType()
+             && (loplugin::TypeCheck(t1).Typedef()
+                 || loplugin::TypeCheck(t2).Typedef()
+                 || llvm::isa<clang::DecltypeType>(t1) || llvm::isa<clang::DecltypeType>(t2)))
+            || isArithmeticOp(subExpr)
+            || llvm::isa<clang::IntegerLiteral>(subExpr->IgnoreParenImpCasts())))
+    {
+        return false;
+    }
+    return true;
+}
+
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
