@@ -2,8 +2,9 @@
 
 #include "MorkParser.hxx"
 #include <iostream>
+#include <sal/log.hxx>
 
-bool openAddressBook(const std::string& path)
+static bool openAddressBook(const std::string& path)
 {
     MorkParser mork;
     // Open and parse mork file
@@ -11,8 +12,8 @@ bool openAddressBook(const std::string& path)
     {
         return false;
     }
+
     const int defaultScope = 0x80;
-    MorkTableMap::Map::const_iterator tableIter;
     MorkTableMap *Tables = mork.getTables( defaultScope );
     if ( Tables )
     {
