@@ -45,7 +45,7 @@ using com::sun::star::beans::XPropertySet;
 
 namespace pq_sdbc_driver
 {
-Column::Column( const ::rtl::Reference< RefCountedMutex > & refMutex,
+Column::Column( const ::rtl::Reference< comphelper::RefCountedMutex > & refMutex,
                 const Reference< css::sdbc::XConnection > & connection,
                 ConnectionSettings *pSettings)
     : ReflectionBase(
@@ -60,13 +60,13 @@ Column::Column( const ::rtl::Reference< RefCountedMutex > & refMutex,
 Reference< XPropertySet > Column::createDataDescriptor(  )
 {
     ColumnDescriptor * pColumn = new ColumnDescriptor(
-        m_refMutex, m_conn, m_pSettings );
+        m_xMutex, m_conn, m_pSettings );
     pColumn->copyValuesFrom( this );
     return Reference< XPropertySet > ( pColumn );
 }
 
 ColumnDescriptor::ColumnDescriptor(
-    const ::rtl::Reference< RefCountedMutex > & refMutex,
+    const ::rtl::Reference< comphelper::RefCountedMutex > & refMutex,
     const Reference< css::sdbc::XConnection > & connection,
     ConnectionSettings *pSettings)
     : ReflectionBase(
@@ -81,7 +81,7 @@ ColumnDescriptor::ColumnDescriptor(
 Reference< XPropertySet > ColumnDescriptor::createDataDescriptor(  )
 {
     ColumnDescriptor * pColumn = new ColumnDescriptor(
-        m_refMutex, m_conn, m_pSettings );
+        m_xMutex, m_conn, m_pSettings );
     pColumn->copyValuesFrom( this );
 
     return Reference< XPropertySet > ( pColumn );
