@@ -46,9 +46,6 @@
 #include "pq_tools.hxx"
 #include "pq_statics.hxx"
 
-using osl::MutexGuard;
-using osl::Mutex;
-
 using com::sun::star::container::XNameAccess;
 
 using com::sun::star::uno::Reference;
@@ -62,7 +59,7 @@ using com::sun::star::beans::XPropertySet;
 
 namespace pq_sdbc_driver
 {
-Key::Key( const ::rtl::Reference< RefCountedMutex > & refMutex,
+Key::Key( const ::rtl::Reference< comphelper::RefCountedMutex > & refMutex,
           const Reference< css::sdbc::XConnection > & connection,
           ConnectionSettings *pSettings,
           const OUString & schemaName,
@@ -81,7 +78,7 @@ Key::Key( const ::rtl::Reference< RefCountedMutex > & refMutex,
 Reference< XPropertySet > Key::createDataDescriptor(  )
 {
     KeyDescriptor * pKeyDescriptor = new KeyDescriptor(
-        m_refMutex, m_conn, m_pSettings );
+        m_xMutex, m_conn, m_pSettings );
     pKeyDescriptor->copyValuesFrom( this );
 
     return Reference< XPropertySet > ( pKeyDescriptor );
@@ -97,7 +94,7 @@ Reference< XNameAccess > Key::getColumns(  )
         getPropertyValue( getStatics().PRIVATE_FOREIGN_COLUMNS ) >>= foreignColumnNames;
 
         m_keyColumns = KeyColumns::create(
-            m_refMutex, m_conn, m_pSettings, m_schemaName,
+            m_xMutex, m_conn, m_pSettings, m_schemaName,
             m_tableName, columnNames, foreignColumnNames );
     }
     return m_keyColumns;
@@ -105,19 +102,11 @@ Reference< XNameAccess > Key::getColumns(  )
 
 Sequence<Type > Key::getTypes()
 {
-    static cppu::OTypeCollection *pCollection;
-    if( ! pCollection )
-    {
-        MutexGuard guard( osl::Mutex::getGlobalMutex() );
-        if( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
-                cppu::UnoType<css::sdbcx::XColumnsSupplier>::get(),
-                ReflectionBase::getTypes());
-            pCollection = &collection;
-        }
-    }
-    return pCollection->getTypes();
+    static cppu::OTypeCollection collection(
+        cppu::UnoType<css::sdbcx::XColumnsSupplier>::get(),
+        ReflectionBase::getTypes());
+
+    return collection.getTypes();
 }
 
 Sequence< sal_Int8> Key::getImplementationId()
@@ -138,7 +127,7 @@ Any Key::queryInterface( const Type & reqType )
 }
 
 
-KeyDescriptor::KeyDescriptor( const ::rtl::Reference< RefCountedMutex > & refMutex,
+KeyDescriptor::KeyDescriptor( const ::rtl::Reference< comphelper::RefCountedMutex > & refMutex,
           const Reference< css::sdbc::XConnection > & connection,
           ConnectionSettings *pSettings )
     : ReflectionBase(
@@ -154,7 +143,7 @@ KeyDescriptor::KeyDescriptor( const ::rtl::Reference< RefCountedMutex > & refMut
 Reference< XPropertySet > KeyDescriptor::createDataDescriptor(  )
 {
     KeyDescriptor * pKeyDescriptor = new KeyDescriptor(
-        m_refMutex, m_conn, m_pSettings );
+        m_xMutex, m_conn, m_pSettings );
     pKeyDescriptor->copyValuesFrom( this );
 
     return Reference< XPropertySet > ( pKeyDescriptor );
@@ -165,26 +154,18 @@ Reference< XNameAccess > KeyDescriptor::getColumns(  )
     // TODO: cash columns object !
     if( !m_keyColumns.is() )
     {
-        m_keyColumns = new KeyColumnDescriptors( m_refMutex, m_conn, m_pSettings );
+        m_keyColumns = new KeyColumnDescriptors( m_xMutex, m_conn, m_pSettings );
     }
     return m_keyColumns;
 }
 
 Sequence<Type > KeyDescriptor::getTypes()
 {
-    static cppu::OTypeCollection *pCollection;
-    if( ! pCollection )
-    {
-        MutexGuard guard( osl::Mutex::getGlobalMutex() );
-        if( !pCollection )
-        {
-            static cppu::OTypeCollection collection(
-                cppu::UnoType<css::sdbcx::XColumnsSupplier>::get(),
-                ReflectionBase::getTypes());
-            pCollection = &collection;
-        }
-    }
-    return pCollection->getTypes();
+    static cppu::OTypeCollection collection(
+        cppu::UnoType<css::sdbcx::XColumnsSupplier>::get(),
+        ReflectionBase::getTypes());
+
+    return collection.getTypes();
 }
 
 Sequence< sal_Int8> KeyDescriptor::getImplementationId()
