@@ -9,18 +9,26 @@
 
 #include <SignSignatureLineDialog.hxx>
 
+#include <sal/log.hxx>
 #include <sal/types.h>
 
 #include <dialmgr.hxx>
 #include <strings.hrc>
 
+#include <comphelper/graphicmimetype.hxx>
 #include <comphelper/processfactory.hxx>
-#include <comphelper/storagehelper.hxx>
-#include <comphelper/xmltools.hxx>
-#include <tools/stream.hxx>
-#include <unotools/streamwrap.hxx>
-#include <vcl/weld.hxx>
+#include <comphelper/xmlsechelper.hxx>
+#include <osl/file.hxx>
+#include <sfx2/docfile.hxx>
+#include <sfx2/docfilt.hxx>
 #include <sfx2/objsh.hxx>
+#include <svx/xoutbmp.hxx>
+#include <tools/stream.hxx>
+#include <unotools/localedatawrapper.hxx>
+#include <unotools/streamwrap.hxx>
+#include <utility>
+#include <vcl/graph.hxx>
+#include <vcl/weld.hxx>
 
 #include <com/sun/star/beans/XPropertySet.hpp>
 #include <com/sun/star/drawing/XShape.hpp>
@@ -29,13 +37,18 @@
 #include <com/sun/star/graphic/XGraphicProvider.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
 #include <com/sun/star/lang/XMultiServiceFactory.hpp>
+#include <com/sun/star/security/CertificateKind.hpp>
 #include <com/sun/star/security/DocumentDigitalSignatures.hpp>
 #include <com/sun/star/security/XCertificate.hpp>
 #include <com/sun/star/security/XDocumentDigitalSignatures.hpp>
 #include <com/sun/star/text/TextContentAnchorType.hpp>
 #include <com/sun/star/text/XTextContent.hpp>
 #include <com/sun/star/text/XTextDocument.hpp>
+#include <com/sun/star/ui/dialogs/FilePicker.hpp>
+#include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
+#include <com/sun/star/ui/dialogs/XFilePicker3.hpp>
 
+using namespace comphelper;
 using namespace css;
 using namespace css::uno;
 using namespace css::beans;
@@ -47,12 +60,15 @@ using namespace css::text;
 using namespace css::drawing;
 using namespace css::graphic;
 using namespace css::security;
+using namespace css::ui::dialogs;
 
 SignSignatureLineDialog::SignSignatureLineDialog(weld::Widget* pParent, Reference<XModel> xModel)
-    : SignatureLineDialogBase(pParent, xModel, "cui/ui/signsignatureline.ui",
+    : SignatureLineDialogBase(pParent, std::move(xModel), "cui/ui/signsignatureline.ui",
                               "SignSignatureLineDialog")
     , m_xEditName(m_xBuilder->weld_entry("edit_name"))
     , m_xEditComment(m_xBuilder->weld_text_view("edit_comment"))
+    , m_xBtnLoadImage(m_xBuilder->weld_button("btn_load_image"))
+    , m_xBtnClearImage(m_xBuilder->weld_button("btn_clear_image"))
     , m_xBtnChooseCertificate(m_xBuilder->weld_button("btn_select_certificate"))
     , m_xBtnSign(m_xBuilder->weld_button("ok"))
     , m_xLabelHint(m_xBuilder->weld_label("label_hint"))
@@ -72,6 +88,8 @@ SignSignatureLineDialog::SignSignatureLineDialog(weld::Widget* pParent, Referenc
         return;
     }
 
+    m_xBtnLoadImage->connect_clicked(LINK(this, SignSignatureLineDialog, loadImage));
+    m_xBtnClearImage->connect_clicked(LINK(this, SignSignatureLineDialog, clearImage));
     m_xBtnChooseCertificate->connect_clicked(
         LINK(this, SignSignatureLineDialog, chooseCertificate));
     m_xEditName->connect_changed(LINK(this, SignSignatureLineDialog, entryChanged));
@@ -114,17 +132,60 @@ SignSignatureLineDialog::SignSignatureLineDialog(weld::Widget* pParent, Referenc
     ValidateFields();
 }
 
+IMPL_LINK_NOARG(SignSignatureLineDialog, loadImage, weld::Button&, void)
+{
+    Reference<XComponentContext> xContext = comphelper::getProcessComponentContext();
+    Reference<XFilePicker3> xFilePicker
+        = FilePicker::createWithMode(xContext, TemplateDescription::FILEOPEN_PREVIEW);
+    if (xFilePicker->execute())
+    {
+        Sequence<OUString> aSelectedFiles = xFilePicker->getSelectedFiles();
+        if (aSelectedFiles.getLength() < 1)
+            return;
+
+        Reference<XGraphicProvider> xProvider = GraphicProvider::create(xContext);
+        Sequence<PropertyValue> aMediaProperties(1);
+        aMediaProperties[0].Name = "URL";
+        aMediaProperties[0].Value <<= aSelectedFiles[0];
+        m_xSignatureImage = xProvider->queryGraphic(aMediaProperties);
+        m_sOriginalImageBtnLabel = m_xBtnLoadImage->get_label();
+
+        INetURLObject aObj(aSelectedFiles[0]);
+        m_xBtnLoadImage->set_label(aObj.GetLastName());
+
+        ValidateFields();
+    }
+}
+
+IMPL_LINK_NOARG(SignSignatureLineDialog, clearImage, weld::Button&, void)
+{
+    m_xSignatureImage.set(nullptr);
+    m_xBtnLoadImage->set_label(m_sOriginalImageBtnLabel);
+    ValidateFields();
+}
+
 IMPL_LINK_NOARG(SignSignatureLineDialog, chooseCertificate, weld::Button&, void)
 {
+    // Document needs to be saved before selecting a certificate
+    SfxObjectShell* pShell = SfxObjectShell::Current();
+    if (!pShell->PrepareForSigning(m_xDialog.get()))
+        return;
+
     Reference<XDocumentDigitalSignatures> xSigner(DocumentDigitalSignatures::createWithVersion(
         comphelper::getProcessComponentContext(), "1.2"));
     OUString aDescription;
-    Reference<XCertificate> xSignCertificate = xSigner->selectSigningCertificate(aDescription);
+    CertificateKind certificateKind = CertificateKind_NONE;
+    // When signing ooxml, we only want X.509 certificates
+    if (pShell->GetMedium()->GetFilter()->IsAlienFormat())
+        certificateKind = CertificateKind_X509;
+    Reference<XCertificate> xSignCertificate
+        = xSigner->selectSigningCertificateWithType(certificateKind, aDescription);
 
     if (xSignCertificate.is())
     {
         m_xSelectedCertifate = xSignCertificate;
-        m_xBtnChooseCertificate->set_label(xSignCertificate->getIssuerName());
+        m_xBtnChooseCertificate->set_label(
+            xmlsec::GetContentPart(xSignCertificate->getSubjectName()));
     }
     ValidateFields();
 }
@@ -133,8 +194,13 @@ IMPL_LINK_NOARG(SignSignatureLineDialog, entryChanged, weld::Entry&, void) { Val
 
 void SignSignatureLineDialog::ValidateFields()
 {
-    bool bEnable = m_xSelectedCertifate.is() && !m_xEditName->get_text().isEmpty();
-    m_xBtnSign->set_sensitive(bEnable);
+    bool bEnableSignBtn = m_xSelectedCertifate.is()
+                          && (!m_xEditName->get_text().isEmpty() || m_xSignatureImage.is());
+    m_xBtnSign->set_sensitive(bEnableSignBtn);
+
+    m_xEditName->set_sensitive(!m_xSignatureImage.is());
+    m_xBtnLoadImage->set_sensitive(m_xEditName->get_text().isEmpty());
+    m_xBtnClearImage->set_sensitive(m_xSignatureImage.is());
 }
 
 void SignSignatureLineDialog::Apply()
@@ -160,9 +226,9 @@ SignSignatureLineDialog::getSignedGraphic(bool bValid)
     aSvgImage = aSvgImage.replaceAll("[SIGNER_NAME]", getCDataString(m_aSuggestedSignerName));
     aSvgImage = aSvgImage.replaceAll("[SIGNER_TITLE]", getCDataString(m_aSuggestedSignerTitle));
 
-    aSvgImage = aSvgImage.replaceAll("[SIGNATURE]", getCDataString(m_xEditName->get_text()));
-    OUString aIssuerLine = CuiResId(RID_SVXSTR_SIGNATURELINE_SIGNED_BY)
-                               .replaceFirst("%1", m_xSelectedCertifate->getIssuerName());
+    OUString aIssuerLine
+        = CuiResId(RID_SVXSTR_SIGNATURELINE_SIGNED_BY)
+              .replaceFirst("%1", xmlsec::GetContentPart(m_xSelectedCertifate->getSubjectName()));
     aSvgImage = aSvgImage.replaceAll("[SIGNED_BY]", getCDataString(aIssuerLine));
     if (bValid)
         aSvgImage = aSvgImage.replaceAll("[INVALID_SIGNATURE]", "");
@@ -177,6 +243,31 @@ SignSignatureLineDialog::getSignedGraphic(bool bValid)
     }
     aSvgImage = aSvgImage.replaceAll("[DATE]", aDate);
 
+    // Custom signature image
+    if (m_xSignatureImage.is())
+    {
+        OUString aGraphicInBase64;
+        Graphic aGraphic(m_xSignatureImage);
+        if (!XOutBitmap::GraphicToBase64(aGraphic, aGraphicInBase64, false))
+            SAL_WARN("cui.dialogs", "Could not convert graphic to base64");
+
+        OUString aImagePart = "<image y=\"825\" x=\"1300\" "
+                              "xlink:href=\"data:[MIMETYPE];base64,[BASE64_IMG]>\" "
+                              "preserveAspectRatio=\"xMidYMid\" height=\"1520\" "
+                              "width=\"7600\" />";
+        aImagePart = aImagePart.replaceAll(
+            "[MIMETYPE]", GraphicMimeTypeHelper::GetMimeTypeForXGraphic(m_xSignatureImage));
+        aImagePart = aImagePart.replaceAll("[BASE64_IMG]", aGraphicInBase64);
+        aSvgImage = aSvgImage.replaceAll("[SIGNATURE_IMAGE]", aImagePart);
+
+        aSvgImage = aSvgImage.replaceAll("[SIGNATURE]", "");
+    }
+    else
+    {
+        aSvgImage = aSvgImage.replaceAll("[SIGNATURE_IMAGE]", "");
+        aSvgImage = aSvgImage.replaceAll("[SIGNATURE]", getCDataString(m_xEditName->get_text()));
+    }
+
     // Create graphic
     SvMemoryStream aSvgStream(4096, 4096);
     aSvgStream.WriteOString(OUStringToOString(aSvgImage, RTL_TEXTENCODING_UTF8));
