@@ -19,6 +19,9 @@
 
 #include <config_features.h>
 #include <osl/process.h>
+#include <sal/log.hxx>
+#include <osl/diagnose.h>
+#include <rtl/character.hxx>
 #include <vcl/layout.hxx>
 #include <vcl/weld.hxx>
 #include <vcl/svapp.hxx>
@@ -79,6 +82,7 @@ AboutDialog::AboutDialog(vcl::Window* pParent)
     m_aBasedTextStr = get<FixedText>("libreoffice")->GetText();
     m_aBasedDerivedTextStr = get<FixedText>("derived")->GetText();
     m_aLocaleStr = get<FixedText>("locale")->GetText();
+    m_aUILocaleStr = get<FixedText>("uilocale")->GetText();
     m_buildIdLinkString = m_pBuildIdLink->GetText();
 
     m_pVersion->SetText(GetVersionString());
@@ -305,6 +309,7 @@ OUString AboutDialog::GetVersionString()
     OUString sBuildId = GetBuildId();
 
     OUString aLocaleStr = Application::GetSettings().GetLanguageTag().getBcp47() + " (" + GetLocaleString() + ")";
+    OUString aUILocaleStr = Application::GetSettings().GetUILanguageTag().getBcp47();
 
     if (!sBuildId.trim().isEmpty())
     {
@@ -326,26 +331,26 @@ OUString AboutDialog::GetVersionString()
         sVersion += "\n" EXTRA_BUILDID;
     }
 
-    if (!aLocaleStr.trim().isEmpty())
+    if (m_aLocaleStr.indexOf("$LOCALE") == -1)
     {
-        sVersion += "\n";
-        if (m_aLocaleStr.indexOf("$LOCALE") == -1)
-        {
-            SAL_WARN( "cui.dialogs", "translated locale string in translations doesn't contain $LOCALE placeholder" );
-            m_aLocaleStr += " $LOCALE";
-        }
-        sVersion += m_aLocaleStr.replaceAll("$LOCALE", aLocaleStr);
+        SAL_WARN( "cui.dialogs", "translated locale string in translations doesn't contain $LOCALE placeholder" );
+        m_aLocaleStr += " $LOCALE";
     }
+    sVersion += "\n" + m_aLocaleStr.replaceAll("$LOCALE", aLocaleStr);
+
+    if (m_aUILocaleStr.indexOf("$LOCALE") == -1)
+    {
+        SAL_WARN( "cui.dialogs", "translated uilocale string in translations doesn't contain $LOCALE placeholder" );
+        m_aUILocaleStr += " $LOCALE";
+    }
+    sVersion += "; " + m_aUILocaleStr.replaceAll("$LOCALE", aUILocaleStr);
 
     OUString aCalcMode = "Calc: "; // Calc calculation mode
 
 #if HAVE_FEATURE_OPENCL
-    bool bSWInterp = officecfg::Office::Common::Misc::UseSwInterpreter::get();
     bool bOpenCL = openclwrapper::GPUEnv::isOpenCLEnabled();
     if (bOpenCL)
         aCalcMode += "CL";
-    else if (bSWInterp)
-        aCalcMode += "group";
 #else
     const bool bOpenCL = false;
 #endif
@@ -360,7 +365,7 @@ OUString AboutDialog::GetVersionString()
         aCalcMode += "threaded";
     }
 
-    sVersion += "; " + aCalcMode;
+    sVersion += "\n" + aCalcMode;
 
     return sVersion;
 }
