@@ -19,6 +19,7 @@
 #include <com/sun/star/script/XStorageBasedLibraryContainer.hpp>
 #include <com/sun/star/script/XLibraryContainer.hpp>
 #include <com/sun/star/util/XModifiable.hpp>
+#include <com/sun/star/util/XCloseable.hpp>
 #include <com/sun/star/container/XHierarchicalNameAccess.hpp>
 #include <com/sun/star/io/XStream.hpp>
 #include <com/sun/star/io/XInputStream.hpp>
@@ -72,17 +73,13 @@ void DialogSaveTest::test()
         uno::Reference< lang::XComponent > xComponent = loadFromDesktop(aFileName);
         CPPUNIT_ASSERT(xComponent.is());
         uno::Reference< frame::XStorable > xDocStorable(xComponent, UNO_QUERY_THROW);
-        CPPUNIT_ASSERT(xDocStorable.is());
         uno::Reference< document::XEmbeddedScripts > xDocScr(xComponent, UNO_QUERY_THROW);
-        CPPUNIT_ASSERT(xDocScr.is());
         uno::Reference< script::XStorageBasedLibraryContainer > xStorBasLib(xDocScr->getBasicLibraries());
         CPPUNIT_ASSERT(xStorBasLib.is());
         uno::Reference< script::XLibraryContainer > xBasLib(xStorBasLib, UNO_QUERY_THROW);
-        CPPUNIT_ASSERT(xBasLib.is());
         uno::Reference< script::XStorageBasedLibraryContainer > xStorDlgLib(xDocScr->getDialogLibraries());
         CPPUNIT_ASSERT(xStorDlgLib.is());
         uno::Reference< script::XLibraryContainer > xDlgLib(xStorDlgLib, UNO_QUERY_THROW);
-        CPPUNIT_ASSERT(xDlgLib.is());
         xBasLib->loadLibrary(sStandard);
         xDlgLib->loadLibrary(sStandard);
         CPPUNIT_ASSERT(xBasLib->isLibraryLoaded(sStandard));
@@ -92,15 +89,12 @@ void DialogSaveTest::test()
         xDlgLib->removeLibrary(sStandard);
 
         // uno::Reference< util::XModifiable > xDlgMod(xDlgLib, UNO_QUERY_THROW);
-        // CPPUNIT_ASSERT(xDlgMod.is());
         // xDlgMod->setModified(sal_True);
 
         // uno::Reference< util::XModifiable > xScrMod(xDocScr, UNO_QUERY_THROW);
-        // CPPUNIT_ASSERT(xScrMod.is());
         // xScrMod->setModified(sal_True);
 
         // uno::Reference< util::XModifiable > xDocMod(xComponent, UNO_QUERY_THROW);
-        // CPPUNIT_ASSERT(xDocMod.is());
         // std::cerr << "** Modified: " << static_cast<bool>(xDocMod->isModified()) << std::endl;
         // xDocMod->setModified(sal_True);
         // std::cerr << "** Modified: " << static_cast<bool>(xDocMod->isModified()) << std::endl;
@@ -112,7 +106,6 @@ void DialogSaveTest::test()
 
         // close
         uno::Reference< util::XCloseable > xDocCloseable(xComponent, UNO_QUERY_THROW);
-        CPPUNIT_ASSERT(xDocCloseable.is());
         xDocCloseable->close(false);
 
         // All our uno::References are (should?) be invalid now -> let them go out of scope
@@ -121,7 +114,6 @@ void DialogSaveTest::test()
         uno::Sequence<uno::Any> args(1);
         args[0] <<= aFileName;
         Reference<container::XHierarchicalNameAccess> xHNA(getMultiServiceFactory()->createInstanceWithArguments("com.sun.star.packages.Package", args), UNO_QUERY_THROW);
-        CPPUNIT_ASSERT(xHNA.is());
         CPPUNIT_ASSERT(!xHNA->hasByHierarchicalName("Basic/Standard"));
         CPPUNIT_ASSERT(!xHNA->hasByHierarchicalName("Dialogs/Standard"));
     }
