@@ -170,7 +170,7 @@ namespace
     void obtain( Any& _out_rValue, ::boost::optional< T > & _rCache, const sal_Int32 _nPos, const Reference < XResultSetMetaData >& _rxResultMeta, T (SAL_CALL XResultSetMetaData::*Getter)( sal_Int32 ) )
     {
         if ( !_rCache )
-            _rCache.reset( (_rxResultMeta.get()->*Getter)( _nPos ) );
+            _rCache = (_rxResultMeta.get()->*Getter)(_nPos);
         _out_rValue <<= *_rCache;
     }
 }
