@@ -20,6 +20,7 @@
 #include <tablecontainer.hxx>
 #include <stringconstants.hxx>
 #include <table.hxx>
+#include <sal/log.hxx>
 #include <comphelper/property.hxx>
 #include <comphelper/processfactory.hxx>
 #include <tools/debug.hxx>
@@ -102,7 +103,6 @@ OTableContainer::OTableContainer(::cppu::OWeakObject& _rParent,
                                  std::atomic<std::size_t>& _nInAppend)
     :OFilteredContainer(_rParent,_rMutex,_xCon,_bCase,_pRefreshListener,_nInAppend)
     ,m_xTableDefinitions(_xTableDefinitions)
-    ,m_pTableMediator( nullptr )
 {
 }
 
@@ -347,9 +347,9 @@ void OTableContainer::dropObject(sal_Int32 _nPos, const OUString& _sElementName)
         Reference<XPropertySet> xTable(getObject(_nPos),UNO_QUERY);
         if ( xTable.is() && m_xMetaData.is() )
         {
-            if( m_xMetaData.is() && m_xMetaData->supportsCatalogsInTableDefinitions() )
+            if (m_xMetaData->supportsCatalogsInTableDefinitions())
                 xTable->getPropertyValue(PROPERTY_CATALOGNAME)  >>= sCatalog;
-            if( m_xMetaData.is() && m_xMetaData->supportsSchemasInTableDefinitions() )
+            if (m_xMetaData->supportsSchemasInTableDefinitions())
                 xTable->getPropertyValue(PROPERTY_SCHEMANAME)   >>= sSchema;
             xTable->getPropertyValue(PROPERTY_NAME)         >>= sTable;
 
