@@ -25,7 +25,6 @@
 #include <stringconstants.hxx>
 #include <comphelper/documentconstants.hxx>
 #include <comphelper/string.hxx>
-#include <svtools/miscopt.hxx>
 
 namespace dbaccess
 {
@@ -300,12 +299,7 @@ OUString ODsnTypeCollection::getEmbeddedDatabase() const
     }
     if ( sEmbeddedDatabaseURL.isEmpty() )
     {
-        SvtMiscOptions aMiscOptions;
-        if( aMiscOptions.IsExperimentalMode() )
-            sEmbeddedDatabaseURL = "sdbc:embedded:firebird";
-        else
-            sEmbeddedDatabaseURL = "sdbc:embedded:hsqldb";
-
+        sEmbeddedDatabaseURL = "sdbc:embedded:firebird";
     }
 
     return sEmbeddedDatabaseURL;
