@@ -23,14 +23,11 @@
 
 #include <map>
 
-//........................................................................
 namespace dbmm
 {
 #define OVERALL_RANGE   100000
 
-    //====================================================================
-    //= misc types
-    //====================================================================
+    // misc types
     struct PhaseData
     {
         // the weight of the phase, relative to all other phases
@@ -52,7 +49,7 @@ namespace dbmm
         {
         }
 
-        PhaseData( const PhaseWeight _nWeight )
+        explicit PhaseData( const PhaseWeight _nWeight )
             :nWeight( _nWeight )
             ,nRange(100)
             ,nGlobalStart(0)
@@ -61,11 +58,9 @@ namespace dbmm
         }
     };
 
-    typedef ::std::map< PhaseID, PhaseData >   Phases;
+    typedef std::map< PhaseID, PhaseData >   Phases;
 
-    //====================================================================
-    //= ProgressMixer_Data
-    //====================================================================
+    // ProgressMixer_Data
     struct ProgressMixer_Data
     {
         Phases              aPhases;
@@ -74,7 +69,7 @@ namespace dbmm
         double              nOverallStretch;
         IProgressConsumer&  rConsumer;
 
-        ProgressMixer_Data( IProgressConsumer& _rConsumer )
+        explicit ProgressMixer_Data( IProgressConsumer& _rConsumer )
             :aPhases()
             ,pCurrentPhase( aPhases.end() )
             ,nWeightSum( 0 )
@@ -84,17 +79,13 @@ namespace dbmm
         }
     };
 
-    //--------------------------------------------------------------------
     namespace
     {
-#if OSL_DEBUG_LEVEL > 0
-        //----------------------------------------------------------------
         bool lcl_isRunning( const ProgressMixer_Data& _rData )
         {
             return _rData.pCurrentPhase != _rData.aPhases.end();
         }
-#endif
-        //----------------------------------------------------------------
+
         void lcl_ensureInitialized( ProgressMixer_Data& _rData )
         {
             OSL_PRECOND( _rData.nWeightSum, "lcl_ensureInitialized: we have no phases, this will crash!" );
@@ -106,37 +97,29 @@ namespace dbmm
 
             // tell the single phases their "overall starting point"
             PhaseWeight nRunningWeight( 0 );
-            for (   Phases::iterator phase = _rData.aPhases.begin();
-                    phase != _rData.aPhases.end();
-                    ++phase
-                )
+            for (auto & phase : _rData.aPhases)
             {
-                phase->second.nGlobalStart = (sal_uInt32)( nRunningWeight * _rData.nOverallStretch );
-                nRunningWeight += phase->second.nWeight;
+                phase.second.nGlobalStart = static_cast<sal_uInt32>( nRunningWeight * _rData.nOverallStretch );
+                nRunningWeight += phase.second.nWeight;
 
-                sal_uInt32 nNextPhaseStart = (sal_uInt32)( nRunningWeight * _rData.nOverallStretch );
-                phase->second.nGlobalRange = nNextPhaseStart - phase->second.nGlobalStart;
+                sal_uInt32 nNextPhaseStart = static_cast<sal_uInt32>( nRunningWeight * _rData.nOverallStretch );
+                phase.second.nGlobalRange = nNextPhaseStart - phase.second.nGlobalStart;
             }
 
             _rData.rConsumer.start( OVERALL_RANGE );
         }
     }
 
-    //====================================================================
-    //= ProgressMixer
-    //====================================================================
-    //--------------------------------------------------------------------
+    // ProgressMixer
     ProgressMixer::ProgressMixer( IProgressConsumer& _rConsumer )
         :m_pData( new ProgressMixer_Data( _rConsumer ) )
     {
     }
 
-    //--------------------------------------------------------------------
     ProgressMixer::~ProgressMixer()
     {
     }
 
-    //--------------------------------------------------------------------
     void ProgressMixer::registerPhase( const PhaseID _nID, const PhaseWeight _nWeight )
     {
         OSL_PRECOND( !lcl_isRunning( *m_pData ), "ProgressMixer::registerPhase: already running!" );
@@ -146,7 +129,6 @@ namespace dbmm
         m_pData->nWeightSum += _nWeight;
     }
 
-    //--------------------------------------------------------------------
     void ProgressMixer::startPhase( const PhaseID _nID, const sal_uInt32 _nPhaseRange )
     {
         OSL_ENSURE( m_pData->aPhases.find( _nID ) != m_pData->aPhases.end(),
@@ -156,7 +138,6 @@ namespace dbmm
         m_pData->pCurrentPhase = m_pData->aPhases.find( _nID );
     }
 
-    //--------------------------------------------------------------------
     void ProgressMixer::advancePhase( const sal_uInt32 _nPhaseProgress )
     {
         OSL_PRECOND( lcl_isRunning( *m_pData ), "ProgresMixer::advancePhase: not running!" );
@@ -168,13 +149,11 @@ namespace dbmm
         const PhaseData& rPhase( m_pData->pCurrentPhase->second );
 
         double nLocalProgress = 1.0 * _nPhaseProgress / rPhase.nRange;
-        sal_uInt32 nOverallProgress = (sal_uInt32)
-            ( rPhase.nGlobalStart + nLocalProgress * rPhase.nGlobalRange );
+        sal_uInt32 nOverallProgress = static_cast<sal_uInt32>( rPhase.nGlobalStart + nLocalProgress * rPhase.nGlobalRange );
 
         m_pData->rConsumer.advance( nOverallProgress );
     }
 
-    //--------------------------------------------------------------------
     void ProgressMixer::endPhase()
     {
         OSL_PRECOND( lcl_isRunning( *m_pData ), "ProgresMixer::endPhase: not running!" );
@@ -193,8 +172,6 @@ namespace dbmm
             m_pData->rConsumer.end();
     }
 
-//........................................................................
 } // namespace dbmm
-//........................................................................
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
