@@ -18,7 +18,7 @@
  */
 
 #include "dbtreeview.hxx"
-#include <svtools/treelistbox.hxx>
+#include <vcl/treelistbox.hxx>
 #include <dbtreelistbox.hxx>
 #include "dbtreemodel.hxx"
 #include <helpids.h>
@@ -50,18 +50,15 @@ DBTreeView::~DBTreeView()
 
 void DBTreeView::dispose()
 {
-    if (m_pTreeListBox)
-    {
-        if (m_pTreeListBox->GetModel())
-        {
-            m_pTreeListBox->GetModel()->RemoveView(m_pTreeListBox);
-            m_pTreeListBox->DisconnectFromModel();
-        }
-    }
     m_pTreeListBox.disposeAndClear();
     vcl::Window::dispose();
 }
 
+SvTreeList* DBTreeView::GetTreeModel()
+{
+    return m_pTreeListBox->GetModel();
+}
+
 void DBTreeView::SetPreExpandHandler(const Link<SvTreeListEntry*,bool>& _rHdl)
 {
     m_pTreeListBox->SetPreExpandHandler(_rHdl);
@@ -78,13 +75,6 @@ void DBTreeView::Resize()
     m_pTreeListBox->SetPosSizePixel(Point(0,0),GetOutputSizePixel());
 }
 
-void DBTreeView::setModel(SvTreeList* _pTreeModel)
-{
-    if (_pTreeModel)
-        _pTreeModel->InsertView(m_pTreeListBox);
-    m_pTreeListBox->SetModel(_pTreeModel);
-}
-
 void DBTreeView::setSelChangeHdl( const Link<LinkParamNone*,void>& _rHdl )
 {
     m_pTreeListBox->SetSelChangeHdl( _rHdl );
