@@ -21,9 +21,6 @@
 #include "DbAdminImpl.hxx"
 #include "tablespage.hxx"
 #include <dsitems.hxx>
-
-#include <propertysetitem.hxx>
-
 #include <dbu_dlg.hxx>
 
 namespace dbaui
@@ -41,16 +38,15 @@ OTableSubscriptionDialog::OTableSubscriptionDialog(vcl::Window* pParent
             ,const css::uno::Any& _aDataSourceName)
     : SfxSingleTabDialog(pParent, _pItems, "TablesFilterDialog",
         "dbaccess/ui/tablesfilterdialog.ui")
-    , m_pImpl( new ODbDataSourceAdministrationHelper( _rxORB, pParent, this ) )
+    , m_pImpl( new ODbDataSourceAdministrationHelper( _rxORB, GetFrameWeld(), pParent ? pParent->GetFrameWeld() : nullptr, this ) )
     , m_bStopExecution(false)
-    , m_pOutSet(_pItems)
 {
     m_pImpl->setDataSourceOrName(_aDataSourceName);
     Reference< XPropertySet > xDatasource = m_pImpl->getCurrentDataSource();
-    m_pOutSet = new SfxItemSet( *_pItems );
+    m_pOutSet.reset(new SfxItemSet( *_pItems ));
 
     m_pImpl->translateProperties(xDatasource, *m_pOutSet);
-    SetInputSet(m_pOutSet);
+    SetInputSet(m_pOutSet.get());
 
     VclPtrInstance<OTableSubscriptionPage> pTabPage(get_content_area(), *m_pOutSet, this);
     pTabPage->SetServiceFactory(_rxORB);
@@ -64,7 +60,7 @@ OTableSubscriptionDialog::~OTableSubscriptionDialog()
 
 void OTableSubscriptionDialog::dispose()
 {
-    delete m_pOutSet;
+    m_pOutSet.reset();
     SfxSingleTabDialog::dispose();
 }
 
@@ -110,12 +106,12 @@ Reference< XPropertySet > const & OTableSubscriptionDialog::getCurrentDataSource
 
 const SfxItemSet* OTableSubscriptionDialog::getOutputSet() const
 {
-    return m_pOutSet;
+    return m_pOutSet.get();
 }
 
 SfxItemSet* OTableSubscriptionDialog::getWriteOutputSet()
 {
-    return m_pOutSet;
+    return m_pOutSet.get();
 }
 
 }   // namespace dbaui
