@@ -32,7 +32,6 @@
 #include <dsitems.hxx>
 #include "dsnItem.hxx"
 #include "optionalboolitem.hxx"
-#include <propertysetitem.hxx>
 #include <stringlistitem.hxx>
 
 #include <unotools/confignode.hxx>
@@ -47,59 +46,45 @@ using namespace com::sun::star::beans;
 using namespace com::sun::star::container;
 
 // ODbAdminDialog
-ODbAdminDialog::ODbAdminDialog(vcl::Window* _pParent
-                               , SfxItemSet const * _pItems
-                               , const Reference< XComponentContext >& _rxContext)
-    : SfxTabDialog(_pParent, "AdminDialog",
-        "dbaccess/ui/admindialog.ui", _pItems)
-    , m_bUIEnabled(true)
+ODbAdminDialog::ODbAdminDialog(weld::Window* pParent,
+                               SfxItemSet const * _pItems,
+                               const Reference< XComponentContext >& _rxContext)
+    : SfxTabDialogController(pParent, "dbaccess/ui/admindialog.ui", "AdminDialog", _pItems)
+    , m_sMainPageID("advanced")
 {
-    m_pImpl.reset(new ODbDataSourceAdministrationHelper(_rxContext,this,this));
+    m_pImpl.reset(new ODbDataSourceAdministrationHelper(_rxContext, m_xDialog.get(), pParent, this));
 
     // add the initial tab page
-    m_nMainPageID = AddTabPage("advanced", OConnectionTabPage::Create, nullptr);
+    AddTabPage(m_sMainPageID, OConnectionTabPage::Create, nullptr);
 
     // remove the reset button - it's meaning is much too ambiguous in this dialog
     RemoveResetButton();
 }
 
 ODbAdminDialog::~ODbAdminDialog()
-{
-    disposeOnce();
-}
-
-void ODbAdminDialog::dispose()
 {
     SetInputSet(nullptr);
-    DELETEZ(m_pExampleSet);
-    SfxTabDialog::dispose();
 }
 
 short ODbAdminDialog::Ok()
 {
-    SfxTabDialog::Ok();
-    m_bUIEnabled = false;
+    SfxTabDialogController::Ok();
     return ( AR_LEAVE_MODIFIED == implApplyChanges() ) ? RET_OK : RET_CANCEL;
         // TODO : AR_ERROR is not handled correctly, we always close the dialog here
 }
 
-void ODbAdminDialog::PageCreated(sal_uInt16 _nId, SfxTabPage& _rPage)
+void ODbAdminDialog::PageCreated(const OString& rId, SfxTabPage& _rPage)
 {
     // register ourself as modified listener
     static_cast<OGenericAdministrationPage&>(_rPage).SetServiceFactory( getORB() );
     static_cast<OGenericAdministrationPage&>(_rPage).SetAdminDialog(this,this);
 
-    vcl::Window *pWin = GetViewWindow();
-    if(pWin)
-        pWin->Invalidate();
-
-    SfxTabDialog::PageCreated(_nId, _rPage);
+    SfxTabDialogController::PageCreated(rId, _rPage);
 }
 
-void ODbAdminDialog::addDetailPage(sal_uInt16 _nPageId, const char* pTextId, CreateTabPage _pCreateFunc)
+void ODbAdminDialog::addDetailPage(const OString& rPageId, const char* pTextId, CreateTabPage pCreateFunc)
 {
-    AddTabPage(_nPageId, DBA_RES(pTextId), _pCreateFunc, nullptr);
-    m_aCurrentDetailPages.push(_nPageId);
+    AddTabPage(rPageId, DBA_RES(pTextId), pCreateFunc);
 }
 
 void ODbAdminDialog::impl_selectDataSource(const css::uno::Any& _aDataSourceName)
@@ -116,35 +101,35 @@ void ODbAdminDialog::impl_selectDataSource(const css::uno::Any& _aDataSourceName
     switch ( eType )
     {
         case  ::dbaccess::DST_DBASE:
-            addDetailPage(PAGE_DBASE, STR_PAGETITLE_ADVANCED, ODriversSettings::CreateDbase);
+            addDetailPage("dbase", STR_PAGETITLE_ADVANCED, ODriversSettings::CreateDbase);
             break;
 
         case  ::dbaccess::DST_ADO:
-            addDetailPage(PAGE_ADO, STR_PAGETITLE_ADVANCED, ODriversSettings::CreateAdo);
+            addDetailPage("ado", STR_PAGETITLE_ADVANCED, ODriversSettings::CreateAdo);
             break;
 
         case  ::dbaccess::DST_FLAT:
-            addDetailPage(PAGE_TEXT, STR_PAGETITLE_ADVANCED, ODriversSettings::CreateText);
+            addDetailPage("text", STR_PAGETITLE_ADVANCED, ODriversSettings::CreateText);
             break;
 
         case  ::dbaccess::DST_ODBC:
-            addDetailPage(PAGE_ODBC, STR_PAGETITLE_ADVANCED, ODriversSettings::CreateODBC);
+            addDetailPage("odbc", STR_PAGETITLE_ADVANCED, ODriversSettings::CreateODBC);
             break;
 
         case  ::dbaccess::DST_MYSQL_ODBC:
-            addDetailPage(PAGE_MYSQL_ODBC, STR_PAGETITLE_ADVANCED, ODriversSettings::CreateMySQLODBC);
+            addDetailPage("mysqlodbc", STR_PAGETITLE_ADVANCED, ODriversSettings::CreateMySQLODBC);
             break;
 
         case  ::dbaccess::DST_MYSQL_JDBC:
-            addDetailPage(PAGE_MYSQL_JDBC, STR_PAGETITLE_ADVANCED, ODriversSettings::CreateMySQLJDBC);
+            addDetailPage("mysqljdbc", STR_PAGETITLE_ADVANCED, ODriversSettings::CreateMySQLJDBC);
             break;
 
         case  ::dbaccess::DST_ORACLE_JDBC:
-            addDetailPage(PAGE_ORACLE_JDBC, STR_PAGETITLE_ADVANCED, ODriversSettings::CreateOracleJDBC);
+            addDetailPage("oraclejdbc", STR_PAGETITLE_ADVANCED, ODriversSettings::CreateOracleJDBC);
             break;
 
         case  ::dbaccess::DST_LDAP:
-            addDetailPage(PAGE_LDAP,STR_PAGETITLE_ADVANCED,ODriversSettings::CreateLDAP);
+            addDetailPage("ldap",STR_PAGETITLE_ADVANCED,ODriversSettings::CreateLDAP);
             break;
         case  ::dbaccess::DST_USERDEFINE1:  /// first user defined driver
         case  ::dbaccess::DST_USERDEFINE2:
@@ -158,8 +143,7 @@ void ODbAdminDialog::impl_selectDataSource(const css::uno::Any& _aDataSourceName
         case  ::dbaccess::DST_USERDEFINE10:
             {
                 OUString aTitle(DBA_RES(STR_PAGETITLE_ADVANCED));
-                AddTabPage(PAGE_USERDRIVER, aTitle, ODriversSettings::CreateUser, nullptr, 1);
-                m_aCurrentDetailPages.push(PAGE_USERDRIVER);
+                AddTabPage("user" + OString(static_cast<int>(eType)), aTitle, ODriversSettings::CreateUser);
             }
             break;
         default:
@@ -177,7 +161,7 @@ void ODbAdminDialog::impl_resetPages(const Reference< XPropertySet >& _rxDatasou
     // reset the pages
 
     // prevent flicker
-    SetUpdateMode(false);
+    m_xDialog->freeze();
 
     // remove all items which relate to indirect properties from the input set
     // (without this, the following may happen: select an arbitrary data source where some indirect properties
@@ -191,33 +175,33 @@ void ODbAdminDialog::impl_resetPages(const Reference< XPropertySet >& _rxDatasou
     m_pImpl->translateProperties(_rxDatasource, *GetInputSetImpl());
 
     // reset the example set
-    delete m_pExampleSet;
-    m_pExampleSet = new SfxItemSet(*GetInputSetImpl());
+    m_xExampleSet.reset(new SfxItemSet(*GetInputSetImpl()));
 
     // special case: MySQL Native does not have the generic "advanced" page
 
     const DbuTypeCollectionItem& rCollectionItem = dynamic_cast<const DbuTypeCollectionItem&>(*getOutputSet()->GetItem(DSID_TYPECOLLECTION));
     ::dbaccess::ODsnTypeCollection* pCollection = rCollectionItem.getCollection();
-    if ( pCollection->determineType(getDatasourceType( *m_pExampleSet )) == ::dbaccess::DST_MYSQL_NATIVE )
+    if ( pCollection->determineType(getDatasourceType( *m_xExampleSet )) == ::dbaccess::DST_MYSQL_NATIVE )
     {
-        AddTabPage( PAGE_MYSQL_NATIVE, DBA_RES(STR_PAGETITLE_CONNECTION), ODriversSettings::CreateMySQLNATIVE, nullptr );
+        OString sMySqlNative("mysqlnative");
+        AddTabPage(sMySqlNative, DBA_RES(STR_PAGETITLE_CONNECTION), ODriversSettings::CreateMySQLNATIVE);
         RemoveTabPage("advanced");
-        m_nMainPageID = PAGE_MYSQL_NATIVE;
+        m_sMainPageID = sMySqlNative;
     }
 
-    ShowPage( m_nMainPageID );
-    SfxTabPage* pConnectionPage = GetTabPage( m_nMainPageID );
+    SetCurPageId(m_sMainPageID);
+    SfxTabPage* pConnectionPage = GetTabPage(m_sMainPageID);
     if ( pConnectionPage )
         pConnectionPage->Reset(GetInputSetImpl());
     // if this is NULL, the page has not been created yet, which means we're called before the
     // dialog was displayed (probably from inside the ctor)
 
-    SetUpdateMode(true);
+    m_xDialog->thaw();
 }
 
-void ODbAdminDialog::setTitle(const OUString& _sTitle)
+void ODbAdminDialog::setTitle(const OUString& rTitle)
 {
-    SetText(_sTitle);
+    m_xDialog->set_title(rTitle);
 }
 
 void ODbAdminDialog::enableConfirmSettings( bool ) {}
@@ -234,15 +218,9 @@ ODbAdminDialog::ApplyResult ODbAdminDialog::implApplyChanges()
         return AR_KEEP;
     }
 
-    if ( !m_pImpl->saveChanges(*m_pExampleSet) )
+    if ( !m_pImpl->saveChanges(*m_xExampleSet) )
         return AR_KEEP;
 
-    if ( m_bUIEnabled )
-        ShowPage(GetCurPageId());
-        // This does the usual ActivatePage, so the pages can save their current status.
-        // This way, next time they're asked what has changed since now and here, they really
-        // can compare with the status they have _now_ (not the one they had before this apply call).
-
     return AR_LEAVE_MODIFIED;
 }
 
@@ -258,7 +236,7 @@ const SfxItemSet* ODbAdminDialog::getOutputSet() const
 
 SfxItemSet* ODbAdminDialog::getWriteOutputSet()
 {
-    return m_pExampleSet;
+    return m_xExampleSet.get();
 }
 
 std::pair< Reference<XConnection>,bool> ODbAdminDialog::createConnection()
@@ -286,7 +264,7 @@ void ODbAdminDialog::clearPassword()
     m_pImpl->clearPassword();
 }
 
-SfxItemSet* ODbAdminDialog::createItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rpPool, std::vector<SfxPoolItem*>*& _rpDefaults, ::dbaccess::ODsnTypeCollection* _pTypeCollection)
+void ODbAdminDialog::createItemSet(std::unique_ptr<SfxItemSet>& _rpSet, SfxItemPool*& _rpPool, std::vector<SfxPoolItem*>*& _rpDefaults, ::dbaccess::ODsnTypeCollection* _pTypeCollection)
 {
     // just to be sure ....
     _rpSet = nullptr;
@@ -321,7 +299,6 @@ SfxItemSet* ODbAdminDialog::createItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rp
     *pCounter++ = new SfxBoolItem(DSID_PARAMETERNAMESUBST, false);
     *pCounter++ = new SfxInt32Item(DSID_CONN_PORTNUMBER, 8100);
     *pCounter++ = new SfxBoolItem(DSID_SUPPRESSVERSIONCL, false);
-    *pCounter++ = new OPropertySetItem(DSID_DATASOURCE_UNO);
     *pCounter++ = new SfxBoolItem(DSID_CONN_SHUTSERVICE, false);
     *pCounter++ = new SfxInt32Item(DSID_CONN_DATAINC, 20);
     *pCounter++ = new SfxInt32Item(DSID_CONN_CACHESIZE, 20);
@@ -422,7 +399,6 @@ SfxItemSet* ODbAdminDialog::createItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rp
         {0,false},
         {0,false},
         {0,false},
-        {0,false}
     };
 
     OSL_ENSURE(SAL_N_ELEMENTS(aItemInfos) == DSID_LAST_ITEM_ID,"Invalid Ids!");
@@ -431,19 +407,13 @@ SfxItemSet* ODbAdminDialog::createItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rp
     _rpPool->FreezeIdRanges();
 
     // and, finally, the set
-    _rpSet = new SfxItemSet(*_rpPool);
-
-    return _rpSet;
+    _rpSet.reset(new SfxItemSet(*_rpPool));
 }
 
-void ODbAdminDialog::destroyItemSet(SfxItemSet*& _rpSet, SfxItemPool*& _rpPool, std::vector<SfxPoolItem*>*& _rpDefaults)
+void ODbAdminDialog::destroyItemSet(std::unique_ptr<SfxItemSet>& _rpSet, SfxItemPool*& _rpPool, std::vector<SfxPoolItem*>*& _rpDefaults)
 {
     // _first_ delete the set (referring the pool)
-    if (_rpSet)
-    {
-        delete _rpSet;
-        _rpSet = nullptr;
-    }
+    _rpSet.reset();
 
     // delete the pool
     if (_rpPool)
