@@ -20,24 +20,22 @@
 #include <drawinglayer/primitive3d/groupprimitive3d.hxx>
 #include <drawinglayer/primitive3d/drawinglayer_primitivetypes3d.hxx>
 
-//////////////////////////////////////////////////////////////////////////////
 
 using namespace com::sun::star;
 
-//////////////////////////////////////////////////////////////////////////////
 
 namespace drawinglayer
 {
     namespace primitive3d
     {
-        GroupPrimitive3D::GroupPrimitive3D( const Primitive3DSequence& rChildren )
+        GroupPrimitive3D::GroupPrimitive3D( const Primitive3DContainer& rChildren )
         :   BasePrimitive3D(),
             maChildren(rChildren)
         {
         }
 
         /** The compare opertator uses the Sequence::==operator, so only checking if
-            the rererences are equal. All non-equal references are interpreted as
+            the references are equal. All non-equal references are interpreted as
             non-equal.
          */
         bool GroupPrimitive3D::operator==( const BasePrimitive3D& rPrimitive ) const
@@ -46,14 +44,14 @@ namespace drawinglayer
             {
                 const GroupPrimitive3D& rCompare = static_cast< const GroupPrimitive3D& >(rPrimitive);
 
-                return (arePrimitive3DSequencesEqual(getChildren(), rCompare.getChildren()));
+                return getChildren() == rCompare.getChildren();
             }
 
             return false;
         }
 
-        /// default: just return children, so all renderers not supporting group will use it's content
-        Primitive3DSequence GroupPrimitive3D::get3DDecomposition(const geometry::ViewInformation3D& /*rViewInformation*/) const
+        /// default: just return children, so all renderers not supporting group will use its content
+        Primitive3DContainer GroupPrimitive3D::get3DDecomposition(const geometry::ViewInformation3D& /*rViewInformation*/) const
         {
             return getChildren();
         }
