@@ -20,6 +20,7 @@
 #include <cppuhelper/factory.hxx>
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/container/XSet.hpp>
+#include <com/sun/star/lang/XSingleServiceFactory.hpp>
 
 #include "source.hxx"
 #include "target.hxx"
@@ -29,13 +30,13 @@ using namespace ::com::sun::star::registry  ;
 using namespace ::cppu                      ;
 using namespace ::com::sun::star::lang;
 
-Reference< XInterface > createDragSource( const Reference< XMultiServiceFactory >& rServiceManager )
+static Reference< XInterface > createDragSource( const Reference< XMultiServiceFactory >& rServiceManager )
 {
     DragSource* pSource= new DragSource( comphelper::getComponentContext(rServiceManager) );
     return Reference<XInterface>( static_cast<XInitialization*>(pSource), UNO_QUERY);
 }
 
-Reference< XInterface > createDropTarget( const Reference< XMultiServiceFactory >& rServiceManager )
+static Reference< XInterface > createDropTarget( const Reference< XMultiServiceFactory >& rServiceManager )
 {
     DropTarget* pTarget= new DropTarget( comphelper::getComponentContext(rServiceManager) );
     return Reference<XInterface>( static_cast<XInitialization*>(pTarget), UNO_QUERY);
