@@ -17,25 +17,17 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#ifndef _PLATFORM_H_
-#define _PLATFORM_H_
+#ifndef INCLUDED_EMBEDDEDOBJ_SOURCE_MSOLE_PLATFORM_H
+#define INCLUDED_EMBEDDEDOBJ_SOURCE_MSOLE_PLATFORM_H
 
 #define STRICT
-#ifndef _WIN32_WINNT
-#define _WIN32_WINNT 0x0400
-#endif
 #define _ATL_APARTMENT_THREADED
 
-#if defined _MSC_VER
-#pragma warning(push, 1)
-#pragma warning(disable: 4548 4555 4917)
-#endif
-
-#include "windows.h"
-
-#if defined _MSC_VER
-#pragma warning(pop)
+#if !defined WIN32_LEAN_AND_MEAN
+# define WIN32_LEAN_AND_MEAN
 #endif
+#include <windows.h>
+#include <ole2.h>
 
 #endif
 
