@@ -25,6 +25,7 @@
 #include <osl/diagnose.h>
 #include <osl/mutex.hxx>
 #include <osl/thread.h>
+#include <sal/log.hxx>
 
 using namespace com::sun::star;
 
@@ -77,7 +78,7 @@ void *CurThreadData::getData()
     return osl_getThreadKeyData(m_hKey);
 }
 
-void o2u_attachCurrentThread()
+static void o2u_attachCurrentThread()
 {
     static CurThreadData oleThreadData;
 
