@@ -381,15 +381,11 @@ namespace pcr
             if ( xDocumentFactory.is() )
                 aAvailableServices = xDocumentFactory->getAvailableServiceNames( );
 
-            const OUString* pFound = std::find_if(
+            bYesItIs = std::any_of(
                 aAvailableServices.begin(),
                 aAvailableServices.end(),
                 StringCompare( _rService )
             );
-            if ( pFound != aAvailableServices.end() )
-            {
-                bYesItIs = true;
-            }
         }
 
         return bYesItIs;
