@@ -31,15 +31,8 @@
 #include <o3tl/char16_t2wchar_t.hxx>
 
 #ifdef _WIN32
-#ifdef _MSC_VER
-#pragma warning(push,1) // disable warnings within system headers
-#pragma warning(disable: 4917)
-#endif
 #include <objbase.h>
 #include <shlobj.h>
-#ifdef _MSC_VER
-#pragma warning(pop)
-#endif
 #endif
 
 namespace container = com::sun::star::container ;
@@ -157,7 +150,7 @@ UpdateCheckROModel::getUpdateEntry(UpdateInfo& rInfo) const
         OUString aUStr = getStringValue(
             OString(OStringLiteral(RELEASE_NOTE) + OString::number(n)).getStr());
         if( !aUStr.isEmpty() )
-            rInfo.ReleaseNotes.push_back(ReleaseNote((sal_Int8) n, aUStr));
+            rInfo.ReleaseNotes.push_back(ReleaseNote(static_cast<sal_Int8>(n), aUStr));
     }
 }
 
