@@ -21,14 +21,12 @@
 #include "constant.hxx"
 #include <cppuhelper/supportsservice.hxx>
 
-#include <osl/diagnose.h>
 
 namespace filter{
     namespace config{
 
-ConfigFlush::ConfigFlush(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR)
+ConfigFlush::ConfigFlush()
     : BaseLock   (       )
-    , m_xSMGR    (xSMGR  )
     , m_lListener(m_aLock)
 {
 }
@@ -38,31 +36,27 @@ ConfigFlush::~ConfigFlush()
 }
 
 OUString SAL_CALL ConfigFlush::getImplementationName()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return impl_getImplementationName();
     // <- SAFE
 }
 
 sal_Bool SAL_CALL ConfigFlush::supportsService(const OUString& sServiceName)
-    throw (css::uno::RuntimeException, std::exception)
 {
     return cppu::supportsService(this, sServiceName);
 }
 
 css::uno::Sequence< OUString > SAL_CALL ConfigFlush::getSupportedServiceNames()
-    throw (css::uno::RuntimeException, std::exception)
 {
     return impl_getSupportedServiceNames();
 }
 
 void SAL_CALL ConfigFlush::refresh()
-    throw(css::uno::RuntimeException, std::exception)
 {
     // notify listener outside the lock!
     // The used listener helper lives if we live
     // and is threadsafe by itself.
-    // Further its not a good idea to hold the own lock
+    // Further it's not a good idea to hold the own lock
     // if an outside object is called :-)
     css::lang::EventObject             aSource    (static_cast< css::util::XRefreshable* >(this));
     ::cppu::OInterfaceContainerHelper* pContainer = m_lListener.getContainer(cppu::UnoType<css::util::XRefreshListener>::get());
@@ -74,7 +68,7 @@ void SAL_CALL ConfigFlush::refresh()
             try
             {
                 // ... this pointer can be interesting to find out, where will be called as listener
-                // Dont optimize it to a direct iterator cast :-)
+                // Don't optimize it to a direct iterator cast :-)
                 css::util::XRefreshListener* pListener = static_cast<css::util::XRefreshListener*>(pIterator.next());
                 pListener->refreshed(aSource);
             }
@@ -90,7 +84,6 @@ void SAL_CALL ConfigFlush::refresh()
 
 
 void SAL_CALL ConfigFlush::addRefreshListener(const css::uno::Reference< css::util::XRefreshListener >& xListener)
-    throw(css::uno::RuntimeException, std::exception)
 {
     // no locks necessary
     // used helper lives if we live and is threadsafe by itself ...
@@ -100,7 +93,6 @@ void SAL_CALL ConfigFlush::addRefreshListener(const css::uno::Reference< css::ut
 
 
 void SAL_CALL ConfigFlush::removeRefreshListener(const css::uno::Reference< css::util::XRefreshListener >& xListener)
-    throw(css::uno::RuntimeException, std::exception)
 {
     // no locks necessary
     // used helper lives if we live and is threadsafe by itself ...
@@ -117,15 +109,13 @@ OUString ConfigFlush::impl_getImplementationName()
 
 css::uno::Sequence< OUString > ConfigFlush::impl_getSupportedServiceNames()
 {
-    css::uno::Sequence< OUString > lServiceNames(1);
-    lServiceNames[0] = "com.sun.star.document.FilterConfigRefresh";
-    return lServiceNames;
+    return { "com.sun.star.document.FilterConfigRefresh" };
 }
 
 
-css::uno::Reference< css::uno::XInterface > ConfigFlush::impl_createInstance(const css::uno::Reference< css::lang::XMultiServiceFactory >& xSMGR)
+css::uno::Reference< css::uno::XInterface > ConfigFlush::impl_createInstance(const css::uno::Reference< css::lang::XMultiServiceFactory >& )
 {
-    ConfigFlush* pNew = new ConfigFlush(xSMGR);
+    ConfigFlush* pNew = new ConfigFlush;
     return css::uno::Reference< css::uno::XInterface >(static_cast< css::util::XRefreshable* >(pNew), css::uno::UNO_QUERY);
 }
 
