@@ -23,6 +23,8 @@
 #include <com/sun/star/ui/dialogs/ExtendedFilePickerElementIds.hpp>
 #include <com/sun/star/ui/dialogs/CommonFilePickerElementIds.hpp>
 #include <com/sun/star/ui/dialogs/ControlActions.hpp>
+#include <sal/log.hxx>
+#include <osl/diagnose.h>
 #include <vcl/lstbox.hxx>
 #include <com/sun/star/uno/Sequence.hxx>
 #include <tools/urlobj.hxx>
