@@ -65,7 +65,6 @@ JobURL::JobURL( /*IN*/ const OUString& sURL )
             {
                 // set the part value
                 m_sEvent     = sPartValue;
-                m_sEventArgs = sPartArguments;
                 m_eRequest  |= E_EVENT;
             }
             else
@@ -77,7 +76,6 @@ JobURL::JobURL( /*IN*/ const OUString& sURL )
             {
                 // set the part value
                 m_sAlias     = sPartValue;
-                m_sAliasArgs = sPartArguments;
                 m_eRequest  |= E_ALIAS;
             }
             else
@@ -89,7 +87,6 @@ JobURL::JobURL( /*IN*/ const OUString& sURL )
             {
                 // set the part value
                 m_sService     = sPartValue;
-                m_sServiceArgs = sPartArguments;
                 m_eRequest    |= E_SERVICE;
             }
         }
@@ -112,7 +109,7 @@ bool JobURL::isValid() const
     @short      get the event item of this job URL
     @descr      Because the three possible parts of such URL (event, alias, service)
                 can't be combined, this method can(!) return a valid value - but it's
-                not a must. Thats why the return value must be used too, to detect a missing
+                not a must. That's why the return value must be used too, to detect a missing
                 event value.
 
     @param      sEvent
@@ -122,7 +119,7 @@ bool JobURL::isValid() const
     @return     <TRUE/> if an event part of the job URL exist and the out parameter
                 sEvent was filled.
 
-    @attention  The out parameter will be reseted every time. Don't use it if method returns <FALSE/>!
+    @attention  The out parameter will be reset every time. Don't use it if method returns <FALSE/>!
 */
 bool JobURL::getEvent( /*OUT*/ OUString& sEvent ) const
 {
@@ -140,7 +137,7 @@ bool JobURL::getEvent( /*OUT*/ OUString& sEvent ) const
     @short      get the alias item of this job URL
     @descr      Because the three possible parts of such URL (event, alias, service)
                 can't be combined, this method can(!) return a valid value - but it's
-                not a must. Thats why the return value must be used too, to detect a missing
+                not a must. that's why the return value must be used too, to detect a missing
                 alias value.
 
     @param      sAlias
@@ -150,7 +147,7 @@ bool JobURL::getEvent( /*OUT*/ OUString& sEvent ) const
     @return     <TRUE/> if an alias part of the job URL exist and the out parameter
                 sAlias was filled.
 
-    @attention  The out parameter will be reseted every time. Don't use it if method returns <FALSE/>!
+    @attention  The out parameter will be reset every time. Don't use it if method returns <FALSE/>!
 */
 bool JobURL::getAlias( /*OUT*/ OUString& sAlias ) const
 {
@@ -168,7 +165,7 @@ bool JobURL::getAlias( /*OUT*/ OUString& sAlias ) const
     @short      get the service item of this job URL
     @descr      Because the three possible parts of such URL (event, service, service)
                 can't be combined, this method can(!) return a valid value - but it's
-                not a must. Thats why the return value must be used too, to detect a missing
+                not a must. That's why the return value must be used too, to detect a missing
                 service value.
 
     @param      sAlias
@@ -178,7 +175,7 @@ bool JobURL::getAlias( /*OUT*/ OUString& sAlias ) const
     @return     <TRUE/> if an service part of the job URL exist and the out parameter
                 sService was filled.
 
-    @attention  The out parameter will be reseted every time. Don't use it if method returns <FALSE/>!
+    @attention  The out parameter will be reset every time. Don't use it if method returns <FALSE/>!
 */
 bool JobURL::getService( /*OUT*/ OUString& sService ) const
 {
@@ -209,12 +206,12 @@ bool JobURL::getService( /*OUT*/ OUString& sService ) const
                     the length of the ascii value <var>pPartIdentifier</var>
 
     @param      rPartValue
-                    returns the part value if <var>sPart</var> was splitted successfully
+                    returns the part value if <var>sPart</var> was split successfully
 
     @param      rPartArguments
-                    returns the part arguments if <var>sPart</var> was splitted successfully
+                    returns the part arguments if <var>sPart</var> was split successfully
 
-    @return     <TRUE/> if the identifier could be found and the string was splitted.
+    @return     <TRUE/> if the identifier could be found and the string was split.
                 <FALSE/> otherwise.
 */
 bool JobURL::implst_split( /*IN*/  const OUString& sPart           ,
@@ -224,10 +221,10 @@ bool JobURL::implst_split( /*IN*/  const OUString& sPart           ,
                                /*OUT*/       OUString& rPartArguments  )
 {
     // first search for the given identifier
-    bool bPartFound = (sPart.matchIgnoreAsciiCaseAsciiL(pPartIdentifier,nPartLength));
+    bool bPartFound = sPart.matchIgnoreAsciiCaseAsciiL(pPartIdentifier,nPartLength);
 
     // If it exist - we can split the part and return sal_True.
-    // Otherwhise we do nothing and return sal_False.
+    // Otherwise we do nothing and return sal_False.
     if (bPartFound)
     {
         // But may the part has optional arguments - separated by a "?".
