@@ -41,7 +41,7 @@ ignoreWidth::transliterateRange( const OUString& str1, const OUString& str2 )
     rtl::Reference< fullwidthToHalfwidth > t1(new fullwidthToHalfwidth);
     rtl::Reference< halfwidthToFullwidth > t2(new halfwidthToFullwidth);
 
-    return transliteration_Ignore::transliterateRange(str1, str2, *t1.get(), *t2.get());
+    return transliteration_Ignore::transliterateRange(str1, str2, *t1, *t2);
 }
 
 sal_Unicode SAL_CALL
