@@ -1,3 +1,4 @@
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  * This file is part of the LibreOffice project.
  *
@@ -135,8 +136,8 @@ public class FactoryHelper {
                 }
             }
 
-            if(_constructor == null) // have not found a useable constructor
-                throw new com.sun.star.uno.RuntimeException(getClass().getName() + " can not find a useable constructor");
+            if(_constructor == null) // have not found a usable constructor
+                throw new com.sun.star.uno.RuntimeException(getClass().getName() + " can not find a usable constructor");
         }
 
         private final XMultiServiceFactory getSMgr( XComponentContext xContext )
@@ -497,3 +498,4 @@ public class FactoryHelper {
 
 }
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
