@@ -1,3 +1,4 @@
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*
  * This file is part of the LibreOffice project.
  *
@@ -18,17 +19,14 @@
 
 package com.sun.star.uno;
 
-import com.sun.star.uno.XWeak;
-import com.sun.star.uno.UnoRuntime;
-import com.sun.star.uno.XAdapter;
-import com.sun.star.uno.XReference;
-
-/** This class holds weak reference to an object. It actually holds a reference to a
-    com.sun.star.XAdapter implementation and obtains a hard reference if necessary.
+/**
+ * This class holds weak reference to an object.
+ *
+ * <p>It actually holds a reference to a <code>com.sun.star.XAdapter</code>
+ * implementation and obtains a hard reference if necessary.
  */
 public class WeakReference
 {
-    private final boolean DEBUG= false;
     private OWeakRefListener m_listener;
     // There is no default constructor. Every instance must register itself with the
     // XAdapter interface, which is done in the constructors. Assume we have this code
@@ -36,32 +34,35 @@ public class WeakReference
     // ref = someOtherWeakReference;
     //
     // ref would not be notified (XReference.dispose()) because it did not register
-    // itself. Therefore the XAdapter would be kept aliver although this is not
+    // itself. Therefore the XAdapter would be kept alive although this is not
     // necessary.
 
-    /** Creates an instance of this class.
-     *@param obj - another instance that is to be copied
+    /**
+     * Creates an instance of this class.
+     *
+     * @param obj another instance that is to be copied.
      */
     public WeakReference(WeakReference obj)
     {
-        if (obj != null)
-        {
-            Object weakImpl= obj.get();
-            if (weakImpl != null)
-            {
-                XWeak weak= UnoRuntime.queryInterface(XWeak.class, weakImpl);
-                if (weak != null)
-                {
-                    XAdapter adapter= weak.queryAdapter();
-                    if (adapter != null)
-                        m_listener= new OWeakRefListener(adapter);
-                }
-            }
+        if (obj == null) {
+            return;
+        }
+        Object weakImpl = obj.get();
+        if (weakImpl == null) {
+            return;
+        }
+        XWeak weak = UnoRuntime.queryInterface(XWeak.class, weakImpl);
+        if (weak != null) {
+            XAdapter adapter = weak.queryAdapter();
+            if (adapter != null)
+                m_listener = new OWeakRefListener(adapter);
         }
     }
 
-    /** Creates an instance of this class.
-     *@param obj XWeak implementation
+    /**
+     * Creates an instance of this class.
+     *
+     * @param obj XWeak implementation.
      */
     public WeakReference(Object obj)
     {
@@ -73,8 +74,11 @@ public class WeakReference
                 m_listener= new OWeakRefListener(adapter);
         }
     }
-    /** Returns a hard reference to the object that is kept weak by this class.
-     *@return a hard reference to the XWeak implementation.
+
+    /**
+     * Returns a hard reference to the object that is kept weak by this class.
+     *
+     * @return a hard reference to the XWeak implementation.
      */
     public Object get()
     {
@@ -84,25 +88,33 @@ public class WeakReference
     }
 }
 
-/** Implementation of com.sun.star.uno.XReference for use with WeakReference.
- *  It keeps the XAdapter implementation and registers always with it. Deregistering
- *  occurs on notification by the adapter and the adapter is released.
+/**
+ * Implementation of com.sun.star.uno.XReference for use with WeakReference.
+ *
+ * <p>It keeps the XAdapter implementation and registers always with it.
+ * Deregistering occurs on notification by the adapter and the adapter is
+ * released.</p>
  */
 class OWeakRefListener implements XReference
 {
-    private final boolean DEBUG= false;
     private XAdapter m_adapter;
 
-    /** The constructor registered this object with adapter.
-     *@param adapter the XAdapter implementation.
+    /**
+     * The constructor registered this object with adapter.
+     *
+     * @param adapter the XAdapter implementation.
      */
     OWeakRefListener( XAdapter adapter)
     {
         m_adapter= adapter;
         m_adapter.addReference(this);
     }
-    /** Method of com.sun.star.uno.XReference. When called, it deregisteres this
-     *  object with the adapter and releases the reference to it.
+
+    /**
+     * Method of <code>com.sun.star.uno.XReference</code>.
+     *
+     * <p>When called, it deregisters this object with the adapter and releases
+     * the reference to it.</p>
      */
     synchronized public void dispose()
     {
@@ -113,9 +125,11 @@ class OWeakRefListener implements XReference
         }
     }
 
-    /** Obtains a hard reference to the object which is kept weak by the adapter
-     *  and returns it.
-     *  @return hard reference to the otherwise weakly kept object.
+    /**
+     * Obtains a hard reference to the object which is kept weak by the adapter
+     * and returns it.
+     *
+     * @return hard reference to the otherwise weakly kept object.
      */
     synchronized Object get()
     {
@@ -136,3 +150,5 @@ class OWeakRefListener implements XReference
         return retVal;
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
