@@ -20,6 +20,7 @@
 #include <rtl/ustring.hxx>
 #include <rtl/ustrbuf.hxx>
 #include <rtl/uri.hxx>
+#include <sal/log.hxx>
 #include <osl/thread.hxx>
 #include <osl/process.h>
 #include <libxml/xpathInternals.h>
@@ -28,7 +29,7 @@
 #include "framework.hxx"
 #include <fwkutil.hxx>
 #include <elements.hxx>
-#include <fwkbase.hxx>
+#include "fwkbase.hxx"
 
 using namespace osl;
 
@@ -116,23 +117,11 @@ VendorSettings::VendorSettings():
     }
 }
 
-boost::optional<VersionInfo> VendorSettings::getVersionInformation(const OUString & sVendor) const
+VersionInfo VendorSettings::getVersionInformation(const OUString & sVendor) const
 {
     OSL_ASSERT(!sVendor.isEmpty());
-    OString osVendor = OUStringToOString(sVendor, RTL_TEXTENCODING_UTF8);
-    CXPathObjectPtr pathObject;
-    pathObject = xmlXPathEvalExpression(
-        reinterpret_cast<xmlChar const *>(
-            OString(
-                "/jf:javaSelection/jf:vendorInfos/jf:vendor[@name=\"" + osVendor
-                + "\"]/jf:minVersion").getStr()),
-        m_xmlPathContextVendorSettings);
-    if (xmlXPathNodeSetIsEmpty(pathObject->nodesetval))
-    {
-        return {};
-    }
-
     VersionInfo aVersionInfo;
+    OString osVendor = OUStringToOString(sVendor, RTL_TEXTENCODING_UTF8);
     //Get minVersion
     OString sExpression = OString(
         "/jf:javaSelection/jf:vendorInfos/jf:vendor[@name=\"") +
