@@ -103,8 +103,6 @@ LwpPara::LwpPara(LwpObjectHeader const & objHdr, LwpSvStream* pStrm)
     , m_nOrdinal(0)
     , m_nFlags(0)
     , m_nLevel(0)
-    , m_pBreaks(nullptr)
-    , m_pIndentOverride(nullptr)
     , m_FontID(0)
     , m_AllText("")
     , m_bHasBullet(false)
