@@ -178,7 +178,7 @@ void LwpSilverBullet::RegisterStyle()
     }
 
     //add style-list to style manager.
-    m_strStyleName = pXFStyleManager->AddStyle(xListStyle.release()).m_pStyle->GetStyleName();
+    m_strStyleName = pXFStyleManager->AddStyle(std::move(xListStyle)).m_pStyle->GetStyleName();
 }
 
 /**
@@ -215,7 +215,7 @@ OUString LwpSilverBullet::GetBulletFontName()
  * @descr:
  * @return:  An UChar32 bullet character.
  */
-OUString LwpSilverBullet::GetBulletChar()
+OUString const & LwpSilverBullet::GetBulletChar()
 {
     return m_xBulletPara->GetBulletChar();
 }
