@@ -71,18 +71,10 @@ XFFont::XFFont()
     , m_bBoldComplex(false)
     , m_eUnderline(enumXFUnderlineNone)
     , m_eCrossout(enumXFCrossoutNone)
-    , m_eRelief(enumXFReliefNone)
     , m_eTransform(enumXFTransformNone)
-    , m_eEmphasize(enumXFEmphasizeNone)
     , m_bWordByWord(false)
-    , m_bEmphasizeTop(true)
-    , m_bOutline(false)
-    , m_bShadow(false)
-    , m_bBlink(false)
     , m_nPosition(33)
     , m_nScale(58)
-    , m_fCharSpace(0)
-    , m_nWidthScale(100)
     , m_nFlag(0)
     , m_bTransparent(false)
 {
@@ -154,47 +146,15 @@ bool operator==(XFFont const & f1, XFFont const & f2)
             return false;
     }
 
-    if( f1.m_nFlag&XFFONT_FLAG_RELIEF )
-    {
-        if( f1.m_eRelief != f2.m_eRelief )
-            return false;
-    }
-
     if( f1.m_nFlag&XFFONT_FLAG_TRANSFORM )
     {
         if( f1.m_eTransform != f2.m_eTransform )
             return false;
     }
 
-    if( f1.m_nFlag&XFFONT_FLAG_EMPHASIZE )
-    {
-        if( f1.m_eEmphasize != f2.m_eEmphasize )
-            return false;
-        if( f1.m_bEmphasizeTop != f2.m_bEmphasizeTop )
-            return false;
-    }
-
     if( f1.m_bWordByWord != f2.m_bWordByWord )
         return false;
 
-    if( f1.m_nFlag&XFFONT_FLAG_OUTLINE )
-    {
-        if( f1.m_bOutline != f2.m_bOutline )
-            return false;
-    }
-
-    if( f1.m_nFlag&XFFONT_FLAG_SHADOW )
-    {
-        if( f1.m_bShadow != f2.m_bShadow )
-            return false;
-    }
-
-    if( f1.m_nFlag&XFFONT_FLAG_BLINK )
-    {
-        if( f1.m_bBlink != f2.m_bBlink )
-            return false;
-    }
-
     if( f1.m_nFlag&XFFONT_FLAG_POSITION )
     {
         if( f1.m_nPosition != f2.m_nPosition )
@@ -207,18 +167,6 @@ bool operator==(XFFont const & f1, XFFont const & f2)
             return false;
     }
 
-    if( f1.m_nFlag&XFFONT_FLAG_CHARSPACE )
-    {
-        if( f1.m_fCharSpace != f2.m_fCharSpace )
-            return false;
-    }
-
-    if( f1.m_nFlag&XFFONT_FLAG_WIDTHSCALE )
-    {
-        if( f1.m_nWidthScale != f2.m_nWidthScale )
-            return false;
-    }
-
     if( f1.m_nFlag&XFFONT_FLAG_COLOR )
     {
         if( f1.m_aColor != f2.m_aColor )
@@ -331,11 +279,6 @@ void XFFont::ToXml(IXFStream *pStrm)
             pAttrList->AddAttribute("fo:score-spaces", "true" );
     }
 
-    if( (m_nFlag & XFFONT_FLAG_RELIEF) && m_eRelief )
-    {
-        pAttrList->AddAttribute("style:font-relief", GetReliefName(m_eRelief) );
-    }
-
     if( (m_nFlag & XFFONT_FLAG_TRANSFORM) && m_eTransform )
     {
         //enumTransformSmallCap is different:
@@ -345,30 +288,6 @@ void XFFont::ToXml(IXFStream *pStrm)
             pAttrList->AddAttribute("fo:text-transform", GetTransformName(m_eTransform) );
     }
 
-    if( (m_nFlag & XFFONT_FLAG_EMPHASIZE) && m_eEmphasize )
-    {
-        OUString empha = GetEmphasizeName(m_eEmphasize);
-        empha += " ";
-        if( m_bEmphasizeTop )
-            empha += "above";
-        pAttrList->AddAttribute("style:text-emphasize", empha );
-    }
-
-    if( (m_nFlag & XFFONT_FLAG_OUTLINE) && m_bOutline )
-    {
-        pAttrList->AddAttribute("style:text-outline", "true" );
-    }
-
-    if( (m_nFlag & XFFONT_FLAG_SHADOW) && m_bShadow )
-    {
-        pAttrList->AddAttribute("fo:text-shadow", "1pt 1pt" );
-    }
-
-    if( (m_nFlag & XFFONT_FLAG_BLINK) && m_bBlink )
-    {
-        pAttrList->AddAttribute("style:text-blinking", "true" );
-    }
-
     //position & scale:
     if( ((m_nFlag & XFFONT_FLAG_SCALE) && m_nScale>0 ) ||
         ((m_nFlag & XFFONT_FLAG_POSITION) && m_nPosition != 0)
@@ -380,17 +299,6 @@ void XFFont::ToXml(IXFStream *pStrm)
         pAttrList->AddAttribute("style:text-position", tmp );
     }
 
-    //char space:
-    if( (m_nFlag & XFFONT_FLAG_CHARSPACE) && m_fCharSpace != 0 )
-    {
-        pAttrList->AddAttribute("fo:letter-spacing", OUString::number(m_fCharSpace)+"cm" );
-    }
-
-    if( (m_nFlag&XFFONT_FLAG_WIDTHSCALE) && m_nWidthScale != 100 )
-    {
-        pAttrList->AddAttribute("style:text-scale", OUString::number(m_nWidthScale)+"%" );
-    }
-
     //Color:
     if( m_nFlag & XFFONT_FLAG_COLOR )
     {
