@@ -29,7 +29,7 @@
 #include <allheaders.hxx>
 
 CPPUNIT_PLUGIN_IMPLEMENT();
-extern "C" SAL_DLLPUBLIC_EXPORT sal_Bool SAL_CALL firstfunc(sal_Bool)
+extern "C" SAL_DLLPUBLIC_EXPORT sal_Bool firstfunc(sal_Bool)
 {
    return true;
 }
