@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "oox/ole/olestorage.hxx"
+#include <oox/ole/olestorage.hxx>
 
 #include <com/sun/star/beans/PropertyValue.hpp>
 #include <com/sun/star/container/XNameContainer.hpp>
@@ -33,10 +33,10 @@
 #include <com/sun/star/uno/XComponentContext.hpp>
 #include <cppuhelper/implbase.hxx>
 #include <osl/diagnose.h>
-#include "oox/helper/binaryinputstream.hxx"
-#include "oox/helper/binaryoutputstream.hxx"
-#include "oox/helper/containerhelper.hxx"
-#include "oox/helper/helper.hxx"
+#include <oox/helper/binaryinputstream.hxx>
+#include <oox/helper/binaryoutputstream.hxx>
+#include <oox/helper/containerhelper.hxx>
+#include <oox/helper/helper.hxx>
 
 namespace oox {
 namespace ole {
@@ -80,7 +80,7 @@ private:
     Reference< XStream > mxTempFile;
     Reference< XOutputStream > mxOutStrm;
     Reference< XSeekable > mxSeekable;
-    OUString            maElementName;
+    OUString const      maElementName;
 };
 
 OleOutputStream::OleOutputStream( const Reference< XComponentContext >& rxContext,
@@ -288,7 +288,7 @@ void OleStorage::implGetElementNames( ::std::vector< OUString >& orElementNames
     {
         aNames = mxStorage->getElementNames();
         if( aNames.getLength() > 0 )
-            orElementNames.insert( orElementNames.end(), aNames.getConstArray(), aNames.getConstArray() + aNames.getLength() );
+            orElementNames.insert( orElementNames.end(), aNames.begin(), aNames.end() );
     }
     catch(const Exception& )
     {
