@@ -50,7 +50,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
     // oObj filled by MultiMethodTest
     public XSingleSelectQueryAnalyzer oObj = null ;
 
-    private final String queryString = "SELECT * FROM \"biblio\"";
+    private static final String queryString = "SELECT * FROM \"biblio\"";
 
     private XSingleSelectQueryComposer xComposer = null;
 
@@ -76,7 +76,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
     }
     /**
     * call <code>setQuery()</code> once with valid query, once with invalid
-    * query. Has ok if only on sceond call <code>SQLException</code> was thrwon
+    * query. Has ok if only on second call <code>SQLException</code> was thrown
     */
     public void _setQuery() {
 
@@ -123,7 +123,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
         try{
             String filter = "\"Identifier\" = 'BOR02b'";
             xComposer.setFilter(filter);
-            tRes.tested("getFilter()", (oObj.getFilter().equals(filter)));
+            tRes.tested("getFilter()", oObj.getFilter().equals(filter));
 
         } catch (com.sun.star.sdbc.SQLException e){
             log.println("unexpected Exception: " + e.toString());
@@ -149,12 +149,13 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
         requiredMethod("getFilter()");
         try{
             oObj.setQuery("SELECT \"Identifier\", \"Type\", \"Address\" FROM \"biblio\" \"biblio\"");
-            String complexFilter = "( \"Identifier\" = '1' AND \"Type\" = '4' ) OR ( \"Identifier\" = '2' AND \"Type\" = '5' ) OR ( \"Identifier\" = '3' AND \"Type\" = '6' AND \"Address\" = '7' ) OR ( \"Address\" = '8' ) OR ( \"Type\" = '9' )";
+            String complexFilter = "( \"Identifier\" >= '1' AND \"Type\" <= '4' ) OR ( \"Identifier\" <> '2' AND \"Type\" = '5' ) OR ( \"Identifier\" < '3' AND \"Type\" > '6' AND \"Address\" = '7' ) OR ( \"Address\" >= '8' ) OR ( \"Type\" = '9' )";
             xComposer.setFilter(complexFilter);
             PropertyValue[][] aStructuredFilter = oObj.getStructuredFilter();
+
             xComposer.setFilter("");
             xComposer.setStructuredFilter(aStructuredFilter);
-            tRes.tested("getStructuredFilter()", (oObj.getFilter().equals(complexFilter)));
+            tRes.tested("getStructuredFilter()", oObj.getFilter().equals(complexFilter));
 
         } catch (com.sun.star.sdbc.SQLException e){
             log.println("unexpected Exception: " + e.toString());
@@ -173,7 +174,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
         try{
             String group = "\"Identifier\"";
             xComposer.setGroup(group);
-            tRes.tested("getGroup()", (oObj.getGroup().equals(group)));
+            tRes.tested("getGroup()", oObj.getGroup().equals(group));
 
         } catch (com.sun.star.sdbc.SQLException e){
             log.println("unexpected Exception: " + e.toString());
@@ -182,8 +183,8 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
     }
 
     /**
-    * Method <code>getGroupColumns</code> retunrs a <code>XIndexAccess</code>
-    * Test has ok status if returned value is an useable <code>XIndexAccess</code>
+    * Method <code>getGroupColumns</code> returns a <code>XIndexAccess</code>
+    * Test has ok status if returned value is an usable <code>XIndexAccess</code>
     */
     public void _getGroupColumns() {
         try{
@@ -210,8 +211,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
         try{
             String clause = "\"Identifier\" = 'BOR02b'";
             xComposer.setHavingClause(clause);
-            tRes.tested("getHavingClause()", (
-                                        oObj.getHavingClause().equals(clause)));
+            tRes.tested("getHavingClause()", oObj.getHavingClause().equals(clause));
 
         } catch (com.sun.star.sdbc.SQLException e){
             log.println("unexpected Exception: " + e.toString());
@@ -234,15 +234,15 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
         requiredMethod("setQuery()");
         requiredMethod("getFilter()");
         executeMethod("getStructuredFilter()");
-        String complexFilter = "( \"Identifier\" = '1' AND \"Type\" = '4' ) OR ( \"Identifier\" = '2' AND \"Type\" = '5' ) OR ( \"Identifier\" = '3' AND \"Type\" = '6' AND \"Address\" = '7' ) OR ( \"Address\" = '8' ) OR ( \"Type\" = '9' )";
 
+        String complexFilter = "( \"Identifier\" >= '1' AND \"Type\" <= '4' ) OR ( \"Identifier\" <> '2' AND \"Type\" = '5' ) OR ( \"Identifier\" < '3' AND \"Type\" > '6' AND \"Address\" = '7' ) OR ( \"Address\" >= '8' ) OR ( \"Type\" = '9' )";
         try{
            xComposer.setHavingClause(complexFilter);
            PropertyValue[][] aStructuredHaving = oObj.getStructuredHavingClause();
            xComposer.setHavingClause("");
            xComposer.setStructuredHavingClause(aStructuredHaving);
            tRes.tested("getStructuredHavingClause()",
-                                (oObj.getHavingClause().equals(complexFilter)));
+                                oObj.getHavingClause().equals(complexFilter));
 
         } catch (com.sun.star.sdbc.SQLException e){
             log.println("unexpected Exception: " + e.toString());
@@ -258,7 +258,7 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
         try{
             String order = "\"Identifier\"";
             xComposer.setOrder(order);
-            tRes.tested("getOrder()", (oObj.getOrder().equals(order)));
+            tRes.tested("getOrder()", oObj.getOrder().equals(order));
 
         } catch (com.sun.star.sdbc.SQLException e){
             log.println("unexpected Exception: " + e.toString());
@@ -267,8 +267,8 @@ public class _XSingleSelectQueryAnalyzer extends MultiMethodTest {
     }
 
     /**
-    * Method <code>getGroupColumns</code> retunrs a <code>XIndexAccess</code>
-    * Test has ok status if returned value is an useable <code>XIndexAccess</code>
+    * Method <code>getGroupColumns</code> returns a <code>XIndexAccess</code>
+    * Test has ok status if returned value is an usable <code>XIndexAccess</code>
     */
     public void _getOrderColumns() {
         try{
