@@ -20,7 +20,6 @@ package mod._sw;
 
 import java.io.PrintWriter;
 
-import lib.StatusException;
 import lib.TestCase;
 import lib.TestEnvironment;
 import lib.TestParameters;
@@ -66,17 +65,11 @@ public class XMLMetaImporter extends TestCase {
     * New text document created.
     */
     @Override
-    protected void initialize( TestParameters tParam, PrintWriter log ) {
+    protected void initialize( TestParameters tParam, PrintWriter log ) throws Exception {
         SOfficeFactory SOF = SOfficeFactory.getFactory( tParam.getMSF() );
 
-        try {
-            log.println( "creating a textdocument" );
-            xTextDoc = SOF.createTextDoc( null );
-        } catch ( com.sun.star.uno.Exception e ) {
-            // Some exception occurs.FAILED
-            e.printStackTrace( log );
-            throw new StatusException( "Couldn't create document", e );
-        }
+        log.println( "creating a textdocument" );
+        xTextDoc = SOF.createTextDoc( null );
     }
 
     /**
@@ -89,7 +82,7 @@ public class XMLMetaImporter extends TestCase {
     }
 
     /**
-    * Creating a Testenvironment for the interfaces to be tested.
+    * Creating a TestEnvironment for the interfaces to be tested.
     * Creates an instance of the service
     * <code>com.sun.star.comp.Writer.XMLMetaImporter</code><p>
     *
@@ -108,9 +101,9 @@ public class XMLMetaImporter extends TestCase {
     * </ul>
     */
     @Override
-    public synchronized TestEnvironment createTestEnvironment( TestParameters tParam,
+    public TestEnvironment createTestEnvironment( TestParameters tParam,
                                                   PrintWriter log )
-                                                    throws StatusException {
+                                                    throws Exception {
 
         XInterface oObj = null;
         Object oInt = null ;
@@ -122,13 +115,8 @@ public class XMLMetaImporter extends TestCase {
 
         XMultiServiceFactory xMSF = tParam.getMSF() ;
 
-        try {
-            oInt = xMSF.createInstance
-                ("com.sun.star.comp.Writer.XMLMetaImporter") ;
-        } catch (com.sun.star.uno.Exception e) {
-            e.printStackTrace(log) ;
-            throw new StatusException("Can't create component.", e) ;
-        }
+        oInt = xMSF.createInstance
+            ("com.sun.star.comp.Writer.XMLMetaImporter") ;
 
         oObj = (XInterface) oInt ;
 
