@@ -67,19 +67,12 @@ public class XMLSettingsImporter extends TestCase {
     * New impress document created.
     */
     @Override
-    protected void initialize( TestParameters tParam, PrintWriter log ) {
-
+    protected void initialize( TestParameters tParam, PrintWriter log ) throws Exception {
         // get a soffice factory object
         SOfficeFactory SOF = SOfficeFactory.getFactory( tParam.getMSF());
 
-        try {
-            log.println( "creating an impress document" );
-            xImpressDoc = SOF.createImpressDoc(null);
-        } catch ( Exception e ) {
-            // Some exception occurs.FAILED
-            e.printStackTrace( log );
-            throw new StatusException( "Couldn't create document", e );
-        }
+        log.println( "creating an impress document" );
+        xImpressDoc = SOF.createImpressDoc(null);
     }
 
     /**
@@ -92,7 +85,7 @@ public class XMLSettingsImporter extends TestCase {
     }
 
     /**
-    * Creating a Testenvironment for the interfaces to be tested.
+    * Creating a TestEnvironment for the interfaces to be tested.
     * Creates an instance of the service
     * <code>com.sun.star.comp.Impress.XMLStylesImporter</code><p>
     *
@@ -111,8 +104,8 @@ public class XMLSettingsImporter extends TestCase {
     * </ul>
     */
     @Override
-    public synchronized TestEnvironment createTestEnvironment
-        (TestParameters tParam, PrintWriter log ) throws StatusException {
+    public TestEnvironment createTestEnvironment
+        (TestParameters tParam, PrintWriter log ) throws Exception {
 
         XInterface oObj = null;
         Object oInt = null ;
@@ -123,14 +116,8 @@ public class XMLSettingsImporter extends TestCase {
 
         XMultiServiceFactory xMSF = tParam.getMSF() ;
 
-        try {
-            oInt = xMSF.createInstance
-                ("com.sun.star.comp.Impress.XMLSettingsImporter") ;
-
-        } catch (com.sun.star.uno.Exception e) {
-            e.printStackTrace(log) ;
-            throw new StatusException("Can't create component.", e) ;
-        }
+        oInt = xMSF.createInstance
+            ("com.sun.star.comp.Impress.XMLSettingsImporter") ;
 
         oObj = (XInterface) oInt ;
 
@@ -169,13 +156,8 @@ public class XMLSettingsImporter extends TestCase {
         XModel xImpressModel = UnoRuntime.queryInterface(XModel.class, xImpressDoc);
         XController xController = xImpressModel.getCurrentController();
         final XPropertySet xPropSet = UnoRuntime.queryInterface(XPropertySet.class, xController);
-        try {
-            log.println("Property \"IsLayerMode\" before import is " +
-                xPropSet.getPropertyValue("IsLayerMode"));
-        } catch (com.sun.star.uno.Exception e) {
-            e.printStackTrace(log);
-            throw new StatusException("Can't create component.", e);
-        }
+        log.println("Property \"IsLayerMode\" before import is " +
+            xPropSet.getPropertyValue("IsLayerMode"));
         final PrintWriter logF = log;
         tEnv.addObjRelation("XDocumentHandler.ImportChecker",
             new ifc.xml.sax._XDocumentHandler.ImportChecker() {
