@@ -20,19 +20,20 @@
 #include "path_helper.hxx"
 #include <osl/diagnose.h>
 #include <rtl/ustring.hxx>
+#include <sal/log.hxx>
 
 #include <algorithm>
 #include <wchar.h>
 
-const rtl::OUString BACKSLASH ("\\");
-const rtl::OUString SLASH     ("/");
+const OUString BACKSLASH ("\\");
+const OUString SLASH     ("/");
 
 void osl_systemPathEnsureSeparator(/*inout*/ rtl_uString** ppustrPath)
 {
     OSL_PRECOND(ppustrPath && (nullptr != *ppustrPath),
                 "osl_systemPathEnsureSeparator: Invalid parameter");
 
-     rtl::OUString path(*ppustrPath);
+     OUString path(*ppustrPath);
     sal_Int32     i = std::max<sal_Int32>(path.lastIndexOf(BACKSLASH), path.lastIndexOf(SLASH));
 
     if (i < (path.getLength()-1))
@@ -46,9 +47,9 @@ void osl_systemPathEnsureSeparator(/*inout*/ rtl_uString** ppustrPath)
                  "osl_systemPathEnsureSeparator: Post condition failed");
 }
 
-void SAL_CALL osl_systemPathRemoveSeparator(/*inout*/ rtl_uString** ppustrPath)
+void osl_systemPathRemoveSeparator(/*inout*/ rtl_uString** ppustrPath)
 {
-    rtl::OUString path(*ppustrPath);
+    OUString path(*ppustrPath);
 
     if (!osl::systemPathIsLogicalDrivePattern(path))
     {
@@ -56,7 +57,7 @@ void SAL_CALL osl_systemPathRemoveSeparator(/*inout*/ rtl_uString** ppustrPath)
 
         if (i > -1 && (i == (path.getLength() - 1)))
         {
-            path = rtl::OUString(path.getStr(), path.getLength() - 1);
+            path = OUString(path.getStr(), path.getLength() - 1);
             rtl_uString_assign(ppustrPath, path.pData);
         }
     }
