@@ -59,7 +59,6 @@ namespace sax_fastparser {
         , mbMarkStackEmpty(true)
         , mpDoubleStr(nullptr)
         , mnDoubleStrCapacity(RTL_STR_MAX_VALUEOFDOUBLE)
-        , mbXescape(true)
     {
         rtl_string_new_WithLength(&mpDoubleStr, mnDoubleStrCapacity);
         mxFastTokenHandler = css::xml::sax::FastTokenHandler::create(
@@ -105,7 +104,7 @@ namespace sax_fastparser {
     /** Characters not allowed in XML 1.0
         XML 1.1 would exclude only U+0000
      */
-    bool invalidChar( char c )
+    static bool invalidChar( char c )
     {
         if (static_cast<unsigned char>(c) >= 0x20)
             return false;
@@ -120,7 +119,7 @@ namespace sax_fastparser {
         return true;
     }
 
-    bool isHexDigit( char c )
+    static bool isHexDigit( char c )
     {
         return ('0' <= c && c <= '9') || ('A' <= c && c <= 'F') || ('a' <= c && c <= 'f');
     }
@@ -136,7 +135,6 @@ namespace sax_fastparser {
             return;
         }
 
-        bool bGood = true;
         const sal_Int32 kXescapeLen = 7;
         char bufXescape[kXescapeLen+1];
         sal_Int32 nNextXescape = 0;
@@ -197,7 +195,6 @@ namespace sax_fastparser {
                             }
                 break;
                 default:
-                            if (mbXescape)
                             {
                                 // Escape characters not valid in XML 1.0 as
                                 // _xHHHH_. A literal "_xHHHH_" has to be
@@ -242,23 +239,10 @@ namespace sax_fastparser {
                                  * scanning for both encoded sequences and
                                  * write as _xHHHH_? */
                             }
-#if OSL_DEBUG_LEVEL > 0
-                            else
-                            {
-                                if (bGood && invalidChar(pStr[i]))
-                                {
-                                    bGood = false;
-                                    // The SAL_WARN() for the single character is
-                                    // issued in writeBytes(), just gather for the
-                                    // SAL_WARN_IF() below.
-                                }
-                            }
-#endif
                             writeBytes( &c, 1 );
                 break;
             }
         }
-        SAL_WARN_IF( !bGood && nLen > 1, "sax", "in '" << OString(pStr,std::min<sal_Int32>(nLen,42)) << "'");
     }
 
     void FastSaxSerializer::endDocument()
