@@ -22,6 +22,8 @@
 #include <scitems.hxx>
 #include <editutil.hxx>
 #include <table.hxx>
+#include <drwlayer.hxx>
+#include <formulaopt.hxx>
 
 #include <sal/config.h>
 #include <editeng/wghtitem.hxx>
@@ -470,7 +472,7 @@ void Test::testSortInFormulaGroup()
 {
     SortRefUpdateSetter aUpdateSet;
 
-    static struct {
+    static const struct {
         SCCOL nCol;
         SCROW nRow;
         const char *pData;
@@ -504,7 +506,7 @@ void Test::testSortInFormulaGroup()
 
     m_pDoc->Sort(0, aSortData, false, true, nullptr, nullptr);
 
-    static struct {
+    static const struct {
         SCCOL nCol;
         SCROW nRow;
         double fValue;
