@@ -11,7 +11,6 @@
 #include <clipcontext.hxx>
 #include <document.hxx>
 #include <clipparam.hxx>
-#include <bcaslot.hxx>
 #include <segmenttree.hxx>
 #include <sharedformula.hxx>
 #include <cellvalues.hxx>
@@ -158,7 +157,7 @@ void ScTable::CopyOneCellFromClip(
                 rSrcStartPos.Col(), rSrcStartPos.Row(), rSrcEndPos.Col(), rSrcEndPos.Row(),
                 rSrcStartPos.Tab());
             tools::Rectangle aDestRect = GetDoc().GetMMRect(nCol1, nRow1, nCol2, nRow2, nTab);
-            pDrawLayer->CopyFromClip(rCxt.getClipDoc()->mpDrawLayer, rSrcStartPos.Tab(),
+            pDrawLayer->CopyFromClip(rCxt.getClipDoc()->mpDrawLayer.get(), rSrcStartPos.Tab(),
                                      aSourceRect, ScAddress(nCol1, nRow1, nTab), aDestRect);
         }
     }
