@@ -53,7 +53,7 @@ std::vector< WeakReference< frame::XModel > > lcl_getAllLivingCharts( ScDocument
             SdrPage* pPage = pDrawLayer->GetPage(static_cast<sal_uInt16>(nTab));
             OSL_ENSURE(pPage,"Page ?");
 
-            SdrObjListIter aIter( *pPage, SdrIterMode::DeepNoGroups );
+            SdrObjListIter aIter( pPage, SdrIterMode::DeepNoGroups );
             SdrObject* pObject = aIter.Next();
             while (pObject)
             {
@@ -157,7 +157,7 @@ ScTemporaryChartLock::~ScTemporaryChartLock()
 
 void ScTemporaryChartLock::StartOrContinueLocking()
 {
-    if(!mapScChartLockGuard.get())
+    if (!mapScChartLockGuard)
         mapScChartLockGuard.reset( new ScChartLockGuard(mpDoc) );
     maTimer.Start();
 }
@@ -170,7 +170,7 @@ void ScTemporaryChartLock::StopLocking()
 
 void ScTemporaryChartLock::AlsoLockThisChart( const Reference< frame::XModel >& xModel )
 {
-    if(mapScChartLockGuard.get())
+    if (mapScChartLockGuard)
         mapScChartLockGuard->AlsoLockThisChart( xModel );
 }
 
