@@ -23,6 +23,7 @@
 #include <stylehelper.hxx>
 #include <global.hxx>
 #include <globstr.hrc>
+#include <scresid.hxx>
 
 //  conversion programmatic <-> display (visible) name
 //  currently, the core always has the visible names
@@ -36,6 +37,13 @@
 #define SC_STYLE_PROG_HEADLINE1     "Heading1"
 #define SC_STYLE_PROG_REPORT        "Report"
 
+#define SC_PIVOT_STYLE_PROG_INNER                  "Pivot Table Value"
+#define SC_PIVOT_STYLE_PROG_RESULT                 "Pivot Table Result"
+#define SC_PIVOT_STYLE_PROG_CATEGORY               "Pivot Table Category"
+#define SC_PIVOT_STYLE_PROG_TITLE                  "Pivot Table Title"
+#define SC_PIVOT_STYLE_PROG_FIELDNAME              "Pivot Table Field"
+#define SC_PIVOT_STYLE_PROG_TOP                    "Pivot Table Corner"
+
 struct ScDisplayNameMap
 {
     OUString  aDispName;
@@ -47,24 +55,42 @@ static const ScDisplayNameMap* lcl_GetStyleNameMap( SfxStyleFamily nType )
     if ( nType == SfxStyleFamily::Para )
     {
         static bool bCellMapFilled = false;
-        static ScDisplayNameMap aCellMap[6];
+        static ScDisplayNameMap aCellMap[12];
         if ( !bCellMapFilled )
         {
-            aCellMap[0].aDispName = ScGlobal::GetRscString( STR_STYLENAME_STANDARD );
+            aCellMap[0].aDispName = ScResId( STR_STYLENAME_STANDARD );
             aCellMap[0].aProgName = SC_STYLE_PROG_STANDARD;
 
-            aCellMap[1].aDispName = ScGlobal::GetRscString( STR_STYLENAME_RESULT );
+            aCellMap[1].aDispName = ScResId( STR_STYLENAME_RESULT );
             aCellMap[1].aProgName = SC_STYLE_PROG_RESULT;
 
-            aCellMap[2].aDispName = ScGlobal::GetRscString( STR_STYLENAME_RESULT1 );
+            aCellMap[2].aDispName = ScResId( STR_STYLENAME_RESULT1 );
             aCellMap[2].aProgName = SC_STYLE_PROG_RESULT1;
 
-            aCellMap[3].aDispName = ScGlobal::GetRscString( STR_STYLENAME_HEADLINE );
+            aCellMap[3].aDispName = ScResId( STR_STYLENAME_HEADLINE );
             aCellMap[3].aProgName = SC_STYLE_PROG_HEADLINE;
 
-            aCellMap[4].aDispName = ScGlobal::GetRscString( STR_STYLENAME_HEADLINE1 );
+            aCellMap[4].aDispName = ScResId( STR_STYLENAME_HEADLINE1 );
             aCellMap[4].aProgName = SC_STYLE_PROG_HEADLINE1;
 
+            aCellMap[5].aDispName = ScResId( STR_PIVOT_STYLENAME_INNER );
+            aCellMap[5].aProgName = SC_PIVOT_STYLE_PROG_INNER;
+
+            aCellMap[6].aDispName = ScResId( STR_PIVOT_STYLENAME_RESULT );
+            aCellMap[6].aProgName = SC_PIVOT_STYLE_PROG_RESULT;
+
+            aCellMap[7].aDispName = ScResId( STR_PIVOT_STYLENAME_CATEGORY );
+            aCellMap[7].aProgName = SC_PIVOT_STYLE_PROG_CATEGORY;
+
+            aCellMap[8].aDispName = ScResId( STR_PIVOT_STYLENAME_TITLE );
+            aCellMap[8].aProgName = SC_PIVOT_STYLE_PROG_TITLE;
+
+            aCellMap[9].aDispName = ScResId( STR_PIVOT_STYLENAME_FIELDNAME );
+            aCellMap[9].aProgName = SC_PIVOT_STYLE_PROG_FIELDNAME;
+
+            aCellMap[10].aDispName = ScResId( STR_PIVOT_STYLENAME_TOP );
+            aCellMap[10].aProgName = SC_PIVOT_STYLE_PROG_TOP;
+
             //  last entry remains empty
 
             bCellMapFilled = true;
@@ -77,10 +103,10 @@ static const ScDisplayNameMap* lcl_GetStyleNameMap( SfxStyleFamily nType )
         static ScDisplayNameMap aPageMap[3];
         if ( !bPageMapFilled )
         {
-            aPageMap[0].aDispName = ScGlobal::GetRscString( STR_STYLENAME_STANDARD );
+            aPageMap[0].aDispName = ScResId( STR_STYLENAME_STANDARD );
             aPageMap[0].aProgName = SC_STYLE_PROG_STANDARD;
 
-            aPageMap[1].aDispName = ScGlobal::GetRscString( STR_STYLENAME_REPORT );
+            aPageMap[1].aDispName = ScResId( STR_STYLENAME_REPORT );
             aPageMap[1].aProgName = SC_STYLE_PROG_REPORT;
 
             //  last entry remains empty
