@@ -23,6 +23,7 @@
 #include <scerrors.hxx>
 #include <fprogressbar.hxx>
 #include <globstr.hrc>
+#include <xlcontent.hxx>
 #include <xltracer.hxx>
 #include <xltable.hxx>
 #include <xihelper.hxx>
@@ -30,9 +31,11 @@
 #include <xiview.hxx>
 #include <xilink.hxx>
 #include <xiname.hxx>
+#include <xlname.hxx>
 #include <xicontent.hxx>
 #include <xiescher.hxx>
 #include <xipivot.hxx>
+#include <xistyle.hxx>
 #include <XclImpChangeTrack.hxx>
 #include <documentimport.hxx>
 
@@ -1074,7 +1077,7 @@ ErrCode ImportExcel8::Read()
                     case EXC_ID_SUPBOOK:        rLinkMgr.ReadSupbook( maStrm );     break;
                     case EXC_ID_XCT:            rLinkMgr.ReadXct( maStrm );         break;
                     case EXC_ID_CRN:            rLinkMgr.ReadCrn( maStrm );         break;
-                    case EXC_ID_EXTERNNAME:     rLinkMgr.ReadExternname( maStrm, pFormConv );  break;
+                    case EXC_ID_EXTERNNAME:     rLinkMgr.ReadExternname( maStrm, pFormConv.get() );  break;
 
                     case EXC_ID_MSODRAWINGGROUP:rObjMgr.ReadMsoDrawingGroup( maStrm ); break;
 
