@@ -23,6 +23,8 @@
 #include <scmatrix.hxx>
 
 #include <svl/sharedstringpool.hxx>
+#include <sal/log.hxx>
+#include <osl/diagnose.h>
 
 #include <algorithm>
 #include <string.h>
@@ -61,16 +63,12 @@ TokenPool::TokenPool( svl::SharedStringPool& rSPool ) :
     ppP_Matrix.reset( new ScMatrix*[ nP_Matrix ] );
     memset( ppP_Matrix.get(), 0, sizeof( ScMatrix* ) * nP_Matrix );
 
-    pScToken = new ScTokenArray;
-
     Reset();
 }
 
 TokenPool::~TokenPool()
 {
     ClearMatrix();
-
-    delete pScToken;
 }
 
 /** Returns the new number of elements, or 0 if overflow. */
@@ -174,7 +172,7 @@ bool TokenPool::GrowMatrix()
     return true;
 }
 
-bool TokenPool::GetElement( const sal_uInt16 nId )
+bool TokenPool::GetElement( const sal_uInt16 nId, ScTokenArray* pScToken )
 {
     if (nId >= nElementCurrent)
     {
@@ -184,7 +182,7 @@ bool TokenPool::GetElement( const sal_uInt16 nId )
 
     bool bRet = true;
     if( pType[ nId ] == T_Id )
-        bRet = GetElementRek( nId );
+        bRet = GetElementRek( nId, pScToken );
     else
     {
         switch( pType[ nId ] )
@@ -194,7 +192,7 @@ bool TokenPool::GetElement( const sal_uInt16 nId )
                     sal_uInt16 n = pElement[ nId ];
                     auto* p = ppP_Str.getIfInRange( n );
                     if (p)
-                        pScToken->AddString(mrStringPool.intern(*p->get()));
+                        pScToken->AddString(mrStringPool.intern(**p));
                     else
                         bRet = false;
                 }
@@ -336,7 +334,7 @@ bool TokenPool::GetElement( const sal_uInt16 nId )
     return bRet;
 }
 
-bool TokenPool::GetElementRek( const sal_uInt16 nId )
+bool TokenPool::GetElementRek( const sal_uInt16 nId, ScTokenArray* pScToken )
 {
 #ifdef DBG_UTIL
     m_nRek++;
@@ -392,9 +390,9 @@ bool TokenPool::GetElementRek( const sal_uInt16 nId )
             else
             {
                 if (pType[ *pCurrent ] == T_Id)
-                    bRet = GetElementRek( *pCurrent );
+                    bRet = GetElementRek( *pCurrent, pScToken );
                 else
-                    bRet = GetElement( *pCurrent );
+                    bRet = GetElement( *pCurrent, pScToken );
             }
         }
         else    // elementary SC_Token
@@ -595,7 +593,7 @@ const TokenId TokenPool::StoreMatrix()
     pElement[ nElementCurrent ] = nP_MatrixCurrent;
     pType[ nElementCurrent ] = T_Matrix;
 
-    ScMatrix* pM = new ScFullMatrix( 0, 0 );
+    ScMatrix* pM = new ScMatrix( 0, 0 );
     pM->IncRef( );
     ppP_Matrix[ nP_MatrixCurrent ] = pM;
 
