@@ -28,12 +28,15 @@
 #include <editeng/ulspitem.hxx>
 #include <editeng/brushitem.hxx>
 #include <oox/export/utils.hxx>
+#include <oox/token/tokens.hxx>
+#include <sax/fastattribs.hxx>
 #include <document.hxx>
 #include <stlpool.hxx>
 #include <stlsheet.hxx>
 #include <attrib.hxx>
 #include <xehelper.hxx>
 #include <xeescher.hxx>
+#include <xltools.hxx>
 
 #include <set>
 #include <limits>
