@@ -27,6 +27,7 @@
 
 #include <svx/svdpage.hxx>
 #include <editeng/outlobj.hxx>
+#include <o3tl/make_unique.hxx>
 #include <svx/svdotext.hxx>
 #include <svx/svdobj.hxx>
 #include <svx/svdoole2.hxx>
@@ -37,20 +38,22 @@
 #include <unotools/ucbstreamhelper.hxx>
 #include <svx/sdasitm.hxx>
 #include <sfx2/docfile.hxx>
+#include <sal/log.hxx>
 
 #include <sot/exchange.hxx>
-#include "xeescher.hxx"
+#include <sot/storage.hxx>
+#include <xeescher.hxx>
 
-#include "global.hxx"
-#include "document.hxx"
-#include "drwlayer.hxx"
-#include "xecontent.hxx"
+#include <global.hxx>
+#include <document.hxx>
+#include <drwlayer.hxx>
+#include <xecontent.hxx>
 #include <editeng/flditem.hxx>
-#include "userdat.hxx"
-#include "xcl97rec.hxx"
-#include "xehelper.hxx"
-#include "xechart.hxx"
-#include "xcl97esc.hxx"
+#include <userdat.hxx>
+#include <xcl97rec.hxx>
+#include <xehelper.hxx>
+#include <xechart.hxx>
+#include <xcl97esc.hxx>
 #include <unotools/streamwrap.hxx>
 #include <oox/ole/olehelper.hxx>
 #include <sfx2/objsh.hxx>
@@ -84,7 +87,7 @@ SvStream* XclEscherExGlobal::ImplQueryPictureStream()
     if( mxPicTempFile->IsValid() )
     {
         mxPicTempFile->EnableKillingFile();
-        mxPicStrm.reset( ::utl::UcbStreamHelper::CreateStream( mxPicTempFile->GetURL(), StreamMode::STD_READWRITE ) );
+        mxPicStrm = ::utl::UcbStreamHelper::CreateStream( mxPicTempFile->GetURL(), StreamMode::STD_READWRITE );
         mxPicStrm->SetEndian( SvStreamEndian::LITTLE );
     }
     return mxPicStrm.get();
@@ -95,7 +98,6 @@ XclEscherEx::XclEscherEx( const XclExpRoot& rRoot, XclExpObjectManager& rObjMgr,
     XclExpRoot( rRoot ),
     mrObjMgr( rObjMgr ),
     pCurrXclObj( nullptr ),
-    pCurrAppData( nullptr ),
     pTheClientData( new XclEscherClientData ),
     pAdditionalText( nullptr ),
     nAdditionalText( 0 ),
@@ -109,7 +111,7 @@ XclEscherEx::~XclEscherEx()
 {
     OSL_ENSURE( aStack.empty(), "~XclEscherEx: stack not empty" );
     DeleteCurrAppData();
-    delete pTheClientData;
+    pTheClientData.reset();
 }
 
 sal_uInt32 XclEscherEx::InitNextDffFragment()
@@ -175,8 +177,8 @@ bool lcl_IsFontwork( const SdrObject* pObj )
     if( pObj->GetObjIdentifier() == OBJ_CUSTOMSHAPE )
     {
         const OUString aTextPath = "TextPath";
-        const SdrCustomShapeGeometryItem& rGeometryItem = static_cast<const SdrCustomShapeGeometryItem&>(
-            pObj->GetMergedItem( SDRATTR_CUSTOMSHAPE_GEOMETRY ) );
+        const SdrCustomShapeGeometryItem& rGeometryItem =
+            pObj->GetMergedItem( SDRATTR_CUSTOMSHAPE_GEOMETRY );
         if( const Any* pAny = rGeometryItem.GetPropertyValueByName( aTextPath, aTextPath ) )
             *pAny >>= bIsFontwork;
     }
@@ -198,8 +200,8 @@ EscherExHostAppData* XclEscherEx::StartShape( const Reference< XShape >& rxShape
             UpdateDffFragmentEnd();
         }
     }
-    aStack.push( std::make_pair( pCurrXclObj, pCurrAppData ) );
-    pCurrAppData = new XclEscherHostAppData;
+    aStack.push( std::make_pair( pCurrXclObj, std::move(pCurrAppData) ) );
+    pCurrAppData.reset( new XclEscherHostAppData );
     SdrObject* pObj = GetSdrObjectFromXShape( rxShape );
     //added for exporting OCX control
     sal_Int16 nMsCtlType = 0;
@@ -222,7 +224,7 @@ EscherExHostAppData* XclEscherEx::StartShape( const Reference< XShape >& rxShape
                     SvGlobalName aObjClsId( xObj->getClassID() );
                     if ( SotExchange::IsChart( aObjClsId ) )
                     {   // yes, it's a chart diagram
-                        mrObjMgr.AddObj( new XclExpChartObj( mrObjMgr, rxShape, pChildAnchor ) );
+                        mrObjMgr.AddObj( o3tl::make_unique<XclExpChartObj>( mrObjMgr, rxShape, pChildAnchor ) );
                         pCurrXclObj = nullptr;     // no metafile or whatsoever
                     }
                     else    // metafile and OLE object
@@ -265,13 +267,13 @@ EscherExHostAppData* XclEscherEx::StartShape( const Reference< XShape >& rxShape
     }
     if ( pCurrXclObj )
     {
-        if ( !mrObjMgr.AddObj( pCurrXclObj ) )
+        if ( !mrObjMgr.AddObj( std::unique_ptr<XclObj>(pCurrXclObj) ) )
         {   // maximum count reached, object got deleted
             pCurrXclObj = nullptr;
         }
         else
         {
-            pCurrAppData->SetClientData( pTheClientData );
+            pCurrAppData->SetClientData( pTheClientData.get() );
             if ( nAdditionalText == 0 )
             {
                 if ( pObj )
@@ -339,7 +341,7 @@ EscherExHostAppData* XclEscherEx::StartShape( const Reference< XShape >& rxShape
     }
     if ( !pCurrXclObj )
         pCurrAppData->SetDontWriteShape( true );
-    return pCurrAppData;
+    return pCurrAppData.get();
 }
 
 void XclEscherEx::EndShape( sal_uInt16 nShapeType, sal_uInt32 nShapeID )
@@ -353,9 +355,8 @@ void XclEscherEx::EndShape( sal_uInt16 nShapeType, sal_uInt32 nShapeID )
         // escher data of last shape not written? -> delete it from object list
         if( nShapeID == 0 )
         {
-            XclObj* pLastObj = mrObjMgr.RemoveLastObj();
-            OSL_ENSURE( pLastObj == pCurrXclObj, "XclEscherEx::EndShape - wrong object" );
-            DELETEZ( pLastObj );
+            std::unique_ptr<XclObj> pLastObj = mrObjMgr.RemoveLastObj();
+            OSL_ENSURE( pLastObj.get() == pCurrXclObj, "XclEscherEx::EndShape - wrong object" );
             pCurrXclObj = nullptr;
         }
 
@@ -382,7 +383,7 @@ void XclEscherEx::EndShape( sal_uInt16 nShapeType, sal_uInt32 nShapeID )
     else
     {
         pCurrXclObj = aStack.top().first;
-        pCurrAppData = aStack.top().second;
+        pCurrAppData = std::move(aStack.top().second);
         aStack.pop();
     }
     if( nAdditionalText == 3 )
@@ -394,7 +395,7 @@ EscherExHostAppData* XclEscherEx::EnterAdditionalTextGroup()
     nAdditionalText = 1;
     pAdditionalText = static_cast<XclEscherClientTextbox*>( pCurrAppData->GetClientTextbox() );
     pCurrAppData->SetClientTextbox( nullptr );
-    return pCurrAppData;
+    return pCurrAppData.get();
 }
 
 void XclEscherEx::EndDocument()
@@ -442,7 +443,7 @@ std::unique_ptr<XclExpTbxControlObj> XclEscherEx::CreateTBXCtrlObj( Reference< X
     if( xTbxCtrl->GetObjType() == EXC_OBJTYPE_UNKNOWN )
         xTbxCtrl.reset();
 
-    if( xTbxCtrl.get() )
+    if (xTbxCtrl)
     {
         // find attached macro
         Reference< XControlModel > xCtrlModel = XclControlHelper::GetControlModel( xShape );
@@ -511,8 +512,8 @@ void XclEscherEx::DeleteCurrAppData()
         delete pCurrAppData->GetClientAnchor();
 //      delete pCurrAppData->GetClientData();
         delete pCurrAppData->GetClientTextbox();
-    delete pCurrAppData->GetInteractionInfo();
-        delete pCurrAppData;
+        delete pCurrAppData->GetInteractionInfo();
+        pCurrAppData.reset();
     }
 }
 
@@ -546,7 +547,7 @@ ShapeInteractionHelper::CreateShapeObj( XclExpObjectManager& rObjMgr, const Refe
 }
 
 void
-ShapeInteractionHelper::PopulateShapeInteractionInfo( XclExpObjectManager& rObjMgr, const Reference< XShape >& xShape, EscherExHostAppData& rHostAppData )
+ShapeInteractionHelper::PopulateShapeInteractionInfo( const XclExpObjectManager& rObjMgr, const Reference< XShape >& xShape, EscherExHostAppData& rHostAppData )
 {
    try
    {
