@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "AccessibleDocumentBase.hxx"
+#include <AccessibleDocumentBase.hxx>
 
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 
