@@ -19,6 +19,7 @@
 
 #include <config_features.h>
 
+#include <sal/log.hxx>
 #include <sfx2/opengrf.hxx>
 #include <svx/svdograf.hxx>
 #include <svx/svdomedia.hxx>
@@ -319,7 +320,7 @@ FuInsertGraphic::FuInsertGraphic( ScTabViewShell&   rViewSh,
             if( nError == ERRCODE_NONE )
             {
                 OUString aFileName = aDlg.GetPath();
-                OUString aFilterName = aDlg.GetDetectedFilter();
+                const OUString& aFilterName = aDlg.GetDetectedFilter();
                 bool bAsLink = aDlg.IsAsLink();
 
                 // really store as link only?
