@@ -34,16 +34,6 @@ ScAreaLinkSaver::ScAreaLinkSaver( const ScAreaLink& rSource ) :
 {
 }
 
-ScAreaLinkSaver::ScAreaLinkSaver( const ScAreaLinkSaver& rCopy ) :
-    aFileName   ( rCopy.aFileName ),
-    aFilterName ( rCopy.aFilterName ),
-    aOptions    ( rCopy.aOptions ),
-    aSourceArea ( rCopy.aSourceArea ),
-    aDestArea   ( rCopy.aDestArea ),
-    nRefresh    ( rCopy.nRefresh )
-{
-}
-
 bool ScAreaLinkSaver::IsEqualSource( const ScAreaLink& rCompare ) const
 {
     return ( aFileName == rCompare.GetFile() &&
@@ -86,9 +76,6 @@ void ScAreaLinkSaver::InsertNewLink( ScDocument* pDoc )
 
 ScAreaLinkSaveCollection::ScAreaLinkSaveCollection() {}
 
-ScAreaLinkSaveCollection::ScAreaLinkSaveCollection( const ScAreaLinkSaveCollection& r ) :
-    maData(r.maData) {}
-
 ScAreaLinkSaveCollection::~ScAreaLinkSaveCollection() {}
 
 bool ScAreaLinkSaveCollection::IsEqual( const ScDocument* pDoc ) const
@@ -159,9 +146,9 @@ void ScAreaLinkSaveCollection::Restore( ScDocument* pDoc )
     }
 }
 
-ScAreaLinkSaveCollection* ScAreaLinkSaveCollection::CreateFromDoc( const ScDocument* pDoc )
+std::unique_ptr<ScAreaLinkSaveCollection> ScAreaLinkSaveCollection::CreateFromDoc( const ScDocument* pDoc )
 {
-    ScAreaLinkSaveCollection* pColl = nullptr;
+    std::unique_ptr<ScAreaLinkSaveCollection> pColl;
 
     sfx2::LinkManager* pLinkManager = const_cast<ScDocument*>(pDoc)->GetLinkManager();
     if (pLinkManager)
@@ -174,7 +161,7 @@ ScAreaLinkSaveCollection* ScAreaLinkSaveCollection::CreateFromDoc( const ScDocum
             if (dynamic_cast<const ScAreaLink*>( pBase) != nullptr)
             {
                 if (!pColl)
-                    pColl = new ScAreaLinkSaveCollection;
+                    pColl.reset(new ScAreaLinkSaveCollection);
 
                 pColl->push_back( ScAreaLinkSaver( *static_cast<ScAreaLink*>(pBase ) ) );
             }
