@@ -343,10 +343,8 @@ void SAL_CALL ScShapeObj::setPropertyValue(const OUString& aPropertyName, const
                 if ( pDoc )
                 {
                     SfxObjectShell* pObjSh = pDoc->GetDocumentShell();
-                    if ( pObjSh && dynamic_cast<const ScDocShell*>( pObjSh) !=  nullptr )
+                    if ( auto pDocSh = dynamic_cast<ScDocShell*>( pObjSh) )
                     {
-                        ScDocShell* pDocSh = static_cast<ScDocShell*>(pObjSh);
-
                         SCTAB nTab = 0;
                         if ( lcl_GetPageNum( pPage, rModel, nTab ) )
                         {
@@ -477,9 +475,8 @@ void SAL_CALL ScShapeObj::setPropertyValue(const OUString& aPropertyName, const
                         if ( pDoc )
                         {
                             SfxObjectShell* pObjSh = pDoc->GetDocumentShell();
-                            if ( pObjSh && dynamic_cast<const ScDocShell*>( pObjSh) !=  nullptr )
+                            if ( auto pDocSh = dynamic_cast<ScDocShell*>( pObjSh) )
                             {
-                                ScDocShell* pDocSh = static_cast<ScDocShell*>(pObjSh);
                                 uno::Reference<drawing::XShape> xShape( mxShapeAgg, uno::UNO_QUERY );
                                 if (xShape.is())
                                 {
@@ -510,9 +507,7 @@ void SAL_CALL ScShapeObj::setPropertyValue(const OUString& aPropertyName, const
                                         xShape->setPosition(aPoint);
                                         pDocSh->SetModified();
                                     }
-                                    else if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL
-                                             || ScDrawLayer::GetAnchorType(*pObj)
-                                                    == SCA_CELL_RESIZE)
+                                    else if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL)
                                     {
                                         awt::Size aUnoSize;
                                         awt::Point aCaptionPoint;
@@ -578,9 +573,8 @@ void SAL_CALL ScShapeObj::setPropertyValue(const OUString& aPropertyName, const
                         if ( pDoc )
                         {
                             SfxObjectShell* pObjSh = pDoc->GetDocumentShell();
-                            if ( pObjSh && dynamic_cast<const ScDocShell*>( pObjSh) !=  nullptr )
+                            if ( auto pDocSh = dynamic_cast<ScDocShell*>( pObjSh) )
                             {
-                                ScDocShell* pDocSh = static_cast<ScDocShell*>(pObjSh);
                                 uno::Reference<drawing::XShape> xShape( mxShapeAgg, uno::UNO_QUERY );
                                 if (xShape.is())
                                 {
@@ -597,9 +591,7 @@ void SAL_CALL ScShapeObj::setPropertyValue(const OUString& aPropertyName, const
                                         xShape->setPosition(aPoint);
                                         pDocSh->SetModified();
                                     }
-                                    else if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL
-                                             || ScDrawLayer::GetAnchorType(*pObj)
-                                                    == SCA_CELL_RESIZE)
+                                    else if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL)
                                     {
                                         awt::Size aUnoSize;
                                         awt::Point aCaptionPoint;
@@ -677,9 +669,8 @@ uno::Any SAL_CALL ScShapeObj::getPropertyValue( const OUString& aPropertyName )
                     if ( lcl_GetPageNum( pPage, rModel, nTab ) )
                     {
                         SfxObjectShell* pObjSh = pDoc->GetDocumentShell();
-                        if ( pObjSh && dynamic_cast<const ScDocShell*>( pObjSh) !=  nullptr )
+                        if ( auto pDocSh = dynamic_cast<ScDocShell*>( pObjSh) )
                         {
-                            ScDocShell* pDocSh = static_cast<ScDocShell*>(pObjSh);
                             uno::Reference< uno::XInterface > xAnchor;
                             if (ScDrawObjData *pAnchor = ScDrawLayer::GetObjDataTab(pObj, nTab))
                                 xAnchor.set(static_cast<cppu::OWeakObject*>(new ScCellObj( pDocSh, pAnchor->maStart)));
@@ -728,8 +719,7 @@ uno::Any SAL_CALL ScShapeObj::getPropertyValue( const OUString& aPropertyName )
                         uno::Reference<drawing::XShape> xShape( mxShapeAgg, uno::UNO_QUERY );
                         if (xShape.is())
                         {
-                            if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL
-                                || ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL_RESIZE)
+                            if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL)
                             {
                                 awt::Size aUnoSize;
                                 awt::Point aCaptionPoint;
@@ -789,8 +779,7 @@ uno::Any SAL_CALL ScShapeObj::getPropertyValue( const OUString& aPropertyName )
                         uno::Reference<drawing::XShape> xShape( mxShapeAgg, uno::UNO_QUERY );
                         if (xShape.is())
                         {
-                            if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL
-                                || ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL_RESIZE)
+                            if (ScDrawLayer::GetAnchorType(*pObj) == SCA_CELL)
                             {
                                 awt::Size aUnoSize;
                                 awt::Point aCaptionPoint;
@@ -1017,10 +1006,8 @@ uno::Reference<text::XTextRange> SAL_CALL ScShapeObj::getAnchor()
         if ( pPage && pDoc )
         {
             SfxObjectShell* pObjSh = pDoc->GetDocumentShell();
-            if ( pObjSh && dynamic_cast<const ScDocShell*>( pObjSh) !=  nullptr )
+            if ( auto pDocSh = dynamic_cast<ScDocShell*>( pObjSh) )
             {
-                ScDocShell* pDocSh = static_cast<ScDocShell*>(pObjSh);
-
                 SCTAB nTab = 0;
                 if ( lcl_GetPageNum( pPage, rModel, nTab ) )
                 {
@@ -1260,10 +1247,8 @@ uno::Reference< uno::XInterface > SAL_CALL ScShapeObj::getParent()
         if ( pPage && pDoc )
         {
             SfxObjectShell* pObjSh = pDoc->GetDocumentShell();
-            if ( pObjSh && dynamic_cast<const ScDocShell*>( pObjSh) !=  nullptr )
+            if ( auto pDocSh = dynamic_cast<ScDocShell*>( pObjSh) )
             {
-                ScDocShell* pDocSh = static_cast<ScDocShell*>(pObjSh);
-
                 SCTAB nTab = 0;
                 if ( lcl_GetPageNum( pPage, rModel, nTab ) )
                 {
@@ -1329,7 +1314,7 @@ SdrObject* ScShapeObj::GetSdrObject() const throw()
 class ShapeUnoEventAccessImpl : public ::cppu::WeakImplHelper< container::XNameReplace >
 {
 private:
-    ScShapeObj* mpShape;
+    ScShapeObj* const mpShape;
 
     ScMacroInfo* getInfo( bool bCreate )
     {
