@@ -17,7 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "scitems.hxx"
+#include <scitems.hxx>
 #include <svx/imapdlg.hxx>
 #include <svx/srchdlg.hxx>
 #include <svl/srchitem.hxx>
@@ -29,24 +29,23 @@
 #include <sfx2/infobar.hxx>
 #include <sfx2/sidebar/SidebarChildWindow.hxx>
 
-#include "cellvalue.hxx"
-#include "docoptio.hxx"
+#include <cellvalue.hxx>
+#include <docoptio.hxx>
 
-#include "tabvwsh.hxx"
-#include "docsh.hxx"
-#include "reffact.hxx"
-#include "scresid.hxx"
-#include "dwfunctr.hxx"
-#include "sc.hrc"
-#include "spelldialog.hxx"
-#include "formulacell.hxx"
+#include <tabvwsh.hxx>
+#include <docsh.hxx>
+#include <reffact.hxx>
+#include <dwfunctr.hxx>
+#include <sc.hrc>
+#include <spelldialog.hxx>
+#include <formulacell.hxx>
 #include <searchresults.hxx>
 
 #include <sfx2/request.hxx>
     // needed for -fsanitize=function visibility of typeinfo for functions of
     // type void(SfxShell*,SfxRequest&) defined in scslots.hxx
-#define ScTabViewShell
-#include "scslots.hxx"
+#define ShellClass_ScTabViewShell
+#include <scslots.hxx>
 
 
 SFX_IMPL_INTERFACE(ScTabViewShell, SfxViewShell)
@@ -55,7 +54,7 @@ void ScTabViewShell::InitInterface_Impl()
 {
     GetStaticInterface()->RegisterObjectBar(SFX_OBJECTBAR_TOOLS,
                                             SfxVisibilityFlags::Standard | SfxVisibilityFlags::FullScreen | SfxVisibilityFlags::Server,
-                                            RID_OBJECTBAR_TOOLS);
+                                            ToolbarId::Objectbar_Tools);
 
     GetStaticInterface()->RegisterChildWindow(FID_INPUTLINE_STATUS);
     GetStaticInterface()->RegisterChildWindow(SfxInfoBarContainerChild::GetChildWindowId());
@@ -109,7 +108,7 @@ SFX_IMPL_NAMED_VIEWFACTORY( ScTabViewShell, "Default" )
     SFX_VIEW_REGISTRATION(ScDocShell);
 }
 
-OUString ScTabViewShell::GetFormula(ScAddress& rAddress)
+OUString ScTabViewShell::GetFormula(const ScAddress& rAddress)
 {
     OUString sFormula;
     ScDocument* pDoc = GetViewData().GetDocument();
