@@ -49,18 +49,18 @@
 #include <unotools/moduleoptions.hxx>
 #include <sot/exchange.hxx>
 #include <tools/diagnose_ex.h>
+#include <sal/log.hxx>
 
-#include "tabvwsh.hxx"
-#include "globstr.hrc"
-#include "scmod.hxx"
-#include "document.hxx"
-#include "sc.hrc"
-#include "client.hxx"
-#include "fuinsert.hxx"
-#include "docsh.hxx"
-#include "chartarr.hxx"
-#include "drawview.hxx"
-#include "ChartRangeSelectionListener.hxx"
+#include <tabvwsh.hxx>
+#include <scmod.hxx>
+#include <document.hxx>
+#include <sc.hrc>
+#include <client.hxx>
+#include <fuinsert.hxx>
+#include <docsh.hxx>
+#include <chartarr.hxx>
+#include <drawview.hxx>
+#include <ChartRangeSelectionListener.hxx>
 #include <gridwin.hxx>
 
 #include <tools/urlobj.hxx>
@@ -69,7 +69,7 @@
 
 using namespace com::sun::star;
 
-void ScTabViewShell::ConnectObject( SdrOle2Obj* pObj )
+void ScTabViewShell::ConnectObject( const SdrOle2Obj* pObj )
 {
     // is called from paint
 
@@ -97,15 +97,13 @@ void ScTabViewShell::ConnectObject( SdrOle2Obj* pObj )
         // the object area must be set after the scaling since it triggers the resizing
         aRect.SetSize( aOleSize );
         pClient->SetObjArea( aRect );
-
-        static_cast<ScClient*>(pClient)->SetGrafEdit( nullptr );
     }
 }
 
 class PopupCallback : public cppu::WeakImplHelper<css::awt::XCallback>
 {
     ScTabViewShell* m_pViewShell;
-    SdrOle2Obj* m_pObject;
+    SdrOle2Obj* const m_pObject;
 
 public:
     explicit PopupCallback(ScTabViewShell* pViewShell, SdrOle2Obj* pObject)
@@ -158,7 +156,7 @@ void ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
         if ( !pClient )
             pClient = new ScClient( this, pWin, GetSdrView()->GetModel(), pObj );
 
-        if ( !(nErr & ERRCODE_ERROR_MASK) && xObj.is() )
+        if ( (sal_uInt32(nErr) & ERRCODE_ERROR_MASK) == 0 && xObj.is() )
         {
             tools::Rectangle aRect = pObj->GetLogicRect();
 
@@ -184,7 +182,7 @@ void ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
                 {
                     MapUnit aUnit = VCLUnoHelper::UnoEmbed2VCLMapUnit( xObj->getMapUnit( pClient->GetAspect() ) );
                     aOleSize = OutputDevice::LogicToLogic( aDrawSize,
-                                            MapUnit::Map100thMM, aUnit );
+                                MapMode(MapUnit::Map100thMM), MapMode(aUnit));
                     awt::Size aSz( aOleSize.Width(), aOleSize.Height() );
                     xObj->setVisualAreaSize( pClient->GetAspect(), aSz );
                 }
@@ -207,8 +205,6 @@ void ScTabViewShell::ActivateObject( SdrOle2Obj* pObj, long nVerb )
             aRect.SetSize( aOleSize );
             pClient->SetObjArea( aRect );
 
-            static_cast<ScClient*>(pClient)->SetGrafEdit( nullptr );
-
             nErr = pClient->DoVerb( nVerb );
             bErrorShown = true;
             // SfxViewShell::DoVerb shows its error messages
@@ -270,7 +266,6 @@ ErrCode ScTabViewShell::DoVerb(long nVerb)
         return ERRCODE_SO_NOTIMPL;          // should not be
 
     SdrOle2Obj* pOle2Obj = nullptr;
-    ErrCode nErr = ERRCODE_NONE;
 
     const SdrMarkList& rMarkList = pView->GetMarkedObjectList();
     if (rMarkList.GetMarkCount() == 1)
@@ -289,7 +284,7 @@ ErrCode ScTabViewShell::DoVerb(long nVerb)
         OSL_FAIL("no object for Verb found");
     }
 
-    return nErr;
+    return ERRCODE_NONE;
 }
 
 void ScTabViewShell::DeactivateOle()
@@ -331,42 +326,48 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
     switch ( nSlot )
     {
         case SID_INSERT_GRAPHIC:
-            FuInsertGraphic(this, pWin, pView, pDrModel, rReq);
+            FuInsertGraphic(*this, pWin, pView, pDrModel, rReq);
             // shell is set in MarkListHasChanged
             break;
 
         case SID_INSERT_AVMEDIA:
-            FuInsertMedia(this, pWin, pView, pDrModel, rReq);
+            FuInsertMedia(*this, pWin, pView, pDrModel, rReq);
             // shell is set in MarkListHasChanged
             break;
 
         case SID_INSERT_DIAGRAM:
-            FuInsertChart(this, pWin, pView, pDrModel, rReq);
+            FuInsertChart(*this, pWin, pView, pDrModel, rReq);
             break;
 
         case SID_INSERT_OBJECT:
         case SID_INSERT_SMATH:
         case SID_INSERT_FLOATINGFRAME:
-            FuInsertOLE(this, pWin, pView, pDrModel, rReq);
+            FuInsertOLE(*this, pWin, pView, pDrModel, rReq);
             break;
 
-        case SID_INSERT_DIAGRAM_FROM_FILE:
-            try
+        case SID_INSERT_SIGNATURELINE:
+        case SID_EDIT_SIGNATURELINE:
             {
-                sfx2::FileDialogHelper aDlg(ui::dialogs::TemplateDescription::FILEOPEN_SIMPLE,
-                        FileDialogFlags::NONE, "com.sun.star.chart2.ChartDocument");
-                if(aDlg.Execute() == ERRCODE_NONE )
-                {
-                    INetURLObject aURLObj( aDlg.GetPath() );
-                    OUString aURL = aURLObj.GetURLNoPass();
-                    FuInsertChartFromFile(this, pWin, pView, pDrModel, rReq, aURL);
-                }
+                const uno::Reference<frame::XModel> xModel( GetViewData().GetDocShell()->GetBaseModel() );
+
+                VclAbstractDialogFactory* pFact = VclAbstractDialogFactory::Create();
+                ScopedVclPtr<AbstractSignatureLineDialog> pDialog(pFact->CreateSignatureLineDialog(
+                    pWin->GetFrameWeld(), xModel, rReq.GetSlot() == SID_EDIT_SIGNATURELINE));
+                pDialog->Execute();
+                break;
             }
-            catch (const uno::Exception& e)
+
+        case SID_SIGN_SIGNATURELINE:
             {
-                SAL_WARN( "sc", "Cannot Insert Chart: " << e.Message);
+                const uno::Reference<frame::XModel> xModel(
+                    GetViewData().GetDocShell()->GetBaseModel());
+
+                VclAbstractDialogFactory* pFact = VclAbstractDialogFactory::Create();
+                ScopedVclPtr<AbstractSignSignatureLineDialog> pDialog(
+                    pFact->CreateSignSignatureLineDialog(GetFrameWeld(), xModel));
+                pDialog->Execute();
+                break;
             }
-            break;
 
         case SID_OBJECTRESIZE:
             {
@@ -376,8 +377,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
 
                 if ( pClient && pClient->IsObjectInPlaceActive() )
                 {
-                    const SfxRectangleItem& rRect =
-                        static_cast<const SfxRectangleItem&>(rReq.GetArgs()->Get(SID_OBJECTRESIZE));
+                    const SfxRectangleItem& rRect = rReq.GetArgs()->Get(SID_OBJECTRESIZE);
                     tools::Rectangle aRect( pWin->PixelToLogic( rRect.GetValue() ) );
 
                     if ( pView->AreObjectsMarked() )
@@ -408,13 +408,10 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
             {
                 SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
                 ScopedVclPtr<SfxAbstractLinksDialog> pDlg(pFact->CreateLinksDialog( pWin, rDoc.GetLinkManager() ));
-                if ( pDlg )
-                {
-                    pDlg->Execute();
-                    rBindings.Invalidate( nSlot );
-                    SfxGetpApp()->Broadcast( SfxHint( SfxHintId::ScAreaLinksChanged ) );     // Navigator
-                    rReq.Done();
-                }
+                pDlg->Execute();
+                rBindings.Invalidate( nSlot );
+                SfxGetpApp()->Broadcast( SfxHint( SfxHintId::ScAreaLinksChanged ) );     // Navigator
+                rReq.Done();
             }
             break;
 
@@ -432,25 +429,25 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
                     if(pPageView)
                     {
                         svx::ODataAccessDescriptor aDescriptor(pDescriptorItem->GetValue());
-                        SdrObject* pNewDBField = pDrView->CreateFieldControl(aDescriptor);
+                        SdrObjectUniquePtr pNewDBField = pDrView->CreateFieldControl(aDescriptor);
 
                         if(pNewDBField)
                         {
                             tools::Rectangle aVisArea = pWin->PixelToLogic(tools::Rectangle(Point(0,0), pWin->GetOutputSizePixel()));
                             Point aObjPos(aVisArea.Center());
                             Size aObjSize(pNewDBField->GetLogicRect().GetSize());
-                            aObjPos.X() -= aObjSize.Width() / 2;
-                            aObjPos.Y() -= aObjSize.Height() / 2;
+                            aObjPos.AdjustX( -(aObjSize.Width() / 2) );
+                            aObjPos.AdjustY( -(aObjSize.Height() / 2) );
                             tools::Rectangle aNewObjectRectangle(aObjPos, aObjSize);
 
                             pNewDBField->SetLogicRect(aNewObjectRectangle);
 
                             // controls must be on control layer, groups on front layer
-                            if ( dynamic_cast<const SdrUnoObj*>( pNewDBField) !=  nullptr )
+                            if ( dynamic_cast<const SdrUnoObj*>( pNewDBField.get() ) !=  nullptr )
                                 pNewDBField->NbcSetLayer(SC_LAYER_CONTROLS);
                             else
                                 pNewDBField->NbcSetLayer(SC_LAYER_FRONT);
-                            if (dynamic_cast<const SdrObjGroup*>( pNewDBField) !=  nullptr)
+                            if (dynamic_cast<const SdrObjGroup*>( pNewDBField.get() ) !=  nullptr)
                             {
                                 SdrObjListIter aIter( *pNewDBField, SdrIterMode::DeepWithGroups );
                                 SdrObject* pSubObj = aIter.Next();
@@ -464,7 +461,7 @@ void ScTabViewShell::ExecDrawIns(SfxRequest& rReq)
                                 }
                             }
 
-                            pView->InsertObjectAtView(pNewDBField, *pPageView);
+                            pView->InsertObjectAtView(pNewDBField.release(), *pPageView);
                         }
                     }
                 }
@@ -485,6 +482,7 @@ void ScTabViewShell::GetDrawInsState(SfxItemSet &rSet)
     bool bTabProt = GetViewData().GetDocument()->IsTabProtected(GetViewData().GetTabNo());
     ScDocShell* pDocShell = GetViewData().GetDocShell();
     bool bShared = pDocShell && pDocShell->IsDocShared();
+    SdrView* pSdrView = GetSdrView();
 
     SfxWhichIter aIter(rSet);
     sal_uInt16 nWhich = aIter.FirstWhich();
@@ -514,6 +512,16 @@ void ScTabViewShell::GetDrawInsState(SfxItemSet &rSet)
                     rSet.DisableItem( nWhich );
                 break;
 
+            case SID_INSERT_SIGNATURELINE:
+                if ( bTabProt || bShared || (pSdrView && pSdrView->GetMarkedObjectCount() != 0))
+                    rSet.DisableItem( nWhich );
+                break;
+            case SID_EDIT_SIGNATURELINE:
+            case SID_SIGN_SIGNATURELINE:
+                if (!IsSignatureLineSelected() || IsSignatureLineSigned())
+                    rSet.DisableItem(nWhich);
+                break;
+
             case SID_INSERT_GRAPHIC:
                 if (bTabProt || bShared)
                 {
@@ -548,10 +556,50 @@ void ScTabViewShell::GetDrawInsState(SfxItemSet &rSet)
     }
 }
 
+bool ScTabViewShell::IsSignatureLineSelected()
+{
+    SdrView* pSdrView = GetSdrView();
+    if (!pSdrView)
+        return false;
+
+    if (pSdrView->GetMarkedObjectCount() != 1)
+        return false;
+
+    SdrObject* pPickObj = pSdrView->GetMarkedObjectByIndex(0);
+    if (!pPickObj)
+        return false;
+
+    SdrGrafObj* pGraphic = dynamic_cast<SdrGrafObj*>(pPickObj);
+    if (!pGraphic)
+        return false;
+
+    return pGraphic->isSignatureLine();
+}
+
+bool ScTabViewShell::IsSignatureLineSigned()
+{
+    SdrView* pSdrView = GetSdrView();
+    if (!pSdrView)
+        return false;
+
+    if (pSdrView->GetMarkedObjectCount() != 1)
+        return false;
+
+    SdrObject* pPickObj = pSdrView->GetMarkedObjectByIndex(0);
+    if (!pPickObj)
+        return false;
+
+    SdrGrafObj* pGraphic = dynamic_cast<SdrGrafObj*>(pPickObj);
+    if (!pGraphic)
+        return false;
+
+    return pGraphic->isSignatureLineSigned();
+}
+
 void ScTabViewShell::ExecuteUndo(SfxRequest& rReq)
 {
     SfxShell* pSh = GetViewData().GetDispatcher().GetShell(0);
-    ::svl::IUndoManager* pUndoManager = pSh->GetUndoManager();
+    SfxUndoManager* pUndoManager = pSh->GetUndoManager();
 
     const SfxItemSet* pReqArgs = rReq.GetArgs();
     ScDocShell* pDocSh = GetViewData().GetDocShell();
@@ -593,7 +641,10 @@ void ScTabViewShell::ExecuteUndo(SfxRequest& rReq)
                     {
                         ViewShellId nViewShellId = GetViewShellId();
                         if (pAction->GetViewShellId() != nViewShellId)
+                        {
+                            rReq.SetReturnValue(SfxUInt32Item(SID_UNDO, static_cast<sal_uInt32>(SID_REPAIRPACKAGE)));
                             return;
+                        }
                     }
                 }
 
@@ -632,7 +683,7 @@ void ScTabViewShell::ExecuteUndo(SfxRequest& rReq)
 void ScTabViewShell::GetUndoState(SfxItemSet &rSet)
 {
     SfxShell* pSh = GetViewData().GetDispatcher().GetShell(0);
-    ::svl::IUndoManager* pUndoManager = pSh->GetUndoManager();
+    SfxUndoManager* pUndoManager = pSh->GetUndoManager();
 
     SfxWhichIter aIter(rSet);
     sal_uInt16 nWhich = aIter.FirstWhich();
