@@ -31,6 +31,7 @@
 #include <svtools/embedhlp.hxx>
 #include <sfx2/objsh.hxx>
 #include <sfx2/viewfrm.hxx>
+#include <sfx2/ipclient.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
 #include <com/sun/star/embed/Aspects.hpp>
 
@@ -167,7 +168,7 @@ void ScViewFunc::PasteDraw( const Point& rLogicPos, SdrModel* pModel,
                         pNewObj->NbcMove(Size(nDiffX,nDiffY));
                     if (pDestPage)
                         pDestPage->InsertObject( pNewObj );
-                    pScDrawView->AddUndo(new SdrUndoInsertObj( *pNewObj ));
+                    pScDrawView->AddUndo(o3tl::make_unique<SdrUndoInsertObj>( *pNewObj ));
 
                     if (ScDrawLayer::IsCellAnchored(*pNewObj))
                         ScDrawLayer::SetCellAnchoredFromPosition(*pNewObj, *GetViewData().GetDocument(), nTab,
