@@ -52,8 +52,8 @@ SdAnimationInfo::SdAnimationInfo(SdrObject& rObject)
                  mnVerb                     (0),
                  mrObject                   (rObject)
 {
-    maBlueScreen = RGB_Color(COL_LIGHTMAGENTA);
-    maDimColor = RGB_Color(COL_LIGHTGRAY);
+    maBlueScreen = COL_LIGHTMAGENTA;
+    maDimColor = COL_LIGHTGRAY;
 }
 
 SdAnimationInfo::SdAnimationInfo(const SdAnimationInfo& rAnmInfo, SdrObject& rObject)
@@ -89,13 +89,13 @@ SdAnimationInfo::~SdAnimationInfo()
 {
 }
 
-SdrObjUserData* SdAnimationInfo::Clone(SdrObject* pObject) const
+std::unique_ptr<SdrObjUserData> SdAnimationInfo::Clone(SdrObject* pObject) const
 {
     DBG_ASSERT( pObject, "SdAnimationInfo::Clone(), pObject must not be null!" );
     if( pObject == nullptr )
         pObject = &mrObject;
 
-    return new SdAnimationInfo(*this, *pObject );
+    return std::unique_ptr<SdrObjUserData>(new SdAnimationInfo(*this, *pObject ));
 }
 
 void SdAnimationInfo::SetBookmark( const OUString& rBookmark )
