@@ -48,6 +48,7 @@
 #include <svx/xtable.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/mnemonic.hxx>
+#include <vcl/lstbox.hxx>
 #include <svl/urihelper.hxx>
 #include <sfx2/filedlghelper.hxx>
 #include <svx/drawitem.hxx>
@@ -219,7 +220,7 @@ void SdTPAction::Construct()
     }
     else if( pOleObj )
     {
-        uno::Reference < embed::XEmbeddedObject > xObj = pOleObj->GetObjRef();
+        const uno::Reference < embed::XEmbeddedObject >& xObj = pOleObj->GetObjRef();
         if ( xObj.is() )
         {
             bOLEAction = true;
