@@ -17,12 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include "fupage.hxx"
+#include <fupage.hxx>
 
 #include <sfx2/viewfrm.hxx>
 
 // arrange Tab-Page
 
+#include <sfx2/sfxdlg.hxx>
 #include <svx/svxids.hrc>
 #include <svx/dialogs.hrc>
 #include <svl/itempool.hxx>
@@ -43,31 +44,31 @@
 #include <editeng/lrspitem.hxx>
 #include <svx/sdr/properties/properties.hxx>
 #include <sfx2/bindings.hxx>
-#include "glob.hrc"
 #include <editeng/shaditem.hxx>
 #include <editeng/boxitem.hxx>
 #include <editeng/sizeitem.hxx>
 #include <editeng/pbinitem.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/opengrf.hxx>
+#include <rtl/ustring.hxx>
 
-#include "strings.hrc"
-#include "sdpage.hxx"
-#include "View.hxx"
-#include "Window.hxx"
-#include "pres.hxx"
-#include "drawdoc.hxx"
-#include "DrawDocShell.hxx"
-#include "ViewShell.hxx"
-#include "ViewShellBase.hxx"
-#include "DrawViewShell.hxx"
-#include "app.hrc"
-#include "unchss.hxx"
-#include "undoback.hxx"
-#include "sdabstdlg.hxx"
-#include "sdresid.hxx"
-#include "sdundogr.hxx"
-#include "helpids.h"
+#include <strings.hrc>
+#include <sdpage.hxx>
+#include <View.hxx>
+#include <Window.hxx>
+#include <pres.hxx>
+#include <drawdoc.hxx>
+#include <DrawDocShell.hxx>
+#include <ViewShell.hxx>
+#include <ViewShellBase.hxx>
+#include <DrawViewShell.hxx>
+#include <app.hrc>
+#include <unchss.hxx>
+#include <undoback.hxx>
+#include <sdabstdlg.hxx>
+#include <sdresid.hxx>
+#include <sdundogr.hxx>
+#include <helpids.h>
 
 #include <memory>
 
@@ -83,7 +84,7 @@ namespace sd {
 #define MAXWIDTH  28350
 
 
-void mergeItemSetsImpl( SfxItemSet& rTarget, const SfxItemSet& rSource )
+static void mergeItemSetsImpl( SfxItemSet& rTarget, const SfxItemSet& rSource )
 {
     const sal_uInt16* pPtr = rSource.GetRanges();
     sal_uInt16 p1, p2;
@@ -110,7 +111,6 @@ FuPage::FuPage( ViewShell* pViewSh, ::sd::Window* pWin, ::sd::View* pView,
 :   FuPoor(pViewSh, pWin, pView, pDoc, rReq),
     mrReq(rReq),
     mpArgs( rReq.GetArgs() ),
-    mpBackgroundObjUndoAction( nullptr ),
     mbPageBckgrdDeleted( false ),
     mbMasterPage( false ),
     mbDisplayBackgroundTabPage( true ),
@@ -146,7 +146,7 @@ void FuPage::DoExecute( SfxRequest& )
         if( !mpArgs )
         {
             mpView->SdrEndTextEdit();
-            mpArgs = ExecuteDialog(mpWindow);
+            mpArgs = ExecuteDialog(mpWindow ? mpWindow->GetFrameWeld() : nullptr);
         }
 
         // if we now have arguments, apply them to current page
@@ -181,7 +181,7 @@ void MergePageBackgroundFilling(SdPage *pPage, SdStyleSheet *pStyleSheet, bool b
         // Only this page, get attributes for background fill
         const SfxItemSet& rBackgroundAttributes = pPage->getSdrPageProperties().GetItemSet();
 
-        if(drawing::FillStyle_NONE != static_cast<const XFillStyleItem&>(rBackgroundAttributes.Get(XATTR_FILLSTYLE)).GetValue())
+        if(drawing::FillStyle_NONE != rBackgroundAttributes.Get(XATTR_FILLSTYLE).GetValue())
         {
             // page attributes are used, take them
             rMergedAttr.Put(rBackgroundAttributes);
@@ -189,7 +189,7 @@ void MergePageBackgroundFilling(SdPage *pPage, SdStyleSheet *pStyleSheet, bool b
         else
         {
             if(pStyleSheet
-                && drawing::FillStyle_NONE != static_cast<const XFillStyleItem&>(pStyleSheet->GetItemSet().Get(XATTR_FILLSTYLE)).GetValue())
+                && drawing::FillStyle_NONE != pStyleSheet->GetItemSet().Get(XATTR_FILLSTYLE).GetValue())
             {
                 // if the page has no fill style, use the settings from the
                 // background stylesheet (if used)
@@ -204,23 +204,20 @@ void MergePageBackgroundFilling(SdPage *pPage, SdStyleSheet *pStyleSheet, bool b
     }
 }
 
-const SfxItemSet* FuPage::ExecuteDialog( vcl::Window* pParent )
+const SfxItemSet* FuPage::ExecuteDialog(weld::Window* pParent)
 {
     if (!mpDrawViewShell)
         return nullptr;
 
-    PageKind ePageKind = mpDrawViewShell->GetPageKind();
-
     SfxItemSet aNewAttr(mpDoc->GetPool(),
-                        mpDoc->GetPool().GetWhich(SID_ATTR_LRSPACE),
-                        mpDoc->GetPool().GetWhich(SID_ATTR_ULSPACE),
-                        SID_ATTR_PAGE, SID_ATTR_PAGE_SHARED,
-                        SID_ATTR_BORDER_OUTER, SID_ATTR_BORDER_OUTER,
-                        SID_ATTR_BORDER_SHADOW, SID_ATTR_BORDER_SHADOW,
-                        XATTR_FILL_FIRST, XATTR_FILL_LAST,
-                        SID_ATTR_PAGE_COLOR,SID_ATTR_PAGE_FILLSTYLE,
-                        EE_PARA_WRITINGDIR, EE_PARA_WRITINGDIR,
-                        0);
+                        {{mpDoc->GetPool().GetWhich(SID_ATTR_LRSPACE),
+                        mpDoc->GetPool().GetWhich(SID_ATTR_ULSPACE)},
+                        {SID_ATTR_PAGE, SID_ATTR_PAGE_SHARED},
+                        {SID_ATTR_BORDER_OUTER, SID_ATTR_BORDER_OUTER},
+                        {SID_ATTR_BORDER_SHADOW, SID_ATTR_BORDER_SHADOW},
+                        {XATTR_FILL_FIRST, XATTR_FILL_LAST},
+                        {SID_ATTR_PAGE_COLOR,SID_ATTR_PAGE_FILLSTYLE},
+                        {EE_PARA_WRITINGDIR, EE_PARA_WRITINGDIR}});
 
     // Retrieve additional data for dialog
 
@@ -252,16 +249,16 @@ const SfxItemSet* FuPage::ExecuteDialog( vcl::Window* pParent )
     aNewAttr.Put( aMaxSizeItem );
 
     // paperbin
-    SvxPaperBinItem aPaperBinItem( SID_ATTR_PAGE_PAPERBIN, (const sal_uInt8)mpPage->GetPaperBin() );
+    SvxPaperBinItem aPaperBinItem( SID_ATTR_PAGE_PAPERBIN, static_cast<sal_uInt8>(mpPage->GetPaperBin()) );
     aNewAttr.Put( aPaperBinItem );
 
-    SvxLRSpaceItem aLRSpaceItem( (sal_uInt16)mpPage->GetLftBorder(), (sal_uInt16)mpPage->GetRgtBorder(), 0, 0, mpDoc->GetPool().GetWhich(SID_ATTR_LRSPACE));
+    SvxLRSpaceItem aLRSpaceItem( static_cast<sal_uInt16>(mpPage->GetLeftBorder()), static_cast<sal_uInt16>(mpPage->GetRightBorder()), 0, 0, mpDoc->GetPool().GetWhich(SID_ATTR_LRSPACE));
     aNewAttr.Put( aLRSpaceItem );
 
-    SvxULSpaceItem aULSpaceItem( (sal_uInt16)mpPage->GetUppBorder(), (sal_uInt16)mpPage->GetLwrBorder(), mpDoc->GetPool().GetWhich(SID_ATTR_ULSPACE));
+    SvxULSpaceItem aULSpaceItem( static_cast<sal_uInt16>(mpPage->GetUpperBorder()), static_cast<sal_uInt16>(mpPage->GetLowerBorder()), mpDoc->GetPool().GetWhich(SID_ATTR_ULSPACE));
     aNewAttr.Put( aULSpaceItem );
 
-    // Applikation
+    // Application
     bool bScale = mpDoc->GetDocumentType() != DocumentType::Draw;
     aNewAttr.Put( SfxBoolItem( SID_ATTR_PAGE_EXT1, bScale ) );
 
@@ -279,7 +276,7 @@ const SfxItemSet* FuPage::ExecuteDialog( vcl::Window* pParent )
         p2 = pPtr[3];
         pPtr += 2;
     }
-    SfxItemSet aMergedAttr( *aNewAttr.GetPool(), p1, p2 );
+    SfxItemSet aMergedAttr( *aNewAttr.GetPool(), {{p1, p2}} );
 
     mergeItemSetsImpl( aMergedAttr, aNewAttr );
 
@@ -296,33 +293,31 @@ const SfxItemSet* FuPage::ExecuteDialog( vcl::Window* pParent )
     const sal_uInt16 nId = GetSlotID();
     if (nId == SID_SAVE_BACKGROUND)
     {
-        const XFillStyleItem& rStyleItem =
-            static_cast<const XFillStyleItem&>(aMergedAttr.Get(XATTR_FILLSTYLE));
-        if (drawing::FillStyle_BITMAP == (drawing::FillStyle)rStyleItem.GetValue())
+        const XFillStyleItem& rStyleItem = aMergedAttr.Get(XATTR_FILLSTYLE);
+        if (drawing::FillStyle_BITMAP == rStyleItem.GetValue())
         {
-            const XFillBitmapItem& rBitmap =
-                static_cast<const XFillBitmapItem&>(aMergedAttr.Get(XATTR_FILLBITMAP));
+            const XFillBitmapItem& rBitmap = aMergedAttr.Get(XATTR_FILLBITMAP);
             const GraphicObject& rGraphicObj = rBitmap.GetGraphicObject();
-            GraphicHelper::ExportGraphic(rGraphicObj.GetGraphic(), "");
+            GraphicHelper::ExportGraphic(pParent, rGraphicObj.GetGraphic(), "");
         }
     }
     else if (nId == SID_SELECT_BACKGROUND)
     {
-        SvxOpenGraphicDialog aDlg(SdResId(STR_SET_BACKGROUND_PICTURE));
+        SvxOpenGraphicDialog aDlg(SdResId(STR_SET_BACKGROUND_PICTURE), pParent);
 
-        if( aDlg.Execute() == GRFILTER_OK )
+        if( aDlg.Execute() == ERRCODE_NONE )
         {
             Graphic     aGraphic;
-            int nError = aDlg.GetGraphic(aGraphic);
-            if( nError == GRFILTER_OK )
+            ErrCode nError = aDlg.GetGraphic(aGraphic);
+            if( nError == ERRCODE_NONE )
             {
-                pTempSet.reset( new SfxItemSet( mpDoc->GetPool(), XATTR_FILL_FIRST, XATTR_FILL_LAST, 0) );
+                pTempSet.reset( new SfxItemSet( mpDoc->GetPool(), svl::Items<XATTR_FILL_FIRST, XATTR_FILL_LAST>{}) );
 
                 pTempSet->Put( XFillStyleItem( drawing::FillStyle_BITMAP ) );
 
                 // MigrateItemSet makes sure the XFillBitmapItem will have a unique name
-                SfxItemSet aMigrateSet( mpDoc->GetPool(), XATTR_FILLBITMAP, XATTR_FILLBITMAP );
-                aMigrateSet.Put(XFillBitmapItem(OUString("background"), aGraphic));
+                SfxItemSet aMigrateSet( mpDoc->GetPool(), svl::Items<XATTR_FILLBITMAP, XATTR_FILLBITMAP>{} );
+                aMigrateSet.Put(XFillBitmapItem("background", aGraphic));
                 SdrModel::MigrateItemSet( &aMigrateSet, pTempSet.get(), mpDoc );
 
                 pTempSet->Put( XFillBmpStretchItem( true ));
@@ -335,8 +330,8 @@ const SfxItemSet* FuPage::ExecuteDialog( vcl::Window* pParent )
     {
         // create the dialog
         SdAbstractDialogFactory* pFact = SdAbstractDialogFactory::Create();
-        ScopedVclPtr<SfxAbstractTabDialog> pDlg( pFact ? pFact->CreateSdTabPageDialog(mpViewShell->GetActiveWindow(), &aMergedAttr, mpDocSh, mbDisplayBackgroundTabPage) : nullptr );
-        if( pDlg.get() && pDlg->Execute() == RET_OK )
+        ScopedVclPtr<SfxAbstractTabDialog> pDlg( pFact->CreateSdTabPageDialog(mpViewShell->GetFrameWeld(), &aMergedAttr, mpDocSh, mbDisplayBackgroundTabPage) );
+        if( pDlg->Execute() == RET_OK )
             pTempSet.reset( new SfxItemSet(*pDlg->GetOutputItemSet()) );
     }
 
@@ -367,38 +362,23 @@ const SfxItemSet* FuPage::ExecuteDialog( vcl::Window* pParent )
                     ( aMergedAttr.GetItem<XFillStyleItem>( XATTR_FILLSTYLE )->GetValue() == drawing::FillStyle_NONE ) ) )
                 mbPageBckgrdDeleted = true;
 
-            bool bSetToAllPages = false;
-
-            // Ask, whether the setting are for the background-page or for the current page
-            if( !mbMasterPage && bChanges )
+            if( !mbMasterPage && bChanges && mbPageBckgrdDeleted )
             {
-                // But don't ask in notice-view, because we can't change the background of
-                // notice-masterpage (at the moment)
-                if( ePageKind != PageKind::Notes )
-                {
-                    ScopedVclPtrInstance<MessageDialog> aQuestionBox(
-                        pParent, SdResId(STR_PAGE_BACKGROUND_TXT),
-                        VclMessageType::Question, VclButtonsType::YesNo);
-                    aQuestionBox->SetText(SdResId(STR_PAGE_BACKGROUND_TITLE));
-                    bSetToAllPages = ( RET_YES == aQuestionBox->Execute() );
-                }
+                 mpBackgroundObjUndoAction.reset( new SdBackgroundObjUndoAction(
+                     *mpDoc, *mpPage, mpPage->getSdrPageProperties().GetItemSet()) );
 
-                if( mbPageBckgrdDeleted )
-                {
-                    mpBackgroundObjUndoAction.reset( new SdBackgroundObjUndoAction(
-                        *mpDoc, *mpPage, mpPage->getSdrPageProperties().GetItemSet()) );
-
-                    if(!mpPage->IsMasterPage())
-                    {
-                        // on normal pages, switch off fill attribute usage
-                        SdrPageProperties& rPageProperties = mpPage->getSdrPageProperties();
-                        rPageProperties.ClearItem( XATTR_FILLBITMAP );
-                        rPageProperties.ClearItem( XATTR_FILLGRADIENT );
-                        rPageProperties.ClearItem( XATTR_FILLHATCH );
-                        rPageProperties.PutItem(XFillStyleItem(drawing::FillStyle_NONE));
-                    }
-                }
+                 if(!mpPage->IsMasterPage())
+                 {
+                     // on normal pages, switch off fill attribute usage
+                     SdrPageProperties& rPageProperties = mpPage->getSdrPageProperties();
+                     rPageProperties.ClearItem( XATTR_FILLBITMAP );
+                     rPageProperties.ClearItem( XATTR_FILLGRADIENT );
+                     rPageProperties.ClearItem( XATTR_FILLHATCH );
+                     rPageProperties.PutItem(XFillStyleItem(drawing::FillStyle_NONE));
+                 }
             }
+
+
             /* Special treatment: reset the INVALIDS to
                NULL-Pointer (otherwise INVALIDs or pointer point
                to DefaultItems in the template; both would
@@ -407,64 +387,15 @@ const SfxItemSet* FuPage::ExecuteDialog( vcl::Window* pParent )
 
             if( mbMasterPage )
             {
-                StyleSheetUndoAction* pAction = new StyleSheetUndoAction(mpDoc, static_cast<SfxStyleSheet*>(pStyleSheet), &(*pTempSet.get()));
-                mpDocSh->GetUndoManager()->AddUndoAction(pAction);
+                mpDocSh->GetUndoManager()->AddUndoAction(o3tl::make_unique<StyleSheetUndoAction>(
+                    mpDoc, static_cast<SfxStyleSheet*>(pStyleSheet), &(*pTempSet)));
                 pStyleSheet->GetItemSet().Put( *(pTempSet.get()) );
                 sdr::properties::CleanupFillProperties( pStyleSheet->GetItemSet() );
                 pStyleSheet->Broadcast(SfxHint(SfxHintId::DataChanged));
             }
-            else if( bSetToAllPages )
-            {
-                OUString aComment(SdResId(STR_UNDO_CHANGE_PAGEFORMAT));
-                ::svl::IUndoManager* pUndoMgr = mpDocSh->GetUndoManager();
-                pUndoMgr->EnterListAction(aComment, aComment, 0, mpViewShell->GetViewShellBase().GetViewShellId());
-                SdUndoGroup* pUndoGroup = new SdUndoGroup(mpDoc);
-                pUndoGroup->SetComment(aComment);
-
-                //Set background on all master pages
-                sal_uInt16 nMasterPageCount = mpDoc->GetMasterSdPageCount(ePageKind);
-                for (sal_uInt16 i = 0; i < nMasterPageCount; ++i)
-                {
-                    SdPage *pMasterPage = mpDoc->GetMasterSdPage(i, ePageKind);
-                    SdStyleSheet *pStyle =
-                        pMasterPage->getPresentationStyle(HID_PSEUDOSHEET_BACKGROUND);
-                    StyleSheetUndoAction* pAction =
-                        new StyleSheetUndoAction(mpDoc, static_cast<SfxStyleSheet*>(pStyle), &(*pTempSet.get()));
-                    pUndoGroup->AddAction(pAction);
-                    pStyle->GetItemSet().Put( *(pTempSet.get()) );
-                    sdr::properties::CleanupFillProperties( pStyleSheet->GetItemSet() );
-                    pStyle->Broadcast(SfxHint(SfxHintId::DataChanged));
-                }
-
-                //Remove background from all pages to reset to the master bg
-                sal_uInt16 nPageCount(mpDoc->GetSdPageCount(ePageKind));
-                for(sal_uInt16 i=0; i<nPageCount; ++i)
-                {
-                    SdPage *pPage = mpDoc->GetSdPage(i, ePageKind);
-
-                    const SfxItemSet& rFillAttributes = pPage->getSdrPageProperties().GetItemSet();
-                       if(drawing::FillStyle_NONE != static_cast<const XFillStyleItem&>(rFillAttributes.Get(XATTR_FILLSTYLE)).GetValue())
-                    {
-                        SdBackgroundObjUndoAction *pBackgroundObjUndoAction = new SdBackgroundObjUndoAction(*mpDoc, *pPage, rFillAttributes);
-                        pUndoGroup->AddAction(pBackgroundObjUndoAction);
-
-                        SdrPageProperties& rPageProperties = pPage->getSdrPageProperties();
-                        rPageProperties.ClearItem( XATTR_FILLBITMAP );
-                        rPageProperties.ClearItem( XATTR_FILLGRADIENT );
-                        rPageProperties.ClearItem( XATTR_FILLHATCH );
-                        rPageProperties.PutItem(XFillStyleItem(drawing::FillStyle_NONE));
-
-                        pPage->ActionChanged();
-                    }
-                }
-
-                pUndoMgr->AddUndoAction(pUndoGroup);
-                pUndoMgr->LeaveListAction();
-
-            }
 
             // if background filling is set to master pages then clear from page set
-            if( mbMasterPage || bSetToAllPages )
+            if( mbMasterPage )
             {
                 for( sal_uInt16 nWhich = XATTR_FILL_FIRST; nWhich <= XATTR_FILL_LAST; nWhich++ )
                 {
@@ -545,7 +476,7 @@ void FuPage::ApplyItemSet( const SfxItemSet* pArgs )
         nLeft = static_cast<const SvxLRSpaceItem*>(pPoolItem)->GetLeft();
         nRight = static_cast<const SvxLRSpaceItem*>(pPoolItem)->GetRight();
 
-        if( mpPage->GetLftBorder() != nLeft || mpPage->GetRgtBorder() != nRight )
+        if( mpPage->GetLeftBorder() != nLeft || mpPage->GetRightBorder() != nRight )
             bSetPageSizeAndBorder = true;
 
     }
@@ -556,7 +487,7 @@ void FuPage::ApplyItemSet( const SfxItemSet* pArgs )
         nUpper = static_cast<const SvxULSpaceItem*>(pPoolItem)->GetUpper();
         nLower = static_cast<const SvxULSpaceItem*>(pPoolItem)->GetLower();
 
-        if( mpPage->GetUppBorder() != nUpper || mpPage->GetLwrBorder() != nLower )
+        if( mpPage->GetUpperBorder() != nUpper || mpPage->GetLowerBorder() != nLower )
             bSetPageSizeAndBorder = true;
     }
 
@@ -585,14 +516,14 @@ void FuPage::ApplyItemSet( const SfxItemSet* pArgs )
     if (nLeft == -1 && nUpper != -1)
     {
         bSetPageSizeAndBorder = true;
-        nLeft  = mpPage->GetLftBorder();
-        nRight = mpPage->GetRgtBorder();
+        nLeft  = mpPage->GetLeftBorder();
+        nRight = mpPage->GetRightBorder();
     }
     else if (nLeft != -1 && nUpper == -1)
     {
         bSetPageSizeAndBorder = true;
-        nUpper = mpPage->GetUppBorder();
-        nLower = mpPage->GetLwrBorder();
+        nUpper = mpPage->GetUpperBorder();
+        nLower = mpPage->GetLowerBorder();
     }
 
     if( bSetPageSizeAndBorder || !mbMasterPage )
@@ -621,7 +552,7 @@ void FuPage::ApplyItemSet( const SfxItemSet* pArgs )
     if( mpBackgroundObjUndoAction )
     {
         // set merge flag, because a SdUndoGroupAction could have been inserted before
-        mpDocSh->GetUndoManager()->AddUndoAction( mpBackgroundObjUndoAction.release(), true );
+        mpDocSh->GetUndoManager()->AddUndoAction( std::move(mpBackgroundObjUndoAction), true );
     }
 
     // Objects can not be bigger than ViewSize
