@@ -16,6 +16,7 @@
 
 #include <rtl/strbuf.hxx>
 #include <config_features.h>
+#include <sal/log.hxx>
 
 #include "DiscoveryService.hxx"
 
@@ -79,6 +80,7 @@ void DiscoveryService::setupSockets()
 #ifdef MACOSX
     // Bonjour for OSX
     zService = new OSXNetworkService();
+    zService->setup();
 #endif
 
 #if HAVE_FEATURE_AVAHI
@@ -88,15 +90,14 @@ void DiscoveryService::setupSockets()
     gethostname(hostname, 1023);
 
     zService = new AvahiNetworkService(hostname);
+    zService->setup();
 #endif
 
 #ifdef _WIN32
     zService = new WINNetworkService();
+    zService->setup();
 #endif
 
-    if (zService)
-        zService->setup();
-
     // Old implementation for backward compatibility matter
     mSocket = socket( AF_INET, SOCK_DGRAM, IPPROTO_UDP );
     if (mSocket == -1)
