@@ -19,22 +19,24 @@
 
 #include "SlsDragAndDropContext.hxx"
 
-#include "SlideSorter.hxx"
-#include "model/SlideSorterModel.hxx"
-#include "model/SlsPageEnumerationProvider.hxx"
-#include "view/SlideSorterView.hxx"
-#include "controller/SlideSorterController.hxx"
-#include "controller/SlsInsertionIndicatorHandler.hxx"
-#include "controller/SlsScrollBarManager.hxx"
-#include "controller/SlsProperties.hxx"
-#include "controller/SlsSelectionFunction.hxx"
-#include "controller/SlsSelectionManager.hxx"
-#include "controller/SlsClipboard.hxx"
-#include "controller/SlsTransferableData.hxx"
-#include "DrawDocShell.hxx"
-#include "drawdoc.hxx"
-#include "app.hrc"
-#include "sdtreelb.hxx"
+#include <SlideSorter.hxx>
+#include <model/SlideSorterModel.hxx>
+#include <model/SlsPageEnumerationProvider.hxx>
+#include <view/SlideSorterView.hxx>
+#include <controller/SlideSorterController.hxx>
+#include <controller/SlsInsertionIndicatorHandler.hxx>
+#include <controller/SlsScrollBarManager.hxx>
+#include <controller/SlsProperties.hxx>
+#include <controller/SlsSelectionFunction.hxx>
+#include <controller/SlsSelectionManager.hxx>
+#include <controller/SlsClipboard.hxx>
+#include <controller/SlsTransferableData.hxx>
+#include <DrawDocShell.hxx>
+#include <drawdoc.hxx>
+#include <Window.hxx>
+#include <app.hrc>
+#include <sdtreelb.hxx>
+#include <sdmod.hxx>
 #include <sfx2/bindings.hxx>
 
 namespace sd { namespace slidesorter { namespace controller {
@@ -62,9 +64,9 @@ DragAndDropContext::DragAndDropContext (SlideSorter& rSlideSorter)
     rSlideSorter.GetController().GetInsertionIndicatorHandler()->UpdateIndicatorIcon(pTransferable);
 }
 
-DragAndDropContext::~DragAndDropContext()
+DragAndDropContext::~DragAndDropContext() COVERITY_NOEXCEPT_FALSE
 {
-    SetTargetSlideSorter (Point(0,0));
+    SetTargetSlideSorter();
 }
 
 void DragAndDropContext::Dispose()
@@ -109,8 +111,7 @@ void DragAndDropContext::UpdatePosition (
     }
 }
 
-void DragAndDropContext::SetTargetSlideSorter(
-    const Point& rMousePosition)
+void DragAndDropContext::SetTargetSlideSorter()
 {
     if (mpTargetSlideSorter != nullptr)
     {
@@ -120,16 +121,6 @@ void DragAndDropContext::SetTargetSlideSorter(
     }
 
     mpTargetSlideSorter = nullptr;
-
-    if (mpTargetSlideSorter != nullptr)
-    {
-        mpTargetSlideSorter->GetController().GetInsertionIndicatorHandler()->Start(
-            false/*bIsOverSourceView*/);
-        mpTargetSlideSorter->GetController().GetInsertionIndicatorHandler()->UpdatePosition(
-            rMousePosition,
-            InsertionIndicatorHandler::UnknownMode);
-
-    }
 }
 
 } } } // end of namespace ::sd::slidesorter::controller
