@@ -17,12 +17,15 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <view/SlsPageObjectLayouter.hxx>
+#include <view/SlsTheme.hxx>
 #include <view/SlsLayouter.hxx>
 #include <model/SlideSorterModel.hxx>
 #include <model/SlsPageDescriptor.hxx>
 #include <Window.hxx>
 #include <rtl/math.hxx>
 #include <basegfx/numeric/ftools.hxx>
+#include <osl/diagnose.h>
 
 namespace sd { namespace slidesorter { namespace view {
 
@@ -38,11 +41,11 @@ public:
     sal_Int32 mnRightBorder;
     sal_Int32 mnTopBorder;
     sal_Int32 mnBottomBorder;
-    sal_Int32 mnVerticalGap;
-    sal_Int32 mnHorizontalGap;
-    Size maMinimalSize;
-    Size maPreferredSize;
-    Size maMaximalSize;
+    static const sal_Int32 gnVerticalGap = (10 - 2*Theme_FocusIndicatorWidth);
+    static const sal_Int32 gnHorizontalGap = (10 - 2*Theme_FocusIndicatorWidth);
+    Size const maMinimalSize;
+    Size const maPreferredSize;
+    Size const maMaximalSize;
     sal_Int32 mnMinimalColumnCount;
     sal_Int32 mnMaximalColumnCount;
     sal_Int32 mnPageCount;
@@ -429,8 +432,6 @@ Layouter::Implementation::Implementation (
       mnRightBorder(5),
       mnTopBorder(5),
       mnBottomBorder(5),
-      mnVerticalGap (10 - 2*Theme_FocusIndicatorWidth),
-      mnHorizontalGap(10 - 2*Theme_FocusIndicatorWidth),
       maMinimalSize(132,98),
       maPreferredSize(200,150),
       maMaximalSize(600,400),
@@ -453,8 +454,6 @@ Layouter::Implementation::Implementation (const Implementation& rImplementation)
       mnRightBorder(rImplementation.mnRightBorder),
       mnTopBorder(rImplementation.mnTopBorder),
       mnBottomBorder(rImplementation.mnBottomBorder),
-      mnVerticalGap(rImplementation.mnVerticalGap),
-      mnHorizontalGap(rImplementation.mnHorizontalGap),
       maMinimalSize(rImplementation.maMinimalSize),
       maPreferredSize(rImplementation.maPreferredSize),
       maMaximalSize(rImplementation.maMaximalSize),
@@ -497,7 +496,7 @@ bool Layouter::Implementation::Rearrange (
     mnBottomBorder = mnRequestedBottomBorder;
     if (mnColumnCount > 1)
     {
-        int nMinimumBorderWidth = mnHorizontalGap/2;
+        int nMinimumBorderWidth = gnHorizontalGap/2;
         if (mnLeftBorder < nMinimumBorderWidth)
             mnLeftBorder = nMinimumBorderWidth;
         if (mnRightBorder < nMinimumBorderWidth)
@@ -505,7 +504,7 @@ bool Layouter::Implementation::Rearrange (
     }
     else
     {
-        int nMinimumBorderHeight = mnVerticalGap/2;
+        int nMinimumBorderHeight = gnVerticalGap/2;
         if (mnTopBorder < nMinimumBorderHeight)
             mnTopBorder = nMinimumBorderHeight;
         if (mnBottomBorder < nMinimumBorderHeight)
@@ -537,7 +536,7 @@ sal_Int32 Layouter::Implementation::GetRowAtPosition (
     if (nY >= 0)
     {
         // Vertical distance from one row to the next.
-        const sal_Int32 nRowOffset (maPageObjectSize.Height() + mnVerticalGap);
+        const sal_Int32 nRowOffset (maPageObjectSize.Height() + gnVerticalGap);
 
         // Calculate row consisting of page objects and gap below.
         nRow = nY / nRowOffset;
@@ -551,7 +550,7 @@ sal_Int32 Layouter::Implementation::GetRowAtPosition (
                 nDistanceIntoGap,
                 eGapMembership,
                 nRow,
-                mnVerticalGap);
+                gnVerticalGap);
             if (!bIncludeBordersAndGaps || nResolvedRow != -1)
                 nRow = nResolvedRow;
         }
@@ -577,7 +576,7 @@ sal_Int32 Layouter::Implementation::GetColumnAtPosition (
     if (nX >= 0)
     {
         // Horizontal distance from one column to the next.
-        const sal_Int32 nColumnOffset (maPageObjectSize.Width() + mnHorizontalGap);
+        const sal_Int32 nColumnOffset (maPageObjectSize.Width() + gnHorizontalGap);
 
         // Calculate row consisting of page objects and gap below.
         nColumn = nX / nColumnOffset;
@@ -595,7 +594,7 @@ sal_Int32 Layouter::Implementation::GetColumnAtPosition (
                 nDistanceIntoGap,
                 eGapMembership,
                 nColumn,
-                mnHorizontalGap);
+                gnHorizontalGap);
             if (!bIncludeBordersAndGaps || nResolvedColumn != -1)
                 nColumn = nResolvedColumn;
         }
@@ -843,12 +842,12 @@ Size Layouter::Implementation::GetTargetSize (
     if (bCalculateWidth)
         aTargetSize.setWidth(
             (rWindowSize.Width() - mnLeftBorder - mnRightBorder
-                - (mnColumnCount-1) * mnHorizontalGap)
+                - (mnColumnCount-1) * gnHorizontalGap)
                     / mnColumnCount);
     else if (bCalculateHeight)
         aTargetSize.setHeight(
             (rWindowSize.Height() - mnTopBorder - mnBottomBorder
-                - (mnRowCount-1) * mnVerticalGap)
+                - (mnRowCount-1) * gnVerticalGap)
                     / mnRowCount);
 
     if (bCalculateWidth)
@@ -912,10 +911,10 @@ sal_Int32 Layouter::Implementation::GetIndex (
     return ::tools::Rectangle(
         Point (mnLeftBorder
             + nColumn * maPageObjectSize.Width()
-            + std::max<sal_Int32>(nColumn,0) * mnHorizontalGap,
+            + std::max<sal_Int32>(nColumn,0) * gnHorizontalGap,
             mnTopBorder
             + nRow * maPageObjectSize.Height()
-            + std::max<sal_Int32>(nRow,0) * mnVerticalGap),
+            + std::max<sal_Int32>(nRow,0) * gnVerticalGap),
         maPageObjectSize);
 }
 
@@ -929,19 +928,19 @@ sal_Int32 Layouter::Implementation::GetIndex (
     if (nColumn == 0)
         aBoundingBox.SetLeft( 0 );
     else
-        aBoundingBox.AdjustLeft( -(mnHorizontalGap/2) );
+        aBoundingBox.AdjustLeft( -(gnHorizontalGap/2) );
     if (nColumn == mnColumnCount-1)
         aBoundingBox.AdjustRight(mnRightBorder );
     else
-        aBoundingBox.AdjustRight(mnHorizontalGap/2 );
+        aBoundingBox.AdjustRight(gnHorizontalGap/2 );
     if (nRow == 0)
         aBoundingBox.SetTop( 0 );
     else
-        aBoundingBox.AdjustTop( -(mnVerticalGap/2) );
+        aBoundingBox.AdjustTop( -(gnVerticalGap/2) );
     if (nRow == mnRowCount-1)
         aBoundingBox.AdjustBottom(mnBottomBorder );
     else
-        aBoundingBox.AdjustBottom(mnVerticalGap/2 );
+        aBoundingBox.AdjustBottom(gnVerticalGap/2 );
     return aBoundingBox;
 }
 
@@ -957,13 +956,13 @@ sal_Int32 Layouter::Implementation::GetIndex (
             + mnRightBorder
             + mnColumnCount * maPageObjectSize.Width();
         if (mnColumnCount > 1)
-            nHorizontalSize +=  (mnColumnCount-1) * mnHorizontalGap;
+            nHorizontalSize +=  (mnColumnCount-1) * gnHorizontalGap;
         nVerticalSize =
             mnTopBorder
             + mnBottomBorder
             + nRowCount * maPageObjectSize.Height();
         if (nRowCount > 1)
-            nVerticalSize += (nRowCount-1) * mnVerticalGap;
+            nVerticalSize += (nRowCount-1) * gnVerticalGap;
     }
 
     return ::tools::Rectangle (
@@ -977,7 +976,7 @@ void Layouter::Implementation::CalculateVerticalLogicalInsertPosition (
     InsertPosition& rPosition) const
 {
     const sal_Int32 nY = rModelPosition.Y() - mnTopBorder + maPageObjectSize.Height()/2;
-    const sal_Int32 nRowHeight (maPageObjectSize.Height() + mnVerticalGap);
+    const sal_Int32 nRowHeight (maPageObjectSize.Height() + gnVerticalGap);
     const sal_Int32 nRow (::std::min(mnPageCount, nY / nRowHeight));
     rPosition.SetLogicalPosition (
         nRow,
@@ -1010,7 +1009,7 @@ void HorizontalImplementation::CalculateRowAndColumnCount (const Size&)
 void HorizontalImplementation::CalculateMaxRowAndColumnCount (const Size& rWindowSize)
 {
     mnMaxColumnCount = (rWindowSize.Width() - mnLeftBorder - mnRightBorder)
-        / (maPageObjectSize.Width()  + mnHorizontalGap);
+        / (maPageObjectSize.Width()  + gnHorizontalGap);
     mnMaxRowCount = 1;
 }
 
@@ -1025,7 +1024,7 @@ void HorizontalImplementation::CalculateLogicalInsertPosition (
     InsertPosition& rPosition) const
 {
     const sal_Int32 nX = rModelPosition.X() - mnLeftBorder + maPageObjectSize.Width()/2;
-    const sal_Int32 nColumnWidth (maPageObjectSize.Width() + mnHorizontalGap);
+    const sal_Int32 nColumnWidth (maPageObjectSize.Width() + gnHorizontalGap);
     const sal_Int32 nColumn (::std::min(mnPageCount, nX / nColumnWidth));
     rPosition.SetLogicalPosition (
         0,
@@ -1059,7 +1058,7 @@ void VerticalImplementation::CalculateRowAndColumnCount (const Size&)
 void VerticalImplementation::CalculateMaxRowAndColumnCount (const Size& rWindowSize)
 {
     mnMaxRowCount = (rWindowSize.Height() - mnTopBorder - mnBottomBorder)
-        / (maPageObjectSize.Height()  + mnVerticalGap);
+        / (maPageObjectSize.Height()  + gnVerticalGap);
     mnMaxColumnCount = 1;
 }
 
@@ -1100,7 +1099,7 @@ void GridImplementation::CalculateRowAndColumnCount (const Size& rWindowSize)
     // Calculate the column count.
     mnColumnCount
         = (rWindowSize.Width() - mnRequestedLeftBorder - mnRequestedRightBorder)
-        / (maPreferredSize.Width()  + mnHorizontalGap);
+        / (maPreferredSize.Width()  + gnHorizontalGap);
     if (mnColumnCount < mnMinimalColumnCount)
         mnColumnCount = mnMinimalColumnCount;
     if (mnColumnCount > mnMaximalColumnCount)
@@ -1111,9 +1110,9 @@ void GridImplementation::CalculateRowAndColumnCount (const Size& rWindowSize)
 void GridImplementation::CalculateMaxRowAndColumnCount (const Size& rWindowSize)
 {
     mnMaxColumnCount = (rWindowSize.Width() - mnLeftBorder - mnRightBorder)
-        / (maPageObjectSize.Width()  + mnHorizontalGap);
+        / (maPageObjectSize.Width()  + gnHorizontalGap);
     mnMaxRowCount = (rWindowSize.Height() - mnTopBorder - mnBottomBorder)
-        / (maPageObjectSize.Height()  + mnVerticalGap);
+        / (maPageObjectSize.Height()  + gnVerticalGap);
 }
 
 Size GridImplementation::CalculateTargetSize (
@@ -1137,7 +1136,7 @@ void GridImplementation::CalculateLogicalInsertPosition (
             mnRowCount-1,
             GetRowAtPosition (rModelPosition.Y(), true, GM_BOTH)));
         const sal_Int32 nX = rModelPosition.X() - mnLeftBorder + maPageObjectSize.Width()/2;
-        const sal_Int32 nColumnWidth (maPageObjectSize.Width() + mnHorizontalGap);
+        const sal_Int32 nColumnWidth (maPageObjectSize.Width() + gnHorizontalGap);
         sal_Int32 nColumn (::std::min(mnColumnCount, nX / nColumnWidth));
         sal_Int32 nIndex (nRow * mnColumnCount + nColumn);
         bool bIsAtRunEnd (nColumn == mnColumnCount);
