@@ -21,6 +21,7 @@
 #include <com/sun/star/linguistic2/XSpellChecker1.hpp>
 
 #include <View.hxx>
+#include <editeng/outlobj.hxx>
 #include <editeng/unolingu.hxx>
 #include <sfx2/request.hxx>
 #include <svx/obj3d.hxx>
@@ -63,6 +64,7 @@
 #include <sdmod.hxx>
 #include <sdpage.hxx>
 #include <sdresid.hxx>
+#include <unokywds.hxx>
 #include <DrawViewShell.hxx>
 #include <futext.hxx>
 #include <fuinsfil.hxx>
@@ -112,9 +114,7 @@ View::View(
     mrDoc(rDrawDoc),
     mpDocSh(rDrawDoc.GetDocSh()),
     mpViewSh(pViewShell),
-    mpDragSrcMarkList(nullptr),
     mpDropMarkerObj(nullptr),
-    mpDropMarker(nullptr),
     mnDragSrcPgNum(SDRPAGE_NOTFOUND),
     mnAction(DND_ACTION_NONE),
     maDropErrorIdle("sd View DropError"),
@@ -137,7 +137,7 @@ View::View(
 
     SetMinMoveDistancePixel(2);
     SetHitTolerancePixel(2);
-    SetMeasureLayer(SdResId(STR_LAYER_MEASURELINES));
+    SetMeasureLayer(sUNO_LayerName_measurelines);
 
     // Timer for delayed drop (has to be for MAC)
     maDropErrorIdle.SetInvokeHandler( LINK(this, View, DropErrorHdl) );
@@ -146,11 +146,7 @@ View::View(
 
 void View::ImplClearDrawDropMarker()
 {
-    if(mpDropMarker)
-    {
-        delete mpDropMarker;
-        mpDropMarker = nullptr;
-    }
+    mpDropMarker.reset();
 }
 
 View::~View()
@@ -474,19 +470,13 @@ void View::CompleteRedraw(OutputDevice* pOutDev, const vcl::Region& rReg, sdr::c
                 SdrOutliner& rOutl = mrDoc.GetDrawOutliner();
                 bool bScreenDisplay(true);
 
-                if(bScreenDisplay && pOutDev && OUTDEV_PRINTER == pOutDev->GetOutDevType())
-                {
-                    // #i75566# printing; suppress AutoColor BackgroundColor generation
-                    // for visibility reasons by giving GetPageBackgroundColor()
-                    // the needed hint
+                // #i75566# printing; suppress AutoColor BackgroundColor generation
+                // for visibility reasons by giving GetPageBackgroundColor()
+                // the needed hint
+                // #i75566# PDF export; suppress AutoColor BackgroundColor generation (see printing)
+                if (pOutDev && ((OUTDEV_PRINTER == pOutDev->GetOutDevType())
+                        || (OUTDEV_PDF == pOutDev->GetOutDevType())))
                     bScreenDisplay = false;
-                }
-
-                if(bScreenDisplay && pOutDev && pOutDev->GetPDFWriter())
-                {
-                    // #i75566# PDF export; suppress AutoColor BackgroundColor generation (see above)
-                    bScreenDisplay = false;
-                }
 
                 // #i75566# Name change GetBackgroundColor -> GetPageBackgroundColor and
                 // hint value if screen display. Only then the AutoColor mechanisms shall be applied
@@ -531,7 +521,7 @@ bool View::IsPresObjSelected(bool bOnPage, bool bOnMasterPage, bool bCheckPresOb
         /* Drag&Drop is in progress
            Source and destination page are different:
            we use the saved mark list */
-        pMarkList = mpDragSrcMarkList;
+        pMarkList = mpDragSrcMarkList.get();
     }
     else
     {
@@ -577,7 +567,7 @@ bool View::IsPresObjSelected(bool bOnPage, bool bOnMasterPage, bool bCheckPresOb
         }
     }
 
-    if (pMarkList != mpDragSrcMarkList)
+    if (pMarkList != mpDragSrcMarkList.get())
     {
        delete pMarkList;
     }
@@ -602,7 +592,8 @@ void View::SelectAll()
 bool View::SetStyleSheet(SfxStyleSheet* pStyleSheet, bool bDontRemoveHardAttr)
 {
     // forward to SdrView
-    return FmFormView::SetStyleSheet(pStyleSheet, bDontRemoveHardAttr);
+    FmFormView::SetStyleSheet(pStyleSheet, bDontRemoveHardAttr);
+    return true;
 }
 
 /**
@@ -699,6 +690,9 @@ bool View::SdrBeginTextEdit(
     {
         mpViewSh->GetViewShellBase().GetDrawController().FireSelectionChangeListener();
 
+        if (pObj && pObj->GetObjIdentifier() == OBJ_TABLE)
+            mpViewSh->UpdateScrollBars();
+
         if (comphelper::LibreOfficeKit::isActive())
         {
             if (OutlinerView* pView = GetTextEditOutlinerView())
@@ -843,7 +837,7 @@ bool View::RestoreDefaultText( SdrTextObj* pTextObj )
  */
 void View::SetMarkedOriginalSize()
 {
-    SdrUndoGroup* pUndoGroup = new SdrUndoGroup(mrDoc);
+    std::unique_ptr<SdrUndoGroup> pUndoGroup(new SdrUndoGroup(mrDoc));
     const size_t nCount = GetMarkedObjectCount();
     bool            bOK = false;
 
@@ -908,10 +902,8 @@ void View::SetMarkedOriginalSize()
     if( bOK )
     {
         pUndoGroup->SetComment(SdResId(STR_UNDO_ORIGINALSIZE));
-        mpDocSh->GetUndoManager()->AddUndoAction(pUndoGroup);
+        mpDocSh->GetUndoManager()->AddUndoAction(std::move(pUndoGroup));
     }
-    else
-        delete pUndoGroup;
 }
 
 /**
@@ -1144,13 +1136,6 @@ bool View::HasMarkedPoints() const
         return FmFormView::HasMarkedPoints();
 }
 
-sal_Int32 View::GetMarkedPointCount() const
-{
-    sal_Int32 nCount = FmFormView::GetMarkedPointCount();
-    nCount += maSmartTags.GetMarkedPointCount();
-    return nCount;
-}
-
 bool View::IsPointMarkable(const SdrHdl& rHdl) const
 {
     if( SmartTagSet::IsPointMarkable( rHdl ) )
@@ -1299,7 +1284,7 @@ void View::ChangeMarkedObjectsBulletsNumbering(
         return;
 
     const bool bUndoEnabled = pSdrModel->IsUndoEnabled();
-    SdrUndoGroup* pUndoGroup = bUndoEnabled ? new SdrUndoGroup(*pSdrModel) : nullptr;
+    std::unique_ptr<SdrUndoGroup> pUndoGroup(bUndoEnabled ? new SdrUndoGroup(*pSdrModel) : nullptr);
 
     const bool bToggleOn = ShouldToggleOn( bToggle, bHandleBullets );
 
@@ -1341,8 +1326,7 @@ void View::ChangeMarkedObjectsBulletsNumbering(
                     pOutliner->SetText(*(pText->GetOutlinerParaObject()));
                     if (bUndoEnabled)
                     {
-                        SdrUndoObjSetText* pTxtUndo = dynamic_cast< SdrUndoObjSetText* >(pSdrModel->GetSdrUndoFactory().CreateUndoObjectSetText(*pTextObj, nCellIndex));
-                        pUndoGroup->AddAction(pTxtUndo);
+                        pUndoGroup->AddAction(pSdrModel->GetSdrUndoFactory().CreateUndoObjectSetText(*pTextObj, nCellIndex));
                     }
                     if ( !bToggleOn )
                     {
@@ -1372,8 +1356,8 @@ void View::ChangeMarkedObjectsBulletsNumbering(
             pOutliner->SetText(*pParaObj);
             if (bUndoEnabled)
             {
-                SdrUndoObjSetText* pTxtUndo = dynamic_cast< SdrUndoObjSetText* >(pSdrModel->GetSdrUndoFactory().CreateUndoObjectSetText(*pTextObj, 0));
-                pUndoGroup->AddAction(pTxtUndo);
+                pUndoGroup->AddAction(
+                    pSdrModel->GetSdrUndoFactory().CreateUndoObjectSetText(*pTextObj, 0));
             }
             if ( !bToggleOn )
             {
@@ -1392,11 +1376,9 @@ void View::ChangeMarkedObjectsBulletsNumbering(
     if ( bUndoEnabled && pUndoGroup->GetActionCount() > 0 )
     {
         pSdrModel->BegUndo();
-        pSdrModel->AddUndo(pUndoGroup);
+        pSdrModel->AddUndo(std::move(pUndoGroup));
         pSdrModel->EndUndo();
     }
-    else
-        delete pUndoGroup;
 }
 
 } // end of namespace sd
