@@ -19,15 +19,14 @@
 
 #include <config_features.h>
 
-#include "appbaslib.hxx"
+#include <appbaslib.hxx>
 
 #include <sfx2/sfxuno.hxx>
-#include "sfxtypes.hxx"
+#include <sfxtypes.hxx>
 #include <sfx2/app.hxx>
 
 #include <basic/basmgr.hxx>
 #include <tools/diagnose_ex.h>
-#include <comphelper/processfactory.hxx>
 #include <cppuhelper/weak.hxx>
 
 using namespace ::com::sun::star::uno;
@@ -77,7 +76,7 @@ void SfxBasicManagerHolder::reset( BasicManager* _pBasicManager )
         }
         catch( const Exception& )
         {
-            DBG_UNHANDLED_EXCEPTION();
+            DBG_UNHANDLED_EXCEPTION("sfx.appl");
         }
     }
 #endif
@@ -96,7 +95,7 @@ void SfxBasicManagerHolder::storeAllLibraries()
     }
     catch( const Exception& )
     {
-        DBG_UNHANDLED_EXCEPTION();
+        DBG_UNHANDLED_EXCEPTION("sfx.appl");
     }
 #endif
 }
@@ -115,7 +114,7 @@ void SfxBasicManagerHolder::setStorage( const Reference< XStorage >& _rxStorage
     }
     catch( const Exception& )
     {
-        DBG_UNHANDLED_EXCEPTION();
+        DBG_UNHANDLED_EXCEPTION("sfx.appl");
     }
 #endif
 }
@@ -165,7 +164,7 @@ bool SfxBasicManagerHolder::LegacyPsswdBinaryLimitExceeded( std::vector< OUStrin
 }
 
 // Service for application library container
-extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface *
 com_sun_star_comp_sfx2_ApplicationDialogLibraryContainer_get_implementation(
     css::uno::XComponentContext *,
     css::uno::Sequence<css::uno::Any> const &)
@@ -177,7 +176,7 @@ com_sun_star_comp_sfx2_ApplicationDialogLibraryContainer_get_implementation(
 }
 
 // Service for application library container
-extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface * SAL_CALL
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface *
 com_sun_star_comp_sfx2_ApplicationScriptLibraryContainer_get_implementation(
     css::uno::XComponentContext *,
     css::uno::Sequence<css::uno::Any> const &)
