@@ -158,7 +158,7 @@ extern "C" bool GetSpecialCharsForEdit( vcl::Window const * i_pParent, const vcl
 
 #endif
 
-OUString SfxGetSpecialCharsForEdit(vcl::Window* pParent, const vcl::Font& rFont)
+static OUString SfxGetSpecialCharsForEdit(vcl::Window* pParent, const vcl::Font& rFont)
 {
     static bool bDetermineFunction = false;
     static PFunc_getSpecialCharsForEdit pfunc_getSpecialCharsForEdit = nullptr;
@@ -218,7 +218,7 @@ void SfxApplication::Initialize_Impl()
         SolarMutexGuard aGuard;
         //ensure instantiation of listener that manages the internal recently-used
         //list
-        SfxPickList::ensure();
+        pImpl->mxAppPickList.reset(new SfxPickList(*this));
     }
 
     DBG_ASSERT( !pImpl->pAppDispat, "AppDispatcher already exists" );
