@@ -38,6 +38,7 @@
 #include <comphelper/processfactory.hxx>
 #include <comphelper/propertyvalue.hxx>
 #include <rtl/strbuf.hxx>
+#include <sal/log.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/childwin.hxx>
@@ -96,9 +97,8 @@ struct SfxObjectBars_Impl
     ToolbarId          eId;      // ConfigId of the Toolbox
     sal_uInt16         nPos;
     SfxVisibilityFlags nFlags;   // special visibility flags
-    SfxInterface*      pIFace;
 
-    SfxObjectBars_Impl() : eId(ToolbarId::None), nPos(0), nFlags(SfxVisibilityFlags::Invisible), pIFace(nullptr) {}
+    SfxObjectBars_Impl() : eId(ToolbarId::None), nPos(0), nFlags(SfxVisibilityFlags::Invisible) {}
 };
 
 struct SfxDispatcher_Impl
@@ -114,7 +114,6 @@ struct SfxDispatcher_Impl
     Idle                 aIdle;        // for Flush
     std::deque<SfxToDo_Impl> aToDoStack;    // not processed Push/Pop
     SfxViewFrame*        pFrame;        // NULL or associated Frame
-    SfxDispatcher*       pParent;       // AppDispatcher, NULL if possible
     tools::SvRef<SfxHintPoster>
                          xPoster;       // Execute asynchronous
     bool                 bFlushing;     // sal_True during Flush //?
@@ -129,7 +128,6 @@ struct SfxDispatcher_Impl
     bool                 bNoUI;         // UI only from Parent Dispatcher
     bool                 bReadOnly;     // Document is ReadOnly
     bool                 bQuiet;        // Only use parent dispatcher
-    bool                 bModal;        // Only slots from parent dispatcher
 
     SfxSlotFilterState   nFilterEnabling; // 1==filter enabled slots,
                                           // 2==ReadOnlyDoc overturned
@@ -393,25 +391,19 @@ void SfxDispatcher::Construct_Impl()
     xImp->bUpdated = false;
     xImp->bLocked = false;
     xImp->bActive = false;
-    xImp->pParent = nullptr;
     xImp->bNoUI = false;
     xImp->bReadOnly = false;
     xImp->bQuiet = false;
-    xImp->bModal = false;
     xImp->pInCallAliveFlag = nullptr;
     xImp->nFilterEnabling = SfxSlotFilterState::DISABLED;
     xImp->nDisableFlags = SfxDisableFlags::NONE;
 
-    xImp->pParent = nullptr;
-
     xImp->bInvalidateOnUnlock = false;
 
     for (SfxObjectBars_Impl & rObjBar : xImp->aObjBars)
         rObjBar.eId = ToolbarId::None;
 
-    Link<SfxRequest*,void> aGenLink( LINK(this, SfxDispatcher, PostMsgHandler) );
-
-    xImp->xPoster = new SfxHintPoster(aGenLink);
+    xImp->xPoster = new SfxHintPoster(std::bind(&SfxDispatcher::PostMsgHandler, this, std::placeholders::_1));
 
     xImp->aIdle.SetPriority(TaskPriority::HIGH_IDLE );
     xImp->aIdle.SetInvokeHandler( LINK(this, SfxDispatcher, EventHdl_Impl ) );
@@ -444,7 +436,7 @@ SfxDispatcher::~SfxDispatcher()
 
     // So that no timer by Reschedule in PlugComm strikes the LeaveRegistrations
     xImp->aIdle.Stop();
-    xImp->xPoster->SetEventHdl( Link<SfxRequest*,void>() );
+    xImp->xPoster->SetEventHdl( std::function<void (std::unique_ptr<SfxRequest>)>() );
 
     // Notify the stack variables in Call_Impl
     if ( xImp->pInCallAliveFlag )
@@ -506,7 +498,7 @@ void SfxDispatcher::Pop(SfxShell& rShell, SfxDispatcherPopFlags nMode)
             << (bUntil ? " (up to)" : ""));
 
     // same shell as on top of the to-do stack?
-    if(xImp->aToDoStack.size() && xImp->aToDoStack.front().pCluster == &rShell)
+    if(!xImp->aToDoStack.empty() && xImp->aToDoStack.front().pCluster == &rShell)
     {
         // cancel inverse actions
         if ( xImp->aToDoStack.front().bPush != bPush )
@@ -624,13 +616,6 @@ sal_uInt16 SfxDispatcher::GetShellLevel(const SfxShell& rShell)
     for ( size_t n = 0; n < xImp->aStack.size(); ++n )
         if ( *( xImp->aStack.rbegin() + n ) == &rShell )
             return n;
-    if ( xImp->pParent )
-    {
-        sal_uInt16 nRet = xImp->pParent->GetShellLevel(rShell);
-        if ( nRet == USHRT_MAX )
-            return nRet;
-        return  nRet + xImp->aStack.size();
-    }
 
     return USHRT_MAX;
 }
@@ -647,8 +632,6 @@ SfxShell *SfxDispatcher::GetShell(sal_uInt16 nIdx) const
     sal_uInt16 nShellCount = xImp->aStack.size();
     if ( nIdx < nShellCount )
         return *(xImp->aStack.rbegin() + nIdx);
-    else if ( xImp->pParent )
-        return xImp->pParent->GetShell( nIdx - nShellCount );
     return nullptr;
 }
 
@@ -718,7 +701,7 @@ void SfxDispatcher::DoActivate_Impl(bool bMDI)
 
     if ( bMDI && xImp->pFrame )
     {
-        xImp->pFrame->GetFrame().GetWorkWindow_Impl()->HidePopups_Impl( false, false, 1 );
+        xImp->pFrame->GetFrame().GetWorkWindow_Impl()->HidePopups_Impl( false, 1 );
     }
 
     if(!xImp->aToDoStack.empty())
@@ -792,7 +775,7 @@ void SfxDispatcher::DoDeactivate_Impl(bool bMDI, SfxViewFrame const * pNew)
 
     if ( bHidePopups )
     {
-        xImp->pFrame->GetFrame().GetWorkWindow_Impl()->HidePopups_Impl( true, false, 1 );
+        xImp->pFrame->GetFrame().GetWorkWindow_Impl()->HidePopups_Impl( true, 1 );
     }
 
     Flush();
@@ -812,13 +795,13 @@ void SfxDispatcher::DoDeactivate_Impl(bool bMDI, SfxViewFrame const * pNew)
                      The SfxShell was not found, ppShell and ppSlot are invalid.
 */
 bool SfxDispatcher::GetShellAndSlot_Impl(sal_uInt16 nSlot, SfxShell** ppShell,
-        const SfxSlot** ppSlot, bool bOwnShellsOnly, bool bModal, bool bRealSlot)
+        const SfxSlot** ppSlot, bool bOwnShellsOnly, bool bRealSlot)
 {
     SFX_STACK(SfxDispatcher::GetShellAndSlot_Impl);
 
     Flush();
     SfxSlotServer aSvr;
-    if ( FindServer_(nSlot, aSvr, bModal) )
+    if ( FindServer_(nSlot, aSvr) )
     {
         if ( bOwnShellsOnly && aSvr.GetShellLevel() >= xImp->aStack.size() )
             return false;
@@ -855,22 +838,16 @@ void SfxDispatcher::Execute_(SfxShell& rShell, const SfxSlot& rSlot,
          ( (eCallMode & SfxCallMode::SYNCHRON) == SfxCallMode::SLOT &&
            rSlot.IsMode(SfxSlotMode::ASYNCHRON) ) )
     {
-        SfxDispatcher *pDispat = this;
-        while ( pDispat )
+        sal_uInt16 nShellCount = xImp->aStack.size();
+        for ( sal_uInt16 n=0; n<nShellCount; n++ )
         {
-            sal_uInt16 nShellCount = pDispat->xImp->aStack.size();
-            for ( sal_uInt16 n=0; n<nShellCount; n++ )
+            if ( &rShell == *(xImp->aStack.rbegin() + n) )
             {
-                if ( &rShell == *(pDispat->xImp->aStack.rbegin() + n) )
-                {
-                    if ( bool(eCallMode & SfxCallMode::RECORD) )
-                        rReq.AllowRecording( true );
-                    pDispat->xImp->xPoster->Post(new SfxRequest(rReq));
-                    return;
-                }
+                if ( bool(eCallMode & SfxCallMode::RECORD) )
+                    rReq.AllowRecording( true );
+                xImp->xPoster->Post(o3tl::make_unique<SfxRequest>(rReq));
+                return;
             }
-
-            pDispat = pDispat->xImp->pParent;
         }
     }
     else
@@ -880,7 +857,7 @@ void SfxDispatcher::Execute_(SfxShell& rShell, const SfxSlot& rSlot,
 /** Helper function to put from rItem below the Which-ID in the pool of the
     Item Sets rSet.
 */
-void MappedPut_Impl(SfxAllItemSet &rSet, const SfxPoolItem &rItem)
+static void MappedPut_Impl(SfxAllItemSet &rSet, const SfxPoolItem &rItem)
 {
     // Put with mapped Which-Id if possible
     const SfxItemPool *pPool = rSet.GetPool();
@@ -895,15 +872,6 @@ const SfxSlot* SfxDispatcher::GetSlot( const OUString& rCommand )
     // Count the number of Shells on the linked Dispatcher
     Flush();
     sal_uInt16 nTotCount = xImp->aStack.size();
-    if ( xImp->pParent )
-    {
-        SfxDispatcher *pParent = xImp->pParent;
-        while ( pParent )
-        {
-            nTotCount = nTotCount + pParent->xImp->aStack.size();
-            pParent = pParent->xImp->pParent;
-        }
-    }
 
     for ( sal_uInt16 i = 0; i < nTotCount; ++i )
     {
@@ -925,8 +893,7 @@ const SfxPoolItem* SfxDispatcher::Execute(sal_uInt16 nSlot, SfxCallMode nCall,
 
     SfxShell *pShell = nullptr;
     const SfxSlot *pSlot = nullptr;
-    if ( GetShellAndSlot_Impl( nSlot,  &pShell, &pSlot, false,
-                               SfxCallMode::MODAL==(nCall&SfxCallMode::MODAL) ) )
+    if ( GetShellAndSlot_Impl( nSlot,  &pShell, &pSlot, false, true ) )
     {
         SfxAllItemSet aSet( pShell->GetPool() );
         if ( pArgs )
@@ -970,8 +937,7 @@ const SfxPoolItem* SfxDispatcher::Execute(sal_uInt16 nSlot, SfxCallMode eCall,
 
     SfxShell *pShell = nullptr;
     const SfxSlot *pSlot = nullptr;
-    if ( GetShellAndSlot_Impl( nSlot,  &pShell, &pSlot, false,
-                               SfxCallMode::MODAL==(eCall&SfxCallMode::MODAL) ) )
+    if ( GetShellAndSlot_Impl( nSlot,  &pShell, &pSlot, false, true ) )
     {
         SfxRequest* pReq;
         if ( pArgs && *pArgs )
@@ -1019,8 +985,7 @@ const SfxPoolItem* SfxDispatcher::Execute(sal_uInt16 nSlot, SfxCallMode eCall,
 
     SfxShell *pShell = nullptr;
     const SfxSlot *pSlot = nullptr;
-    if ( GetShellAndSlot_Impl( nSlot,  &pShell, &pSlot, false,
-                               SfxCallMode::MODAL==(eCall&SfxCallMode::MODAL) ) )
+    if ( GetShellAndSlot_Impl( nSlot,  &pShell, &pSlot, false, true ) )
     {
         SfxAllItemSet aSet( pShell->GetPool() );
         SfxItemIter aIter(rArgs);
@@ -1071,8 +1036,7 @@ const SfxPoolItem* SfxDispatcher::ExecuteList(sal_uInt16 nSlot, SfxCallMode eCal
 
     SfxShell *pShell = nullptr;
     const SfxSlot *pSlot = nullptr;
-    if ( GetShellAndSlot_Impl( nSlot, &pShell, &pSlot, false,
-                               SfxCallMode::MODAL==(eCall&SfxCallMode::MODAL) ) )
+    if ( GetShellAndSlot_Impl( nSlot, &pShell, &pSlot, false, true ) )
     {
        SfxAllItemSet aSet( pShell->GetPool() );
 
@@ -1103,7 +1067,7 @@ const SfxPoolItem* SfxDispatcher::ExecuteList(sal_uInt16 nSlot, SfxCallMode eCal
 
 /** Helper method to receive the asynchronously executed <SfxRequest>s.
 */
-IMPL_LINK(SfxDispatcher, PostMsgHandler, SfxRequest*, pReq, void)
+void SfxDispatcher::PostMsgHandler(std::unique_ptr<SfxRequest> pReq)
 {
     DBG_ASSERT( !xImp->bFlushing, "recursive call to dispatcher" );
     SFX_STACK(SfxDispatcher::PostMsgHandler);
@@ -1115,7 +1079,7 @@ IMPL_LINK(SfxDispatcher, PostMsgHandler, SfxRequest*, pReq, void)
         {
             Flush();
             SfxSlotServer aSvr;
-            if ( FindServer_(pReq->GetSlot(), aSvr, true ) ) // HACK(x), whatever that was supposed to mean
+            if ( FindServer_(pReq->GetSlot(), aSvr ) ) // HACK(x), whatever that was supposed to mean
             {
                 const SfxSlot *pSlot = aSvr.GetSlot();
                 SfxShell *pSh = GetShell(aSvr.GetShellLevel());
@@ -1129,13 +1093,11 @@ IMPL_LINK(SfxDispatcher, PostMsgHandler, SfxRequest*, pReq, void)
         else
         {
             if ( xImp->bLocked )
-                xImp->aReqArr.emplace_back(new SfxRequest(*pReq));
+                xImp->aReqArr.emplace_back(std::move(pReq));
             else
-                xImp->xPoster->Post(new SfxRequest(*pReq));
+                xImp->xPoster->Post(std::move(pReq));
         }
     }
-
-    delete pReq;
 }
 
 void SfxDispatcher::SetMenu_Impl()
@@ -1177,22 +1139,17 @@ void SfxDispatcher::Update_Impl( bool bForce )
     if ( !xImp->pFrame )
         return;
 
-    SfxDispatcher *pDisp = this;
     bool bUpdate = bForce;
-    while ( pDisp && pDisp->xImp->pFrame )
+    if ( xImp->pFrame )
     {
-        SfxWorkWindow *pWork = pDisp->xImp->pFrame->GetFrame().GetWorkWindow_Impl();
+        SfxWorkWindow *pWork = xImp->pFrame->GetFrame().GetWorkWindow_Impl();
         SfxDispatcher *pAct = pWork->GetBindings().GetDispatcher_Impl();
-        if ( pAct == pDisp || pAct == this )
+        if (pAct == this)
         {
             if ( !bUpdate )
-                bUpdate = !pDisp->xImp->bUpdated;
-            pDisp->xImp->bUpdated = true;
+                bUpdate = !xImp->bUpdated;
+            xImp->bUpdated = true;
         }
-        else
-            break;
-
-        pDisp = pDisp->xImp->pParent;
     }
 
     if ( !bUpdate || xImp->pFrame->GetFrame().IsClosing_Impl() )
@@ -1237,29 +1194,20 @@ void SfxDispatcher::Update_Impl( bool bForce )
     SfxWorkWindow *pWorkWin = xImp->pFrame->GetFrame().GetWorkWindow_Impl();
     pWorkWin->ResetStatusBar_Impl();
 
-    SfxDispatcher *pDispat = this;
-    while ( pDispat )
     {
-        SfxWorkWindow *pWork = pDispat->xImp->pFrame->GetFrame().GetWorkWindow_Impl();
+        SfxWorkWindow *pWork = xImp->pFrame->GetFrame().GetWorkWindow_Impl();
         SfxDispatcher *pAct = pWork->GetBindings().GetDispatcher_Impl();
-        if ( pAct == pDispat || pAct == this )
+        if (pAct == this)
         {
             pWork->ResetObjectBars_Impl();
             pWork->ResetChildWindows_Impl();
         }
-
-        pDispat = pDispat->xImp->pParent;
     }
 
     bool bIsActive = false;
     SfxDispatcher *pActDispat = pWorkWin->GetBindings().GetDispatcher_Impl();
-    pDispat = this;
-    while ( pActDispat && !bIsActive )
-    {
-        if ( pDispat == pActDispat )
-            bIsActive = true;
-        pActDispat = pActDispat->xImp->pParent;
-    }
+    if ( !bIsActive && this == pActDispat )
+        bIsActive = true;
 
     Update_Impl_( bUIActive, !bIsIPActive, bIsIPActive, pWorkWin );
     if ( (bUIActive || bIsActive) && !comphelper::LibreOfficeKit::isActive() )
@@ -1283,17 +1231,12 @@ void SfxDispatcher::Update_Impl_( bool bUIActive, bool bIsMDIApp, bool bIsIPOwne
     SfxWorkWindow *pWorkWin = xImp->pFrame->GetFrame().GetWorkWindow_Impl();
     bool bIsActive = false;
     SfxDispatcher *pActDispat = pWorkWin->GetBindings().GetDispatcher_Impl();
-    SfxDispatcher *pDispat = this;
-    while ( pActDispat && !bIsActive )
+    if ( pActDispat && !bIsActive )
     {
-        if ( pDispat == pActDispat )
+        if ( this == pActDispat )
             bIsActive = true;
-        pActDispat = pActDispat->xImp->pParent;
     }
 
-    if ( xImp->pParent && !xImp->bQuiet /* && bUIActive */ )
-        xImp->pParent->Update_Impl_( bUIActive, bIsMDIApp, bIsIPOwner, pTaskWin );
-
     for (SfxObjectBars_Impl & rObjBar : xImp->aObjBars)
         rObjBar.eId = ToolbarId::None;
     xImp->aChildWins.clear();
@@ -1347,11 +1290,10 @@ void SfxDispatcher::Update_Impl_( bool bUIActive, bool bIsMDIApp, bool bIsIPOwne
             rBar.nPos = nPos;
             rBar.nFlags = nFlags;
             rBar.eId = pIFace->GetObjectBarId(nNo);
-            rBar.pIFace = pIFace;
 
             if ( bUIActive || bIsActive )
             {
-                pWorkWin->SetObjectBar_Impl(nPos, nFlags, rBar.eId, rBar.pIFace);
+                pWorkWin->SetObjectBar_Impl(nPos, nFlags, rBar.eId);
             }
 
             if ( !bVisible )
@@ -1412,7 +1354,7 @@ void SfxDispatcher::Update_Impl_( bool bUIActive, bool bIsMDIApp, bool bIsIPOwne
             SfxObjectBars_Impl& rBar = xImp->aObjBars[nPos];
             rBar = rFixed;
             pWorkWin->SetObjectBar_Impl(rFixed.nPos, rFixed.nFlags,
-                rFixed.eId, rFixed.pIFace);
+                rFixed.eId);
         }
     }
 
@@ -1421,12 +1363,10 @@ void SfxDispatcher::Update_Impl_( bool bUIActive, bool bIsMDIApp, bool bIsIPOwne
         bool bIsTaskActive = false;
 
         SfxDispatcher *pActDispatcher = pTaskWin->GetBindings().GetDispatcher_Impl();
-        SfxDispatcher *pDispatcher = this;
-        while ( pActDispatcher && !bIsTaskActive )
+        if ( pActDispatcher && !bIsTaskActive )
         {
-            if ( pDispatcher == pActDispatcher )
+            if ( this == pActDispatcher )
                 bIsTaskActive = true;
-            pActDispatcher = pActDispatcher->xImp->pParent;
         }
 
         if (bIsTaskActive && eStatBarId != StatusBarId::None && xImp->pFrame)
@@ -1447,9 +1387,6 @@ void SfxDispatcher::FlushImpl()
 
     xImp->aIdle.Stop();
 
-    if ( xImp->pParent )
-        xImp->pParent->Flush();
-
     xImp->bFlushing = !xImp->bFlushing;
     if ( !xImp->bFlushing )
     {
@@ -1617,11 +1554,15 @@ void SfxDispatcher::SetSlotFilter(SfxSlotFilterState nEnable,
     GetBindings()->InvalidateAll(true);
 }
 
-extern "C" int SfxCompareSIDs_Impl(const void* pSmaller, const void* pBigger)
+extern "C" {
+
+static int SfxCompareSIDs_Impl(const void* pSmaller, const void* pBigger)
 {
     return static_cast<long>(*static_cast<sal_uInt16 const *>(pSmaller)) - static_cast<long>(*static_cast<sal_uInt16 const *>(pBigger));
 }
 
+}
+
 /** Searches for 'nSID' in the Filter set by <SetSlotFilter()> and
     returns sal_True, if the SIDis allowed, or sal_False, if it is
     disabled by the Filter.
@@ -1661,7 +1602,6 @@ SfxSlotFilterState SfxDispatcher::IsSlotEnabledByFilter_Impl( sal_uInt16 nSID )
 
     @param nSlot Slot-Id to search for
     @param rServer <SfxSlotServer>-Instance to fill
-    @param bModal Despite ModalMode
 
     @return         true
                     The Slot was found, rServer is valid.
@@ -1669,7 +1609,7 @@ SfxSlotFilterState SfxDispatcher::IsSlotEnabledByFilter_Impl( sal_uInt16 nSID )
                     false
                     The Slot is currently not served, rServer is invalid.
 */
-bool SfxDispatcher::FindServer_(sal_uInt16 nSlot, SfxSlotServer& rServer, bool bModal)
+bool SfxDispatcher::FindServer_(sal_uInt16 nSlot, SfxSlotServer& rServer)
 {
     SFX_STACK(SfxDispatcher::FindServer_);
 
@@ -1683,15 +1623,6 @@ bool SfxDispatcher::FindServer_(sal_uInt16 nSlot, SfxSlotServer& rServer, bool b
     // Count the number of Shells in the linked dispatchers.
     Flush();
     sal_uInt16 nTotCount = xImp->aStack.size();
-    if ( xImp->pParent )
-    {
-        SfxDispatcher *pParent = xImp->pParent;
-        while ( pParent )
-        {
-            nTotCount = nTotCount + pParent->xImp->aStack.size();
-            pParent = pParent->xImp->pParent;
-        }
-    }
 
     // Verb-Slot?
     if (nSlot >= SID_VERB_START && nSlot <= SID_VERB_END)
@@ -1726,22 +1657,14 @@ bool SfxDispatcher::FindServer_(sal_uInt16 nSlot, SfxSlotServer& rServer, bool b
     // In Quiet-Mode only Parent-Dispatcher
     if ( xImp->bQuiet )
     {
-        if ( xImp->pParent )
-        {
-            bool bRet = xImp->pParent->FindServer_( nSlot, rServer, bModal );
-            rServer.SetShellLevel
-                ( rServer.GetShellLevel() + xImp->aStack.size() );
-            return bRet;
-        }
-        else
-            return false;
+        return false;
     }
 
     bool bReadOnly = ( SfxSlotFilterState::ENABLED_READONLY != nSlotEnableMode && xImp->bReadOnly );
 
     // search through all the shells of the chained dispatchers
     // from top to bottom
-    sal_uInt16 nFirstShell = xImp->bModal && !bModal ? xImp->aStack.size() : 0;
+    sal_uInt16 nFirstShell = 0;
     for ( sal_uInt16 i = nFirstShell; i < nTotCount; ++i )
     {
         SfxShell *pObjShell = GetShell(i);
@@ -1956,7 +1879,7 @@ void SfxDispatcher::Lock( bool bLock )
     if ( !bLock )
     {
         for(size_t i = 0; i < xImp->aReqArr.size(); ++i)
-            xImp->xPoster->Post(xImp->aReqArr[i].release());
+            xImp->xPoster->Post(std::move(xImp->aReqArr[i]));
         xImp->aReqArr.clear();
     }
 }
@@ -2020,7 +1943,7 @@ SfxItemState SfxDispatcher::QueryState( sal_uInt16 nSlot, const SfxPoolItem* &rp
 {
     SfxShell *pShell = nullptr;
     const SfxSlot *pSlot = nullptr;
-    if ( GetShellAndSlot_Impl( nSlot, &pShell, &pSlot, false, false ) )
+    if ( GetShellAndSlot_Impl( nSlot, &pShell, &pSlot, false, true ) )
     {
         rpState = pShell->GetSlotState(nSlot);
         if ( !rpState )
@@ -2036,7 +1959,7 @@ SfxItemState SfxDispatcher::QueryState( sal_uInt16 nSID, css::uno::Any& rAny )
 {
     SfxShell *pShell = nullptr;
     const SfxSlot *pSlot = nullptr;
-    if ( GetShellAndSlot_Impl( nSID, &pShell, &pSlot, false, false ) )
+    if ( GetShellAndSlot_Impl( nSID, &pShell, &pSlot, false, true ) )
     {
         const SfxPoolItem* pItem( nullptr );
 
@@ -2075,8 +1998,6 @@ bool SfxDispatcher::IsReadOnlyShell_Impl( sal_uInt16 nShell ) const
         else
             return xImp->bReadOnly;
     }
-    else if ( xImp->pParent )
-        return xImp->pParent->IsReadOnlyShell_Impl( nShell - nShellCount );
     return true;
 }
 
@@ -2116,15 +2037,9 @@ void SfxDispatcher::InvalidateBindings_Impl( bool bModify )
     else
     {
         SfxDispatcher *pDisp = GetBindings()->GetDispatcher_Impl();
-        while ( pDisp )
+        if ( pDisp == this )
         {
-            if ( pDisp == this )
-            {
-                GetBindings()->InvalidateAll( bModify );
-                break;
-            }
-
-            pDisp = pDisp->xImp->pParent;
+            GetBindings()->InvalidateAll( bModify );
         }
     }
 }
