@@ -29,35 +29,34 @@
 #include <sfx2/msg.hxx>
 #include <sfx2/app.hxx>
 #include <sfx2/msgpool.hxx>
-#include <sfx2/sfxresid.hxx>
 #include <sfx2/objsh.hxx>
 #include <rtl/strbuf.hxx>
 
 extern "C" {
 
-static int SAL_CALL
+static int
 SfxCompareSlots_qsort( const void* pSmaller, const void* pBigger )
 {
-    return ( (int) static_cast<SfxSlot const *>(pSmaller)->GetSlotId() ) -
-           ( (int) static_cast<SfxSlot const *>(pBigger)->GetSlotId() );
+    return static_cast<int>(static_cast<SfxSlot const *>(pSmaller)->GetSlotId()) -
+           static_cast<int>(static_cast<SfxSlot const *>(pBigger)->GetSlotId());
 }
 
-static int SAL_CALL
+static int
 SfxCompareSlots_bsearch( const void* pSmaller, const void* pBigger )
 {
-    return ( (int) *static_cast<sal_uInt16 const *>(pSmaller) ) -
-           ( (int) static_cast<SfxSlot const *>(pBigger)->GetSlotId() );
+    return static_cast<int>(*static_cast<sal_uInt16 const *>(pSmaller)) -
+           static_cast<int>(static_cast<SfxSlot const *>(pBigger)->GetSlotId());
 }
 
 }
 
 struct SfxObjectUI_Impl
 {
-    sal_uInt16         nPos;
-    SfxVisibilityFlags nFlags;
-    sal_uInt32         nObjId;
-    bool               bContext;
-    SfxShellFeature    nFeature;
+    sal_uInt16 const         nPos;
+    SfxVisibilityFlags const nFlags;
+    sal_uInt32 const         nObjId;
+    bool                     bContext;
+    SfxShellFeature const    nFeature;
 
     SfxObjectUI_Impl(sal_uInt16 n, SfxVisibilityFlags f, sal_uInt32 nId, SfxShellFeature nFeat) :
         nPos(n),
@@ -73,8 +72,10 @@ typedef std::vector<SfxObjectUI_Impl*> SfxObjectUIArr_Impl;
 
 struct SfxInterface_Impl
 {
-    SfxObjectUIArr_Impl     aObjectBars;    // registered ObjectBars
-    SfxObjectUIArr_Impl     aChildWindows;  // registered ChildWindows
+    std::vector<std::unique_ptr<SfxObjectUI_Impl>>
+                            aObjectBars;    // registered ObjectBars
+    std::vector<std::unique_ptr<SfxObjectUI_Impl>>
+                            aChildWindows;  // registered ChildWindows
     OUString                aPopupName;     // registered PopupMenu
     StatusBarId             eStatBarResId;  // registered StatusBar
     SfxModule*              pModule;
@@ -86,15 +87,6 @@ struct SfxInterface_Impl
         , bRegistered(false)
     {
     }
-
-    ~SfxInterface_Impl()
-    {
-        for (SfxObjectUIArr_Impl::const_iterator it = aObjectBars.begin(); it != aObjectBars.end(); ++it)
-            delete *it;
-
-        for (SfxObjectUIArr_Impl::const_iterator it = aChildWindows.begin(); it != aChildWindows.end(); ++it)
-            delete *it;
-    }
 };
 
 static SfxObjectUI_Impl* CreateObjectBarUI_Impl(sal_uInt16 nPos, SfxVisibilityFlags nFlags, ToolbarId eId, SfxShellFeature nFeature);
@@ -201,7 +193,11 @@ SfxInterface::~SfxInterface()
     if ( bRegistered )
     {
         if ( pMod )
-            pMod->GetSlotPool()->ReleaseInterface(*this);
+        {
+            // can return nullptr if we are called from the SfxSlotPool destructor
+            if (pMod->GetSlotPool())
+                pMod->GetSlotPool()->ReleaseInterface(*this);
+        }
         else
             SfxGetpApp()->GetAppSlotPool_Impl().ReleaseInterface(*this);
     }
@@ -222,7 +218,7 @@ const SfxSlot* SfxInterface::GetSlot( sal_uInt16 nFuncId ) const
     if ( !p && pGenoType )
         return pGenoType->GetSlot( nFuncId );
 
-    return p ? static_cast<const SfxSlot*>(p) : nullptr;
+    return static_cast<const SfxSlot*>(p);
 }
 
 const SfxSlot* SfxInterface::GetSlot( const OUString& rCommand ) const
@@ -262,24 +258,6 @@ const SfxSlot* SfxInterface::GetRealSlot( const SfxSlot *pSlot ) const
 }
 
 
-const SfxSlot* SfxInterface::GetRealSlot( sal_uInt16 nSlotId ) const
-{
-
-    assert( pSlots );
-    assert( nCount );
-
-    const SfxSlot *pSlot = GetSlot(nSlotId);
-    if ( !pSlot )
-    {
-        if(pGenoType)
-            return pGenoType->GetRealSlot(nSlotId);
-        SAL_WARN( "sfx.control", "unknown Slot" );
-        return nullptr;
-    }
-
-    return nullptr;
-}
-
 void SfxInterface::RegisterPopupMenu( const OUString& rResourceName )
 {
     pImplData->aPopupName = rResourceName;
@@ -294,7 +272,7 @@ void SfxInterface::RegisterObjectBar(sal_uInt16 nPos, SfxVisibilityFlags nFlags,
 {
     SfxObjectUI_Impl* pUI = CreateObjectBarUI_Impl(nPos, nFlags, eId, nFeature);
     if ( pUI )
-        pImplData->aObjectBars.push_back(pUI);
+        pImplData->aObjectBars.emplace_back(pUI);
 }
 
 SfxObjectUI_Impl* CreateObjectBarUI_Impl(sal_uInt16 nPos, SfxVisibilityFlags nFlags, ToolbarId eId, SfxShellFeature nFeature)
@@ -302,7 +280,7 @@ SfxObjectUI_Impl* CreateObjectBarUI_Impl(sal_uInt16 nPos, SfxVisibilityFlags nFl
     if (nFlags == SfxVisibilityFlags::Invisible)
         nFlags |= SfxVisibilityFlags::Standard;
 
-    return new SfxObjectUI_Impl(nPos, nFlags, (sal_uInt32)eId, nFeature);
+    return new SfxObjectUI_Impl(nPos, nFlags, static_cast<sal_uInt32>(eId), nFeature);
 }
 
 ToolbarId SfxInterface::GetObjectBarId(sal_uInt16 nNo) const
@@ -321,7 +299,7 @@ ToolbarId SfxInterface::GetObjectBarId(sal_uInt16 nNo) const
 
     assert( nNo<pImplData->aObjectBars.size() );
 
-    return (ToolbarId)pImplData->aObjectBars[nNo]->nObjId;
+    return static_cast<ToolbarId>(pImplData->aObjectBars[nNo]->nObjId);
 }
 
 sal_uInt16 SfxInterface::GetObjectBarPos( sal_uInt16 nNo ) const
@@ -379,7 +357,7 @@ void SfxInterface::RegisterChildWindow(sal_uInt16 nId, bool bContext, SfxShellFe
 {
     SfxObjectUI_Impl* pUI = new SfxObjectUI_Impl(0, SfxVisibilityFlags::Invisible, nId, nFeature);
     pUI->bContext = bContext;
-    pImplData->aChildWindows.push_back(pUI);
+    pImplData->aChildWindows.emplace_back(pUI);
 }
 
 void SfxInterface::RegisterStatusBar(StatusBarId eId)
