@@ -21,8 +21,8 @@
 #include <sfx2/titledockwin.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/dispatch.hxx>
-#include "sfxlocal.hrc"
-#include "bitmaps.hlst"
+#include <sfx2/strings.hrc>
+#include <bitmaps.hlst>
 #include <sfx2/sfxresid.hxx>
 
 #include <svl/eitem.hxx>
@@ -122,7 +122,7 @@ namespace sfx2
         // Place the content window.
         if ( m_nTitleBarHeight < aToolBoxSize.Height() )
             m_nTitleBarHeight = aToolBoxSize.Height();
-        aWindowSize.Height() -= m_nTitleBarHeight;
+        aWindowSize.AdjustHeight( -(m_nTitleBarHeight) );
         m_aContentWindow->SetPosSizePixel(
             Point( m_aBorder.Left(), m_nTitleBarHeight + m_aBorder.Top() ),
             Size(
@@ -200,7 +200,7 @@ namespace sfx2
 
         // Paint title bar text.
         rRenderContext.SetLineColor(rStyleSettings.GetActiveTextColor());
-        aTitleBarBox.Left() += 3;
+        aTitleBarBox.AdjustLeft(3 );
         rRenderContext.DrawText(aTitleBarBox,
                                 !m_sTitle.isEmpty() ? m_sTitle : GetText(),
                                 DrawTextFlags::Left | DrawTextFlags::VCenter | DrawTextFlags::MultiLine | DrawTextFlags::WordBreak);
@@ -217,6 +217,7 @@ namespace sfx2
         // Get the closer bitmap and set it as right most button.
         BitmapEx aBitmapEx(SFX_BMP_CLOSE_DOC);
         m_aToolbox->InsertItem(1, Image(aBitmapEx));
+        m_aToolbox->SetQuickHelpText(1, SfxResId(STR_CLOSE_PANE));
         m_aToolbox->ShowItem( 1 );
     }
 
@@ -252,14 +253,6 @@ namespace sfx2
         SfxDockingWindow::StateChanged( i_nType );
     }
 
-    void TitledDockingWindow::EndDocking( const tools::Rectangle& i_rRect, bool i_bFloatMode )
-    {
-        SfxDockingWindow::EndDocking( i_rRect, i_bFloatMode );
-
-        m_aEndDockingHdl.Call( this );
-    }
-
-
     void TitledDockingWindow::DataChanged( const DataChangedEvent& i_rDataChangedEvent )
     {
         SfxDockingWindow::DataChanged( i_rDataChangedEvent );
