@@ -18,11 +18,9 @@
  */
 #include <sfx2/sidebar/IContextChangeReceiver.hxx>
 
-
 namespace sfx2 { namespace sidebar {
 
-
-IContextChangeReceiver::~IContextChangeReceiver (void)
+IContextChangeReceiver::~IContextChangeReceiver()
 {
 }
 
