@@ -20,6 +20,8 @@
 #include <com/sun/star/xml/sax/SAXParseException.hpp>
 #include <com/sun/star/beans/PropertyAttribute.hpp>
 
+#include <sal/log.hxx>
+#include <sfx2/infobar.hxx>
 #include <sfx2/objsh.hxx>
 #include <o3tl/make_unique.hxx>
 #include <comphelper/processfactory.hxx>
@@ -27,15 +29,17 @@
 #include <unotools/ucbstreamhelper.hxx>
 #include <unotools/streamwrap.hxx>
 #include <cppuhelper/implbase.hxx>
-#include <sfx2/sfx.hrc>
+#include <sfx2/strings.hrc>
 #include <sfx2/sfxresid.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <tools/datetime.hxx>
 #include <unotools/datetime.hxx>
-#include <vcl/layout.hxx>
+#include <vcl/weld.hxx>
 #include <svl/fstathelper.hxx>
 #include <config_folders.h>
 
+#include <officecfg/Office/Common.hxx>
+
 using namespace com::sun::star;
 
 namespace
@@ -89,6 +93,9 @@ class SfxClassificationCategory
 public:
     /// PROP_BACNAME() is stored separately for easier lookup.
     OUString m_aName;
+    OUString m_aAbbreviatedName; //< An abbreviation to display instead of m_aName.
+    OUString m_aIdentifier; //< The Identifier of this entry.
+    size_t m_nConfidentiality; //< 0 is the lowest (least-sensitive).
     std::map<OUString, OUString> m_aLabels;
 };
 
@@ -97,71 +104,58 @@ class SfxClassificationParser : public cppu::WeakImplHelper<xml::sax::XDocumentH
 {
 public:
     std::vector<SfxClassificationCategory> m_aCategories;
+    std::vector<OUString> m_aMarkings;
+    std::vector<OUString> m_aIPParts;
+    std::vector<OUString> m_aIPPartNumbers;
 
     OUString m_aPolicyAuthorityName;
-    bool m_bInPolicyAuthorityName;
+    bool m_bInPolicyAuthorityName = false;
     OUString m_aPolicyName;
-    bool m_bInPolicyName;
+    bool m_bInPolicyName = false;
     OUString m_aProgramID;
-    bool m_bInProgramID;
+    bool m_bInProgramID = false;
     OUString m_aScale;
-    bool m_bInScale;
+    bool m_bInScale = false;
     OUString m_aConfidentalityValue;
-    bool m_bInConfidentalityValue;
+    bool m_bInConfidentalityValue = false;
     OUString m_aIdentifier;
-    bool m_bInIdentifier;
+    bool m_bInIdentifier = false;
     OUString m_aValue;
-    bool m_bInValue;
+    bool m_bInValue = false;
 
     /// Pointer to a value in m_aCategories, the currently parsed category.
-    SfxClassificationCategory* m_pCategory;
+    SfxClassificationCategory* m_pCategory = nullptr;
 
     SfxClassificationParser();
-    ~SfxClassificationParser() override;
 
-    void SAL_CALL startDocument() throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL startDocument() override;
 
-    void SAL_CALL endDocument() throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL endDocument() override;
 
-    void SAL_CALL startElement(const OUString& aName, const uno::Reference<xml::sax::XAttributeList>& xAttribs)
-    throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL startElement(const OUString& rName, const uno::Reference<xml::sax::XAttributeList>& xAttribs) override;
 
-    void SAL_CALL endElement(const OUString& aName) throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL endElement(const OUString& rName) override;
 
-    void SAL_CALL characters(const OUString& aChars) throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL characters(const OUString& rChars) override;
 
-    void SAL_CALL ignorableWhitespace(const OUString& aWhitespaces) throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL ignorableWhitespace(const OUString& rWhitespaces) override;
 
-    void SAL_CALL processingInstruction(const OUString& aTarget, const OUString& aData) throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL processingInstruction(const OUString& rTarget, const OUString& rData) override;
 
-    void SAL_CALL setDocumentLocator(const uno::Reference<xml::sax::XLocator>& xLocator)
-    throw (xml::sax::SAXException, uno::RuntimeException, std::exception) override;
+    void SAL_CALL setDocumentLocator(const uno::Reference<xml::sax::XLocator>& xLocator) override;
 };
 
-SfxClassificationParser::SfxClassificationParser()
-    : m_bInPolicyAuthorityName(false)
-    , m_bInPolicyName(false)
-    , m_bInProgramID(false)
-    , m_bInScale(false)
-    , m_bInConfidentalityValue(false)
-    , m_bInIdentifier(false)
-    , m_bInValue(false)
-    , m_pCategory(nullptr)
+SfxClassificationParser::SfxClassificationParser() = default;
+
+void SAL_CALL SfxClassificationParser::startDocument()
 {
 }
 
-SfxClassificationParser::~SfxClassificationParser() = default;
-
-void SAL_CALL SfxClassificationParser::startDocument() throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
-{
-}
-
-void SAL_CALL SfxClassificationParser::endDocument() throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
+void SAL_CALL SfxClassificationParser::endDocument()
 {
 }
 
 void SAL_CALL SfxClassificationParser::startElement(const OUString& rName, const uno::Reference<xml::sax::XAttributeList>& xAttribs)
-throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
 {
     if (rName == "baf:PolicyAuthorityName")
     {
@@ -180,7 +174,7 @@ throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
     }
     else if (rName == "baf:BusinessAuthorizationCategory")
     {
-        OUString aName = xAttribs->getValueByName("Name");
+        const OUString aName = xAttribs->getValueByName("Name");
         if (!m_pCategory && !aName.isEmpty())
         {
             OUString aIdentifier = xAttribs->getValueByName("Identifier");
@@ -188,7 +182,13 @@ throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
             // Create a new category and initialize it with the data that's true for all categories.
             m_aCategories.emplace_back(SfxClassificationCategory());
             SfxClassificationCategory& rCategory = m_aCategories.back();
+
             rCategory.m_aName = aName;
+            // Set the abbreviated name, if any, otherwise fallback on the full name.
+            const OUString aAbbreviatedName = xAttribs->getValueByName("loextAbbreviatedName");
+            rCategory.m_aAbbreviatedName = !aAbbreviatedName.isEmpty() ? aAbbreviatedName : aName;
+            rCategory.m_aIdentifier = aIdentifier;
+
             rCategory.m_aLabels["PolicyAuthority:Name"] = m_aPolicyAuthorityName;
             rCategory.m_aLabels["Policy:Name"] = m_aPolicyName;
             rCategory.m_aLabels["BusinessAuthorization:Identifier"] = m_aProgramID;
@@ -225,6 +225,21 @@ throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
             m_pCategory = &rCategory;
         }
     }
+    else if (rName == "loext:Marking")
+    {
+        OUString aName = xAttribs->getValueByName("Name");
+        m_aMarkings.push_back(aName);
+    }
+    else if (rName == "loext:IntellectualPropertyPart")
+    {
+        OUString aName = xAttribs->getValueByName("Name");
+        m_aIPParts.push_back(aName);
+    }
+    else if (rName == "loext:IntellectualPropertyPartNumber")
+    {
+        OUString aName = xAttribs->getValueByName("Name");
+        m_aIPPartNumbers.push_back(aName);
+    }
     else if (rName == "baf:Scale")
     {
         m_aScale.clear();
@@ -247,7 +262,7 @@ throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
     }
 }
 
-void SAL_CALL SfxClassificationParser::endElement(const OUString& rName) throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
+void SAL_CALL SfxClassificationParser::endElement(const OUString& rName)
 {
     if (rName == "baf:PolicyAuthorityName")
         m_bInPolicyAuthorityName = false;
@@ -270,6 +285,7 @@ void SAL_CALL SfxClassificationParser::endElement(const OUString& rName) throw (
         {
             std::map<OUString, OUString>& rLabels = m_pCategory->m_aLabels;
             rLabels[PROP_IMPACTLEVEL()] = m_aConfidentalityValue;
+            m_pCategory->m_nConfidentiality = m_aConfidentalityValue.toInt32(); // 0-based class sensitivity; 0 is lowest.
             // Set the two other type of levels as well, if they're not set
             // yet: they're optional in BAF, but not in BAILS.
             if (rLabels.find("Impact:Level:Integrity") == rLabels.end())
@@ -294,7 +310,7 @@ void SAL_CALL SfxClassificationParser::endElement(const OUString& rName) throw (
     }
 }
 
-void SAL_CALL SfxClassificationParser::characters(const OUString& rChars) throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
+void SAL_CALL SfxClassificationParser::characters(const OUString& rChars)
 {
     if (m_bInPolicyAuthorityName)
         m_aPolicyAuthorityName += rChars;
@@ -312,15 +328,15 @@ void SAL_CALL SfxClassificationParser::characters(const OUString& rChars) throw
         m_aValue += rChars;
 }
 
-void SAL_CALL SfxClassificationParser::ignorableWhitespace(const OUString& /*rWhitespace*/) throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
+void SAL_CALL SfxClassificationParser::ignorableWhitespace(const OUString& /*rWhitespace*/)
 {
 }
 
-void SAL_CALL SfxClassificationParser::processingInstruction(const OUString& /*rTarget*/, const OUString& /*rData*/) throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
+void SAL_CALL SfxClassificationParser::processingInstruction(const OUString& /*rTarget*/, const OUString& /*rData*/)
 {
 }
 
-void SAL_CALL SfxClassificationParser::setDocumentLocator(const uno::Reference<xml::sax::XLocator>& /*xLocator*/) throw (xml::sax::SAXException, uno::RuntimeException, std::exception)
+void SAL_CALL SfxClassificationParser::setDocumentLocator(const uno::Reference<xml::sax::XLocator>& /*xLocator*/)
 {
 }
 
@@ -334,9 +350,15 @@ public:
     std::map<SfxClassificationPolicyType, SfxClassificationCategory> m_aCategory;
     /// Possible categories of a policy to choose from.
     std::vector<SfxClassificationCategory> m_aCategories;
+    std::vector<OUString> m_aMarkings;
+    std::vector<OUString> m_aIPParts;
+    std::vector<OUString> m_aIPPartNumbers;
+
     uno::Reference<document::XDocumentProperties> m_xDocumentProperties;
 
-    explicit Impl(const uno::Reference<document::XDocumentProperties>& xDocumentProperties);
+    bool const m_bUseLocalized;
+
+    explicit Impl(uno::Reference<document::XDocumentProperties> xDocumentProperties, bool bUseLocalized);
     void parsePolicy();
     /// Synchronize m_aLabels back to the document properties.
     void pushToDocumentProperties();
@@ -344,9 +366,11 @@ public:
     void setStartValidity(SfxClassificationPolicyType eType);
 };
 
-SfxClassificationHelper::Impl::Impl(const uno::Reference<document::XDocumentProperties>& xDocumentProperties)
-    : m_xDocumentProperties(xDocumentProperties)
+SfxClassificationHelper::Impl::Impl(uno::Reference<document::XDocumentProperties> xDocumentProperties, bool bUseLocalized)
+    : m_xDocumentProperties(std::move(xDocumentProperties))
+    , m_bUseLocalized(bUseLocalized)
 {
+    parsePolicy();
 }
 
 void SfxClassificationHelper::Impl::parsePolicy()
@@ -357,7 +381,7 @@ void SfxClassificationHelper::Impl::parsePolicy()
 
     // See if there is a localized variant next to the configured XML.
     OUString aExtension(".xml");
-    if (aPath.endsWith(aExtension))
+    if (aPath.endsWith(aExtension) && m_bUseLocalized)
     {
         OUString aBase = aPath.copy(0, aPath.getLength() - aExtension.getLength());
         const LanguageTag& rLanguageTag = Application::GetSettings().GetLanguageTag();
@@ -367,8 +391,8 @@ void SfxClassificationHelper::Impl::parsePolicy()
             aPath = aLocalized;
     }
 
-    SvStream* pStream = utl::UcbStreamHelper::CreateStream(aPath, StreamMode::READ);
-    uno::Reference<io::XInputStream> xInputStream(new utl::OStreamWrapper(*pStream));
+    std::unique_ptr<SvStream> pStream = utl::UcbStreamHelper::CreateStream(aPath, StreamMode::READ);
+    uno::Reference<io::XInputStream> xInputStream(new utl::OStreamWrapper(std::move(pStream)));
     xml::sax::InputSource aParserInput;
     aParserInput.aInputStream = xInputStream;
 
@@ -382,17 +406,20 @@ void SfxClassificationHelper::Impl::parsePolicy()
     }
     catch (const xml::sax::SAXParseException& rException)
     {
-        SAL_WARN("sfx.view", "parsePolicy() failed: " << rException.Message);
+        SAL_WARN("sfx.view", "parsePolicy() failed: " << rException);
     }
     m_aCategories = xClassificationParser->m_aCategories;
+    m_aMarkings = xClassificationParser->m_aMarkings;
+    m_aIPParts = xClassificationParser->m_aIPParts;
+    m_aIPPartNumbers = xClassificationParser->m_aIPPartNumbers;
 }
 
-bool lcl_containsProperty(const uno::Sequence<beans::Property>& rProperties, const OUString& rName)
+static bool lcl_containsProperty(const uno::Sequence<beans::Property>& rProperties, const OUString& rName)
 {
-    return std::find_if(rProperties.begin(), rProperties.end(), [&](const beans::Property& rProperty)
+    return std::any_of(rProperties.begin(), rProperties.end(), [&](const beans::Property& rProperty)
     {
         return rProperty.Name == rName;
-    }) != rProperties.end();
+    });
 }
 
 void SfxClassificationHelper::Impl::setStartValidity(SfxClassificationPolicyType eType)
@@ -437,7 +464,7 @@ void SfxClassificationHelper::Impl::pushToDocumentProperties()
             }
             catch (const uno::Exception& rException)
             {
-                SAL_WARN("sfx.view", "pushDocumentProperties() failed for property " << rLabel.first << ": " << rException.Message);
+                SAL_WARN("sfx.view", "pushDocumentProperties() failed for property " << rLabel.first << ": " << rException);
             }
         }
     }
@@ -502,14 +529,24 @@ bool SfxClassificationHelper::ShowPasteInfo(SfxClassificationCheckPasteResult eR
     case SfxClassificationCheckPasteResult::TargetDocNotClassified:
     {
         if (!Application::IsHeadlessModeEnabled())
-            ScopedVclPtrInstance<MessageDialog>(nullptr, SfxResId(STR_TARGET_DOC_NOT_CLASSIFIED), VclMessageType::Info)->Execute();
+        {
+            std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(nullptr,
+                                                                     VclMessageType::Info, VclButtonsType::Ok,
+                                                                     SfxResId(STR_TARGET_DOC_NOT_CLASSIFIED)));
+            xBox->run();
+        }
         return false;
     }
     break;
     case SfxClassificationCheckPasteResult::DocClassificationTooLow:
     {
         if (!Application::IsHeadlessModeEnabled())
-            ScopedVclPtrInstance<MessageDialog>(nullptr, SfxResId(STR_DOC_CLASSIFICATION_TOO_LOW), VclMessageType::Info)->Execute();
+        {
+            std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(nullptr,
+                                                                     VclMessageType::Info, VclButtonsType::Ok,
+                                                                     SfxResId(STR_DOC_CLASSIFICATION_TOO_LOW)));
+            xBox->run();
+        }
         return false;
     }
     break;
@@ -518,9 +555,12 @@ bool SfxClassificationHelper::ShowPasteInfo(SfxClassificationCheckPasteResult eR
     return true;
 }
 
-SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::XDocumentProperties>& xDocumentProperties)
-    : m_pImpl(o3tl::make_unique<Impl>(xDocumentProperties))
+SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::XDocumentProperties>& xDocumentProperties, bool bUseLocalizedPolicy)
+    : m_pImpl(o3tl::make_unique<Impl>(xDocumentProperties, bUseLocalizedPolicy))
 {
+    if (!xDocumentProperties.is())
+        return;
+
     uno::Reference<beans::XPropertyContainer> xPropertyContainer = xDocumentProperties->getUserDefinedProperties();
     if (!xPropertyContainer.is())
         return;
@@ -542,6 +582,7 @@ SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::
                 // It's a prefix we did not recognize, ignore.
                 continue;
 
+            //TODO: Support abbreviated names(?)
             if (rProperty.Name == (aPrefix + PROP_BACNAME()))
                 m_pImpl->m_aCategory[eType].m_aName = aValue;
             else
@@ -552,11 +593,67 @@ SfxClassificationHelper::SfxClassificationHelper(const uno::Reference<document::
 
 SfxClassificationHelper::~SfxClassificationHelper() = default;
 
+std::vector<OUString> const & SfxClassificationHelper::GetMarkings()
+{
+    return m_pImpl->m_aMarkings;
+}
+
+std::vector<OUString> const & SfxClassificationHelper::GetIntellectualPropertyParts()
+{
+    return m_pImpl->m_aIPParts;
+}
+
+std::vector<OUString> const & SfxClassificationHelper::GetIntellectualPropertyPartNumbers()
+{
+    return m_pImpl->m_aIPPartNumbers;
+}
+
 const OUString& SfxClassificationHelper::GetBACName(SfxClassificationPolicyType eType)
 {
     return m_pImpl->m_aCategory[eType].m_aName;
 }
 
+const OUString& SfxClassificationHelper::GetAbbreviatedBACName(const OUString& sFullName)
+{
+    for (const auto& category : m_pImpl->m_aCategories)
+    {
+        if (category.m_aName == sFullName)
+            return category.m_aAbbreviatedName;
+    }
+
+    return sFullName;
+}
+
+OUString SfxClassificationHelper::GetBACNameForIdentifier(const OUString& sIdentifier)
+{
+    OUString aRet;
+    if (sIdentifier.isEmpty())
+        return aRet;
+
+    for (const auto& category : m_pImpl->m_aCategories)
+    {
+        if (category.m_aIdentifier == sIdentifier)
+            return category.m_aName;
+    }
+
+    return aRet;
+}
+
+OUString SfxClassificationHelper::GetHigherClass(const OUString& first, const OUString& second)
+{
+    size_t nFirstConfidentiality = 0;
+    size_t nSecondConfidentiality = 0;
+    for (const auto& category : m_pImpl->m_aCategories)
+    {
+        if (category.m_aName == first)
+            nFirstConfidentiality = category.m_nConfidentiality;
+        if (category.m_aName == second)
+            nSecondConfidentiality = category.m_nConfidentiality;
+    }
+
+    return nFirstConfidentiality >= nSecondConfidentiality ? first : second;
+}
+
 bool SfxClassificationHelper::HasImpactLevel()
 {
     auto itCategory = m_pImpl->m_aCategory.find(SfxClassificationPolicyType::IntellectualProperty);
@@ -569,10 +666,7 @@ bool SfxClassificationHelper::HasImpactLevel()
         return false;
 
     it = rCategory.m_aLabels.find(PROP_PREFIX_INTELLECTUALPROPERTY() + PROP_IMPACTLEVEL());
-    if (it == rCategory.m_aLabels.end())
-        return false;
-
-    return true;
+    return it != rCategory.m_aLabels.end();
 }
 
 bool SfxClassificationHelper::HasDocumentHeader()
@@ -583,10 +677,7 @@ bool SfxClassificationHelper::HasDocumentHeader()
 
     SfxClassificationCategory& rCategory = itCategory->second;
     auto it = rCategory.m_aLabels.find(PROP_PREFIX_INTELLECTUALPROPERTY() + PROP_DOCHEADER());
-    if (it == rCategory.m_aLabels.end() || it->second.isEmpty())
-        return false;
-
-    return true;
+    return it != rCategory.m_aLabels.end() && !it->second.isEmpty();
 }
 
 bool SfxClassificationHelper::HasDocumentFooter()
@@ -597,15 +688,14 @@ bool SfxClassificationHelper::HasDocumentFooter()
 
     SfxClassificationCategory& rCategory = itCategory->second;
     auto it = rCategory.m_aLabels.find(PROP_PREFIX_INTELLECTUALPROPERTY() + PROP_DOCFOOTER());
-    if (it == rCategory.m_aLabels.end() || it->second.isEmpty())
-        return false;
-
-    return true;
+    return it != rCategory.m_aLabels.end() && !it->second.isEmpty();
 }
 
-basegfx::BColor SfxClassificationHelper::GetImpactLevelColor()
+InfoBarType SfxClassificationHelper::GetImpactLevelType()
 {
-    basegfx::BColor aRet;
+    InfoBarType aRet;
+
+    aRet = InfoBarType::Warning;
 
     auto itCategory = m_pImpl->m_aCategory.find(SfxClassificationPolicyType::IntellectualProperty);
     if (itCategory == m_pImpl->m_aCategory.end())
@@ -613,48 +703,36 @@ basegfx::BColor SfxClassificationHelper::GetImpactLevelColor()
 
     SfxClassificationCategory& rCategory = itCategory->second;
     auto it = rCategory.m_aLabels.find(PROP_PREFIX_INTELLECTUALPROPERTY() + PROP_IMPACTSCALE());
+    OUString aScale = it->second;
     if (it == rCategory.m_aLabels.end())
         return aRet;
-    OUString aScale = it->second;
 
     it = rCategory.m_aLabels.find(PROP_PREFIX_INTELLECTUALPROPERTY() + PROP_IMPACTLEVEL());
+    OUString aLevel = it->second;
     if (it == rCategory.m_aLabels.end())
         return aRet;
-    OUString aLevel = it->second;
 
     // The spec defines two valid scale values: FIPS-199 and UK-Cabinet.
     if (aScale == "UK-Cabinet")
     {
-        static std::map<OUString, basegfx::BColor> aColors;
-        if (aColors.empty())
-        {
-            // Green -> brown -> orange -> red.
-            aColors["0"] = basegfx::BColor(0.0, 0.5, 0.0);
-            aColors["1"] = basegfx::BColor(0.5, 0.5, 0.0);
-            aColors["2"] = basegfx::BColor(1.0, 0.5, 0.0);
-            aColors["3"] = basegfx::BColor(0.5, 0.0, 0.0);
-        }
-        auto itColor = aColors.find(aLevel);
-        if (itColor == aColors.end())
-            return aRet;
-        aRet = itColor->second;
+        if (aLevel == "0")
+            aRet = InfoBarType::Success;
+        else if (aLevel == "1")
+            aRet = InfoBarType::Warning;
+        else if (aLevel == "2")
+            aRet = InfoBarType::Warning;
+        else if (aLevel == "3")
+            aRet = InfoBarType::Danger;
     }
     else if (aScale == "FIPS-199")
     {
-        static std::map<OUString, basegfx::BColor> aColors;
-        if (aColors.empty())
-        {
-            // Green -> orange -> red.
-            aColors["Low"] = basegfx::BColor(0.0, 0.5, 0.0);
-            aColors["Moderate"] = basegfx::BColor(1.0, 0.5, 0.0);
-            aColors["High"] = basegfx::BColor(0.5, 0.0, 0.0);
-        }
-        auto itColor = aColors.find(aLevel);
-        if (itColor == aColors.end())
-            return aRet;
-        aRet = itColor->second;
+        if (aLevel == "Low")
+            aRet = InfoBarType::Success;
+        else if (aLevel == "Moderate")
+            aRet = InfoBarType::Warning;
+        else if (aLevel == "High")
+            aRet = InfoBarType::Danger;
     }
-
     return aRet;
 }
 
@@ -743,6 +821,32 @@ std::vector<OUString> SfxClassificationHelper::GetBACNames()
     return aRet;
 }
 
+std::vector<OUString> SfxClassificationHelper::GetBACIdentifiers()
+{
+    if (m_pImpl->m_aCategories.empty())
+        m_pImpl->parsePolicy();
+
+    std::vector<OUString> aRet;
+    std::transform(m_pImpl->m_aCategories.begin(), m_pImpl->m_aCategories.end(), std::back_inserter(aRet), [](const SfxClassificationCategory& rCategory)
+    {
+        return rCategory.m_aIdentifier;
+    });
+    return aRet;
+}
+
+std::vector<OUString> SfxClassificationHelper::GetAbbreviatedBACNames()
+{
+    if (m_pImpl->m_aCategories.empty())
+        m_pImpl->parsePolicy();
+
+    std::vector<OUString> aRet;
+    std::transform(m_pImpl->m_aCategories.begin(), m_pImpl->m_aCategories.end(), std::back_inserter(aRet), [](const SfxClassificationCategory& rCategory)
+    {
+        return rCategory.m_aAbbreviatedName;
+    });
+    return aRet;
+}
+
 void SfxClassificationHelper::SetBACName(const OUString& rName, SfxClassificationPolicyType eType)
 {
     if (m_pImpl->m_aCategories.empty())
@@ -759,6 +863,8 @@ void SfxClassificationHelper::SetBACName(const OUString& rName, SfxClassificatio
     }
 
     m_pImpl->m_aCategory[eType].m_aName = it->m_aName;
+    m_pImpl->m_aCategory[eType].m_aAbbreviatedName = it->m_aAbbreviatedName;
+    m_pImpl->m_aCategory[eType].m_nConfidentiality = it->m_nConfidentiality;
     m_pImpl->m_aCategory[eType].m_aLabels.clear();
     const OUString& rPrefix = policyTypeToString(eType);
     for (const auto& rLabel : it->m_aLabels)
@@ -781,11 +887,9 @@ void SfxClassificationHelper::UpdateInfobar(SfxViewFrame& rViewFrame)
     {
         OUString aMessage = SfxResId(STR_CLASSIFIED_DOCUMENT);
         aMessage = aMessage.replaceFirst("%1", aBACName);
-        basegfx::BColor aBackgroundColor = GetImpactLevelColor();
-        basegfx::BColor aForegroundColor(1.0, 1.0, 1.0);
 
         rViewFrame.RemoveInfoBar("classification");
-        rViewFrame.AppendInfoBar("classification", aMessage, &aBackgroundColor, &aForegroundColor, &aForegroundColor, WB_CENTER);
+        rViewFrame.AppendInfoBar("classification", aMessage, GetImpactLevelType());
     }
 }
 
@@ -840,4 +944,48 @@ const OUString& SfxClassificationHelper::PROP_PREFIX_INTELLECTUALPROPERTY()
     return sProp;
 }
 
+SfxClassificationPolicyType SfxClassificationHelper::getPolicyType()
+{
+    sal_Int32 nPolicyTypeNumber = officecfg::Office::Common::Classification::Policy::get();
+    auto eType = static_cast<SfxClassificationPolicyType>(nPolicyTypeNumber);
+    return eType;
+}
+
+namespace sfx
+{
+
+namespace
+{
+
+OUString getProperty(uno::Reference<beans::XPropertyContainer> const& rxPropertyContainer,
+                     OUString const& rName)
+{
+    try
+    {
+        uno::Reference<beans::XPropertySet> xPropertySet(rxPropertyContainer, uno::UNO_QUERY);
+        return xPropertySet->getPropertyValue(rName).get<OUString>();
+    }
+    catch (const css::uno::Exception&)
+    {
+    }
+
+    return OUString();
+}
+
+} // end anonymous namespace
+
+sfx::ClassificationCreationOrigin getCreationOriginProperty(uno::Reference<beans::XPropertyContainer> const & rxPropertyContainer,
+                                                            sfx::ClassificationKeyCreator const & rKeyCreator)
+{
+    OUString sValue = getProperty(rxPropertyContainer, rKeyCreator.makeCreationOriginKey());
+    if (sValue.isEmpty())
+        return sfx::ClassificationCreationOrigin::NONE;
+
+    return (sValue == "BAF_POLICY")
+                ? sfx::ClassificationCreationOrigin::BAF_POLICY
+                : sfx::ClassificationCreationOrigin::MANUAL;
+}
+
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
