@@ -19,6 +19,8 @@
 
 #include <sfx2/app.hxx>
 #include <sfx2/viewfac.hxx>
+#include <sfx2/viewfrm.hxx>
+#include <sfx2/viewsh.hxx>
 #include <rtl/ustrbuf.hxx>
 
 SfxViewShell *SfxViewFactory::CreateInstance(SfxViewFrame *pFrame, SfxViewShell *pOldSh )
@@ -28,10 +30,7 @@ SfxViewShell *SfxViewFactory::CreateInstance(SfxViewFrame *pFrame, SfxViewShell
 
 OUString SfxViewFactory::GetLegacyViewName() const
 {
-    OUStringBuffer aViewName;
-    aViewName.append( "view" );
-    aViewName.append( sal_Int32( GetOrdinal() ) );
-    return aViewName.makeStringAndClear();
+    return "view" + OUString::number( sal_uInt16( GetOrdinal() ) );
 }
 
 OUString SfxViewFactory::GetAPIViewName() const
@@ -39,7 +38,7 @@ OUString SfxViewFactory::GetAPIViewName() const
     if ( !m_sViewName.isEmpty() )
         return m_sViewName;
 
-    if ( GetOrdinal() == 0 )
+    if ( GetOrdinal() == SFX_INTERFACE_NONE )
         return OUString( "Default" );
 
     return GetLegacyViewName();
@@ -48,7 +47,7 @@ OUString SfxViewFactory::GetAPIViewName() const
 // CTOR / DTOR -----------------------------------------------------------
 
 SfxViewFactory::SfxViewFactory( SfxViewCtor fnC,
-                                sal_uInt16 nOrdinal, const sal_Char* asciiViewName ):
+                                SfxInterfaceId nOrdinal, const sal_Char* asciiViewName ):
     fnCreate(fnC),
     nOrd(nOrdinal),
     m_sViewName( OUString::createFromAscii( asciiViewName ) )
