@@ -19,13 +19,14 @@
 
 #include <config_features.h>
 
+#include <sal/log.hxx>
 #include <svl/stritem.hxx>
 #include <svl/eitem.hxx>
 #include <svl/whiter.hxx>
-#include <vcl/layout.hxx>
-#include <vcl/msgbox.hxx>
 #include <vcl/toolbox.hxx>
+#include <vcl/weld.hxx>
 #include <svl/intitem.hxx>
+#include <svtools/langhelp.hxx>
 #include <svtools/sfxecode.hxx>
 #include <svtools/ehdl.hxx>
 #include <com/sun/star/frame/XLayoutManager.hpp>
@@ -40,7 +41,6 @@
 #include <cppuhelper/implbase.hxx>
 
 #include <osl/file.hxx>
-#include <osl/mutex.hxx>
 #include <tools/urlobj.hxx>
 #include <unotools/tempfile.hxx>
 #include <unotools/pathoptions.hxx>
@@ -51,6 +51,7 @@
 #include <basic/basmgr.hxx>
 #include <basic/sbuno.hxx>
 #include <framework/actiontriggerhelper.hxx>
+#include <comphelper/lok.hxx>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/sequenceashashmap.hxx>
 #include <toolkit/helper/vclunohelper.hxx>
@@ -58,8 +59,8 @@
 #include <vcl/commandinfoprovider.hxx>
 #include <LibreOfficeKit/LibreOfficeKitEnums.h>
 
+#include <officecfg/Setup.hxx>
 #include <sfx2/app.hxx>
-#include "view.hrc"
 #include <sfx2/viewsh.hxx>
 #include "viewimp.hxx"
 #include <sfx2/sfxresid.hxx>
@@ -68,21 +69,21 @@
 #include <sfx2/printer.hxx>
 #include <sfx2/docfile.hxx>
 #include <sfx2/dispatch.hxx>
-#include "arrdecl.hxx"
+#include <arrdecl.hxx>
 #include <sfx2/docfac.hxx>
-#include "sfxlocal.hrc"
+#include <sfx2/strings.hrc>
 #include <sfx2/sfxbasecontroller.hxx>
 #include <sfx2/mailmodelapi.hxx>
-#include "bluthsndapi.hxx"
+#include <bluthsndapi.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <sfx2/event.hxx>
 #include <sfx2/fcontnr.hxx>
 #include <sfx2/ipclient.hxx>
-#include "workwin.hxx"
+#include <workwin.hxx>
 #include <sfx2/objface.hxx>
 #include <sfx2/docfilt.hxx>
 #include <sfx2/lokhelper.hxx>
-#include "openuriexternally.hxx"
+#include <openuriexternally.hxx>
 #include <shellimpl.hxx>
 
 #include <vector>
@@ -95,8 +96,8 @@ using namespace ::com::sun::star::beans;
 using namespace ::com::sun::star::util;
 using namespace ::cppu;
 
-#define SfxViewShell
-#include "sfxslots.hxx"
+#define ShellClass_SfxViewShell
+#include <sfxslots.hxx>
 
 
 class SfxClipboardChangeListener : public ::cppu::WeakImplHelper<
@@ -125,7 +126,7 @@ public:
         AsyncExecuteInfo( AsyncExecuteCmd eCmd, SfxClipboardChangeListener* pListener ) :
             m_eCmd( eCmd ), m_xListener( pListener ) {}
 
-        AsyncExecuteCmd m_eCmd;
+        AsyncExecuteCmd const m_eCmd;
         rtl::Reference<SfxClipboardChangeListener> m_xListener;
     };
 
@@ -156,12 +157,18 @@ SfxClipboardChangeListener::SfxClipboardChangeListener( SfxViewShell* pView, con
 void SfxClipboardChangeListener::ChangedContents()
 {
     const SolarMutexGuard aGuard;
-    if( m_pViewShell )
+    if (m_pViewShell)
     {
         SfxBindings& rBind = m_pViewShell->GetViewFrame()->GetBindings();
-        rBind.Invalidate( SID_PASTE );
-        rBind.Invalidate( SID_PASTE_SPECIAL );
-        rBind.Invalidate( SID_CLIPBOARD_FORMAT_ITEMS );
+        rBind.Invalidate(SID_PASTE);
+        rBind.Invalidate(SID_PASTE_SPECIAL);
+        rBind.Invalidate(SID_CLIPBOARD_FORMAT_ITEMS);
+
+        if (comphelper::LibreOfficeKit::isActive())
+        {
+            // In the future we might send the payload as well.
+            SfxLokHelper::notifyAllViews(LOK_CALLBACK_CLIPBOARD_CHANGED, "");
+        }
     }
 }
 
@@ -209,36 +216,13 @@ void SAL_CALL SfxClipboardChangeListener::changedContents( const datatransfer::c
     Application::PostUserEvent( LINK( nullptr, SfxClipboardChangeListener, AsyncExecuteHdl_Impl ), pInfo );
 }
 
-class SfxInPlaceClientList
-{
-    typedef std::vector<SfxInPlaceClient*> DataType;
-    DataType maData;
-
-public:
-    typedef DataType::iterator iterator;
-
-    SfxInPlaceClient* at( size_t i ) { return maData.at(i); }
-
-    iterator begin() { return maData.begin(); }
-    iterator end() { return maData.end(); }
-
-    void push_back( SfxInPlaceClient* p ) { maData.push_back(p); }
-    void erase( const iterator& it ) { maData.erase(it); }
-    size_t size() const { return maData.size(); }
-};
-
 sal_uInt32 SfxViewShell_Impl::m_nLastViewShellId = 0;
 
 SfxViewShell_Impl::SfxViewShell_Impl(SfxViewShellFlags const nFlags)
 : aInterceptorContainer( aMutex )
-,   m_bControllerSet(false)
 ,   m_bHasPrintOptions(nFlags & SfxViewShellFlags::HAS_PRINTOPTIONS)
 ,   m_bIsShowView(!(nFlags & SfxViewShellFlags::NO_SHOW))
-,   m_bGotOwnership(false)
-,   m_bGotFrameOwnership(false)
 ,   m_nFamily(0xFFFF)   // undefined, default set by TemplateDialog
-,   m_pController(nullptr)
-,   mpIPClientList(nullptr)
 ,   m_pLibreOfficeKitViewCallback(nullptr)
 ,   m_pLibreOfficeKitViewData(nullptr)
 ,   m_bTiledSearching(false)
@@ -247,14 +231,13 @@ SfxViewShell_Impl::SfxViewShell_Impl(SfxViewShellFlags const nFlags)
 
 SfxViewShell_Impl::~SfxViewShell_Impl()
 {
-    DELETEZ(mpIPClientList);
 }
 
-SfxInPlaceClientList* SfxViewShell_Impl::GetIPClientList_Impl( bool bCreate ) const
+std::vector< SfxInPlaceClient* > *SfxViewShell_Impl::GetIPClients_Impl( bool bCreate ) const
 {
-    if (!mpIPClientList && bCreate)
-        mpIPClientList = new SfxInPlaceClientList;
-    return mpIPClientList;
+    if (!mpIPClients && bCreate)
+        mpIPClients.reset(new std::vector< SfxInPlaceClient* >);
+    return mpIPClients.get();
 }
 
 SFX_IMPL_SUPERCLASS_INTERFACE(SfxViewShell,SfxShell)
@@ -313,7 +296,7 @@ enum ETypeFamily
     E_OOO_DOC
 };
 
-OUString impl_searchFormatTypeForApp(const css::uno::Reference< css::frame::XFrame >& xFrame     ,
+static OUString impl_searchFormatTypeForApp(const css::uno::Reference< css::frame::XFrame >& xFrame     ,
                                                   ETypeFamily                                eTypeFamily)
 {
     try
@@ -329,16 +312,13 @@ OUString impl_searchFormatTypeForApp(const css::uno::Reference< css::frame::XFra
             case E_MS_DOC:
             {
                 if ( sModule == "com.sun.star.text.TextDocument" )
-                    sType = "writer_MS_Word_97";
+                    sType = "writer_MS_Word_2007";
                 else
                 if ( sModule == "com.sun.star.sheet.SpreadsheetDocument" )
-                    sType = "calc_MS_Excel_97";
-                else
-                if ( sModule == "com.sun.star.drawing.DrawingDocument" )
-                    sType = "impress_MS_PowerPoint_97";
+                    sType = "MS Excel 2007 XML";
                 else
                 if ( sModule == "com.sun.star.presentation.PresentationDocument" )
-                    sType = "impress_MS_PowerPoint_97";
+                    sType = "MS PowerPoint 2007 XML";
             }
             break;
 
@@ -374,18 +354,18 @@ OUString impl_searchFormatTypeForApp(const css::uno::Reference< css::frame::XFra
 
 void SfxViewShell::NewIPClient_Impl( SfxInPlaceClient *pIPClient )
 {
-    pImpl->GetIPClientList_Impl()->push_back(pIPClient);
+    pImpl->GetIPClients_Impl()->push_back(pIPClient);
 }
 
-void SfxViewShell::IPClientGone_Impl( SfxInPlaceClient *pIPClient )
+void SfxViewShell::IPClientGone_Impl( SfxInPlaceClient const *pIPClient )
 {
-    SfxInPlaceClientList* pClientList = pImpl->GetIPClientList_Impl();
+    std::vector< SfxInPlaceClient* > *pClients = pImpl->GetIPClients_Impl();
 
-    for( SfxInPlaceClientList::iterator it = pClientList->begin(); it != pClientList->end(); ++it )
+    for(std::vector< SfxInPlaceClient* >::iterator it = pClients->begin(); it != pClients->end(); ++it)
     {
         if ( *it == pIPClient )
         {
-            pClientList->erase( it );
+            pClients->erase( it );
             break;
         }
     }
@@ -422,17 +402,14 @@ void SfxViewShell::ExecMisc_Impl( SfxRequest &rReq )
                     aValue >>= xLayoutManager;
                     if ( xLayoutManager.is() )
                     {
-                        OUString aTextResString( "private:resource/toolbar/textobjectbar" );
-                        uno::Reference< ui::XUIElement > xElement = xLayoutManager->getElement( aTextResString );
+                        uno::Reference< ui::XUIElement > xElement = xLayoutManager->getElement( "private:resource/toolbar/textobjectbar" );
                         if(!xElement.is())
                         {
-                            OUString aFrameResString( "private:resource/toolbar/frameobjectbar" );
-                            xElement = xLayoutManager->getElement( aFrameResString );
+                            xElement = xLayoutManager->getElement( "private:resource/toolbar/frameobjectbar" );
                         }
                         if(!xElement.is())
                         {
-                            OUString aOleResString( "private:resource/toolbar/oleobjectbar" );
-                            xElement = xLayoutManager->getElement( aOleResString );
+                            xElement = xLayoutManager->getElement( "private:resource/toolbar/oleobjectbar" );
                         }
                         if(xElement.is())
                         {
@@ -474,7 +451,7 @@ void SfxViewShell::ExecMisc_Impl( SfxRequest &rReq )
         {
             SfxObjectShell* pDoc = GetObjectShell();
             if ( pDoc && pDoc->QueryHiddenInformation(
-                             HiddenWarningFact::WhenSaving, &GetViewFrame()->GetWindow() ) != RET_YES )
+                             HiddenWarningFact::WhenSaving, GetViewFrame()->GetWindow().GetFrameWeld() ) != RET_YES )
                 break;
 
 
@@ -521,8 +498,11 @@ void SfxViewShell::ExecMisc_Impl( SfxRequest &rReq )
 
             if ( eResult == SfxMailModel::SEND_MAIL_ERROR )
             {
-                ScopedVclPtrInstance< MessageDialog > aBox(SfxGetpApp()->GetTopWindow(), SfxResId( STR_ERROR_SEND_MAIL ), VclMessageType::Info);
-                aBox->Execute();
+                vcl::Window* pWin = SfxGetpApp()->GetTopWindow();
+                std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(pWin ? pWin->GetFrameWeld() : nullptr,
+                                                                         VclMessageType::Info, VclButtonsType::Ok,
+                                                                         SfxResId(STR_ERROR_SEND_MAIL)));
+                xBox->run();
                 rReq.Ignore();
             }
             else
@@ -535,15 +515,18 @@ void SfxViewShell::ExecMisc_Impl( SfxRequest &rReq )
             SfxBluetoothModel aModel;
             SfxObjectShell* pDoc = GetObjectShell();
             if ( pDoc && pDoc->QueryHiddenInformation(
-                            HiddenWarningFact::WhenSaving, &GetViewFrame()->GetWindow() ) != RET_YES )
+                            HiddenWarningFact::WhenSaving, GetViewFrame()->GetWindow().GetFrameWeld() ) != RET_YES )
                 break;
             uno::Reference < frame::XFrame > xFrame( pFrame->GetFrame().GetFrameInterface() );
             SfxMailModel::SendMailResult eResult = aModel.SaveAndSend( xFrame );
             if( eResult == SfxMailModel::SEND_MAIL_ERROR )
             {
-                    ScopedVclPtrInstance< MessageDialog > aBox(SfxGetpApp()->GetTopWindow(), SfxResId( STR_ERROR_SEND_MAIL ), VclMessageType::Info);
-                    aBox->Execute();
-                    rReq.Ignore();
+                vcl::Window* pWin = SfxGetpApp()->GetTopWindow();
+                std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(pWin ? pWin->GetFrameWeld() : nullptr,
+                                                                         VclMessageType::Info, VclButtonsType::Ok,
+                                                                         SfxResId(STR_ERROR_SEND_MAIL)));
+                xBox->run();
+                rReq.Ignore();
             }
             else
                 rReq.Done();
@@ -589,7 +572,6 @@ void SfxViewShell::ExecMisc_Impl( SfxRequest &rReq )
                 OUString aFilterName;
                 OUString aTypeName( "generic_HTML" );
                 OUString aFileName;
-                OUString aExtension( "htm" );
 
                 OUString aLocation = xStorable->getLocation();
                 INetURLObject aFileObj( aLocation );
@@ -641,7 +623,7 @@ void SfxViewShell::ExecMisc_Impl( SfxRequest &rReq )
 
                 INetURLObject aFilePathObj( aTempDir.GetURL() );
                 aFilePathObj.insertName( aFileName );
-                aFilePathObj.setExtension( aExtension );
+                aFilePathObj.setExtension( "htm" );
 
                 OUString aFileURL = aFilePathObj.GetMainURL( INetURLObject::DecodeMechanism::NONE );
 
@@ -660,7 +642,8 @@ void SfxViewShell::ExecMisc_Impl( SfxRequest &rReq )
                     return;
                 }
 
-                rReq.Done(sfx2::openUriExternally(aFileURL, true));
+                sfx2::openUriExternally(aFileURL, true);
+                rReq.Done(true);
                 break;
             }
             else
@@ -797,7 +780,7 @@ SfxInPlaceClient* SfxViewShell::FindIPClient
     vcl::Window*             pObjParentWin
 )   const
 {
-    SfxInPlaceClientList *pClients = pImpl->GetIPClientList_Impl(false);
+    std::vector< SfxInPlaceClient* > *pClients = pImpl->GetIPClients_Impl(false);
     if ( !pClients )
         return nullptr;
 
@@ -822,7 +805,7 @@ SfxInPlaceClient* SfxViewShell::GetIPClient() const
 SfxInPlaceClient* SfxViewShell::GetUIActiveIPClient_Impl() const
 {
     // this method is needed as long as SFX still manages the border space for ChildWindows (see SfxFrame::Resize)
-    SfxInPlaceClientList *pClients = pImpl->GetIPClientList_Impl(false);
+    std::vector< SfxInPlaceClient* > *pClients = pImpl->GetIPClients_Impl(false);
     if ( !pClients )
         return nullptr;
 
@@ -837,13 +820,15 @@ SfxInPlaceClient* SfxViewShell::GetUIActiveIPClient_Impl() const
 
 SfxInPlaceClient* SfxViewShell::GetUIActiveClient() const
 {
-    SfxInPlaceClientList *pClients = pImpl->GetIPClientList_Impl(false);
+    std::vector< SfxInPlaceClient* > *pClients = pImpl->GetIPClients_Impl(false);
     if ( !pClients )
         return nullptr;
 
+    const bool bIsTiledRendering = comphelper::LibreOfficeKit::isActive();
+
     for (SfxInPlaceClient* pIPClient : *pClients)
     {
-        if ( pIPClient->IsObjectUIActive() )
+        if ( pIPClient->IsObjectUIActive() || ( bIsTiledRendering && pIPClient->IsObjectInPlaceActive() ) )
             return pIPClient;
     }
 
@@ -869,16 +854,6 @@ void SfxViewShell::Deactivate(bool /*bMDI*/)
 }
 
 
-void SfxViewShell::AdjustPosSizePixel
-(
-    const Point&    /*rToolOffset*/,// Upper left corner Tools in Frame-Window
-    const Size&     /*rSize*/       // All available sizes.
-)
-
-{
-}
-
-
 void SfxViewShell::Move()
 
 /*  [Description]
@@ -1053,9 +1028,6 @@ void SfxViewShell::SetWindow
     // Disconnect existing IP-Clients if possible
     DisconnectAllClients();
 
-    //TODO: should we have a "ReconnectAllClients" method?
-    DiscardClients_Impl();
-
     // Switch View-Port
     bool bHadFocus = pWindow && pWindow->HasChildPathFocus( true );
     pWindow = pViewPort;
@@ -1084,10 +1056,10 @@ SfxViewShell::SfxViewShell
 :   SfxShell(this)
 ,   pImpl( new SfxViewShell_Impl(nFlags) )
 ,   pFrame(pViewFrame)
-,   pSubShell(nullptr)
 ,   pWindow(nullptr)
 ,   bNoNewWindow( nFlags & SfxViewShellFlags::NO_NEWWINDOW )
 ,   mbPrinterSettingsModified(false)
+,   maLOKLanguageTag("en-US", true)
 {
 
     SetMargin( pViewFrame->GetMargin_Impl() );
@@ -1098,6 +1070,9 @@ SfxViewShell::SfxViewShell
     // Insert into list
     SfxViewShellArr_Impl &rViewArr = SfxGetpApp()->GetViewShells_Impl();
     rViewArr.push_back(this);
+
+    if (comphelper::LibreOfficeKit::isActive())
+        pViewFrame->GetWindow().SetLOKNotifier(this, true);
 }
 
 
@@ -1121,6 +1096,9 @@ SfxViewShell::~SfxViewShell()
         pImpl->m_pController->ReleaseShell_Impl();
         pImpl->m_pController.clear();
     }
+
+    if (GetViewFrame()->GetWindow().GetLOKNotifier())
+        GetViewFrame()->GetWindow().ReleaseLOKNotifier();
 }
 
 bool SfxViewShell::PrepareClose
@@ -1128,13 +1106,18 @@ bool SfxViewShell::PrepareClose
     bool bUI     // TRUE: Allow Dialog and so on, FALSE: silent-mode
 )
 {
+    if (GetViewFrame()->GetWindow().GetLOKNotifier())
+        GetViewFrame()->GetWindow().ReleaseLOKNotifier();
+
     SfxPrinter *pPrinter = GetPrinter();
     if ( pPrinter && pPrinter->IsPrinting() )
     {
         if ( bUI )
         {
-            ScopedVclPtrInstance< MessageDialog > aInfoBox(&GetViewFrame()->GetWindow(), SfxResId( STR_CANT_CLOSE ), VclMessageType::Info );
-            aInfoBox->Execute();
+            std::unique_ptr<weld::MessageDialog> xBox(Application::CreateMessageDialog(GetViewFrame()->GetWindow().GetFrameWeld(),
+                                                                     VclMessageType::Info, VclButtonsType::Ok,
+                                                                     SfxResId(STR_CANT_CLOSE)));
+            xBox->run();
         }
 
         return false;
@@ -1284,8 +1267,8 @@ void SfxViewShell::PushSubShells_Impl( bool bPush )
     SfxDispatcher *pDisp = pFrame->GetDispatcher();
     if ( bPush )
     {
-        for(SfxShellArr_Impl::const_iterator i = pImpl->aArr.begin(); i != pImpl->aArr.end(); ++i)
-            pDisp->Push(**i);
+        for (auto const& elem : pImpl->aArr)
+            pDisp->Push(*elem);
     }
     else if(!pImpl->aArr.empty())
     {
@@ -1316,6 +1299,37 @@ void SfxViewShell::WriteUserDataSequence ( uno::Sequence < beans::PropertyValue
 }
 
 
+// returns the number of current available shells of spec. type viewing the specified doc.
+size_t SfxViewShell::GetActiveShells ( bool bOnlyVisible )
+{
+    size_t nShells = 0;
+
+    // search for a SfxViewShell of the specified type
+    SfxViewShellArr_Impl &rShells = SfxGetpApp()->GetViewShells_Impl();
+    SfxViewFrameArr_Impl &rFrames = SfxGetpApp()->GetViewFrames_Impl();
+    for (SfxViewShell* pShell : rShells)
+    {
+        if ( pShell )
+        {
+            // sometimes dangling SfxViewShells exist that point to a dead SfxViewFrame
+            // these ViewShells shouldn't be accessible anymore
+            // a destroyed ViewFrame is not in the ViewFrame array anymore, so checking this array helps
+            for (SfxViewFrame* pFrame : rFrames)
+            {
+                if ( pFrame == pShell->GetViewFrame() )
+                {
+                    // only ViewShells with a valid ViewFrame will be returned
+                    if ( !bOnlyVisible || pFrame->IsVisible() )
+                        ++nShells;
+                }
+            }
+        }
+    }
+
+    return nShells;
+}
+
+
 // returns the first shell of spec. type viewing the specified doc.
 SfxViewShell* SfxViewShell::GetFirst
 (
@@ -1421,7 +1435,7 @@ void SfxViewShell::Notify( SfxBroadcaster& rBC,
 
 bool SfxViewShell::ExecKey_Impl(const KeyEvent& aKey)
 {
-    if (!pImpl->m_xAccExec.get())
+    if (!pImpl->m_xAccExec)
     {
         pImpl->m_xAccExec = ::svt::AcceleratorExecute::createAcceleratorHelper();
         pImpl->m_xAccExec->init(::comphelper::getProcessComponentContext(),
@@ -1474,6 +1488,23 @@ void SfxViewShell::afterCallbackRegistered()
 {
 }
 
+vcl::Window* SfxViewShell::GetEditWindowForActiveOLEObj() const
+{
+    vcl::Window* pEditWin = nullptr;
+    SfxInPlaceClient* pIPClient = GetIPClient();
+    if (pIPClient)
+    {
+        pEditWin = pIPClient->GetEditWin();
+    }
+    return pEditWin;
+}
+
+void SfxViewShell::SetLOKLanguageTag(const OUString& rBcp47LanguageTag)
+{
+    css::uno::Sequence<OUString> inst(officecfg::Setup::Office::InstalledLocales::get()->getElementNames());
+    maLOKLanguageTag = LanguageTag(getInstalledLocaleForSystemUILanguage(inst, /* bRequestInstallIfMissing */ false, rBcp47LanguageTag), true).makeFallback();
+}
+
 void SfxViewShell::NotifyCursor(SfxViewShell* /*pViewShell*/) const
 {
 }
@@ -1511,7 +1542,7 @@ void SfxViewShell::dumpAsXml(xmlTextWriterPtr pWriter) const
 {
     xmlTextWriterStartElement(pWriter, BAD_CAST("SfxViewShell"));
     xmlTextWriterWriteFormatAttribute(pWriter, BAD_CAST("ptr"), "%p", this);
-    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("id"), BAD_CAST(OString::number((sal_Int32)GetViewShellId()).getStr()));
+    xmlTextWriterWriteAttribute(pWriter, BAD_CAST("id"), BAD_CAST(OString::number(static_cast<sal_Int32>(GetViewShellId())).getStr()));
     xmlTextWriterEndElement(pWriter);
 }
 
@@ -1559,10 +1590,10 @@ void SfxViewShell::ShowCursor( bool /*bOn*/ )
 }
 
 
-void SfxViewShell::ResetAllClients_Impl( SfxInPlaceClient *pIP )
+void SfxViewShell::ResetAllClients_Impl( SfxInPlaceClient const *pIP )
 {
 
-    SfxInPlaceClientList *pClients = pImpl->GetIPClientList_Impl(false);
+    std::vector< SfxInPlaceClient* > *pClients = pImpl->GetIPClients_Impl(false);
     if ( !pClients )
         return;
 
@@ -1576,7 +1607,7 @@ void SfxViewShell::ResetAllClients_Impl( SfxInPlaceClient *pIP )
 
 void SfxViewShell::DisconnectAllClients()
 {
-    SfxInPlaceClientList *pClients = pImpl->GetIPClientList_Impl(false);
+    std::vector< SfxInPlaceClient* > *pClients = pImpl->GetIPClients_Impl(false);
     if ( !pClients )
         return;
 
@@ -1593,7 +1624,7 @@ void SfxViewShell::QueryObjAreaPixel( tools::Rectangle& ) const
 
 void SfxViewShell::VisAreaChanged()
 {
-    SfxInPlaceClientList *pClients = pImpl->GetIPClientList_Impl(false);
+    std::vector< SfxInPlaceClient* > *pClients = pImpl->GetIPClients_Impl(false);
     if ( !pClients )
         return;
 
@@ -1607,7 +1638,7 @@ void SfxViewShell::VisAreaChanged()
 
 
 void SfxViewShell::CheckIPClient_Impl(
-        SfxInPlaceClient *const pIPClient, const tools::Rectangle& rVisArea)
+        SfxInPlaceClient const *const pIPClient, const tools::Rectangle& rVisArea)
 {
     if ( GetObjectShell()->IsInClose() )
         return;
@@ -1615,8 +1646,7 @@ void SfxViewShell::CheckIPClient_Impl(
     bool bAlwaysActive =
         ( ( pIPClient->GetObjectMiscStatus() & embed::EmbedMisc::EMBED_ACTIVATEIMMEDIATELY ) != 0 );
     bool bActiveWhenVisible =
-        ( (( pIPClient->GetObjectMiscStatus() & embed::EmbedMisc::MS_EMBED_ACTIVATEWHENVISIBLE ) != 0 ) ||
-         svt::EmbeddedObjectRef::IsGLChart(pIPClient->GetObject()));
+        ( pIPClient->GetObjectMiscStatus() & embed::EmbedMisc::MS_EMBED_ACTIVATEWHENVISIBLE ) != 0;
 
     // this method is called when a client is created
     if (!pIPClient->IsObjectInPlaceActive())
@@ -1632,31 +1662,13 @@ void SfxViewShell::CheckIPClient_Impl(
             }
             catch (const uno::Exception& e)
             {
-                SAL_WARN("sfx.view", "SfxViewShell::CheckIPClient_Impl exception: " << e.Message);
+                SAL_WARN("sfx.view", "SfxViewShell::CheckIPClient_Impl: " << e);
             }
         }
     }
 }
 
 
-void SfxViewShell::DiscardClients_Impl()
-
-/*  [Description]
-
-    The purpose of this Method is to prevent the saving of Objects when closing
-    the Document, if the user has chosen to close without saving.
-*/
-
-{
-    SfxInPlaceClientList *pClients = pImpl->GetIPClientList_Impl(false);
-    if ( !pClients )
-        return;
-
-    for ( size_t n = 0; n < pClients->size(); )
-        delete pClients->at( n );
-}
-
-
 SfxObjectShell* SfxViewShell::GetObjectShell()
 {
     return pFrame ? pFrame->GetObjectShell() : nullptr;
@@ -1694,9 +1706,9 @@ void SfxViewShell::SetMargin( const Size& rSize )
     // the default margin was verified using www.apple.com !!
     Size aMargin = rSize;
     if ( aMargin.Width() == -1 )
-        aMargin.Width() = DEFAULT_MARGIN_WIDTH;
+        aMargin.setWidth( DEFAULT_MARGIN_WIDTH );
     if ( aMargin.Height() == -1 )
-        aMargin.Height() = DEFAULT_MARGIN_HEIGHT;
+        aMargin.setHeight( DEFAULT_MARGIN_HEIGHT );
 
     if ( aMargin != pImpl->aMargin )
     {
@@ -1726,7 +1738,6 @@ void SfxViewShell::JumpToMark( const OUString& rMark )
 void SfxViewShell::SetController( SfxBaseController* pController )
 {
     pImpl->m_pController = pController;
-    pImpl->m_bControllerSet = true;
 
     // there should be no old listener, but if there is one, it should be disconnected
     if (  pImpl->xClipboardListener.is() )
@@ -1755,7 +1766,7 @@ void SfxViewShell::RemoveContextMenuInterceptor_Impl( const uno::Reference< ui::
     pImpl->aInterceptorContainer.removeInterface( xInterceptor );
 }
 
-void Change( Menu* pMenu, SfxViewShell* pView )
+static void Change( Menu* pMenu, SfxViewShell* pView )
 {
     SfxDispatcher *pDisp = pView->GetViewFrame()->GetDispatcher();
     sal_uInt16 nCount = pMenu->GetItemCount();
@@ -1917,21 +1928,7 @@ bool SfxViewShell::TryContextMenuInterception( Menu& rMenu, const OUString& rMen
     return true;
 }
 
-void SfxViewShell::TakeOwnership_Impl()
-{
-    // currently there is only one reason to take Ownership: a hidden frame is printed
-    // so the ViewShell will check this on EndPrint (->prnmon.cxx)
-    pImpl->m_bGotOwnership = true;
-}
-
-void SfxViewShell::TakeFrameOwnership_Impl()
-{
-    // currently there is only one reason to take Ownership: a hidden frame is printed
-    // so the ViewShell will check this on EndPrint (->prnmon.cxx)
-    pImpl->m_bGotFrameOwnership = true;
-}
-
-bool SfxViewShell::HandleNotifyEvent_Impl( NotifyEvent& rEvent )
+bool SfxViewShell::HandleNotifyEvent_Impl( NotifyEvent const & rEvent )
 {
     if (pImpl->m_pController.is())
         return pImpl->m_pController->HandleEvent_Impl( rEvent );
@@ -1968,6 +1965,11 @@ Reference< view::XRenderable > SfxViewShell::GetRenderable()
     return xRender;
 }
 
+void SfxViewShell::notifyWindow(vcl::LOKWindowId nDialogId, const OUString& rAction, const std::vector<vcl::LOKPayloadItem>& rPayload) const
+{
+    SfxLokHelper::notifyWindow(this, nDialogId, rAction, rPayload);
+}
+
 uno::Reference< datatransfer::clipboard::XClipboardNotifier > SfxViewShell::GetClipboardNotifier()
 {
     uno::Reference< datatransfer::clipboard::XClipboardNotifier > xClipboardNotifier;
@@ -2002,4 +2004,9 @@ void SfxViewShell::AddRemoveClipboardListener( const uno::Reference < datatransf
     }
 }
 
+weld::Window* SfxViewShell::GetFrameWeld() const
+{
+    return pWindow ? pWindow->GetFrameWeld() : nullptr;
+}
+
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
