@@ -24,6 +24,7 @@
 #include <rtl/bootstrap.hxx>
 #include <sfx2/strings.hrc>
 #include <unotools/resmgr.hxx>
+#include <i18nlangtag/languagetag.hxx>
 
 #include <wchar.h>
 #define WIN32_LEAN_AND_MEAN
@@ -39,10 +40,9 @@
 #include <stdexcept>
 
 #if OSL_DEBUG_LEVEL > 0
-    void dumpParameter();
+    static void dumpParameter();
 #endif
 
-typedef std::vector<std::wstring> StringList_t;
 typedef std::vector<MapiRecipDescW> MapiRecipientList_t;
 typedef std::vector<MapiFileDescW> MapiAttachmentList_t;
 
@@ -55,9 +55,9 @@ namespace /* private */
     std::wstring gFrom;
     std::wstring gSubject;
     std::wstring gBody;
-    StringList_t gTo;
-    StringList_t gCc;
-    StringList_t gBcc;
+    std::vector<std::wstring> gTo;
+    std::vector<std::wstring> gCc;
+    std::vector<std::wstring> gBcc;
     // Keep temp filepath and displayed name
     std::vector<std::pair<std::wstring, std::wstring>> gAttachments;
     int gMapiFlags = 0;
@@ -76,7 +76,7 @@ namespace /* private */
     @returns
     the email address prefixed with the specified prefix.
 */
-inline std::wstring prefixEmailAddress(
+static inline std::wstring prefixEmailAddress(
     const std::wstring& aEmailAddress,
     const std::wstring& aPrefix = L"SMTP:")
 {
@@ -84,7 +84,7 @@ inline std::wstring prefixEmailAddress(
 }
 
 /** @internal */
-void addRecipient(
+static void addRecipient(
     ULONG recipClass,
     const std::wstring& recipAddress,
     MapiRecipientList_t* pMapiRecipientList)
@@ -99,7 +99,7 @@ void addRecipient(
 }
 
 /** @internal */
-void initRecipientList(MapiRecipientList_t* pMapiRecipientList)
+static void initRecipientList(MapiRecipientList_t* pMapiRecipientList)
 {
     OSL_ASSERT(pMapiRecipientList->empty());
 
@@ -117,7 +117,7 @@ void initRecipientList(MapiRecipientList_t* pMapiRecipientList)
 }
 
 /** @internal */
-void initAttachmentList(MapiAttachmentList_t* pMapiAttachmentList)
+static void initAttachmentList(MapiAttachmentList_t* pMapiAttachmentList)
 {
     OSL_ASSERT(pMapiAttachmentList->empty());
 
@@ -141,7 +141,7 @@ void initAttachmentList(MapiAttachmentList_t* pMapiAttachmentList)
 }
 
 /** @internal */
-void initMapiOriginator(MapiRecipDescW* pMapiOriginator)
+static void initMapiOriginator(MapiRecipDescW* pMapiOriginator)
 {
     ZeroMemory(pMapiOriginator, sizeof(*pMapiOriginator));
 
@@ -151,7 +151,7 @@ void initMapiOriginator(MapiRecipDescW* pMapiOriginator)
 }
 
 /** @internal */
-void initMapiMessage(
+static void initMapiMessage(
     MapiRecipDescW* aMapiOriginator,
     MapiRecipientList_t& aMapiRecipientList,
     MapiAttachmentList_t& aMapiAttachmentList,
@@ -185,7 +185,7 @@ const wchar_t* const KnownParameters[] =
 };
 
 /** @internal */
-bool isKnownParameter(const wchar_t* aParameterName)
+static bool isKnownParameter(const wchar_t* aParameterName)
 {
     for (const wchar_t* KnownParameter : KnownParameters)
         if (_wcsicmp(aParameterName, KnownParameter) == 0)
@@ -195,7 +195,7 @@ bool isKnownParameter(const wchar_t* aParameterName)
 }
 
 /** @internal */
-void initParameter(int argc, wchar_t* argv[])
+static void initParameter(int argc, wchar_t* argv[])
 {
     for (int i = 1; i < argc; i++)
     {
@@ -250,7 +250,7 @@ void initParameter(int argc, wchar_t* argv[])
     }
 }
 
-void ShowError(ULONG nMAPIResult)
+static void ShowError(ULONG nMAPIResult)
 {
     if (!gBootstrap.isEmpty())
         rtl::Bootstrap::setIniFilename(gBootstrap);
