@@ -21,11 +21,11 @@
 #include <tools/diagnose_ex.h>
 
 #include "drawshapesubsetting.hxx"
-#include "subsettableshapemanager.hxx"
-#include "eventqueue.hxx"
-#include "eventmultiplexer.hxx"
+#include <subsettableshapemanager.hxx>
+#include <eventqueue.hxx>
+#include <eventmultiplexer.hxx>
 #include "intrinsicanimationactivity.hxx"
-#include "intrinsicanimationeventhandler.hxx"
+#include <intrinsicanimationeventhandler.hxx>
 
 #include <memory>
 
@@ -65,8 +65,7 @@ namespace slideshow
                                         const DrawShapeSharedPtr&       rDrawShape,
                                         const WakeupEventSharedPtr&     rWakeupEvent,
                                         const ::std::vector<double>&    rTimeouts,
-                                        ::std::size_t                   nNumLoops,
-                                        CycleMode                       eCycleMode );
+                                        ::std::size_t                   nNumLoops );
             IntrinsicAnimationActivity(const IntrinsicAnimationActivity&) = delete;
             IntrinsicAnimationActivity& operator=(const IntrinsicAnimationActivity&) = delete;
 
@@ -83,11 +82,10 @@ namespace slideshow
             SlideShowContext                        maContext;
             std::weak_ptr<DrawShape>              mpDrawShape;
             WakeupEventSharedPtr                    mpWakeupEvent;
-            IntrinsicAnimationEventHandlerSharedPtr mpListener;
+            IntrinsicAnimationEventHandlerSharedPtr const mpListener;
             ::std::vector<double>                   maTimeouts;
-            CycleMode                               meCycleMode;
             ::std::size_t                           mnCurrIndex;
-            ::std::size_t                           mnNumLoops;
+            ::std::size_t const                     mnNumLoops;
             ::std::size_t                           mnLoopCount;
             bool                                    mbIsActive;
         };
@@ -115,14 +113,12 @@ namespace slideshow
                                                                 const DrawShapeSharedPtr&       rDrawShape,
                                                                 const WakeupEventSharedPtr&     rWakeupEvent,
                                                                 const ::std::vector<double>&    rTimeouts,
-                                                                ::std::size_t                   nNumLoops,
-                                                                CycleMode                       eCycleMode ) :
+                                                                ::std::size_t                   nNumLoops ) :
             maContext( rContext ),
             mpDrawShape( rDrawShape ),
             mpWakeupEvent( rWakeupEvent ),
             mpListener( new IntrinsicAnimationListener(*this) ),
             maTimeouts( rTimeouts ),
-            meCycleMode( eCycleMode ),
             mnCurrIndex(0),
             mnNumLoops(nNumLoops),
             mnLoopCount(0),
@@ -177,12 +173,16 @@ namespace slideshow
                 return false;
             }
 
+            const ::std::size_t nNumFrames(maTimeouts.size());
+
             // mnNumLoops == 0 means infinite looping
             if( mnNumLoops != 0 &&
                 mnLoopCount >= mnNumLoops )
             {
-                // #i55294# After finishing the loops, display the first frame
-                pDrawShape->setIntrinsicAnimationFrame( 0 );
+                // #i55294# After finishing the loops, display the last frame
+                // powerpoint 2013 and firefox etc show the last frame when
+                // the animation ends
+                pDrawShape->setIntrinsicAnimationFrame(nNumFrames - 1);
                 maContext.mpSubsettableShapeManager->notifyShapeUpdate( pDrawShape );
 
                 end();
@@ -191,36 +191,14 @@ namespace slideshow
             }
 
             ::std::size_t       nNewIndex = 0;
-            const ::std::size_t nNumFrames(maTimeouts.size());
-            switch( meCycleMode )
-            {
-                case CYCLE_LOOP:
-                {
-                    pDrawShape->setIntrinsicAnimationFrame( mnCurrIndex );
 
-                    mpWakeupEvent->start();
-                    mpWakeupEvent->setNextTimeout( maTimeouts[mnCurrIndex] );
+            pDrawShape->setIntrinsicAnimationFrame( mnCurrIndex );
 
-                    mnLoopCount += (mnCurrIndex + 1) / nNumFrames;
-                    nNewIndex = (mnCurrIndex + 1) % nNumFrames;
-                    break;
-                }
+            mpWakeupEvent->start();
+            mpWakeupEvent->setNextTimeout( maTimeouts[mnCurrIndex] );
 
-                case CYCLE_PINGPONGLOOP:
-                {
-                    ::std::size_t nTrueIndex( mnCurrIndex < nNumFrames ?
-                                              mnCurrIndex :
-                                              2*nNumFrames - mnCurrIndex - 1 );
-                    pDrawShape->setIntrinsicAnimationFrame( nTrueIndex );
-
-                    mpWakeupEvent->start();
-                    mpWakeupEvent->setNextTimeout( maTimeouts[nTrueIndex] );
-
-                    mnLoopCount += (mnCurrIndex + 1) / (2*nNumFrames);
-                    nNewIndex = (mnCurrIndex + 1) % 2*nNumFrames;
-                    break;
-                }
-            }
+            mnLoopCount += (mnCurrIndex + 1) / nNumFrames;
+            nNewIndex = (mnCurrIndex + 1) % nNumFrames;
 
             maContext.mrEventQueue.addEvent( mpWakeupEvent );
             maContext.mpSubsettableShapeManager->notifyShapeUpdate( pDrawShape );
@@ -259,16 +237,14 @@ namespace slideshow
             const DrawShapeSharedPtr&       rDrawShape,
             const WakeupEventSharedPtr&     rWakeupEvent,
             const ::std::vector<double>&    rTimeouts,
-            ::std::size_t                   nNumLoops,
-            CycleMode                       eCycleMode )
+            sal_uInt32                      nNumLoops)
         {
             return ActivitySharedPtr(
                 new IntrinsicAnimationActivity(rContext,
                                                rDrawShape,
                                                rWakeupEvent,
                                                rTimeouts,
-                                               nNumLoops,
-                                               eCycleMode) );
+                                               nNumLoops) );
         }
     }
 }
