@@ -37,8 +37,6 @@ BEGIN
 
     @languageproducts = ();
     $build = "";
-    $minor = "";
-    $lastminor = "";
     $os = "";
     $cpuname = "";
     $com = "";
@@ -256,7 +254,6 @@ BEGIN
     %allcabinetassigns = ();
     %cabfilecounter = ();
     %lastsequence = ();
-    %dontdeletecomponents = ();
     %allcalculated_guids = ();
     %calculated_component_guids = ();
     %all_english_languagestrings = ();
