@@ -21,6 +21,7 @@
 #include "itemholder2.hxx"
 
 #include <osl/diagnose.h>
+#include <sal/log.hxx>
 #include <comphelper/processfactory.hxx>
 #include <com/sun/star/lang/XComponent.hpp>
 #include <com/sun/star/configuration/theDefaultProvider.hpp>
@@ -50,11 +51,7 @@ ItemHolder2::ItemHolder2()
         if(bMessage)
         {
             bMessage = false;
-            OString sMsg = "CreateInstance with arguments exception: "
-                         + OString(rEx.Message.getStr(),
-                                   rEx.Message.getLength(),
-                                   RTL_TEXTENCODING_ASCII_US);
-            OSL_FAIL(sMsg.getStr());
+            SAL_WARN( "svl", "CreateInstance with arguments exception: " << rEx);
         }
     }
 #else
@@ -82,12 +79,8 @@ void ItemHolder2::impl_addItem(EItem eItem)
 {
     ::osl::ResettableMutexGuard aLock(m_aLock);
 
-    TItems::const_iterator pIt;
-    for (  pIt  = m_lItems.begin();
-           pIt != m_lItems.end()  ;
-         ++pIt                    )
+    for ( auto const & rInfo : m_lItems )
     {
-        const TItemInfo& rInfo = *pIt;
         if (rInfo.eItem == eItem)
             return;
     }
@@ -96,22 +89,18 @@ void ItemHolder2::impl_addItem(EItem eItem)
     aNewItem.eItem = eItem;
     impl_newItem(aNewItem);
     if (aNewItem.pItem)
-        m_lItems.push_back(aNewItem);
+        m_lItems.emplace_back(std::move(aNewItem));
 }
 
 void ItemHolder2::impl_releaseAllItems()
 {
-    ::osl::ResettableMutexGuard aLock(m_aLock);
-
-    TItems::iterator pIt;
-    for (  pIt  = m_lItems.begin();
-           pIt != m_lItems.end()  ;
-         ++pIt                    )
+    std::vector< TItemInfo > items;
     {
-        TItemInfo& rInfo = *pIt;
-        impl_deleteItem(rInfo);
+        ::osl::MutexGuard aLock(m_aLock);
+        items.swap(m_lItems);
     }
-    m_lItems.clear();
+
+    // items will be freed when the block exits
 }
 
 void ItemHolder2::impl_newItem(TItemInfo& rItem)
@@ -119,11 +108,11 @@ void ItemHolder2::impl_newItem(TItemInfo& rItem)
     switch(rItem.eItem)
     {
         case EItem::CJKOptions :
-            rItem.pItem = new SvtCJKOptions();
+            rItem.pItem.reset( new SvtCJKOptions() );
             break;
 
         case EItem::CTLOptions :
-            rItem.pItem = new SvtCTLOptions();
+            rItem.pItem.reset( new SvtCTLOptions() );
             break;
 
         default:
@@ -132,13 +121,4 @@ void ItemHolder2::impl_newItem(TItemInfo& rItem)
     }
 }
 
-void ItemHolder2::impl_deleteItem(TItemInfo& rItem)
-{
-    if (rItem.pItem)
-    {
-        delete rItem.pItem;
-        rItem.pItem = nullptr;
-    }
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
