@@ -14,13 +14,12 @@
 #include <comphelper/sequence.hxx>
 #include <com/sun/star/beans/PropertyValue.hpp>
 
-
 using namespace com::sun::star;
 
 SfxGrabBagItem::SfxGrabBagItem() = default;
 
-SfxGrabBagItem::SfxGrabBagItem(sal_uInt16 nWhich) :
-    SfxPoolItem(nWhich)
+SfxGrabBagItem::SfxGrabBagItem(sal_uInt16 nWhich)
+    : SfxPoolItem(nWhich)
 {
 }
 
@@ -47,7 +46,7 @@ bool SfxGrabBagItem::PutValue(const uno::Any& rVal, sal_uInt8 /*nMemberId*/)
         comphelper::OSequenceIterator<beans::PropertyValue> i(aValue);
         while (i.hasMoreElements())
         {
-            beans::PropertyValue aPropertyValue = i.nextElement().get<beans::PropertyValue>();
+            auto aPropertyValue = i.nextElement().get<beans::PropertyValue>();
             m_aMap[aPropertyValue.Name] = aPropertyValue.Value;
         }
         return true;
