@@ -26,12 +26,14 @@
 #include <vcl/button.hxx>
 #include <vcl/fixed.hxx>
 #include <vcl/settings.hxx>
+#include <vcl/commandevent.hxx>
 #include <comphelper/processfactory.hxx>
 #include <unotools/calendarwrapper.hxx>
 #include <unotools/localedatawrapper.hxx>
 #include <com/sun/star/i18n/Weekdays.hpp>
 #include <com/sun/star/i18n/CalendarDisplayIndex.hpp>
 #include <com/sun/star/i18n/CalendarFieldIndex.hpp>
+#include <sal/log.hxx>
 
 #include <svtools/strings.hrc>
 #include <svtools/svtresid.hxx>
@@ -84,7 +86,6 @@ void Calendar::ImplInit( WinBits nWinStyle )
     mbNextIn                = false;
     mbTravelSelect          = false;
     mbAllSel                = false;
-    mbDropPos               = false;
 
     OUString aGregorian( "gregorian");
     maCalendarWrapper.loadCalendar( aGregorian,
@@ -113,10 +114,6 @@ void Calendar::ImplInit( WinBits nWinStyle )
     for (sal_Int32 i = 0; i < 31; ++i)
         maDayTexts[i] = OUString::number(i+1);
 
-    maDragScrollTimer.SetInvokeHandler( LINK( this, Calendar, ScrollHdl ) );
-    maDragScrollTimer.SetTimeout( GetSettings().GetMouseSettings().GetScrollRepeat() );
-    mnDragScrollHitTest = 0;
-
     ImplInitSettings();
 }
 
@@ -606,9 +603,6 @@ void Calendar::ImplDrawDate(vcl::RenderContext& rRenderContext,
     // if needed do FocusRect
     if (bFocus && HasFocus())
         ShowFocus(aDateRect);
-
-    if (mbDropPos && maDropDate == Date(nDay, nMonth, nYear))
-        ImplInvertDropPos();
 }
 
 void Calendar::ImplDraw(vcl::RenderContext& rRenderContext)
@@ -878,14 +872,6 @@ void Calendar::ImplUpdate( bool bCalcNew )
     mbFormat = true;
 }
 
-void Calendar::ImplInvertDropPos()
-{
-    tools::Rectangle aRect = GetDateRect( maDropDate );//this is one Pixel to width and one to height
-    aRect.SetBottom( aRect.Top()+mnDayHeight-1 );
-    aRect.SetRight( aRect.Left()+mnDayWidth-1 );
-    Invert( aRect );
-}
-
 void Calendar::ImplScroll( bool bPrev )
 {
     Date aNewFirstMonth = GetFirstMonth();
@@ -1031,16 +1017,6 @@ void Calendar::ImplEndTracking( bool bCancel )
     mpOldSelectTable.reset();
 }
 
-IMPL_LINK_NOARG( Calendar, ScrollHdl, Timer*, void )
-{
-    bool bPrevIn = (mnDragScrollHitTest & CALENDAR_HITTEST_PREV) != 0;
-    bool bNextIn = (mnDragScrollHitTest & CALENDAR_HITTEST_NEXT) != 0;
-    if( bNextIn || bPrevIn )
-    {
-        ImplScroll( bPrevIn );
-    }
-}
-
 void Calendar::MouseButtonDown( const MouseEvent& rMEvt )
 {
     if ( rMEvt.IsLeft() && !mbMenuDown )
@@ -1380,7 +1356,6 @@ void Calendar::SetFirstDate( const Date& rNewFirstDate )
     if ( maFirstDate != rNewFirstDate )
     {
         maFirstDate = Date( 1, rNewFirstDate.GetMonth(), rNewFirstDate.GetYear() );
-        mbDropPos = false;
         ImplUpdate();
     }
 }
@@ -1755,7 +1730,6 @@ CalendarField::CalendarField(vcl::Window* pParent, WinBits nWinStyle)
     , mpCalendar(nullptr)
     , mpTodayBtn(nullptr)
     , mpNoneBtn(nullptr)
-    , maDefaultDate( Date::EMPTY )
     , mbToday(false)
     , mbNone(false)
 {
@@ -1836,10 +1810,7 @@ bool CalendarField::ShowDropDown( bool bShow )
         Date aDate = GetDate();
         if ( IsEmptyDate() || !aDate.IsValidAndGregorian() )
         {
-            if ( maDefaultDate.IsValidAndGregorian() )
-                aDate = maDefaultDate;
-            else
-                aDate = Date( Date::SYSTEM );
+            aDate = Date( Date::SYSTEM );
         }
         pCalendar->SetCurDate( aDate );
         Point       aPos( GetParent()->OutputToScreenPixel( GetPosPixel() ) );
