@@ -20,6 +20,7 @@
 #include <unotools/accessiblestatesethelper.hxx>
 #include <vcl/svapp.hxx>
 #include <vcl/settings.hxx>
+#include <sal/log.hxx>
 #include <svtools/valueset.hxx>
 #include "valueimp.hxx"
 #include <comphelper/servicehelper.hxx>
@@ -66,7 +67,6 @@ SvtValueSetItem::SvtValueSetItem( SvtValueSet& rParent )
     , mnId(0)
     , meType(VALUESETITEM_NONE)
     , mbVisible(true)
-    , mpData(nullptr)
     , mxAcc()
 {
 }
@@ -420,7 +420,7 @@ uno::Reference< accessibility::XAccessible > SAL_CALL ValueSetAcc::getAccessible
 
         if( VALUESET_ITEM_NONEITEM != nItemPos )
         {
-            ValueSetItem *const pItem = mpParent->mItemList[nItemPos];
+            ValueSetItem *const pItem = mpParent->mItemList[nItemPos].get();
             xRet = pItem->GetAccessible( false/*bIsTransientChildrenDisabled*/ );
         }
     }
@@ -1072,32 +1072,6 @@ SvtValueItemAcc::~SvtValueItemAcc()
 {
 }
 
-void SvtValueItemAcc::FireAccessibleEvent( short nEventId, const uno::Any& rOldValue, const uno::Any& rNewValue )
-{
-    if( !nEventId )
-        return;
-
-    ::std::vector< uno::Reference< accessibility::XAccessibleEventListener > >                  aTmpListeners( mxEventListeners );
-    accessibility::AccessibleEventObject                                                        aEvtObject;
-
-    aEvtObject.EventId = nEventId;
-    aEvtObject.Source = static_cast<uno::XWeak*>(this);
-    aEvtObject.NewValue = rNewValue;
-    aEvtObject.OldValue = rOldValue;
-
-    for (auto const& tmpListener : aTmpListeners)
-    {
-        tmpListener->notifyEvent( aEvtObject );
-    }
-}
-
-
-void SvtValueItemAcc::ParentDestroyed()
-{
-    const ::osl::MutexGuard aGuard( maMutex );
-    mpParent = nullptr;
-}
-
 namespace
 {
     class theSvtValueItemAccUnoTunnelId : public rtl::Static< UnoTunnelIdInit, theSvtValueItemAccUnoTunnelId > {};
@@ -1431,6 +1405,25 @@ sal_Int64 SAL_CALL SvtValueItemAcc::getSomething( const uno::Sequence< sal_Int8
     return nRet;
 }
 
+void SvtValueItemAcc::FireAccessibleEvent( short nEventId, const uno::Any& rOldValue, const uno::Any& rNewValue )
+{
+    if( !nEventId )
+        return;
+
+    ::std::vector< uno::Reference< accessibility::XAccessibleEventListener > >                  aTmpListeners( mxEventListeners );
+    accessibility::AccessibleEventObject                                                        aEvtObject;
+
+    aEvtObject.EventId = nEventId;
+    aEvtObject.Source = static_cast<uno::XWeak*>(this);
+    aEvtObject.NewValue = rNewValue;
+    aEvtObject.OldValue = rOldValue;
+
+    for (auto const& tmpListener : aTmpListeners)
+    {
+        tmpListener->notifyEvent( aEvtObject );
+    }
+}
+
 SvtValueSetAcc::SvtValueSetAcc( SvtValueSet* pParent ) :
     ValueSetAccComponentBase (m_aMutex),
     mpParent( pParent ),
@@ -1733,7 +1726,7 @@ uno::Reference< accessibility::XAccessible > SAL_CALL SvtValueSetAcc::getAccessi
 
         if( VALUESET_ITEM_NONEITEM != nItemPos )
         {
-            SvtValueSetItem *const pItem = mpParent->mItemList[nItemPos];
+            SvtValueSetItem *const pItem = mpParent->mItemList[nItemPos].get();
             xRet = pItem->GetAccessible( false/*bIsTransientChildrenDisabled*/ );
         }
     }
@@ -1840,7 +1833,6 @@ void SAL_CALL SvtValueSetAcc::selectAccessibleChild( sal_Int32 nChildIndex )
         throw lang::IndexOutOfBoundsException();
 
     mpParent->SelectItem( pItem->mnId );
-    mpParent->Select ();
 }
 
 
