@@ -17,6 +17,7 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
+#include <osl/diagnose.h>
 #include <vcl/fixed.hxx>
 #include <vcl/button.hxx>
 #include <vcl/tabpage.hxx>
@@ -76,7 +77,7 @@ void WizardDialog::SetEmptyViewMargin()
 
 void WizardDialog::ImplCalcSize( Size& rSize )
 {
-    // ButtonBar-Hoehe berechnen
+    // calculate ButtonBar height
     long                nMaxHeight = 0;
     ImplWizButtonData*  pBtnData = mpFirstBtn;
     while ( pBtnData )
@@ -90,7 +91,7 @@ void WizardDialog::ImplCalcSize( Size& rSize )
         nMaxHeight += WIZARDDIALOG_BUTTON_OFFSET_Y*2;
     rSize.AdjustHeight(nMaxHeight );
 
-    // View-Window-Groesse dazurechnen
+    // add in the view window size
     if ( mpViewWindow && mpViewWindow->IsVisible() )
     {
         Size aViewSize = mpViewWindow->GetSizePixel();
