@@ -140,7 +140,7 @@ tools::PolyPolygon SvxContourDlg::CreateAutoContour( const Graphic& rGraphic,
             aBmp = rGraphic.GetBitmapEx().GetMask();
         else
         {
-            aBmp = rGraphic.GetBitmap();
+            aBmp = rGraphic.GetBitmapEx().GetBitmap();
             nContourFlags |= XOutFlags::ContourEdgeDetect;
         }
     }
@@ -689,7 +689,7 @@ IMPL_LINK( SvxSuperContourDlg, PipetteClickHdl, ContourWindow&, rWnd, void )
 
         if( aGraphic.GetType() == GraphicType::Bitmap )
         {
-            Bitmap      aBmp( aGraphic.GetBitmap() );
+            Bitmap      aBmp( aGraphic.GetBitmapEx().GetBitmap() );
             const long  nTol = static_cast<long>(m_pMtfTolerance->GetValue() * 255L / 100L);
 
             aMask = aBmp.CreateMask( rColor, nTol );
