@@ -35,7 +35,6 @@
 #include <com/sun/star/accessibility/AccessibleEventObject.hpp>
 #include <com/sun/star/accessibility/AccessibleEventId.hpp>
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
-#include <comphelper/types.hxx>
 #include <svl/itemset.hxx>
 #include <unicode/uchar.h>
 #include <rtl/ustrbuf.hxx>
@@ -45,8 +44,8 @@ using namespace ::com::sun::star::uno;
 using namespace ::com::sun::star;
 
 
-SvxSearchCharSet::SvxSearchCharSet(weld::ScrolledWindow* pScrolledWindow, const VclPtr<VirtualDevice>& rVirDev)
-    : SvxShowCharSet(pScrolledWindow, rVirDev)
+SvxSearchCharSet::SvxSearchCharSet(std::unique_ptr<weld::ScrolledWindow> pScrolledWindow, const VclPtr<VirtualDevice>& rVirDev)
+    : SvxShowCharSet(std::move(pScrolledWindow), rVirDev)
     , nCount(0)
 {
 }
