@@ -22,9 +22,11 @@
 #include <basic/sbxvar.hxx>
 #include <rtl/math.hxx>
 #include <unotools/intlwrapper.hxx>
+#include <unotools/localedatawrapper.hxx>
 #include <com/sun/star/chart/ChartAxisArrangeOrderType.hpp>
 
 #include <float.h>
+#include <climits>
 
 #include <svx/chrtitem.hxx>
 
