@@ -84,7 +84,7 @@ bool XPatternList::Create()
     return true;
 }
 
-Bitmap XPatternList::CreateBitmap( long nIndex, const Size& rSize ) const
+BitmapEx XPatternList::CreateBitmap( long nIndex, const Size& rSize ) const
 {
     assert( nIndex < Count() );
 
@@ -133,21 +133,21 @@ Bitmap XPatternList::CreateBitmap( long nIndex, const Size& rSize ) const
                 }
             }
         }
-        rBitmapEx = pVirtualDevice->GetBitmap(Point(0, 0), rSize);
-        return rBitmapEx.GetBitmap();
+        rBitmapEx = pVirtualDevice->GetBitmapEx(Point(0, 0), rSize);
+        return rBitmapEx;
     }
     else
-        return Bitmap();
+        return BitmapEx();
 }
 
-Bitmap XPatternList::CreateBitmapForUI( long nIndex )
+BitmapEx XPatternList::CreateBitmapForUI( long nIndex )
 {
     const StyleSettings& rStyleSettings = Application::GetSettings().GetStyleSettings();
     const Size& rSize = rStyleSettings.GetListBoxPreviewDefaultPixelSize();
     return CreateBitmap(nIndex, rSize);
 }
 
-Bitmap XPatternList::GetBitmapForPreview( long nIndex, const Size& rSize )
+BitmapEx XPatternList::GetBitmapForPreview( long nIndex, const Size& rSize )
 {
     return CreateBitmap(nIndex, rSize);
 }
