@@ -17,15 +17,13 @@
  *   the License at http://www.apache.org/licenses/LICENSE-2.0 .
  */
 
-#include <osl/mutex.hxx>
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 #include <unotools/accessiblestatesethelper.hxx>
-#include <comphelper/servicehelper.hxx>
 #include <cppuhelper/supportsservice.hxx>
 #include <vcl/svapp.hxx>
 #include <hffrm.hxx>
 #include "accheaderfooter.hxx"
-#include "access.hrc"
+#include <strings.hrc>
 
 using namespace ::com::sun::star;
 using namespace ::com::sun::star::lang;
@@ -63,13 +61,13 @@ OUString SAL_CALL SwAccessibleHeaderFooter::getAccessibleDescription()
 
     ThrowIfDisposed();
 
-    sal_uInt16 nResId = AccessibleRole::HEADER == GetRole()
+    const char* pResId = AccessibleRole::HEADER == GetRole()
         ? STR_ACCESS_HEADER_DESC
         : STR_ACCESS_FOOTER_DESC ;
 
     OUString sArg( GetFormattedPageNumber() );
 
-    return GetResource( nResId, &sArg );
+    return GetResource(pResId, &sArg);
 }
 
 OUString SAL_CALL SwAccessibleHeaderFooter::getImplementationName()
