@@ -24,6 +24,8 @@
 #include <com/sun/star/uri/UriReferenceFactory.hpp>
 #include <com/sun/star/uri/XVndSunStarScriptUrl.hpp>
 #include <comphelper/processfactory.hxx>
+#include <o3tl/make_unique.hxx>
+#include <osl/diagnose.h>
 
 using namespace ::com::sun::star;
 
@@ -46,14 +48,14 @@ SwMacroField::SwMacroField(SwMacroFieldType* pInitType,
     m_bIsScriptURL = isScriptURL(m_aMacro);
 }
 
-OUString SwMacroField::Expand() const
+OUString SwMacroField::ExpandImpl(SwRootFrame const*const) const
 {
     return m_aText ;
 }
 
-SwField* SwMacroField::Copy() const
+std::unique_ptr<SwField> SwMacroField::Copy() const
 {
-    return new SwMacroField(static_cast<SwMacroFieldType*>(GetTyp()), m_aMacro, m_aText);
+    return o3tl::make_unique<SwMacroField>(static_cast<SwMacroFieldType*>(GetTyp()), m_aMacro, m_aText);
 }
 
 OUString SwMacroField::GetFieldName() const
