@@ -781,7 +781,7 @@ void SwFlyLayFrame::Modify( const SfxPoolItem* pOld, const SfxPoolItem *pNew )
         {
             SwNodeIndex aIdx( pAnch->GetContentAnchor()->nNode );
             SwContentFrame *pContent = GetFormat()->GetDoc()->GetNodes().GoNext( &aIdx )->
-                         GetContentNode()->getLayoutFrame( getRootFrame(), nullptr, nullptr, false );
+                GetContentNode()->getLayoutFrame(getRootFrame(), nullptr, nullptr);
             if( pContent )
             {
                 SwFlyFrame *pTmp = pContent->FindFlyFrame();
@@ -1295,14 +1295,11 @@ bool CalcClipRect( const SdrObject *pSdrObj, SwRect &rRect, bool bMove )
                     if ( !pCell && pUp->IsCellFrame() )
                         pCell = pUp;
                 }
-                if ( bMove )
+                if ( bMove && pUp->IsRootFrame() )
                 {
-                    if ( pUp->IsRootFrame() )
-                    {
-                        rRect  = pUp->getFramePrintArea();
-                        rRect += pUp->getFrameArea().Pos();
-                        pUp = nullptr;
-                    }
+                    rRect  = pUp->getFramePrintArea();
+                    rRect += pUp->getFrameArea().Pos();
+                    pUp = nullptr;
                 }
                 if ( pUp )
                 {
