@@ -22,6 +22,7 @@
 #include <hintids.hxx>
 #include <svl/ctloptions.hxx>
 #include <sfx2/printer.hxx>
+#include <sal/log.hxx>
 #include <editeng/hyphenzoneitem.hxx>
 #include <editeng/escapementitem.hxx>
 #include <editeng/hngpnctitem.hxx>
@@ -86,8 +87,7 @@ using namespace ::com::sun::star::beans;
 #define DRAW_SPECIAL_OPTIONS_ROTATE 2
 
 SwLineInfo::SwLineInfo()
-    : pRuler( nullptr ),
-      pSpace( nullptr ),
+    : pSpace( nullptr ),
       nVertAlign( SvxParaVertAlignItem::Align::Automatic ),
       nDefTabStop( 0 ),
       bListTabStopIncluded( false ),
@@ -162,7 +162,7 @@ SwTextInfo::SwTextInfo( const SwTextInfo &rInf )
 
 #if OSL_DEBUG_LEVEL > 0
 
-void ChkOutDev( const SwTextSizeInfo &rInf )
+static void ChkOutDev( const SwTextSizeInfo &rInf )
 {
     if ( !rInf.GetVsh() )
         return;
@@ -173,7 +173,7 @@ void ChkOutDev( const SwTextSizeInfo &rInf )
 }
 #endif
 
-inline TextFrameIndex GetMinLen( const SwTextSizeInfo &rInf )
+static TextFrameIndex GetMinLen( const SwTextSizeInfo &rInf )
 {
     const TextFrameIndex nTextLen(rInf.GetText().getLength());
     if (rInf.GetLen() == TextFrameIndex(COMPLETE_STRING))
@@ -1702,11 +1702,29 @@ SwTwips SwTextFormatInfo::GetLineWidth()
     if (!pLastTab)
         return nLineWidth;
 
+    // Consider tab portions over the printing bounds of the text frame.
     if (pLastTab->GetTabPos() <= Width())
         return nLineWidth;
 
-    // Consider tab portions over the printing bounds of the text frame.
-    nLineWidth = pLastTab->GetTabPos() - X();
+    // Calculate the width that starts at the left (or in case of first line:
+    // first) margin, but ends after the right paragraph margin:
+    //
+    // +--------------------+
+    // |LL|              |RR|
+    // +--------------------+
+    // ^ m_nLeftMargin (absolute)
+    //    ^ nLeftMarginWidth (relative to m_nLeftMargin), X() is relative to this
+    //                   ^ right margin
+    //                      ^ paragraph right
+    // <--------------------> is GetTextFrame()->getFrameArea().Width()
+    //    <-------------->    is Width()
+    //    <-----------------> is what we need to be able to compare to X() (nTextFrameWidth)
+    SwTwips nLeftMarginWidth = m_nLeftMargin - GetTextFrame()->getFrameArea().Left();
+    SwTwips nTextFrameWidth = GetTextFrame()->getFrameArea().Width() - nLeftMarginWidth;
+
+    // If there is one such tab portion, then text is allowed to use the full
+    // text frame area to the right (RR above, but not LL).
+    nLineWidth = nTextFrameWidth - X();
 
     return nLineWidth;
 }
@@ -1843,7 +1861,7 @@ SwFontSave::SwFontSave(const SwTextSizeInfo &rInf, SwFont *pNew,
         // 1. the fonts have a different magic number
         // 2. they have different script types
         // 3. their background colors differ (this is not covered by 1.)
-        if( pFnt->DifferentMagic( pNew, pFnt->GetActual() ) ||
+        if( pFnt->DifferentFontCacheId( pNew, pFnt->GetActual() ) ||
             pNew->GetActual() != pFnt->GetActual() ||
             ( ! pNew->GetBackColor() && pFnt->GetBackColor() ) ||
             ( pNew->GetBackColor() && ! pFnt->GetBackColor() ) ||
