@@ -22,6 +22,7 @@
 #include <com/sun/star/i18n/ScriptType.hpp>
 #include <com/sun/star/i18n/XBreakIterator.hpp>
 #include <vcl/graph.hxx>
+#include <o3tl/make_unique.hxx>
 #include <editeng/brushitem.hxx>
 #include <vcl/metric.hxx>
 #include <vcl/outdev.hxx>
@@ -51,14 +52,14 @@ SwLinePortion *SwFieldPortion::Compress()
 
 SwFieldPortion *SwFieldPortion::Clone( const OUString &rExpand ) const
 {
-    SwFont *pNewFnt;
-    if( nullptr != ( pNewFnt = m_pFont ) )
+    std::unique_ptr<SwFont> pNewFnt;
+    if( m_pFont )
     {
-        pNewFnt = new SwFont( *m_pFont );
+        pNewFnt.reset(new SwFont( *m_pFont ));
     }
     // #i107143#
     // pass placeholder property to created <SwFieldPortion> instance.
-    SwFieldPortion* pClone = new SwFieldPortion( rExpand, pNewFnt, m_bPlaceHolder );
+    SwFieldPortion* pClone = new SwFieldPortion( rExpand, std::move(pNewFnt), m_bPlaceHolder );
     pClone->SetNextOffset( m_nNextOffset );
     pClone->m_bNoLength = m_bNoLength;
     return pClone;
@@ -72,8 +73,8 @@ void SwFieldPortion::TakeNextOffset( const SwFieldPortion* pField )
     m_bFollow = true;
 }
 
-SwFieldPortion::SwFieldPortion( const OUString &rExpand, SwFont *pFont, bool bPlaceHold )
-    : m_aExpand(rExpand), m_pFont(pFont), m_nNextOffset(0), m_nNextScriptChg(COMPLETE_STRING), m_nViewWidth(0)
+SwFieldPortion::SwFieldPortion( const OUString &rExpand, std::unique_ptr<SwFont> pFont, bool bPlaceHold )
+    : m_aExpand(rExpand), m_pFont(std::move(pFont)), m_nNextOffset(0), m_nNextScriptChg(COMPLETE_STRING), m_nViewWidth(0)
     , m_bFollow( false ), m_bLeft( false), m_bHide( false)
     , m_bCenter (false), m_bHasFollow( false )
     , m_bAnimated( false), m_bNoPaint( false)
@@ -103,16 +104,14 @@ SwFieldPortion::SwFieldPortion( const SwFieldPortion& rField )
     , m_nAttrFieldType( rField.m_nAttrFieldType)
 {
     if ( rField.HasFont() )
-        m_pFont = new SwFont( *rField.GetFont() );
-    else
-        m_pFont = nullptr;
+        m_pFont.reset( new SwFont( *rField.GetFont() ) );
 
     SetWhichPor( POR_FLD );
 }
 
 SwFieldPortion::~SwFieldPortion()
 {
-    delete m_pFont;
+    m_pFont.reset();
     if( pBlink )
         pBlink->Delete( this );
 }
@@ -172,7 +171,7 @@ SwFieldSlot::SwFieldSlot( const SwTextFormatInfo* pNew, const SwFieldPortion *pP
             pInf->SetFakeLineStart( nIdx > pInf->GetLineStart() );
             pInf->SetIdx(TextFrameIndex(0));
         }
-        else
+        else if (nIdx < TextFrameIndex(pOldText->getLength()))
         {
             aText = (*pOldText).replaceAt(sal_Int32(nIdx), 1, aText);
         }
@@ -283,7 +282,7 @@ void SwFieldPortion::CheckScript( const SwTextSizeInfo &rInf )
     else if ( nTmp != nActual )
     {
         if( !m_pFont )
-            m_pFont = new SwFont( *rInf.GetFont() );
+            m_pFont.reset( new SwFont( *rInf.GetFont() ) );
         m_pFont->SetActual( nTmp );
     }
 
@@ -318,9 +317,9 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
              rInf.SetUnderScorePos( rInf.GetIdx() );
 
         if( m_pFont )
-            m_pFont->GoMagic( rInf.GetVsh(), m_pFont->GetActual() );
+            m_pFont->AllocFontCacheId( rInf.GetVsh(), m_pFont->GetActual() );
 
-        SwFontSave aSave( rInf, m_pFont );
+        SwFontSave aSave( rInf, m_pFont.get() );
 
         // Length must be 0: the length is set for bFull after format
         // and passed along in nRest. Or else the old length would be
@@ -405,8 +404,7 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
             SwFieldPortion *pField = Clone( aNew );
             if( !aNew.isEmpty() && !pField->GetFont() )
             {
-                SwFont *pNewFnt = new SwFont( *rInf.GetFont() );
-                pField->SetFont( pNewFnt );
+                pField->SetFont( o3tl::make_unique<SwFont>( *rInf.GetFont() ) );
             }
             pField->SetFollow( true );
             SetHasFollow( true );
@@ -428,7 +426,7 @@ bool SwFieldPortion::Format( SwTextFormatInfo &rInf )
 
 void SwFieldPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
-    SwFontSave aSave( rInf, m_pFont );
+    SwFontSave aSave( rInf, m_pFont.get() );
 
     OSL_ENSURE(GetLen() <= TextFrameIndex(1), "SwFieldPortion::Paint: rest-portion pollution?");
     if( Width() && ( !m_bPlaceHolder || rInf.GetOpt().IsShowPlaceHolderFields() ) )
@@ -459,33 +457,29 @@ void SwFieldPortion::HandlePortion( SwPortionHandler& rPH ) const
         nH = m_pFont->GetSize(m_pFont->GetActual()).Height();
         nW = m_pFont->GetSize(m_pFont->GetActual()).Width();
     }
-    rPH.Special( GetLen(), m_aExpand, GetWhichPor(), nH, nW, m_pFont );
-    if( GetWhichPor() == POR_FLD )
-    {
-        rPH.SetAttrFieldType(m_nAttrFieldType);
-    }
+    rPH.Special( GetLen(), m_aExpand, GetWhichPor(), nH, nW, m_pFont.get() );
 }
 
 SwPosSize SwFieldPortion::GetTextSize( const SwTextSizeInfo &rInf ) const
 {
-    SwFontSave aSave( rInf, m_pFont );
+    SwFontSave aSave( rInf, m_pFont.get() );
     SwPosSize aSize( SwExpandPortion::GetTextSize( rInf ) );
     return aSize;
 }
 
 SwFieldPortion *SwHiddenPortion::Clone(const OUString &rExpand ) const
 {
-    SwFont *pNewFnt;
-    if( nullptr != ( pNewFnt = m_pFont ) )
-        pNewFnt = new SwFont( *m_pFont );
-    return new SwHiddenPortion( rExpand, pNewFnt );
+    std::unique_ptr<SwFont> pNewFnt;
+    if( m_pFont )
+        pNewFnt.reset(new SwFont( *m_pFont ));
+    return new SwHiddenPortion( rExpand, std::move(pNewFnt) );
 }
 
 void SwHiddenPortion::Paint( const SwTextPaintInfo &rInf ) const
 {
     if( Width() )
     {
-        SwFontSave aSave( rInf, m_pFont );
+        SwFontSave aSave( rInf, m_pFont.get() );
         rInf.DrawViewOpt( *this, POR_HIDDEN );
         SwExpandPortion::Paint( rInf );
     }
@@ -498,12 +492,12 @@ bool SwHiddenPortion::GetExpText( const SwTextSizeInfo &rInf, OUString &rText )
 }
 
 SwNumberPortion::SwNumberPortion( const OUString &rExpand,
-                                  SwFont *pFont,
+                                  std::unique_ptr<SwFont> pFont,
                                   const bool bLft,
                                   const bool bCntr,
                                   const sal_uInt16 nMinDst,
                                   const bool bLabelAlignmentPosAndSpaceModeActive )
-        : SwFieldPortion( rExpand, pFont ),
+        : SwFieldPortion( rExpand, std::move(pFont) ),
           nFixWidth(0),
           nMinDist( nMinDst ),
           mbLabelAlignmentPosAndSpaceModeActive( bLabelAlignmentPosAndSpaceModeActive )
@@ -521,11 +515,11 @@ TextFrameIndex SwNumberPortion::GetCursorOfst(const sal_uInt16) const
 
 SwFieldPortion *SwNumberPortion::Clone( const OUString &rExpand ) const
 {
-    SwFont *pNewFnt;
-    if( nullptr != ( pNewFnt = m_pFont ) )
-        pNewFnt = new SwFont( *m_pFont );
+    std::unique_ptr<SwFont> pNewFnt;
+    if( m_pFont )
+        pNewFnt.reset(new SwFont( *m_pFont ));
 
-    return new SwNumberPortion( rExpand, pNewFnt, IsLeft(), IsCenter(),
+    return new SwNumberPortion( rExpand, std::move(pNewFnt), IsLeft(), IsCenter(),
                                 nMinDist, mbLabelAlignmentPosAndSpaceModeActive );
 }
 
@@ -678,7 +672,7 @@ void SwNumberPortion::Paint( const SwTextPaintInfo &rInf ) const
                             STRIKEOUT_NONE != m_pFont->GetStrikeout() ) &&
                             !m_pFont->IsWordLineMode();
 
-        SwFontSave aSave( rInf, m_pFont );
+        SwFontSave aSave( rInf, m_pFont.get() );
 
         if( nFixWidth == Width() && ! HasFollow() )
             SwExpandPortion::Paint( rInf );
@@ -741,13 +735,13 @@ void SwNumberPortion::Paint( const SwTextPaintInfo &rInf ) const
 
 SwBulletPortion::SwBulletPortion( const sal_Unicode cBullet,
                                   const OUString& rBulletFollowedBy,
-                                  SwFont *pFont,
+                                  std::unique_ptr<SwFont> pFont,
                                   const bool bLft,
                                   const bool bCntr,
                                   const sal_uInt16 nMinDst,
                                   const bool bLabelAlignmentPosAndSpaceModeActive )
     : SwNumberPortion( OUStringLiteral1(cBullet) + rBulletFollowedBy,
-                       pFont, bLft, bCntr, nMinDst,
+                       std::move(pFont), bLft, bCntr, nMinDst,
                        bLabelAlignmentPosAndSpaceModeActive )
 {
     SetWhichPor( POR_BULLET );
@@ -802,7 +796,7 @@ SwGrfNumPortion::~SwGrfNumPortion()
         if (pGraph)
             pGraph->StopAnimation( nullptr, nId );
     }
-    delete pBrush;
+    pBrush.reset();
 }
 
 void SwGrfNumPortion::StopAnimation( OutputDevice* pOut )
@@ -995,7 +989,7 @@ void SwGrfNumPortion::Paint( const SwTextPaintInfo &rInf ) const
 
     if( bDraw && aTmp.HasArea() )
     {
-        DrawGraphic( pBrush, const_cast<OutputDevice*>(rInf.GetOut()),
+        DrawGraphic( pBrush.get(), const_cast<OutputDevice*>(rInf.GetOut()),
             aTmp, aRepaint, m_bReplace ? GRFNUM_REPLACE : GRFNUM_YES );
     }
 }
