@@ -82,7 +82,7 @@ bool SwTextFrame::Hyphenate(SwInterHyphInfoTextFrame & rHyphInf)
 
         SwTextFormatInfo aInf( getRootFrame()->GetCurrShell()->GetOut(), this, true ); // true for interactive hyph!
         SwTextFormatter aLine( this, &aInf );
-        aLine.CharToLine( rHyphInf.nStart );
+        aLine.CharToLine( rHyphInf.m_nStart );
 
         // If we're within the first word of a row, it could've been hyphenated
         // in the row earlier.
@@ -97,7 +97,7 @@ bool SwTextFrame::Hyphenate(SwInterHyphInfoTextFrame & rHyphInf)
                 aLine.Next();
         }
 
-        const TextFrameIndex nEnd = rHyphInf.nEnd;
+        const TextFrameIndex nEnd = rHyphInf.m_nEnd;
         while( !bRet && aLine.GetStart() < nEnd )
         {
             bRet = aLine.Hyphenate( rHyphInf );
@@ -168,9 +168,9 @@ bool SwTextFormatter::Hyphenate(SwInterHyphInfoTextFrame & rHyphInf)
         // HyphPortion in the specified range.
 
         SwLinePortion *pPos = m_pCurr->GetPortion();
-        const TextFrameIndex nPamStart = rHyphInf.nStart;
+        const TextFrameIndex nPamStart = rHyphInf.m_nStart;
         nWrdStart = m_nStart;
-        const TextFrameIndex nEnd = rHyphInf.nEnd;
+        const TextFrameIndex nEnd = rHyphInf.m_nEnd;
         while( pPos )
         {
             // Either we are above or we are running into a HyphPortion
@@ -216,7 +216,7 @@ bool SwTextFormatter::Hyphenate(SwInterHyphInfoTextFrame & rHyphInf)
         return false;
 
     // nWrdStart contains the position in string that should be hyphenated
-    rHyphInf.nWordStart = nWrdStart;
+    rHyphInf.m_nWordStart = nWrdStart;
 
     TextFrameIndex nLen(0);
     const TextFrameIndex nEnd = nWrdStart;
@@ -242,8 +242,8 @@ bool SwTextFormatter::Hyphenate(SwInterHyphInfoTextFrame & rHyphInf)
     if ( xHyphWord.is() )
     {
         rHyphInf.SetHyphWord( xHyphWord );
-        rHyphInf.nWordStart = nWrdStart;
-        rHyphInf.nWordLen = nLen;
+        rHyphInf.m_nWordStart = nWrdStart;
+        rHyphInf.m_nWordLen = nLen;
         return true;
     }
 
@@ -252,7 +252,7 @@ bool SwTextFormatter::Hyphenate(SwInterHyphInfoTextFrame & rHyphInf)
 
 bool SwTextPortion::CreateHyphen( SwTextFormatInfo &rInf, SwTextGuess const &rGuess )
 {
-    Reference< XHyphenatedWord >  xHyphWord = rGuess.HyphWord();
+    const Reference< XHyphenatedWord >&  xHyphWord = rGuess.HyphWord();
 
     OSL_ENSURE( !pPortion, "SwTextPortion::CreateHyphen(): another portion, another planet..." );
     OSL_ENSURE( xHyphWord.is(), "SwTextPortion::CreateHyphen(): You are lucky! The code is robust here." );
@@ -264,7 +264,7 @@ bool SwTextPortion::CreateHyphen( SwTextFormatInfo &rInf, SwTextGuess const &rGu
         ( rInf.IsInterHyph() && InFieldGrp() ) )
         return false;
 
-    SwHyphPortion *pHyphPor;
+    std::unique_ptr<SwHyphPortion> pHyphPor;
     TextFrameIndex nPorEnd;
     SwTextSizeInfo aInf( rInf );
 
@@ -282,11 +282,11 @@ bool SwTextPortion::CreateHyphen( SwTextFormatInfo &rInf, SwTextGuess const &rGu
         // soft hyphen at alternative spelling position?
         if( rInf.GetText()[sal_Int32(rInf.GetSoftHyphPos())] == CHAR_SOFTHYPHEN )
         {
-            pHyphPor = new SwSoftHyphStrPortion( aAltText );
+            pHyphPor.reset(new SwSoftHyphStrPortion( aAltText ));
             nTmpLen = 1;
         }
         else {
-            pHyphPor = new SwHyphStrPortion( aAltText );
+            pHyphPor.reset(new SwHyphStrPortion( aAltText ));
         }
 
         // length of pHyphPor is adjusted
@@ -297,16 +297,16 @@ bool SwTextPortion::CreateHyphen( SwTextFormatInfo &rInf, SwTextGuess const &rGu
     else
     {
         // second case: no alternative spelling
-        pHyphPor = new SwHyphPortion;
+        pHyphPor.reset(new SwHyphPortion);
         pHyphPor->SetLen(TextFrameIndex(1));
 
-        static const void* pLastMagicNo = nullptr;
+        static const void* nLastFontCacheId = nullptr;
         static sal_uInt16 aMiniCacheH = 0, aMiniCacheW = 0;
-        const void* pTmpMagic;
+        const void* nTmpFontCacheId;
         sal_uInt16 nFntIdx;
-        rInf.GetFont()->GetMagic( pTmpMagic, nFntIdx, rInf.GetFont()->GetActual() );
-        if( !pLastMagicNo || pLastMagicNo != pTmpMagic ) {
-            pLastMagicNo = pTmpMagic;
+        rInf.GetFont()->GetFontCacheId( nTmpFontCacheId, nFntIdx, rInf.GetFont()->GetActual() );
+        if( !nLastFontCacheId || nLastFontCacheId != nTmpFontCacheId ) {
+            nLastFontCacheId = nTmpFontCacheId;
             static_cast<SwPosSize&>(*pHyphPor) = pHyphPor->GetTextSize( rInf );
             aMiniCacheH = pHyphPor->Height();
             aMiniCacheW = pHyphPor->Width();
@@ -331,7 +331,7 @@ bool SwTextPortion::CreateHyphen( SwTextFormatInfo &rInf, SwTextGuess const &rGu
         SetLen( aInf.GetLen() );
         CalcTextSize( aInf );
 
-        Insert( pHyphPor );
+        Insert( pHyphPor.release() );
 
         short nKern = rInf.GetFont()->CheckKerning();
         if( nKern )
@@ -341,7 +341,7 @@ bool SwTextPortion::CreateHyphen( SwTextFormatInfo &rInf, SwTextGuess const &rGu
     }
 
     // last exit for the lost
-    delete pHyphPor;
+    pHyphPor.reset();
     BreakCut( rInf, rGuess );
     return false;
 }
