@@ -18,8 +18,8 @@
  */
 
 #include "txtpaint.hxx"
-#include "swrect.hxx"
-#include "rootfrm.hxx"
+#include <swrect.hxx>
+#include <rootfrm.hxx>
 
 SwSaveClip::~SwSaveClip()
 {
@@ -46,14 +46,14 @@ void SwSaveClip::ChgClip_( const SwRect &rRect, const SwTextFrame* pFrame,
     const bool bVertical = pFrame && pFrame->IsVertical();
 
     if ( pFrame && pFrame->IsRightToLeft() )
-        pFrame->SwitchLTRtoRTL( (SwRect&)rRect );
+        pFrame->SwitchLTRtoRTL( const_cast<SwRect&>(rRect) );
 
     if ( bVertical )
-        pFrame->SwitchHorizontalToVertical( (SwRect&)rRect );
+        pFrame->SwitchHorizontalToVertical( const_cast<SwRect&>(rRect) );
 
     if ( !pOut || (!rRect.HasArea() && !pOut->IsClipRegion()) )
     {
-        (SwRect&)rRect = aOldRect;
+        const_cast<SwRect&>(rRect) = aOldRect;
         return;
     }
 
@@ -75,14 +75,14 @@ void SwSaveClip::ChgClip_( const SwRect &rRect, const SwTextFrame* pFrame,
         // (see frmform.cxx) because for some fonts it could be too small.
         // Consequently, we have to enlarge the clipping rectangle as well.
         if ( bEnlargeRect && ! bVertical )
-            aRect.Bottom() += 40;
+            aRect.AdjustBottom(40 );
 
         // If the ClipRect is identical, nothing will happen
         if( pOut->IsClipRegion() ) // no && because of Mac
         {
             if ( aRect == pOut->GetClipRegion().GetBoundRect() )
             {
-                (SwRect&)rRect = aOldRect;
+                const_cast<SwRect&>(rRect) = aOldRect;
                 return;
             }
         }
@@ -105,7 +105,7 @@ void SwSaveClip::ChgClip_( const SwRect &rRect, const SwTextFrame* pFrame,
     }
     bChg = true;
 
-    (SwRect&)rRect = aOldRect;
+    const_cast<SwRect&>(rRect) = aOldRect;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
