@@ -27,7 +27,6 @@
 #include <com/sun/star/xml/dom/XNodeList.hpp>
 #include <comphelper/processfactory.hxx>
 #include <comphelper/propertysequence.hxx>
-#include <comphelper/sequenceashashmap.hxx>
 #include <doc.hxx>
 #include <docsh.hxx>
 #include <IDocumentStylePoolAccess.hxx>
@@ -40,6 +39,7 @@
 #include <unotools/streamwrap.hxx>
 #include <unotextrange.hxx>
 #include <sfx2/docfile.hxx>
+#include <sal/log.hxx>
 #define AUTOTEXT_GALLERY "autoTxt"
 
 using namespace css;
@@ -100,9 +100,9 @@ ErrCode SwDOCXReader::Read(SwDoc& rDoc, const OUString& /* rBaseURL */, SwPaM& r
     return ret;
 }
 
-int SwDOCXReader::GetReaderType()
+SwReaderType SwDOCXReader::GetReaderType()
 {
-    return SW_STORAGE_READER | SW_STREAM_READER;
+    return SwReaderType::Storage | SwReaderType::Stream;
 }
 
 bool SwDOCXReader::HasGlossaries() const
@@ -218,13 +218,11 @@ bool SwDOCXReader::MakeEntries( SwDoc *pD, SwTextBlocks &rBlocks )
                 // Need to check make sure the shortcut is not already being used
                 sal_Int32 nStart = 0;
                 sal_uInt16 nCurPos = rBlocks.GetIndex( sShortcut );
-                sal_Int32 nLen = sShortcut.getLength();
 
                 while( sal_uInt16(-1) != nCurPos )
                 {
-                    sShortcut = sShortcut.copy( 0, nLen );
                     // add an Number to it
-                    sShortcut += OUString::number( ++nStart );
+                    sShortcut = aLNm + OUString::number( ++nStart );
                     nCurPos = rBlocks.GetIndex( sShortcut );
                 }
 
