@@ -144,6 +144,7 @@ const sal_Char* sCSS1_PV_justify = "justify";
 const sal_Char* sCSS1_P_text_indent = "text-indent";
 
 const sal_Char* sCSS1_P_line_height = "line-height";
+const sal_Char* sCSS1_P_list_style_type = "list-style-type";
 
 // Strings for box properties
 
@@ -189,6 +190,7 @@ const sal_Char* sCSS1_PV_inset = "inset";
 const sal_Char* sCSS1_PV_outset = "outset";
 
 const sal_Char* sCSS1_P_width = "width";
+const sal_Char* sCSS1_P_max_width = "max-width";
 
 const sal_Char* sCSS1_P_height = "height";
 
