@@ -87,14 +87,14 @@ using namespace ::com::sun::star::form;
 const sal_uInt16 TABINDEX_MIN = 0;
 const sal_uInt16 TABINDEX_MAX = 32767;
 
-static HTMLOptionEnum<FormSubmitMethod> aHTMLFormMethodTable[] =
+static HTMLOptionEnum<FormSubmitMethod> const aHTMLFormMethodTable[] =
 {
     { OOO_STRING_SVTOOLS_HTML_METHOD_get,   FormSubmitMethod_GET    },
     { OOO_STRING_SVTOOLS_HTML_METHOD_post,  FormSubmitMethod_POST   },
     { nullptr,                              FormSubmitMethod(0)     }
 };
 
-static HTMLOptionEnum<FormSubmitEncoding> aHTMLFormEncTypeTable[] =
+static HTMLOptionEnum<FormSubmitEncoding> const aHTMLFormEncTypeTable[] =
 {
     { OOO_STRING_SVTOOLS_HTML_ET_url,       FormSubmitEncoding_URL          },
     { OOO_STRING_SVTOOLS_HTML_ET_multipart, FormSubmitEncoding_MULTIPART    },
@@ -104,7 +104,7 @@ static HTMLOptionEnum<FormSubmitEncoding> aHTMLFormEncTypeTable[] =
 
 enum HTMLWordWrapMode { HTML_WM_OFF, HTML_WM_HARD, HTML_WM_SOFT };
 
-static HTMLOptionEnum<HTMLWordWrapMode> aHTMLTextAreaWrapTable[] =
+static HTMLOptionEnum<HTMLWordWrapMode> const aHTMLTextAreaWrapTable[] =
 {
     { OOO_STRING_SVTOOLS_HTML_WW_off,      HTML_WM_OFF     },
     { OOO_STRING_SVTOOLS_HTML_WW_hard,     HTML_WM_HARD    },
@@ -177,9 +177,9 @@ const sal_Char * aEventOptionTable[] =
 
 class SwHTMLForm_Impl
 {
-    SwDocShell                  *m_pDocShell;
+    SwDocShell                  * const m_pDocShell;
 
-    SvKeyValueIterator          *m_pHeaderAttrs;
+    SvKeyValueIterator          * const m_pHeaderAttrs;
 
     // Cached interfaces
     uno::Reference< drawing::XDrawPage >            m_xDrawPage;
@@ -366,8 +366,8 @@ class SwHTMLImageWatcher :
     uno::Reference< drawing::XShape >       xShape;     // the control
     uno::Reference< XImageProducerSupplier >    xSrc;
     uno::Reference< awt::XImageConsumer >   xThis;      // reference to self
-    bool                            bSetWidth;
-    bool                            bSetHeight;
+    bool const                            bSetWidth;
+    bool const                            bSetHeight;
 
     void clear();
 
@@ -1379,7 +1379,7 @@ void SwHTMLParser::EndForm( bool bAppend )
 
 void SwHTMLParser::InsertInput()
 {
-    assert(m_pPendStack == nullptr);
+    assert(m_vPendingStack.empty());
 
     if( !m_pFormImpl || !m_pFormImpl->GetFormComps().is() )
         return;
@@ -1851,7 +1851,7 @@ void SwHTMLParser::InsertInput()
 
 void SwHTMLParser::NewTextArea()
 {
-    assert(m_pPendStack == nullptr);
+    assert(m_vPendingStack.empty());
 
     OSL_ENSURE( !m_bTextArea, "TextArea in TextArea?" );
     OSL_ENSURE( !m_pFormImpl || !m_pFormImpl->GetFCompPropSet().is(),
@@ -2133,7 +2133,7 @@ void SwHTMLParser::InsertTextAreaText( HtmlTokenId nToken )
 
 void SwHTMLParser::NewSelect()
 {
-    assert(m_pPendStack == nullptr);
+    assert(m_vPendingStack.empty());
 
     OSL_ENSURE( !m_bSelect, "Select in Select?" );
     OSL_ENSURE( !m_pFormImpl || !m_pFormImpl->GetFCompPropSet().is(),
@@ -2347,7 +2347,7 @@ void SwHTMLParser::NewSelect()
 
 void SwHTMLParser::EndSelect()
 {
-    assert(m_pPendStack == nullptr);
+    assert(m_vPendingStack.empty());
 
     OSL_ENSURE( m_bSelect, "no Select" );
     OSL_ENSURE( m_pFormImpl && m_pFormImpl->GetFCompPropSet().is(),
