@@ -31,7 +31,6 @@
 #include <ndtxt.hxx>
 #include <txatbase.hxx>
 #include <fmtfsize.hxx>
-#include <drawdoc.hxx>
 #include <frmatr.hxx>
 #include "docxattributeoutput.hxx"
 #include "docxexportfilter.hxx"
@@ -40,6 +39,7 @@
 #include <comphelper/sequence.hxx>
 #include <comphelper/sequenceashashmap.hxx>
 #include <o3tl/make_unique.hxx>
+#include <sal/log.hxx>
 
 #include <IDocumentDrawModelAccess.hxx>
 
@@ -118,6 +118,13 @@ void lclMovePositionWithRotation(awt::Point& aPos, const Size& rSize, sal_Int64
     aPos.X += nXDiff;
     aPos.Y += nYDiff;
 }
+
+/// Determines if the anchor is inside a paragraph.
+bool IsAnchorTypeInsideParagraph(const ww8::Frame* pFrame)
+{
+    const SwFormatAnchor& rAnchor = pFrame->GetFrameFormat().GetAttrSet().GetAnchor();
+    return rAnchor.GetAnchorId() != RndStdIds::FLY_AT_PAGE;
+}
 }
 
 ExportDataSaveRestore::ExportDataSaveRestore(DocxExport& rExport, sal_uLong nStt, sal_uLong nEnd,
@@ -186,7 +193,7 @@ struct DocxSdrExport::Impl
     bool checkFrameBtlr(SwNode* pStartNode, bool bDML);
 };
 
-DocxSdrExport::DocxSdrExport(DocxExport& rExport, sax_fastparser::FSHelperPtr pSerializer,
+DocxSdrExport::DocxSdrExport(DocxExport& rExport, const sax_fastparser::FSHelperPtr& pSerializer,
                              oox::drawingml::DrawingML* pDrawingML)
     : m_pImpl(o3tl::make_unique<Impl>(*this, rExport, pSerializer, pDrawingML))
 {
@@ -654,7 +661,7 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
         auto it = aGrabBag.find("EG_WrapType");
         if (it != aGrabBag.end())
         {
-            OUString sType = it->second.get<OUString>();
+            auto sType = it->second.get<OUString>();
             if (sType == "wrapTight")
                 nWrapToken = XML_wrapTight;
             else if (sType == "wrapThrough")
@@ -671,10 +678,8 @@ void DocxSdrExport::startDMLAnchorInline(const SwFrameFormat* pFrameFormat, cons
             {
                 m_pImpl->m_pSerializer->startElementNS(XML_wp, XML_wrapPolygon, XML_edited, "0",
                                                        FSEND);
-                drawing::PointSequenceSequence aSeqSeq
-                    = it->second.get<drawing::PointSequenceSequence>();
-                std::vector<awt::Point> aPoints(
-                    comphelper::sequenceToContainer<std::vector<awt::Point>>(aSeqSeq[0]));
+                auto aSeqSeq = it->second.get<drawing::PointSequenceSequence>();
+                auto aPoints(comphelper::sequenceToContainer<std::vector<awt::Point>>(aSeqSeq[0]));
                 for (auto i = aPoints.begin(); i != aPoints.end(); ++i)
                 {
                     awt::Point& rPoint = *i;
@@ -770,7 +775,7 @@ void DocxSdrExport::writeVMLDrawing(const SdrObject* sdrObj, const SwFrameFormat
     m_pImpl->m_pSerializer->endElementNS(XML_w, XML_pict);
 }
 
-bool lcl_isLockedCanvas(const uno::Reference<drawing::XShape>& xShape)
+static bool lcl_isLockedCanvas(const uno::Reference<drawing::XShape>& xShape)
 {
     bool bRet = false;
     uno::Sequence<beans::PropertyValue> propList = lclGetProperty(xShape, "InteropGrabBag");
@@ -979,7 +984,7 @@ void DocxSdrExport::writeDMLAndVMLDrawing(const SdrObject* sdrObj,
 }
 
 // Converts ARGB transparency (0..255) to drawingml alpha (opposite, and 0..100000)
-OString lcl_ConvertTransparency(const Color& rColor)
+static OString lcl_ConvertTransparency(const Color& rColor)
 {
     if (rColor.GetTransparency() > 0)
     {
@@ -1396,7 +1401,7 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
                                       bool bTextBoxOnly)
 {
     bool bDMLAndVMLDrawingOpen = m_pImpl->m_bDMLAndVMLDrawingOpen;
-    m_pImpl->m_bDMLAndVMLDrawingOpen = true;
+    m_pImpl->m_bDMLAndVMLDrawingOpen = IsAnchorTypeInsideParagraph(pParentFrame);
 
     sax_fastparser::FSHelperPtr pFS = m_pImpl->m_pSerializer;
     const SwFrameFormat& rFrameFormat = pParentFrame->GetFrameFormat();
@@ -1517,28 +1522,25 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
     }
 
     //first, loop through ALL of the chained textboxes to identify a unique ID for each chain, and sequence number for each textbox in that chain.
-    std::map<OUString, MSWordExportBase::LinkedTextboxInfo>::iterator linkedTextboxesIter;
     if (!m_pImpl->m_rExport.m_bLinkedTextboxesHelperInitialized)
     {
         sal_Int32 nSeq = 0;
-        linkedTextboxesIter = m_pImpl->m_rExport.m_aLinkedTextboxesHelper.begin();
-        while (linkedTextboxesIter != m_pImpl->m_rExport.m_aLinkedTextboxesHelper.end())
+        for (auto& rEntry : m_pImpl->m_rExport.m_aLinkedTextboxesHelper)
         {
             //find the start of a textbox chain: has no PREVIOUS link, but does have NEXT link
-            if (linkedTextboxesIter->second.sPrevChain.isEmpty()
-                && !linkedTextboxesIter->second.sNextChain.isEmpty())
+            if (rEntry.second.sPrevChain.isEmpty() && !rEntry.second.sNextChain.isEmpty())
             {
                 //assign this chain a unique ID and start a new sequence
                 nSeq = 0;
-                linkedTextboxesIter->second.nId = ++m_pImpl->m_rExport.m_nLinkedTextboxesChainId;
-                linkedTextboxesIter->second.nSeq = nSeq;
+                rEntry.second.nId = ++m_pImpl->m_rExport.m_nLinkedTextboxesChainId;
+                rEntry.second.nSeq = nSeq;
 
-                OUString sCheckForBrokenChains = linkedTextboxesIter->first;
+                OUString sCheckForBrokenChains = rEntry.first;
 
                 //follow the chain and assign the same id, and incremental sequence numbers.
                 std::map<OUString, MSWordExportBase::LinkedTextboxInfo>::iterator followChainIter;
-                followChainIter = m_pImpl->m_rExport.m_aLinkedTextboxesHelper.find(
-                    linkedTextboxesIter->second.sNextChain);
+                followChainIter
+                    = m_pImpl->m_rExport.m_aLinkedTextboxesHelper.find(rEntry.second.sNextChain);
                 while (followChainIter != m_pImpl->m_rExport.m_aLinkedTextboxesHelper.end())
                 {
                     //verify that the NEXT textbox also points to me as the PREVIOUS.
@@ -1558,7 +1560,6 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
                         followChainIter->second.sNextChain);
                 }
             }
-            ++linkedTextboxesIter;
         }
         m_pImpl->m_rExport.m_bLinkedTextboxesHelperInitialized = true;
     }
@@ -1577,7 +1578,8 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
     }
 
     // second, check if THIS textbox is linked and then decide whether to write the tag txbx or linkedTxbx
-    linkedTextboxesIter = m_pImpl->m_rExport.m_aLinkedTextboxesHelper.find(sLinkChainName);
+    std::map<OUString, MSWordExportBase::LinkedTextboxInfo>::iterator linkedTextboxesIter
+        = m_pImpl->m_rExport.m_aLinkedTextboxesHelper.find(sLinkChainName);
     if (linkedTextboxesIter != m_pImpl->m_rExport.m_aLinkedTextboxesHelper.end())
     {
         if ((linkedTextboxesIter->second.nId != 0) && (linkedTextboxesIter->second.nSeq != 0))
@@ -1691,7 +1693,7 @@ void DocxSdrExport::writeDMLTextFrame(ww8::Frame const* pParentFrame, int nAncho
 void DocxSdrExport::writeVMLTextFrame(ww8::Frame const* pParentFrame, bool bTextBoxOnly)
 {
     bool bDMLAndVMLDrawingOpen = m_pImpl->m_bDMLAndVMLDrawingOpen;
-    m_pImpl->m_bDMLAndVMLDrawingOpen = true;
+    m_pImpl->m_bDMLAndVMLDrawingOpen = IsAnchorTypeInsideParagraph(pParentFrame);
 
     sax_fastparser::FSHelperPtr pFS = m_pImpl->m_pSerializer;
     const SwFrameFormat& rFrameFormat = pParentFrame->GetFrameFormat();
