@@ -19,11 +19,13 @@
 
 #include "xmlexpit.hxx"
 
+#include <osl/diagnose.h>
 #include <rtl/ustrbuf.hxx>
 #include <sax/tools/converter.hxx>
 #include <svl/itempool.hxx>
 #include <svl/poolitem.hxx>
 #include <svl/itemset.hxx>
+#include <utility>
 #include <xmloff/xmluconv.hxx>
 #include <xmloff/attrlist.hxx>
 #include <xmloff/nmspmap.hxx>
@@ -33,9 +35,9 @@
 #include <editeng/xmlcnitm.hxx>
 #include <xmloff/xmlexp.hxx>
 #include <xmloff/xmlprhdl.hxx>
-#include <editeng/memberids.hrc>
-#include "hintids.hxx"
-#include "unomid.h"
+#include <editeng/memberids.h>
+#include <hintids.hxx>
+#include <unomid.h>
 #include <svx/unomid.hxx>
 #include <editeng/lrspitem.hxx>
 #include <editeng/ulspitem.hxx>
@@ -44,14 +46,15 @@
 #include <editeng/formatbreakitem.hxx>
 #include <editeng/keepitem.hxx>
 #include <editeng/brushitem.hxx>
-#include "fmtpdsc.hxx"
-#include "fmtornt.hxx"
-#include "fmtfsize.hxx"
+#include <fmtpdsc.hxx>
+#include <fmtornt.hxx>
+#include <fmtfsize.hxx>
 
-#include "fmtlsplt.hxx"
+#include <fmtlsplt.hxx>
 #include "xmlithlp.hxx"
 
-#include "fmtrowsplt.hxx"
+#include <fmtrowsplt.hxx>
+#include <osl/diagnose.h>
 
 using ::editeng::SvxBorderLine;
 using namespace ::com::sun::star;
@@ -278,7 +281,7 @@ const SfxPoolItem* SvXMLExportItemMapper::GetItem( const SfxItemSet& rSet,
 
 SvXMLExportItemMapper::SvXMLExportItemMapper( SvXMLItemMapEntriesRef rMapEntries )
 {
-    mrMapEntries = rMapEntries;
+    mrMapEntries = std::move(rMapEntries);
 }
 
 SvXMLExportItemMapper::~SvXMLExportItemMapper()
@@ -296,11 +299,9 @@ void SvXMLExportItemMapper::exportXML( SvXMLExport& rExport,
     exportXML( rExport, rExport.GetAttrList(), rSet, rUnitConverter,
                rExport.GetNamespaceMap(), nFlags, &aIndexArray );
 
-    if( rExport.GetAttrList().getLength() > 0L ||
-        (nFlags & SvXmlExportFlags::EMPTY) ||
-        !aIndexArray.empty() )
+    if( rExport.GetAttrList().getLength() > 0 || !aIndexArray.empty() )
     {
-        if( (nFlags & SvXmlExportFlags::IGN_WS) )
+        if( nFlags & SvXmlExportFlags::IGN_WS )
         {
             rExport.IgnorableWhitespace();
         }
@@ -508,7 +509,7 @@ bool SvXMLExportItemMapper::QueryXMLValue(
                 nX *= pShadow->GetWidth();
                 nY *= pShadow->GetWidth();
 
-                ::sax::Converter::convertColor(aOut, pShadow->GetColor().GetColor());
+                ::sax::Converter::convertColor(aOut, pShadow->GetColor());
                 aOut.append( ' ' );
                 rUnitConverter.convertMeasureToXML( aOut, nX );
                 aOut.append( ' ' );
@@ -775,7 +776,7 @@ bool SvXMLExportItemMapper::QueryXMLValue(
                                 aOut.append( GetXMLToken( eStyle ) );
                                 aOut.append( ' ' );
                                 ::sax::Converter::convertColor(aOut,
-                                        pLine->GetColor().GetColor());
+                                        pLine->GetColor());
                             }
                         }
                         else
@@ -898,23 +899,11 @@ bool SvXMLExportItemMapper::QueryXMLValue(
                     else
                     {
                         ::sax::Converter::convertColor(aOut,
-                                rBrush.GetColor().GetColor());
+                                rBrush.GetColor());
                     }
                     bOk = true;
                     break;
 
-                case MID_GRAPHIC_LINK:
-                    if (rBrush.GetGraphicPos() != GPOS_NONE)
-                    {
-                        uno::Any aAny;
-                        rBrush.QueryValue( aAny, MID_GRAPHIC_URL );
-                        OUString sTmp;
-                        aAny >>= sTmp;
-                        aOut.append( sTmp );
-                        bOk = true;
-                    }
-                    break;
-
                 case MID_GRAPHIC_POSITION:
                     switch (rBrush.GetGraphicPos())
                     {
