@@ -18,6 +18,7 @@
  */
 #include "vbadocumentproperties.hxx"
 #include <cppuhelper/implbase.hxx>
+#include <sal/log.hxx>
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 #include <com/sun/star/beans/NamedValue.hpp>
@@ -704,9 +705,11 @@ protected:
     {
         uno::Sequence< OUString > aNames( getCount() );
         OUString* pName = aNames.getArray();
-        DocPropsByName::iterator it_end = mNamedDocProps.end();
-        for(  DocPropsByName::iterator it = mNamedDocProps.begin(); it != it_end; ++it, ++pName )
-           *pName = it->first;
+        for (const auto& rEntry : mNamedDocProps)
+        {
+           *pName = rEntry.first;
+           ++pName;
+        }
         return aNames;
     }
 
