@@ -31,12 +31,10 @@
 #include <wrtsh.hxx>
 #include <view.hxx>
 #include <edtwin.hxx>
-#include <helpids.h>
 #include <globals.hrc>
 #include <drawbase.hxx>
 #include <beziersh.hxx>
-#include <strings.hrc>
-#define SwBezierShell
+#define ShellClass_SwBezierShell
 #include <sfx2/msg.hxx>
 #include <swslots.hxx>
 
