@@ -52,31 +52,47 @@ void SwDrawShell::ExecDrawDlg(SfxRequest& rReq)
         case FN_DRAWTEXT_ATTR_DLG:
         {
             SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-            if ( pFact )
-            {
-                ScopedVclPtr<SfxAbstractTabDialog> pDlg(pFact->CreateTextTabDialog(rReq.GetFrameWeld(), &aNewAttr, pView));
-                sal_uInt16 nResult = pDlg->Execute();
+            ScopedVclPtr<SfxAbstractTabDialog> pDlg(pFact->CreateTextTabDialog(rReq.GetFrameWeld(), &aNewAttr, pView));
+            sal_uInt16 nResult = pDlg->Execute();
 
-                if (nResult == RET_OK)
+            if (nResult == RET_OK)
+            {
+                if (pView->AreObjectsMarked())
                 {
-                    if (pView->AreObjectsMarked())
-                    {
-                        pSh->StartAction();
-                        pView->SetAttributes(*pDlg->GetOutputItemSet());
-                        rReq.Done(*(pDlg->GetOutputItemSet()));
-                        pSh->EndAction();
-                    }
+                    pSh->StartAction();
+                    pView->SetAttributes(*pDlg->GetOutputItemSet());
+                    rReq.Done(*(pDlg->GetOutputItemSet()));
+                    pSh->EndAction();
                 }
             }
         }
         break;
 
+        case SID_MEASURE_DLG:
+        {
+            bool bHasMarked = pView->AreObjectsMarked();
+
+            SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
+            ScopedVclPtr<SfxAbstractDialog> pDlg(pFact->CreateSfxDialog(rReq.GetFrameWindow(),
+                                                 aNewAttr, pView, RID_SVXPAGE_MEASURE));
+            if (pDlg->Execute() == RET_OK)
+            {
+                pSh->StartAction();
+                if (bHasMarked)
+                    pView->SetAttrToMarked(*pDlg->GetOutputItemSet(), false);
+                else
+                    pView->SetDefaultAttr(*pDlg->GetOutputItemSet(), false);
+                pSh->EndAction();
+            }
+        }
+        break;
+
         case SID_ATTRIBUTES_AREA:
         {
             bool bHasMarked = pView->AreObjectsMarked();
 
             SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-            ScopedVclPtr<AbstractSvxAreaTabDialog> pDlg(pFact->CreateSvxAreaTabDialog( nullptr,
+            ScopedVclPtr<AbstractSvxAreaTabDialog> pDlg(pFact->CreateSvxAreaTabDialog(rReq.GetFrameWeld(),
                                                                             &aNewAttr,
                                                                             pDoc,
                                                                             true));
@@ -117,13 +133,11 @@ void SwDrawShell::ExecDrawDlg(SfxRequest& rReq)
                 pObj = rMarkList.GetMark(0)->GetMarkedSdrObj();
 
             SvxAbstractDialogFactory* pFact = SvxAbstractDialogFactory::Create();
-            OSL_ENSURE(pFact, "Dialog creation failed!");
-            ScopedVclPtr<SfxAbstractTabDialog> pDlg(pFact->CreateSvxLineTabDialog( nullptr,
+            ScopedVclPtr<SfxAbstractTabDialog> pDlg(pFact->CreateSvxLineTabDialog(rReq.GetFrameWeld(),
                     &aNewAttr,
                 pDoc,
                 pObj,
                 bHasMarked));
-            OSL_ENSURE(pDlg, "Dialog creation failed!");
             if (pDlg->Execute() == RET_OK)
             {
                 pSh->StartAction();
