@@ -7,8 +7,8 @@
  * file, You can obtain one at http://mozilla.org/MPL/2.0/.
  */
 
-#include "navmgr.hxx"
-#include "wrtsh.hxx"
+#include <navmgr.hxx>
+#include <wrtsh.hxx>
 #include <sfx2/bindings.hxx>
 #include <sfx2/viewfrm.hxx>
 #include <cmdid.h>
@@ -51,7 +51,7 @@ SwNavigationMgr::~SwNavigationMgr()
     SolarMutexGuard g;
     for (auto & it : m_entries)
     {
-        EndListening(it.get()->m_aNotifier);
+        EndListening(it->m_aNotifier);
     }
     m_entries.clear();
 }
@@ -62,14 +62,12 @@ void SwNavigationMgr::Notify(SfxBroadcaster& rBC, const SfxHint& rHint)
     // m_entries if that happens
     if (typeid(rHint) == typeid(sw::UnoCursorHint))
     {
-        for (auto it = m_entries.begin(); it != m_entries.end(); ++it)
+        auto it = std::find_if(m_entries.begin(), m_entries.end(),
+            [&rBC](const sw::UnoCursorPointer& rItem) { return !rItem || &rBC == &rItem.get()->m_aNotifier; });
+        if (it != m_entries.end())
         {
-            if (!it->get() || & rBC == & it->get()->m_aNotifier)
-            {
-                EndListening(rBC);
-                m_entries.erase(it);
-                break;
-            }
+            EndListening(rBC);
+            m_entries.erase(it);
         }
     }
 }
