@@ -26,7 +26,6 @@
 #include <com/sun/star/accessibility/AccessibleStateType.hpp>
 #include <com/sun/star/accessibility/AccessibleRole.hpp>
 #include <toolkit/helper/vclunohelper.hxx>
-#include <toolkit/helper/externallock.hxx>
 #include <vcl/window.hxx>
 
 
@@ -46,7 +45,6 @@ namespace toolkit
 
 
     OAccessibleControlContext::OAccessibleControlContext()
-        : OAccessibleControlContext_Base(new VCLExternalSolarLock)
     {
         // nothing to do here, we have a late ctor
     }
@@ -135,11 +133,7 @@ namespace toolkit
 
     Reference< XAccessible > SAL_CALL OAccessibleControlContext::getAccessibleParent(  )
     {
-        OContextEntryGuard aGuard( this );
-        OSL_ENSURE( implGetForeignControlledParent().is(), "OAccessibleControlContext::getAccessibleParent: somebody forgot to set a parent!" );
-            // this parent of us is foreign controlled - somebody has to set it using the OAccessibleImplementationAccess
-            // class, before integrating our instance into an AccessibleDocumentModel
-        return implGetForeignControlledParent();
+        return Reference< XAccessible >();
     }
 
 
@@ -178,7 +172,7 @@ namespace toolkit
         if ( isAlive() )
         {
             // no own states, only the ones which are foreign controlled
-            pStateSet = new ::utl::AccessibleStateSetHelper( implGetForeignControlledStates() );
+            pStateSet = new ::utl::AccessibleStateSetHelper( 0 );
         }
         else
         {   // only the DEFUNC state if we're already disposed
@@ -277,21 +271,12 @@ namespace toolkit
             if ( pVCLParent )
                 aVCLParentScreenPos = pVCLParent->GetPosPixel();
 
-            // the screen position of the "accessible parent" of the control
-            Reference< XAccessible > xParentAcc( implGetForeignControlledParent() );
-            Reference< XAccessibleComponent > xParentAccComponent;
-            if ( xParentAcc.is() )
-                xParentAccComponent.set(xParentAcc->getAccessibleContext(), css::uno::UNO_QUERY);
-            awt::Point aAccParentScreenPos( 0, 0 );
-            if ( xParentAccComponent.is() )
-                aAccParentScreenPos = xParentAccComponent->getLocationOnScreen();
-
             // now the size of the control
             aBounds = xWindow->getPosSize();
 
             // correct the pos
-            aBounds.X = aWindowRelativePos.X() + aVCLParentScreenPos.X() - aAccParentScreenPos.X;
-            aBounds.Y = aWindowRelativePos.Y() + aVCLParentScreenPos.Y() - aAccParentScreenPos.Y;
+            aBounds.X = aWindowRelativePos.X() + aVCLParentScreenPos.X();
+            aBounds.Y = aWindowRelativePos.Y() + aVCLParentScreenPos.Y();
         }
 
         return aBounds;
@@ -318,11 +303,11 @@ namespace toolkit
         OContextEntryGuard aGuard( this );
 
         VclPtr< vcl::Window > pWindow = implGetWindow();
-        sal_Int32 nColor = 0;
+        Color nColor;
         if ( pWindow )
         {
             if ( pWindow->IsControlForeground() )
-                nColor = pWindow->GetControlForeground().GetColor();
+                nColor = pWindow->GetControlForeground();
             else
             {
                 vcl::Font aFont;
@@ -330,10 +315,10 @@ namespace toolkit
                     aFont = pWindow->GetControlFont();
                 else
                     aFont = pWindow->GetFont();
-                nColor = aFont.GetColor().GetColor();
+                nColor = aFont.GetColor();
             }
         }
-        return nColor;
+        return sal_Int32(nColor);
     }
 
 
@@ -344,16 +329,16 @@ namespace toolkit
         OContextEntryGuard aGuard( this );
 
         VclPtr< vcl::Window > pWindow = implGetWindow();
-        sal_Int32 nColor = 0;
+        Color nColor;
         if ( pWindow )
         {
             if ( pWindow->IsControlBackground() )
-                nColor = pWindow->GetControlBackground().GetColor();
+                nColor = pWindow->GetControlBackground();
             else
-                nColor = pWindow->GetBackground().GetColor().GetColor();
+                nColor = pWindow->GetBackground().GetColor();
         }
 
-        return nColor;
+        return sal_Int32(nColor);
     }
 
 
