@@ -41,7 +41,11 @@
 
 #include <tools/diagnose_ex.h>
 
-#ifdef DBG_UTIL
+#if defined __GLIBCXX__
+#include <cxxabi.h>
+#endif
+
+#ifndef NDEBUG
 
 struct DebugData
 {
@@ -97,6 +101,11 @@ void DbgUnhandledException(const css::uno::Any & caught, const char* currentFunc
         if ( exception.Context.is() )
         {
             const char* pContext = typeid( *exception.Context.get() ).name();
+#if defined __GLIBCXX__
+            // demangle the type name, not necessary under windows, we already get demangled names there
+            int status;
+            pContext = abi::__cxa_demangle( pContext, nullptr, nullptr, &status);
+#endif
             sMessage += "\n    context: ";
             sMessage += pContext;
         }
