@@ -48,7 +48,7 @@ struct ResultListEntry
     uno::Reference< ucb::XContentIdentifier > xId;
     uno::Reference< ucb::XContent >           xContent;
     uno::Reference< sdbc::XRow >              xRow;
-    HierarchyEntryData                        aData;
+    HierarchyEntryData const                  aData;
 
     explicit ResultListEntry( const HierarchyEntryData& rEntry ) : aData( rEntry ) {}
 };
@@ -57,7 +57,7 @@ struct ResultListEntry
 // ResultList.
 
 
-typedef std::vector< ResultListEntry* > ResultList;
+typedef std::vector< std::unique_ptr<ResultListEntry> > ResultList;
 
 
 // struct DataSupplier_Impl.
@@ -70,8 +70,8 @@ struct DataSupplier_Impl
     rtl::Reference< HierarchyContent >              m_xContent;
     uno::Reference< uno::XComponentContext >        m_xContext;
     HierarchyEntry                                  m_aFolder;
-    HierarchyEntry::iterator                        m_aIterator;
-    sal_Int32                                       m_nOpenMode;
+    HierarchyEntry::iterator const                  m_aIterator;
+    sal_Int32 const                                 m_nOpenMode;
     bool                                        m_bCountFinal;
 
     DataSupplier_Impl(
@@ -84,22 +84,9 @@ struct DataSupplier_Impl
                      rContent->getProvider().get() ),
                  rContent->getIdentifier()->getContentIdentifier() ),
       m_nOpenMode( nOpenMode ), m_bCountFinal( false ) {}
-    ~DataSupplier_Impl();
 };
 
 
-DataSupplier_Impl::~DataSupplier_Impl()
-{
-    ResultList::const_iterator it  = m_aResults.begin();
-    ResultList::const_iterator end = m_aResults.end();
-
-    while ( it != end )
-    {
-        delete (*it);
-        ++it;
-    }
-}
-
 }
 
 
@@ -247,7 +234,7 @@ bool HierarchyResultSetDataSupplier::getResult( sal_uInt32 nIndex )
         const HierarchyEntryData& rResult = *m_pImpl->m_aIterator;
         if ( checkResult( rResult ) )
         {
-            m_pImpl->m_aResults.push_back( new ResultListEntry( rResult ) );
+            m_pImpl->m_aResults.emplace_back( new ResultListEntry( rResult ) );
 
             if ( nPos == nIndex )
             {
@@ -294,7 +281,7 @@ sal_uInt32 HierarchyResultSetDataSupplier::totalCount()
     {
         const HierarchyEntryData& rResult = *m_pImpl->m_aIterator;
         if ( checkResult( rResult ) )
-            m_pImpl->m_aResults.push_back( new ResultListEntry( rResult ) );
+            m_pImpl->m_aResults.emplace_back( new ResultListEntry( rResult ) );
     }
 
     m_pImpl->m_bCountFinal = true;
