@@ -34,7 +34,7 @@
 using namespace com::sun::star;
 
 
-extern "C" SAL_DLLPUBLIC_EXPORT void * SAL_CALL ucpdav1_component_getFactory(
+extern "C" SAL_DLLPUBLIC_EXPORT void * ucpdav1_component_getFactory(
     const sal_Char * pImplName, void * pServiceManager, void * /*pRegistryKey*/ )
 {
     void * pRet = nullptr;
