@@ -8,6 +8,7 @@
 import time
 import threading
 from uitest.config import DEFAULT_SLEEP
+from uitest.config import MAX_WAIT
 from uitest.uihelper.common import get_state_as_dict
 
 from com.sun.star.uno import RuntimeException
@@ -57,7 +58,7 @@ class UITest(object):
         with EventListener(self._xContext, "OnLoad") as event:
             component = desktop.loadComponentFromURL(url, "_default", 0, tuple())
             time_ = 0
-            while time_ < 30:
+            while time_ < MAX_WAIT:
                 if event.executed:
                     frames = self.get_frames()
                     if len(frames) == 1:
@@ -67,11 +68,12 @@ class UITest(object):
                 time_ += DEFAULT_SLEEP
                 time.sleep(DEFAULT_SLEEP)
 
-    def execute_dialog_through_command(self, command):
-        with EventListener(self._xContext, "DialogExecute") as event:
-            self._xUITest.executeDialog(command)
+    def execute_dialog_through_command(self, command, printNames=False):
+        with EventListener(self._xContext, "DialogExecute", printNames=printNames) as event:
+            if not self._xUITest.executeDialog(command):
+                raise DialogNotExecutedException(command)
             time_ = 0
-            while time_ < 30:
+            while time_ < MAX_WAIT:
                 if event.executed:
                     time.sleep(DEFAULT_SLEEP)
                     return
@@ -80,11 +82,12 @@ class UITest(object):
 
         raise DialogNotExecutedException(command)
 
-    def execute_modeless_dialog_through_command(self, command):
-        with EventListener(self._xContext, "ModelessDialogVisible") as event:
-            self._xUITest.executeCommand(command)
+    def execute_modeless_dialog_through_command(self, command, printNames=False):
+        with EventListener(self._xContext, "ModelessDialogVisible", printNames = printNames) as event:
+            if not self._xUITest.executeCommand(command):
+                raise DialogNotExecutedException(command)
             time_ = 0
-            while time_ < 30:
+            while time_ < MAX_WAIT:
                 if event.executed:
                     time.sleep(DEFAULT_SLEEP)
                     return
@@ -100,7 +103,7 @@ class UITest(object):
         with EventListener(self._xContext, event_name) as event:
             ui_object.executeAction(action, parameters)
             time_ = 0
-            while time_ < 30:
+            while time_ < MAX_WAIT:
                 if event.executed:
                     time.sleep(DEFAULT_SLEEP)
                     return
@@ -132,7 +135,7 @@ class UITest(object):
         with EventListener(self._xContext, "OnNew") as event:
             xBtn.executeAction("CLICK", tuple())
             time_ = 0
-            while time_ < 30:
+            while time_ < MAX_WAIT:
                 if event.executed:
                     frames = self.get_frames()
                     self.get_desktop().setActiveFrame(frames[0])
@@ -149,7 +152,7 @@ class UITest(object):
         with EventListener(self._xContext, "DialogClosed" ) as event:
             button.executeAction("CLICK", tuple())
             time_ = 0
-            while time_ < 30:
+            while time_ < MAX_WAIT:
                 if event.executed:
                     time.sleep(DEFAULT_SLEEP)
                     return
@@ -159,9 +162,10 @@ class UITest(object):
 
     def close_doc(self):
         with EventListener(self._xContext, ["DialogExecute", "OnViewClosed"] ) as event:
-            self._xUITest.executeDialog(".uno:CloseDoc")
+            if not self._xUITest.executeDialog(".uno:CloseDoc"):
+                print(".uno:CloseDoc failed")
             time_ = 0
-            while time_ < 30:
+            while time_ < MAX_WAIT:
                 if event.hasExecuted("DialogExecute"):
                     xCloseDlg = self._xUITest.getTopFocusWindow()
                     xNoBtn = xCloseDlg.getChild("discard")
@@ -173,16 +177,37 @@ class UITest(object):
                 time_ += DEFAULT_SLEEP
                 time.sleep(DEFAULT_SLEEP)
 
-    def execute_blocking_action(self, action, dialog_element, args = ()):
+    def execute_blocking_action(self, action, dialog_element=None,
+            args=(), dialog_handler=None, printNames=False):
+        """Executes an action which blocks while a dialog is shown.
+
+        Click a button or perform some other action on the dialog when it
+        is shown.
+
+        Args:
+            action(callable): Will be called to show a dialog, and is expected
+                to block while the dialog is shown.
+            dialog_element(str, optional): The name of a button on the dialog
+                which will be clicked when the dialog is shown.
+            args(tuple, optional): The arguments to be passed to `action`
+            dialog_handler(callable, optional): Will be called when the dialog
+                is shown, with the dialog object passed as a parameter.
+            printNames: print all received event names
+        """
+
         thread = threading.Thread(target=action, args=args)
-        with EventListener(self._xContext, ["DialogExecute", "ModelessDialogExecute"]) as event:
+        with EventListener(self._xContext, ["DialogExecute", "ModelessDialogExecute", "ModelessDialogVisible"], printNames=printNames) as event:
             thread.start()
             time_ = 0
-            while time_ < 30:
+            # we are not necessarily opening a dialog, so wait much longer
+            while time_ < 10 * MAX_WAIT:
                 if event.executed:
                     xDlg = self._xUITest.getTopFocusWindow()
-                    xUIElement = xDlg.getChild(dialog_element)
-                    xUIElement.executeAction("CLICK", tuple())
+                    if dialog_element:
+                        xUIElement = xDlg.getChild(dialog_element)
+                        xUIElement.executeAction("CLICK", tuple())
+                    if dialog_handler:
+                        dialog_handler(xDlg)
                     thread.join()
                     return
 
