@@ -24,13 +24,14 @@
 using namespace com::sun::star;
 using namespace ooo::vba;
 
-ScVbaCheckbox::ScVbaCheckbox( const uno::Reference< ov::XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext >& xContext, const uno::Reference< uno::XInterface >& xControl, const uno::Reference< frame::XModel >& xModel, ov::AbstractGeometryAttributes* pGeomHelper ) : CheckBoxImpl_BASE( xParent, xContext, xControl, xModel, pGeomHelper )
+ScVbaCheckbox::ScVbaCheckbox( const uno::Reference< ov::XHelperInterface >& xParent, const uno::Reference< uno::XComponentContext >& xContext, const uno::Reference< uno::XInterface >& xControl, const uno::Reference< frame::XModel >& xModel, std::unique_ptr<ov::AbstractGeometryAttributes> pGeomHelper )
+    : CheckBoxImpl_BASE( xParent, xContext, xControl, xModel, std::move(pGeomHelper) )
 {
 }
 
 // Attributes
 OUString SAL_CALL
-ScVbaCheckbox::getCaption() throw (css::uno::RuntimeException, std::exception)
+ScVbaCheckbox::getCaption()
 {
     OUString Label;
     m_xProps->getPropertyValue( "Label" ) >>= Label;
@@ -38,13 +39,13 @@ ScVbaCheckbox::getCaption() throw (css::uno::RuntimeException, std::exception)
 }
 
 void SAL_CALL
-ScVbaCheckbox::setCaption( const OUString& _caption ) throw (css::uno::RuntimeException, std::exception)
+ScVbaCheckbox::setCaption( const OUString& _caption )
 {
     m_xProps->setPropertyValue( "Label", uno::makeAny( _caption ) );
 }
 
 uno::Any SAL_CALL
-ScVbaCheckbox::getValue() throw (css::uno::RuntimeException, std::exception)
+ScVbaCheckbox::getValue()
 {
     sal_Int16 nValue = -1;
     m_xProps->getPropertyValue( "State" ) >>= nValue;
@@ -57,7 +58,7 @@ ScVbaCheckbox::getValue() throw (css::uno::RuntimeException, std::exception)
 }
 
 void SAL_CALL
-ScVbaCheckbox::setValue( const uno::Any& _value ) throw (css::uno::RuntimeException, std::exception)
+ScVbaCheckbox::setValue( const uno::Any& _value )
 {
     sal_Int16 nValue = 0;
     sal_Int16 nOldValue = 0;
@@ -77,7 +78,7 @@ ScVbaCheckbox::setValue( const uno::Any& _value ) throw (css::uno::RuntimeExcept
         fireClickEvent();
 }
 
-uno::Reference< msforms::XNewFont > SAL_CALL ScVbaCheckbox::getFont() throw (uno::RuntimeException, std::exception)
+uno::Reference< msforms::XNewFont > SAL_CALL ScVbaCheckbox::getFont()
 {
     return new VbaNewFont( m_xProps );
 }
@@ -100,32 +101,32 @@ ScVbaCheckbox::getServiceNames()
     return aServiceNames;
 }
 
-sal_Int32 SAL_CALL ScVbaCheckbox::getBackColor() throw (uno::RuntimeException, std::exception)
+sal_Int32 SAL_CALL ScVbaCheckbox::getBackColor()
 {
     return ScVbaControl::getBackColor();
 }
 
-void SAL_CALL ScVbaCheckbox::setBackColor( sal_Int32 nBackColor ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaCheckbox::setBackColor( sal_Int32 nBackColor )
 {
     ScVbaControl::setBackColor( nBackColor );
 }
 
-sal_Bool SAL_CALL ScVbaCheckbox::getAutoSize() throw (uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL ScVbaCheckbox::getAutoSize()
 {
     return ScVbaControl::getAutoSize();
 }
 
-void SAL_CALL ScVbaCheckbox::setAutoSize( sal_Bool bAutoSize ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaCheckbox::setAutoSize( sal_Bool bAutoSize )
 {
     ScVbaControl::setAutoSize( bAutoSize );
 }
 
-sal_Bool SAL_CALL ScVbaCheckbox::getLocked() throw (uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL ScVbaCheckbox::getLocked()
 {
     return ScVbaControl::getLocked();
 }
 
-void SAL_CALL ScVbaCheckbox::setLocked( sal_Bool bLocked ) throw (uno::RuntimeException, std::exception)
+void SAL_CALL ScVbaCheckbox::setLocked( sal_Bool bLocked )
 {
     ScVbaControl::setLocked( bLocked );
 }
