@@ -20,15 +20,15 @@
 #ifndef INCLUDED_VCL_INC_QUARTZ_SALBMP_H
 #define INCLUDED_VCL_INC_QUARTZ_SALBMP_H
 
-#include "tools/gen.hxx"
+#include <tools/gen.hxx>
 
 #include <vcl/salbtype.hxx>
 
-#include "quartz/salgdi.h"
+#include <quartz/salgdi.h>
 
-#include "salinst.hxx"
-#include "salvd.hxx"
-#include "salbmp.hxx"
+#include <salinst.hxx>
+#include <salvd.hxx>
+#include <salbmp.hxx>
 
 #include <memory>
 
@@ -76,7 +76,7 @@ public:
 
     bool            ScalingSupported() const override;
     bool            Scale( const double& rScaleX, const double& rScaleY, BmpScaleFlag nScaleFlag ) override;
-    bool            Replace( const Color& rSearchColor, const Color& rReplaceColor, sal_uLong nTol ) override;
+    bool            Replace( const Color& rSearchColor, const Color& rReplaceColor, sal_uInt8 nTol ) override;
 
 private:
     // quartz helper
@@ -93,7 +93,7 @@ public:
 
 public:
     CGImageRef      CreateWithMask( const QuartzSalBitmap& rMask, int nX, int nY, int nWidth, int nHeight ) const;
-    CGImageRef      CreateColorMask( int nX, int nY, int nWidth, int nHeight, SalColor nMaskColor ) const;
+    CGImageRef      CreateColorMask( int nX, int nY, int nWidth, int nHeight, Color nMaskColor ) const;
     CGImageRef      CreateCroppedImage( int nX, int nY, int nWidth, int nHeight ) const;
 };
 
