@@ -29,6 +29,7 @@
 #include <Qt5Menu.hxx>
 #include <Qt5DragAndDrop.hxx>
 
+#include <QtCore/QMimeData>
 #include <QtCore/QPoint>
 #include <QtCore/QSize>
 #include <QtGui/QIcon>
@@ -93,6 +94,11 @@ Qt5Frame::Qt5Frame(Qt5Frame* pParent, SalFrameStyleFlags nStyle, bool bUseCairo)
     {
         if (nStyle & SalFrameStyleFlags::INTRO)
             aWinFlags |= Qt::SplashScreen;
+        // floating toolbars are frameless tool windows
+        // + they must be able to receive keyboard focus
+        else if ((nStyle & SalFrameStyleFlags::FLOAT)
+                 && (nStyle & SalFrameStyleFlags::OWNERDRAWDECORATION))
+            aWinFlags |= Qt::Tool | Qt::FramelessWindowHint;
         else if (nStyle & (SalFrameStyleFlags::FLOAT | SalFrameStyleFlags::TOOLTIP))
             aWinFlags |= Qt::ToolTip;
         else if ((nStyle & SalFrameStyleFlags::FLOAT)
@@ -102,8 +108,6 @@ Qt5Frame::Qt5Frame(Qt5Frame* pParent, SalFrameStyleFlags nStyle, bool bUseCairo)
             aWinFlags |= Qt::Dialog;
         else if (nStyle & SalFrameStyleFlags::TOOLWINDOW)
             aWinFlags |= Qt::Tool;
-        else if (nStyle & SalFrameStyleFlags::OWNERDRAWDECORATION)
-            aWinFlags |= Qt::Window | Qt::FramelessWindowHint | Qt::WindowDoesNotAcceptFocus;
         else
             aWinFlags |= Qt::Window;
     }
@@ -158,6 +162,8 @@ Qt5Frame::Qt5Frame(Qt5Frame* pParent, SalFrameStyleFlags nStyle, bool bUseCairo)
     //m_aSystemData.pWidget = m_pQWidget;
     //m_aSystemData.nScreen = m_nXScreen.getXScreen();
     m_aSystemData.pToolkit = "qt5";
+
+    SetIcon(SV_ICON_ID_OFFICE);
 }
 
 Qt5Frame::~Qt5Frame()
@@ -288,6 +294,14 @@ bool Qt5Frame::isMaximized() const
         return m_pQWidget->isMaximized();
 }
 
+void Qt5Frame::SetWindowStateImpl(Qt::WindowStates eState)
+{
+    if (m_pTopLevel)
+        m_pTopLevel->setWindowState(eState);
+    else
+        m_pQWidget->setWindowState(eState);
+}
+
 void Qt5Frame::SetTitle(const OUString& rTitle)
 {
     m_pQWidget->window()->setWindowTitle(toQString(rTitle));
@@ -514,7 +528,19 @@ void Qt5Frame::SetWindowState(const SalFrameState* pState)
 
     if ((pState->mnMask & WindowStateMask::State) && (pState->mnState & WindowStateState::Maximized)
         && !isMaximized() && (pState->mnMask & nMaxGeometryMask) == nMaxGeometryMask)
-        m_pQWidget->showMaximized();
+    {
+        if (m_pTopLevel)
+        {
+            m_pTopLevel->resize(pState->mnWidth, pState->mnHeight);
+            m_pTopLevel->move(pState->mnX, pState->mnY);
+        }
+        else
+        {
+            m_pQWidget->resize(pState->mnWidth, pState->mnHeight);
+            m_pQWidget->move(pState->mnX, pState->mnY);
+        }
+        SetWindowStateImpl(Qt::WindowMaximized);
+    }
     else if (pState->mnMask
              & (WindowStateMask::X | WindowStateMask::Y | WindowStateMask::Width
                 | WindowStateMask::Height))
@@ -542,16 +568,12 @@ void Qt5Frame::SetWindowState(const SalFrameState* pState)
     }
     else if (pState->mnMask & WindowStateMask::State && !isChild())
     {
-        if (pState->mnState & WindowStateState::Maximized && m_pTopLevel)
-        {
-            m_pTopLevel->showMaximized();
-            return;
-        }
-
-        if ((pState->mnState & WindowStateState::Minimized) && isWindow())
-            m_pQWidget->showMinimized();
+        if (pState->mnState & WindowStateState::Maximized)
+            SetWindowStateImpl(Qt::WindowMaximized);
+        else if ((pState->mnState & WindowStateState::Minimized))
+            SetWindowStateImpl(Qt::WindowMinimized);
         else
-            m_pQWidget->showNormal();
+            SetWindowStateImpl(Qt::WindowNoState);
     }
 }
 
@@ -590,9 +612,19 @@ void Qt5Frame::ShowFullScreen(bool bFullScreen, sal_Int32 nScreen)
     if (!isWindow())
         m_pTopLevel->show();
 
-    // do that before going fullscreen
-    SetScreenNumber(nScreen);
-    m_bFullScreen ? windowHandle()->showFullScreen() : windowHandle()->showNormal();
+    if (m_bFullScreen)
+    {
+        m_aRestoreGeometry = m_pTopLevel->geometry();
+        // do that before going fullscreen
+        SetScreenNumber(nScreen);
+        windowHandle()->showFullScreen();
+    }
+    else
+    {
+        windowHandle()->showNormal();
+        m_pTopLevel->setGeometry(m_aRestoreGeometry);
+        m_aRestoreGeometry = QRect();
+    }
 }
 
 void Qt5Frame::StartPresentation(bool)
@@ -610,7 +642,6 @@ void Qt5Frame::SetAlwaysOnTop(bool bOnTop)
         pWidget->setWindowFlags(flags | Qt::CustomizeWindowHint | Qt::WindowStaysOnTopHint);
     else
         pWidget->setWindowFlags(flags & ~(Qt::CustomizeWindowHint | Qt::WindowStaysOnTopHint));
-    pWidget->show();
 }
 
 void Qt5Frame::ToTop(SalFrameToTop nFlags)
@@ -619,8 +650,10 @@ void Qt5Frame::ToTop(SalFrameToTop nFlags)
 
     if (isWindow() && !(nFlags & SalFrameToTop::GrabFocusOnly))
         pWidget->raise();
-    pWidget->setFocus();
-    pWidget->activateWindow();
+    if ((nFlags & SalFrameToTop::RestoreWhenMin) || (nFlags & SalFrameToTop::ForegroundTask))
+        pWidget->activateWindow();
+    else if ((nFlags & SalFrameToTop::GrabFocus) || (nFlags & SalFrameToTop::GrabFocusOnly))
+        m_pQWidget->setFocus();
 }
 
 void Qt5Frame::SetPointer(PointerStyle ePointerStyle)
@@ -1076,7 +1109,8 @@ void Qt5Frame::deregisterDropTarget(Qt5DropTarget const* pDropTarget)
     m_pDropTarget = nullptr;
 }
 
-void Qt5Frame::draggingStarted(const int x, const int y, const QMimeData* pQMimeData)
+void Qt5Frame::draggingStarted(const int x, const int y, Qt::DropActions eActions,
+                               const QMimeData* pQMimeData)
 {
     assert(m_pDropTarget);
 
@@ -1085,11 +1119,11 @@ void Qt5Frame::draggingStarted(const int x, const int y, const QMimeData* pQMime
     aEvent.Context = static_cast<css::datatransfer::dnd::XDropTargetDragContext*>(m_pDropTarget);
     aEvent.LocationX = x;
     aEvent.LocationY = y;
-    aEvent.DropAction = css::datatransfer::dnd::DNDConstants::ACTION_MOVE;
-    aEvent.SourceActions = css::datatransfer::dnd::DNDConstants::ACTION_MOVE;
+    aEvent.DropAction = getPreferredDropAction(eActions);
+    aEvent.SourceActions = toVclDropActions(eActions);
 
     css::uno::Reference<css::datatransfer::XTransferable> xTransferable;
-    if (pQMimeData)
+    if (!pQMimeData->hasFormat(sInternalMimeType))
         xTransferable = new Qt5DnDTransferable(pQMimeData);
     else
         xTransferable = Qt5DragSource::m_ActiveDragSource->GetTransferable();
@@ -1121,7 +1155,7 @@ void Qt5Frame::dropping(const int x, const int y, const QMimeData* pQMimeData)
     aEvent.SourceActions = css::datatransfer::dnd::DNDConstants::ACTION_MOVE;
 
     css::uno::Reference<css::datatransfer::XTransferable> xTransferable;
-    if (pQMimeData)
+    if (!pQMimeData->hasFormat(sInternalMimeType))
         xTransferable = new Qt5DnDTransferable(pQMimeData);
     else
         xTransferable = Qt5DragSource::m_ActiveDragSource->GetTransferable();
