@@ -67,6 +67,12 @@ Qt5Instance::Qt5Instance(bool bUseCairo)
             Qt::BlockingQueuedConnection);
     connect(this, &Qt5Instance::createMenuSignal, this, &Qt5Instance::CreateMenu,
             Qt::BlockingQueuedConnection);
+
+    // this one needs to be queued non-blocking
+    // in order to have this event arriving to correct event processing loop
+    connect(this, &Qt5Instance::deleteObjectLaterSignal, this,
+            [](QObject* pObject) { Qt5Instance::deleteObjectLater(pObject); },
+            Qt::QueuedConnection);
 }
 
 Qt5Instance::~Qt5Instance()
@@ -78,6 +84,8 @@ Qt5Instance::~Qt5Instance()
         free(m_pFakeArgvFreeable[i]);
 }
 
+void Qt5Instance::deleteObjectLater(QObject* pObject) { pObject->deleteLater(); }
+
 SalFrame* Qt5Instance::CreateChildFrame(SystemParentData* /*pParent*/, SalFrameStyleFlags nStyle)
 {
     return new Qt5Frame(nullptr, nStyle, m_bUseCairo);
@@ -94,7 +102,7 @@ void Qt5Instance::DestroyFrame(SalFrame* pFrame)
     if (pFrame)
     {
         assert(dynamic_cast<Qt5Frame*>(pFrame));
-        static_cast<Qt5Frame*>(pFrame)->deleteLater();
+        Q_EMIT deleteObjectLaterSignal(static_cast<Qt5Frame*>(pFrame));
     }
 }
 
@@ -109,7 +117,7 @@ void Qt5Instance::DestroyObject(SalObject* pObject)
     if (pObject)
     {
         assert(dynamic_cast<Qt5Object*>(pObject));
-        static_cast<Qt5Object*>(pObject)->deleteLater();
+        Q_EMIT deleteObjectLaterSignal(static_cast<Qt5Object*>(pObject));
     }
 }
 
