@@ -188,20 +188,20 @@ void Qt5Widget::wheelEvent(QWheelEvent* pEvent)
     pEvent->accept();
 }
 
-void Qt5Widget::startDrag()
+void Qt5Widget::startDrag(sal_Int8 nSourceActions)
 {
     // internal drag source
     QMimeData* mimeData = new QMimeData;
-    mimeData->setData(m_InternalMimeType, nullptr);
+    mimeData->setData(sInternalMimeType, nullptr);
 
     QDrag* drag = new QDrag(this);
     drag->setMimeData(mimeData);
-    drag->exec(Qt::CopyAction | Qt::MoveAction, Qt::MoveAction);
+    drag->exec(toQtDropActions(nSourceActions), Qt::MoveAction);
 }
 
 void Qt5Widget::dragEnterEvent(QDragEnterEvent* event)
 {
-    if (event->mimeData()->hasFormat(m_InternalMimeType))
+    if (event->mimeData()->hasFormat(sInternalMimeType))
         event->accept();
     else
         event->acceptProposedAction();
@@ -211,7 +211,7 @@ void Qt5Widget::dragMoveEvent(QDragMoveEvent* event)
 {
     QPoint point = event->pos();
 
-    m_pFrame->draggingStarted(point.x(), point.y(), event->mimeData());
+    m_pFrame->draggingStarted(point.x(), point.y(), event->possibleActions(), event->mimeData());
     QWidget::dragMoveEvent(event);
 }
 
