@@ -18,6 +18,7 @@
  */
 
 
+#include <vcl/commandevent.hxx>
 #include <vcl/decoview.hxx>
 #include <vcl/dialog.hxx>
 #include <vcl/event.hxx>
@@ -28,6 +29,7 @@
 #include <vcl/combobox.hxx>
 #include <vcl/settings.hxx>
 #include <vcl/uitest/uiobject.hxx>
+#include <sal/log.hxx>
 
 #include <svdata.hxx>
 #include <controldata.hxx>
@@ -81,7 +83,6 @@ void ListBox::ImplInitListBoxData()
     mnLineCount     = 0;
     m_nMaxWidthChars = -1;
     mbDDAutoSize    = true;
-    mbEdgeBlending  = false;
 }
 
 void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
@@ -127,7 +128,7 @@ void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
         mpImplWin->SetUserDrawHdl( LINK( this, ListBox, ImplUserDrawHdl ) );
         mpImplWin->Show();
         mpImplWin->GetDropTarget()->addDropTargetListener(xDrop);
-        mpImplWin->SetEdgeBlending(GetEdgeBlending());
+        mpImplWin->SetEdgeBlending(false);
 
         mpBtn = VclPtr<ImplBtn>::Create( this, WB_NOLIGHTBORDER | WB_RECTSTYLE );
         ImplInitDropDownButton( mpBtn );
@@ -148,7 +149,7 @@ void ListBox::ImplInit( vcl::Window* pParent, WinBits nStyle )
     mpImplLB->SetFocusHdl( LINK( this, ListBox, ImplFocusHdl ) );
     mpImplLB->SetListItemSelectHdl( LINK( this, ListBox, ImplListItemSelectHdl ) );
     mpImplLB->SetPosPixel( Point() );
-    mpImplLB->SetEdgeBlending(GetEdgeBlending());
+    mpImplLB->SetEdgeBlending(false);
     mpImplLB->Show();
 
     mpImplLB->GetDropTarget()->addDropTargetListener(xDrop);
@@ -1241,11 +1242,6 @@ Size ListBox::CalcSubEditSize() const
     return aSz;
 }
 
-long ListBox::CalcWindowSizePixel(sal_uInt16 nLines) const
-{
-    return mpImplLB->GetEntryHeight() * nLines;
-}
-
 Size ListBox::GetOptimalSize() const
 {
     return CalcMinimumSize();
@@ -1422,41 +1418,23 @@ bool ListBox::set_property(const OString &rKey, const OUString &rValue)
         SelectEntryPos(rValue.toInt32());
     else if (rKey == "max-width-chars")
         setMaxWidthChars(rValue.toInt32());
+    else if (rKey == "can-focus")
+    {
+        // as far as I can see in Gtk, setting a ComboBox as can.focus means
+        // the focus gets stuck in it, so try here to behave like gtk does
+        // with the settings that work, i.e. can.focus of false doesn't
+        // set the hard WB_NOTABSTOP
+        WinBits nBits = GetStyle();
+        nBits &= ~(WB_TABSTOP|WB_NOTABSTOP);
+        if (toBool(rValue))
+            nBits |= WB_TABSTOP;
+        SetStyle(nBits);
+    }
     else
         return Control::set_property(rKey, rValue);
     return true;
 }
 
-void ListBox::SetEdgeBlending(bool bNew)
-{
-    if(mbEdgeBlending != bNew)
-    {
-        mbEdgeBlending = bNew;
-
-        if(IsDropDownBox())
-        {
-            assert(mpImplWin);
-            mpImplWin->Invalidate();
-        }
-        else
-        {
-            mpImplLB->Invalidate();
-        }
-
-        if(mpImplWin)
-        {
-            mpImplWin->SetEdgeBlending(GetEdgeBlending());
-        }
-
-        if(mpImplLB)
-        {
-            mpImplLB->SetEdgeBlending(GetEdgeBlending());
-        }
-
-        Invalidate();
-    }
-}
-
 FactoryFunction ListBox::GetUITestFactory() const
 {
     return ListBoxUIObject::create;
