@@ -18,6 +18,7 @@
  */
 
 #include <osl/file.h>
+#include <sal/log.hxx>
 #include <tools/stream.hxx>
 #include <tools/vcompat.hxx>
 #include <unotools/tempfile.hxx>
@@ -45,7 +46,8 @@ GfxLink::GfxLink(std::unique_ptr<sal_uInt8[]> pBuf, sal_uInt32 nSize, GfxLinkTyp
     , mbPrefMapModeValid(false)
     , mbPrefSizeValid(false)
 {
-    SAL_WARN_IF(mpSwapInData.get() == nullptr || mnSwapInDataSize <= 0, "vcl", "GfxLink::GfxLink(): empty/NULL buffer given");
+    SAL_WARN_IF(mpSwapInData == nullptr || mnSwapInDataSize <= 0, "vcl",
+                "GfxLink::GfxLink(): empty/NULL buffer given");
 }
 
 bool GfxLink::operator==( const GfxLink& rGfxLink ) const
@@ -78,8 +80,14 @@ bool GfxLink::IsNative() const
 const sal_uInt8* GfxLink::GetData() const
 {
     if( IsSwappedOut() )
-        const_cast<GfxLink*>(this)->SwapIn();
-
+    {
+        auto pData = GetSwapInData();
+        if (pData)
+        {
+            mpSwapInData = pData;
+            mpSwapOutData.reset();
+        }
+    }
     return mpSwapInData.get();
 }
 
@@ -166,19 +174,6 @@ void GfxLink::SwapOut()
     }
 }
 
-void GfxLink::SwapIn()
-{
-    if( IsSwappedOut() )
-    {
-        auto pData = GetSwapInData();
-        if (pData)
-        {
-            mpSwapInData = pData;
-            mpSwapOutData.reset();
-        }
-    }
-}
-
 bool GfxLink::ExportNative( SvStream& rOStream ) const
 {
     if( GetDataSize() )
