@@ -20,6 +20,7 @@
 #include <cassert>
 
 #include <sal/types.h>
+#include <sal/log.hxx>
 
 #include <memory>
 #include <vcl/gdimtf.hxx>
@@ -109,71 +110,4 @@ void OutputDevice::DrawPixel( const Point& rPt, const Color& rColor )
         mpAlphaVDev->DrawPixel( rPt );
 }
 
-void OutputDevice::DrawPixel( const tools::Polygon& rPts, const Color* pColors )
-{
-    assert(!is_double_buffered_window());
-
-    if ( !pColors )
-    {
-        DrawPixel( rPts, GetLineColor() );
-    }
-    else
-    {
-        SAL_WARN_IF( !pColors, "vcl", "OutputDevice::DrawPixel: No color array specified" );
-
-        const sal_uInt16 nSize = rPts.GetSize();
-
-        if ( nSize )
-        {
-            if ( mpMetaFile )
-            {
-                for ( sal_uInt16 i = 0; i < nSize; i++ )
-                {
-                    mpMetaFile->AddAction( new MetaPixelAction( rPts[ i ], pColors[ i ] ) );
-                }
-            }
-            if ( !IsDeviceOutputNecessary() || ImplIsRecordLayout() )
-                return;
-
-            if ( mpGraphics || AcquireGraphics() )
-            {
-                if ( mbInitClipRegion )
-                    InitClipRegion();
-
-                if ( mbOutputClipped )
-                    return;
-
-                for ( sal_uInt16 i = 0; i < nSize; i++ )
-                {
-                    const Point aPt( ImplLogicToDevicePixel( rPts[ i ] ) );
-                    mpGraphics->DrawPixel( aPt.X(), aPt.Y(), pColors[ i ], this );
-                }
-            }
-        }
-    }
-
-    if( mpAlphaVDev )
-        mpAlphaVDev->DrawPixel( rPts, pColors );
-}
-
-void OutputDevice::DrawPixel( const tools::Polygon& rPts, const Color& rColor )
-{
-    assert(!is_double_buffered_window());
-
-    if( rColor != COL_TRANSPARENT && ! ImplIsRecordLayout() )
-    {
-        const sal_uInt16 nSize = rPts.GetSize();
-        std::unique_ptr<Color[]> pColArray(new Color[ nSize ]);
-
-        for( sal_uInt16 i = 0; i < nSize; i++ )
-        {
-            pColArray[ i ] = rColor;
-        }
-        DrawPixel( rPts, pColArray.get() );
-    }
-
-    if( mpAlphaVDev )
-        mpAlphaVDev->DrawPixel( rPts, rColor );
-}
-
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
