@@ -443,7 +443,7 @@ SalI18N_InputContext::GetWeightingOfIMStyle( XIMStyle nStyle )
     };
 
     StyleWeightingT const *pWeightPtr;
-    const StyleWeightingT pWeight[] = {
+    static const StyleWeightingT pWeight[] = {
         { XIMPreeditCallbacks, 0x10000000 },
         { XIMPreeditPosition,  0x02000000 },
         { XIMPreeditArea,      0x01000000 },
@@ -465,15 +465,11 @@ SalI18N_InputContext::GetWeightingOfIMStyle( XIMStyle nStyle )
     return nWeight;
 }
 
-Bool
+bool
 SalI18N_InputContext::IsSupportedIMStyle( XIMStyle nStyle ) const
 {
-    if (   (nStyle & mnSupportedPreeditStyle)
-           && (nStyle & g_nSupportedStatusStyle) )
-    {
-        return True;
-    }
-    return False;
+    return (nStyle & mnSupportedPreeditStyle)
+           && (nStyle & g_nSupportedStatusStyle);
 }
 
 bool
