@@ -105,7 +105,7 @@ GlyphSet::AddNotdef (glyph_map_t &rGlyphMap)
         rGlyphMap[0] = 0;
 }
 
-bool
+void
 GlyphSet::AddGlyphID (
                      sal_GlyphId nGlyph,
                      unsigned char* nOutGlyphID,
@@ -136,8 +136,6 @@ GlyphSet::AddGlyphID (
     aGlyphSet [nGlyph] = nSize;
     *nOutGlyphSetID   = maGlyphList.size();
     *nOutGlyphID      = aGlyphSet [nGlyph];
-
-    return true;
 }
 
 OString
@@ -244,8 +242,8 @@ GlyphSet::PSUploadFont (osl::File& rOutFile, PrinterGfx &rGfx, bool bAllowType42
     TrueTypeFont *pTTFont;
     OString aTTFileName (rGfx.GetFontMgr().getFontFileSysPath(mnFontID));
     int nFace = rGfx.GetFontMgr().getFontFaceNumber(mnFontID);
-    sal_Int32 nSuccess = OpenTTFontFile(aTTFileName.getStr(), nFace, &pTTFont);
-    if (nSuccess != SF_OK)
+    SFErrCodes nSuccess = OpenTTFontFile(aTTFileName.getStr(), nFace, &pTTFont);
+    if (nSuccess != SFErrCodes::Ok)
         return;
 
     utl::TempFile aTmpFile;
