@@ -38,6 +38,7 @@
 #include <osl/diagnose.h>
 #include <osl/process.h>
 #include <rtl/process.h>
+#include <sal/log.hxx>
 #include <com/sun/star/ui/dialogs/TemplateDescription.hpp>
 #include <com/sun/star/ui/dialogs/ControlActions.hpp>
 #include <com/sun/star/uno/Any.hxx>
@@ -89,9 +90,7 @@ SalGtkFilePicker::SalGtkFilePicker( const uno::Reference< uno::XComponentContext
     mbPreviewState( false ),
     mHID_Preview( 0 ),
     m_pPreview( nullptr ),
-    m_pPseudoFilter( nullptr ),
-    m_PreviewImageWidth( 256 ),
-    m_PreviewImageHeight( 256 )
+    m_pPseudoFilter( nullptr )
 {
     int i;
 
@@ -703,7 +702,7 @@ uno::Sequence<OUString> SAL_CALL SalGtkFilePicker::getFiles()
 namespace
 {
 
-bool lcl_matchFilter( const rtl::OUString& rFilter, const rtl::OUString& rExt )
+bool lcl_matchFilter( const OUString& rFilter, const OUString& rExt )
 {
     const sal_Unicode cSep {';'};
     sal_Int32 nIdx {0};
@@ -1234,7 +1233,7 @@ uno::Any SalGtkFilePicker::HandleGetListValue(GtkComboBox *pWidget, sal_Int16 nC
                             &iter, 0, &item, -1);
                         aItemList[i] = OUString(item, strlen(item), RTL_TEXTENCODING_UTF8);
                         g_free(item);
-                        gtk_tree_model_iter_next(pTree, &iter);
+                        (void)gtk_tree_model_iter_next(pTree, &iter);
                     }
                 }
                 aAny <<= aItemList;
@@ -1422,7 +1421,7 @@ sal_Int32 SAL_CALL SalGtkFilePicker::getAvailableWidth()
 
     OSL_ASSERT( m_pDialog != nullptr );
 
-    return m_PreviewImageWidth;
+    return g_PreviewImageWidth;
 }
 
 sal_Int32 SAL_CALL SalGtkFilePicker::getAvailableHeight()
@@ -1431,7 +1430,7 @@ sal_Int32 SAL_CALL SalGtkFilePicker::getAvailableHeight()
 
     OSL_ASSERT( m_pDialog != nullptr );
 
-    return m_PreviewImageHeight;
+    return g_PreviewImageHeight;
 }
 
 void SAL_CALL SalGtkFilePicker::setImage( sal_Int16 /*aImageFormat*/, const uno::Any& /*aImage*/ )
@@ -1514,8 +1513,8 @@ void SalGtkFilePicker::update_preview_cb( GtkFileChooser *file_chooser, SalGtkFi
     {
         GdkPixbuf *pixbuf = gdk_pixbuf_new_from_file_at_size(
                 filename,
-                pobjFP->m_PreviewImageWidth,
-                pobjFP->m_PreviewImageHeight, nullptr );
+                g_PreviewImageWidth,
+                g_PreviewImageHeight, nullptr );
 
         have_preview = ( pixbuf != nullptr );
 
@@ -1850,7 +1849,7 @@ GtkFileFilter* SalGtkFilePicker::implAddFilter( const OUString& rFilter, const O
     OString aFilterName = OUStringToOString( aShrunkName, RTL_TEXTENCODING_UTF8 );
     gtk_file_filter_set_name( filter, aFilterName.getStr() );
 
-    OUString aTokens;
+    OUStringBuffer aTokens;
 
     bool bAllGlob = rType == "*.*" || rType == "*";
     if (bAllGlob)
@@ -1858,10 +1857,9 @@ GtkFileFilter* SalGtkFilePicker::implAddFilter( const OUString& rFilter, const O
     else
     {
         sal_Int32 nIndex = 0;
-        OUString aToken;
         do
         {
-            aToken = rType.getToken( 0, ';', nIndex );
+            OUString aToken = rType.getToken( 0, ';', nIndex );
             // Assume all have the "*.<extn>" syntax
             sal_Int32 nStarDot = aToken.lastIndexOf( "*." );
             if (nStarDot >= 0)
@@ -1869,8 +1867,8 @@ GtkFileFilter* SalGtkFilePicker::implAddFilter( const OUString& rFilter, const O
             if (!aToken.isEmpty())
             {
                 if (!aTokens.isEmpty())
-                    aTokens += ",";
-                aTokens = aTokens += aToken;
+                    aTokens.append(",");
+                aTokens.append(aToken);
                 gtk_file_filter_add_custom (filter, GTK_FILE_FILTER_URI,
                     case_insensitive_filter,
                     g_strdup( OUStringToOString(aToken, RTL_TEXTENCODING_UTF8).getStr() ),
@@ -1898,7 +1896,7 @@ GtkFileFilter* SalGtkFilePicker::implAddFilter( const OUString& rFilter, const O
         gtk_list_store_append (m_pFilterStore, &iter);
         gtk_list_store_set (m_pFilterStore, &iter,
             0, OUStringToOString(shrinkFilterName( rFilter, true ), RTL_TEXTENCODING_UTF8).getStr(),
-            1, OUStringToOString(aTokens, RTL_TEXTENCODING_UTF8).getStr(),
+            1, OUStringToOString(aTokens.makeStringAndClear(), RTL_TEXTENCODING_UTF8).getStr(),
             2, aFilterName.getStr(),
             3, OUStringToOString(rType, RTL_TEXTENCODING_UTF8).getStr(),
             -1);
@@ -1944,15 +1942,15 @@ void SalGtkFilePicker::SetFilters()
         }
         if (aAllFormats.size() > 1)
         {
-            OUString sAllFilter;
+            OUStringBuffer sAllFilter;
             for (auto const& format : aAllFormats)
             {
                 if (!sAllFilter.isEmpty())
-                    sAllFilter += ";";
-                sAllFilter += format;
+                    sAllFilter.append(";");
+                sAllFilter.append(format);
             }
             sPseudoFilter = getResString(FILE_PICKER_ALLFORMATS);
-            m_pPseudoFilter = implAddFilter( sPseudoFilter, sAllFilter );
+            m_pPseudoFilter = implAddFilter( sPseudoFilter, sAllFilter.makeStringAndClear() );
         }
     }
 
