@@ -119,7 +119,7 @@ GtkSalSystem::countScreenMonitors()
                     GdkRectangleCoincident()));
             nMonitors = std::distance(aGeometries.begin(), aUniqueEnd);
         }
-        maScreenMonitors.push_back(std::make_pair(pScreen, nMonitors));
+        maScreenMonitors.emplace_back(pScreen, nMonitors);
     }
 }
 
@@ -150,13 +150,13 @@ GdkScreen *
 GtkSalSystem::getScreenMonitorFromIdx (int nIdx, gint &nMonitor)
 {
     GdkScreen *pScreen = nullptr;
-    for (ScreenMonitors_t::const_iterator aIt(maScreenMonitors.begin()), aEnd(maScreenMonitors.end()); aIt != aEnd; ++aIt)
+    for (auto const& screenMonitor : maScreenMonitors)
     {
-        pScreen = aIt->first;
+        pScreen = screenMonitor.first;
         if (!pScreen)
             break;
-        if (nIdx >= aIt->second)
-            nIdx -= aIt->second;
+        if (nIdx >= screenMonitor.second)
+            nIdx -= screenMonitor.second;
         else
             break;
     }
@@ -173,11 +173,11 @@ int
 GtkSalSystem::getScreenIdxFromPtr (GdkScreen *pScreen)
 {
     int nIdx = 0;
-    for (ScreenMonitors_t::const_iterator aIt(maScreenMonitors.begin()), aEnd(maScreenMonitors.end()); aIt != aEnd; ++aIt)
+    for (auto const& screenMonitor : maScreenMonitors)
     {
-        if (aIt->first == pScreen)
+        if (screenMonitor.first == pScreen)
             return nIdx;
-        nIdx += aIt->second;
+        nIdx += screenMonitor.second;
     }
     g_warning ("failed to find screen %p", pScreen);
     return 0;
@@ -269,8 +269,7 @@ static OString MapToGtkAccelerator(const OUString &rStr)
 }
 
 int GtkSalSystem::ShowNativeDialog (const OUString& rTitle, const OUString& rMessage,
-                                    const std::list< OUString >& rButtonNames,
-                                    int nDefaultButton)
+                                    const std::vector< OUString >& rButtonNames)
 {
     OString aTitle (OUStringToOString (rTitle, RTL_TEXTENCODING_UTF8));
     OString aMessage (OUStringToOString (rMessage, RTL_TEXTENCODING_UTF8));
@@ -278,14 +277,13 @@ int GtkSalSystem::ShowNativeDialog (const OUString& rTitle, const OUString& rMes
     GtkDialog *pDialog = GTK_DIALOG (
         g_object_new (GTK_TYPE_MESSAGE_DIALOG,
                       "title", aTitle.getStr(),
-                      "message-type", (int)GTK_MESSAGE_WARNING,
+                      "message-type", int(GTK_MESSAGE_WARNING),
                       "text", aMessage.getStr(),
                       nullptr));
     int nButton = 0;
-    std::list< OUString >::const_iterator it;
-    for (it = rButtonNames.begin(); it != rButtonNames.end(); ++it)
-        gtk_dialog_add_button (pDialog, MapToGtkAccelerator(*it).getStr(), nButton++);
-    gtk_dialog_set_default_response (pDialog, nDefaultButton);
+    for (auto const& buttonName : rButtonNames)
+        gtk_dialog_add_button (pDialog, MapToGtkAccelerator(buttonName).getStr(), nButton++);
+    gtk_dialog_set_default_response (pDialog, 0/*nDefaultButton*/);
 
     nButton = gtk_dialog_run (pDialog);
     if (nButton < 0)
