@@ -20,12 +20,13 @@ using com::sun::star::uno::Sequence;
 using com::sun::star::uno::XComponentContext;
 using com::sun::star::uno::XInterface;
 
-bool FreehandImportFilter::doImportDocument(librevenge::RVNGInputStream &rInput, OdgGenerator &rGenerator, utl::MediaDescriptor &)
+bool FreehandImportFilter::doImportDocument(weld::Window*, librevenge::RVNGInputStream& rInput,
+                                            OdgGenerator& rGenerator, utl::MediaDescriptor&)
 {
     return libfreehand::FreeHandDocument::parse(&rInput, &rGenerator);
 }
 
-bool FreehandImportFilter::doDetectFormat(librevenge::RVNGInputStream &rInput, OUString &rTypeName)
+bool FreehandImportFilter::doDetectFormat(librevenge::RVNGInputStream& rInput, OUString& rTypeName)
 {
     if (libfreehand::FreeHandDocument::isSupported(&rInput))
     {
@@ -38,32 +39,27 @@ bool FreehandImportFilter::doDetectFormat(librevenge::RVNGInputStream &rInput, O
 
 // XServiceInfo
 OUString SAL_CALL FreehandImportFilter::getImplementationName()
-throw (RuntimeException, std::exception)
 {
     return OUString("com.sun.star.comp.Draw.FreehandImportFilter");
 }
 
-sal_Bool SAL_CALL FreehandImportFilter::supportsService(const OUString &rServiceName)
-throw (RuntimeException, std::exception)
+sal_Bool SAL_CALL FreehandImportFilter::supportsService(const OUString& rServiceName)
 {
     return cppu::supportsService(this, rServiceName);
 }
 
-Sequence< OUString > SAL_CALL FreehandImportFilter::getSupportedServiceNames()
-throw (RuntimeException, std::exception)
+Sequence<OUString> SAL_CALL FreehandImportFilter::getSupportedServiceNames()
 {
-    Sequence < OUString > aRet(2);
-    OUString *pArray = aRet.getArray();
-    pArray[0] =  "com.sun.star.document.ImportFilter";
-    pArray[1] =  "com.sun.star.document.ExtendedTypeDetection";
+    Sequence<OUString> aRet(2);
+    OUString* pArray = aRet.getArray();
+    pArray[0] = "com.sun.star.document.ImportFilter";
+    pArray[1] = "com.sun.star.document.ExtendedTypeDetection";
     return aRet;
 }
 
-extern "C"
-SAL_DLLPUBLIC_EXPORT css::uno::XInterface *SAL_CALL
+extern "C" SAL_DLLPUBLIC_EXPORT css::uno::XInterface*
 com_sun_star_comp_Draw_FreehandImportFilter_get_implementation(
-    css::uno::XComponentContext *const context,
-    const css::uno::Sequence<css::uno::Any> &)
+    css::uno::XComponentContext* const context, const css::uno::Sequence<css::uno::Any>&)
 {
     return cppu::acquire(new FreehandImportFilter(context));
 }
