@@ -50,7 +50,7 @@ namespace xmloff
 
     OUString VCLTimeHandler::getAttributeValue( const Any& i_propertyValue ) const
     {
-        Time aTime;
+        css::util::Time aTime;
         OSL_VERIFY( i_propertyValue >>= aTime );
 
         Duration aDuration; // default-inited to 0
@@ -64,10 +64,10 @@ namespace xmloff
         return aBuffer.makeStringAndClear();
     }
 
-    bool VCLTimeHandler::getPropertyValues( const OUString i_attributeValue, PropertyValues& o_propertyValues ) const
+    bool VCLTimeHandler::getPropertyValues( const OUString& i_attributeValue, PropertyValues& o_propertyValues ) const
     {
         Duration aDuration;
-        Time aTime;
+        css::util::Time aTime;
         if (::sax::Converter::convertDuration( aDuration, i_attributeValue ))
         {
             aTime = Time(aDuration.NanoSeconds, aDuration.Seconds,
@@ -84,19 +84,16 @@ namespace xmloff
                 return false;
             }
             // legacy integer was in centiseconds
-            nVCLTime *= ::Time::nanoPerCenti;
-            aTime = ::Time(nVCLTime).GetUNOTime();
+            nVCLTime *= ::tools::Time::nanoPerCenti;
+            aTime = ::tools::Time(nVCLTime).GetUNOTime();
         }
 
         const Any aPropertyValue( makeAny( aTime ) );
 
         OSL_ENSURE( o_propertyValues.size() == 1, "VCLTimeHandler::getPropertyValues: time strings represent exactly one property - not more, not less!" );
-        for (   PropertyValues::iterator prop = o_propertyValues.begin();
-                prop != o_propertyValues.end();
-                ++prop
-            )
+        for ( auto& prop : o_propertyValues )
         {
-            prop->second = aPropertyValue;
+            prop.second = aPropertyValue;
         }
         return true;
     }
