@@ -42,6 +42,7 @@
 #include "table.hxx"
 
 #include <osl/diagnose.h>
+#include <sal/log.hxx>
 
 #include <memory>
 
@@ -60,7 +61,6 @@ namespace {
 struct ColumnInfo
 {
     OUString msStyleName;
-    bool mbVisibility;
     OUString msDefaultCellStyleName;
 };
 
@@ -71,7 +71,7 @@ class XMLProxyContext : public SvXMLImportContext
 public:
     XMLProxyContext( SvXMLImport& rImport, const SvXMLImportContextRef& xParent, sal_uInt16 nPrfx, const OUString& rLName );
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
 
 private:
     SvXMLImportContextRef mxParent;
@@ -79,10 +79,10 @@ private:
 
 struct MergeInfo
 {
-    sal_Int32 mnStartColumn;
-    sal_Int32 mnStartRow;
-    sal_Int32 mnEndColumn;
-    sal_Int32 mnEndRow;
+    sal_Int32 const mnStartColumn;
+    sal_Int32 const mnStartRow;
+    sal_Int32 const mnEndColumn;
+    sal_Int32 const mnEndRow;
 
     MergeInfo( sal_Int32 nStartColumn, sal_Int32 nStartRow, sal_Int32 nColumnSpan, sal_Int32 nRowSpan )
         : mnStartColumn( nStartColumn ), mnStartRow( nStartRow ), mnEndColumn( nStartColumn + nColumnSpan - 1 ), mnEndRow( nStartRow + nRowSpan - 1 ) {};
@@ -93,9 +93,9 @@ typedef std::vector< std::shared_ptr< MergeInfo > > MergeInfoVector;
 class XMLTableImportContext : public SvXMLImportContext
 {
 public:
-    XMLTableImportContext( const rtl::Reference< XMLTableImport >& xThis, sal_uInt16 nPrfx, const OUString& rLName, Reference< XColumnRowRange >& xColumnRowRange );
+    XMLTableImportContext( const rtl::Reference< XMLTableImport >& xThis, sal_uInt16 nPrfx, const OUString& rLName, Reference< XColumnRowRange > const & xColumnRowRange );
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
 
     virtual void StartElement( const Reference< XAttributeList >& xAttrList ) override;
 
@@ -103,9 +103,9 @@ public:
 
     void InitColumns();
 
-    SvXMLImportContext * ImportColumn( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList );
+    SvXMLImportContextRef ImportColumn( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList );
     SvXMLImportContext * ImportRow( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList );
-    SvXMLImportContext * ImportCell( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList );
+    SvXMLImportContextRef ImportCell( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList );
 
     OUString GetDefaultCellStyleName() const;
 
@@ -132,7 +132,7 @@ public:
                           sal_uInt16 nPrfx, const OUString& rLName,
                           const css::uno::Reference< css::xml::sax::XAttributeList >& xAttrList );
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
 
     virtual void EndElement() override;
 
@@ -153,7 +153,7 @@ class XMLTableTemplateContext : public SvXMLStyleContext
 public:
     XMLTableTemplateContext( SvXMLImport& rImport, sal_uInt16 nPrfx, const OUString& rLName, const Reference< XAttributeList >& xAttrList );
 
-    virtual SvXMLImportContext *CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
+    virtual SvXMLImportContextRef CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList ) override;
 
     virtual void StartElement( const Reference< XAttributeList >& xAttrList ) override;
 
@@ -173,7 +173,7 @@ XMLProxyContext::XMLProxyContext( SvXMLImport& rImport, const SvXMLImportContext
 {
 }
 
-SvXMLImportContext * XMLProxyContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
+SvXMLImportContextRef XMLProxyContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
 {
     if( mxParent.is() )
         return mxParent->CreateChildContext( nPrefix, rLocalName, xAttrList );
@@ -230,7 +230,7 @@ XMLTableImport::~XMLTableImport()
 {
 }
 
-SvXMLImportContext* XMLTableImport::CreateTableContext( sal_uInt16 nPrfx, const OUString& rLName, Reference< XColumnRowRange >& xColumnRowRange )
+SvXMLImportContext* XMLTableImport::CreateTableContext( sal_uInt16 nPrfx, const OUString& rLName, Reference< XColumnRowRange > const & xColumnRowRange )
 {
     rtl::Reference< XMLTableImport > xThis( this );
     return new XMLTableImportContext( xThis, nPrfx, rLName, xColumnRowRange );
@@ -270,10 +270,10 @@ void XMLTableImport::insertTabletemplate(const OUString& rsStyleName, bool bOver
 
         std::shared_ptr<XMLTableTemplate> xT(it->second);
 
-        for (auto aStyleIter=xT->begin(); aStyleIter != xT->end(); ++aStyleIter) try
+        for (const auto& rStyle : *xT) try
         {
-            const OUString sPropName((*aStyleIter).first);
-            const OUString sStyleName((*aStyleIter).second);
+            const OUString sPropName(rStyle.first);
+            const OUString sStyleName(rStyle.second);
             // Internally unassigned cell styles are stored by display name.
             // However table-template elements reference cell styles by its encoded name.
             // This loop is looking for cell style by their encoded names.
@@ -323,17 +323,17 @@ void XMLTableImport::finishStyles()
 
         Reference< XSingleServiceFactory > xFactory( xTableFamily, UNO_QUERY_THROW );
 
-        for( XMLTableTemplateMap::iterator aTemplateIter( maTableTemplates.begin() ); aTemplateIter != maTableTemplates.end(); ++aTemplateIter ) try
+        for( const auto& rTemplate : maTableTemplates ) try
         {
-            const OUString sTemplateName( (*aTemplateIter).first );
+            const OUString sTemplateName( rTemplate.first );
             Reference< XNameReplace > xTemplate( xFactory->createInstance(), UNO_QUERY_THROW );
 
-            std::shared_ptr< XMLTableTemplate > xT( (*aTemplateIter).second );
+            std::shared_ptr< XMLTableTemplate > xT( rTemplate.second );
 
-            for( XMLTableTemplate::iterator aStyleIter( xT->begin() ); aStyleIter != xT->end(); ++aStyleIter ) try
+            for( const auto& rStyle : *xT ) try
             {
-                const OUString sPropName( (*aStyleIter).first );
-                const OUString sStyleName( (*aStyleIter).second );
+                const OUString sPropName( rStyle.first );
+                const OUString sStyleName( rStyle.second );
                 xTemplate->replaceByName( sPropName, xCellFamily->getByName( sStyleName ) );
             }
             catch( Exception& )
@@ -363,7 +363,7 @@ void XMLTableImport::finishStyles()
 
 // class XMLTableImport
 
-XMLTableImportContext::XMLTableImportContext( const rtl::Reference< XMLTableImport >& xImporter, sal_uInt16 nPrfx, const OUString& rLName,  Reference< XColumnRowRange >& xColumnRowRange )
+XMLTableImportContext::XMLTableImportContext( const rtl::Reference< XMLTableImport >& xImporter, sal_uInt16 nPrfx, const OUString& rLName,  Reference< XColumnRowRange > const & xColumnRowRange )
 : SvXMLImportContext( xImporter->mrImport, nPrfx, rLName )
 , mxTable( xColumnRowRange, UNO_QUERY )
 , mxColumns( xColumnRowRange->getColumns() )
@@ -373,7 +373,7 @@ XMLTableImportContext::XMLTableImportContext( const rtl::Reference< XMLTableImpo
 {
 }
 
-SvXMLImportContext * XMLTableImportContext::ImportColumn( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
+SvXMLImportContextRef XMLTableImportContext::ImportColumn( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
 {
     if( mxColumns.is() && (mnCurrentRow == -1) ) try
     {
@@ -404,15 +404,10 @@ SvXMLImportContext * XMLTableImportContext::ImportColumn( sal_uInt16 nPrefix, co
                 {
                     xInfo->msDefaultCellStyleName = sValue;
                 }
-                else if( IsXMLToken( aLocalName, XML_VISIBILITY ) )
-                {
-                    xInfo->mbVisibility = IsXMLToken( sValue, XML_VISIBLE );
-                }
             }
             else if ( (XML_NAMESPACE_XML == nPrefix2) &&
                  IsXMLToken(aLocalName, XML_ID)   )
             {
-                (void) sValue;
 //FIXME: TODO
             }
         }
@@ -540,7 +535,7 @@ SvXMLImportContext * XMLTableImportContext::ImportRow( sal_uInt16 nPrefix, const
     return new XMLProxyContext( GetImport(), xThis, nPrefix, rLocalName );
 }
 
-SvXMLImportContext * XMLTableImportContext::ImportCell( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
+SvXMLImportContextRef XMLTableImportContext::ImportCell( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
 {
     mnCurrentColumn++;
     if( mxColumns.is() ) try
@@ -573,7 +568,7 @@ SvXMLImportContext * XMLTableImportContext::ImportCell( sal_uInt16 nPrefix, cons
     return SvXMLImportContext::CreateChildContext( nPrefix, rLocalName, xAttrList);
 }
 
-SvXMLImportContext *XMLTableImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
+SvXMLImportContextRef XMLTableImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
 {
     if( nPrefix == XML_NAMESPACE_TABLE )
     {
@@ -601,11 +596,8 @@ void XMLTableImportContext::EndElement()
 {
     if( !maMergeInfos.empty() )
     {
-        MergeInfoVector::iterator aIter( maMergeInfos.begin() );
-        while( aIter != maMergeInfos.end() )
+        for( const std::shared_ptr< MergeInfo >& xInfo : maMergeInfos )
         {
-            std::shared_ptr< MergeInfo > xInfo( (*aIter++) );
-
             if( xInfo.get() ) try
             {
                 Reference< XCellRange > xRange( mxTable->getCellRangeByPosition( xInfo->mnStartColumn, xInfo->mnStartRow, xInfo->mnEndColumn, xInfo->mnEndRow ) );
@@ -674,7 +666,6 @@ XMLCellImportContext::XMLCellImportContext( SvXMLImport& rImport, const Referenc
         else if ( (XML_NAMESPACE_XML == nPrefix2) &&
              IsXMLToken(aLocalName, XML_ID)   )
         {
-            (void) sValue;
 //FIXME: TODO
         }
 //FIXME: RDFa (table:table-cell)
@@ -703,7 +694,7 @@ XMLCellImportContext::XMLCellImportContext( SvXMLImport& rImport, const Referenc
     }
 }
 
-SvXMLImportContext * XMLCellImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
+SvXMLImportContextRef XMLCellImportContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
 {
     // create text cursor on demand
     if( !mxCursor.is() )
@@ -798,7 +789,7 @@ void XMLTableTemplateContext::CreateAndInsert(bool bOverwrite)
        xTableImport->insertTabletemplate(msTemplateStyleName, bOverwrite);
 }
 
-SvXMLImportContext * XMLTableTemplateContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
+SvXMLImportContextRef XMLTableTemplateContext::CreateChildContext( sal_uInt16 nPrefix, const OUString& rLocalName, const Reference< XAttributeList >& xAttrList )
 {
     if( nPrefix == XML_NAMESPACE_TABLE )
     {
