@@ -21,7 +21,6 @@
 
 #include <com/sun/star/lang/DisposedException.hpp>
 #include <osl/diagnose.h>
-#include <osl/time.h>
 #include <rtl/random.h>
 #include <rtl/ref.hxx>
 
@@ -203,10 +202,7 @@ uno::Sequence< ::sal_Int8 > SAL_CALL OCipherContext::finalizeCipherContextAndDis
 
         if ( nPaddingSize > 1 )
         {
-            TimeValue aTime;
-            osl_getSystemTime( &aTime );
             rtlRandomPool aRandomPool = rtl_random_createPool();
-            rtl_random_addBytes( aRandomPool, &aTime, 8 );
             rtl_random_getBytes( aRandomPool, m_aLastBlock.getArray() + nOldLastBlockLen, nPaddingSize - 1 );
             rtl_random_destroyPool ( aRandomPool );
         }
