@@ -30,24 +30,19 @@
 #include <libxml/uri.h>
 #include <xmlsec-wrapper.h>
 
-#define XMLSTREAMIO_INITIALIZED 0x01
-#define XMLSTREAMIO_REGISTERED  0x02
-
-/* Global variables */
-/*-
- * Enable stream I/O or not.
- */
-static char enableXmlStreamIO = 0x00 ;
+static bool g_bInputCallbacksEnabled = false;
+static bool g_bInputCallbacksRegistered = false;
 
 static css::uno::Reference< css::xml::crypto::XUriBinding > m_xUriBinding ;
 
-extern "C"
-int xmlStreamMatch( const char* uri )
+extern "C" {
+
+static int xmlStreamMatch( const char* uri )
 {
     css::uno::Reference< css::io::XInputStream > xInputStream ;
 
-    if( ( enableXmlStreamIO & XMLSTREAMIO_INITIALIZED ) &&
-        ( enableXmlStreamIO & XMLSTREAMIO_REGISTERED ) ) {
+    if (g_bInputCallbacksEnabled && g_bInputCallbacksRegistered)
+    {
         if( uri == nullptr || !m_xUriBinding.is() )
             return 0 ;
         //XMLSec first unescapes the uri and  calls this function. For example, we pass the Uri
@@ -73,13 +68,12 @@ int xmlStreamMatch( const char* uri )
         return 0 ;
 }
 
-extern "C"
-void* xmlStreamOpen( const char* uri )
+static void* xmlStreamOpen( const char* uri )
 {
     css::uno::Reference< css::io::XInputStream > xInputStream ;
 
-    if( ( enableXmlStreamIO & XMLSTREAMIO_INITIALIZED ) &&
-        ( enableXmlStreamIO & XMLSTREAMIO_REGISTERED ) ) {
+    if (g_bInputCallbacksEnabled && g_bInputCallbacksRegistered)
+    {
         if( uri == nullptr || !m_xUriBinding.is() )
             return nullptr ;
 
@@ -107,16 +101,15 @@ void* xmlStreamOpen( const char* uri )
     return nullptr ;
 }
 
-extern "C"
-int xmlStreamRead( void* context, char* buffer, int len )
+static int xmlStreamRead( void* context, char* buffer, int len )
 {
     int numbers ;
     css::uno::Reference< css::io::XInputStream > xInputStream ;
     css::uno::Sequence< sal_Int8 > outSeqs( len ) ;
 
     numbers = 0 ;
-    if( ( enableXmlStreamIO & XMLSTREAMIO_INITIALIZED ) &&
-        ( enableXmlStreamIO & XMLSTREAMIO_REGISTERED ) ) {
+    if (g_bInputCallbacksEnabled && g_bInputCallbacksRegistered)
+    {
         if( context != nullptr ) {
             xInputStream = static_cast<css::io::XInputStream*>(context);
             if( !xInputStream.is() )
@@ -132,11 +125,10 @@ int xmlStreamRead( void* context, char* buffer, int len )
     return numbers ;
 }
 
-extern "C"
-int xmlStreamClose( void * context )
+static int xmlStreamClose( void * context )
 {
-    if( ( enableXmlStreamIO & XMLSTREAMIO_INITIALIZED ) &&
-        ( enableXmlStreamIO & XMLSTREAMIO_REGISTERED ) ) {
+    if (g_bInputCallbacksEnabled && g_bInputCallbacksRegistered)
+    {
         if( context != nullptr ) {
             css::io::XInputStream* pInputStream ;
             pInputStream = static_cast<css::io::XInputStream*>(context);
@@ -147,10 +139,12 @@ int xmlStreamClose( void * context )
     return 0 ;
 }
 
+}
+
 XSECXMLSEC_DLLPUBLIC int xmlEnableStreamInputCallbacks()
 {
-
-    if( !( enableXmlStreamIO & XMLSTREAMIO_INITIALIZED ) ) {
+    if (!g_bInputCallbacksEnabled)
+    {
         //Register the callbacks into xmlSec
         //In order to make the xmlsec io finding the callbacks firstly,
         //I put the callbacks at the very beginning.
@@ -203,7 +197,7 @@ XSECXMLSEC_DLLPUBLIC int xmlEnableStreamInputCallbacks()
             }
         }
 
-        enableXmlStreamIO |= XMLSTREAMIO_INITIALIZED ;
+        g_bInputCallbacksEnabled = true;
     }
 
     return 0 ;
@@ -212,14 +206,14 @@ XSECXMLSEC_DLLPUBLIC int xmlEnableStreamInputCallbacks()
 XSECXMLSEC_DLLPUBLIC int xmlRegisterStreamInputCallbacks(
     css::uno::Reference< css::xml::crypto::XUriBinding > const & aUriBinding
 ) {
-    if( !( enableXmlStreamIO & XMLSTREAMIO_INITIALIZED ) ) {
+    if (!g_bInputCallbacksEnabled)
+    {
         if( xmlEnableStreamInputCallbacks() < 0 )
             return -1 ;
     }
 
-    if( !( enableXmlStreamIO & XMLSTREAMIO_REGISTERED ) ) {
-        enableXmlStreamIO |= XMLSTREAMIO_REGISTERED ;
-    }
+    if (!g_bInputCallbacksRegistered)
+        g_bInputCallbacksRegistered = true;
 
     m_xUriBinding = aUriBinding ;
 
@@ -228,12 +222,13 @@ XSECXMLSEC_DLLPUBLIC int xmlRegisterStreamInputCallbacks(
 
 XSECXMLSEC_DLLPUBLIC int xmlUnregisterStreamInputCallbacks()
 {
-    if( enableXmlStreamIO & XMLSTREAMIO_REGISTERED ) {
+    if (g_bInputCallbacksRegistered)
+    {
         //Clear the uri-stream binding
         m_xUriBinding.clear() ;
 
         //disable the registered flag
-        enableXmlStreamIO &= ~XMLSTREAMIO_REGISTERED ;
+        g_bInputCallbacksRegistered = false;
     }
 
     return 0 ;
@@ -241,7 +236,7 @@ XSECXMLSEC_DLLPUBLIC int xmlUnregisterStreamInputCallbacks()
 
 XSECXMLSEC_DLLPUBLIC void xmlDisableStreamInputCallbacks() {
     xmlUnregisterStreamInputCallbacks() ;
-    enableXmlStreamIO &= ~XMLSTREAMIO_INITIALIZED ;
+    g_bInputCallbacksEnabled = false;
 }
 
 /* vim:set shiftwidth=4 softtabstop=4 expandtab: */
